diff --git a/RELEASE_NOTES.txt b/RELEASE_NOTES.txt
index 6370e24..0af24a0 100644
--- a/RELEASE_NOTES.txt
+++ b/RELEASE_NOTES.txt
@@ -1,3 +1,13 @@
+==== 1.9.4.2 ====
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+] NOTE: Current Release Notes are maintained at:                                                                              [
+]                                                                                                                             [
+] http://devdocs.magento.com/guides/m1x/ce19-ee114/ce1.9_release-notes.html                                                   [
+]                                                                                                                             [
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 ==== 1.9.4.1 ====
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
diff --git a/app/Mage.php b/app/Mage.php
index 89b63ed..e2ae8a2 100644
--- a/app/Mage.php
+++ b/app/Mage.php
@@ -174,7 +174,7 @@ final class Mage
             'major'     => '1',
             'minor'     => '9',
             'revision'  => '4',
-            'patch'     => '1',
+            'patch'     => '2',
             'stability' => '',
             'number'    => '',
         );
@@ -816,9 +816,9 @@ final class Mage
             ',',
             (string) self::getConfig()->getNode('dev/log/allowedFileExtensions', Mage_Core_Model_Store::DEFAULT_CODE)
         );
-        $logValidator = new Zend_Validate_File_Extension($_allowedFileExtensions);
         $logDir = self::getBaseDir('var') . DS . 'log';
-        if (!$logValidator->isValid($logDir . DS . $file)) {
+        $validatedFileExtension = pathinfo($file, PATHINFO_EXTENSION);
+        if (!$validatedFileExtension || !in_array($validatedFileExtension, $_allowedFileExtensions)) {
             return;
         }
 
diff --git a/app/code/core/Mage/Admin/Model/Block.php b/app/code/core/Mage/Admin/Model/Block.php
index ba329cb..c2ad8ed 100644
--- a/app/code/core/Mage/Admin/Model/Block.php
+++ b/app/code/core/Mage/Admin/Model/Block.php
@@ -57,7 +57,7 @@ class Mage_Admin_Model_Block extends Mage_Core_Model_Abstract
         if (in_array($this->getBlockName(), $disallowedBlockNames)) {
             $errors[] = Mage::helper('adminhtml')->__('Block Name is disallowed.');
         }
-        if (!Zend_Validate::is($this->getBlockName(), 'Regex', array('/^[-_a-zA-Z0-9\/]*$/'))) {
+        if (!Zend_Validate::is($this->getBlockName(), 'Regex', array('/^[-_a-zA-Z0-9]+\/[-_a-zA-Z0-9\/]+$/'))) {
             $errors[] = Mage::helper('adminhtml')->__('Block Name is incorrect.');
         }
 
diff --git a/app/code/core/Mage/Admin/Model/User.php b/app/code/core/Mage/Admin/Model/User.php
index eac448a..c651195 100644
--- a/app/code/core/Mage/Admin/Model/User.php
+++ b/app/code/core/Mage/Admin/Model/User.php
@@ -590,7 +590,7 @@ class Mage_Admin_Model_User extends Mage_Core_Model_Abstract
         }
 
         if ($this->userExists()) {
-            $errors[] = Mage::helper('adminhtml')->__('A user with the same user name or email aleady exists.');
+            $errors[] = Mage::helper('adminhtml')->__('A user with the same user name or email already exists.');
         }
 
         if (count($errors) === 0) {
diff --git a/app/code/core/Mage/AdminNotification/etc/system.xml b/app/code/core/Mage/AdminNotification/etc/system.xml
index cd9e2b6..9e763d0 100644
--- a/app/code/core/Mage/AdminNotification/etc/system.xml
+++ b/app/code/core/Mage/AdminNotification/etc/system.xml
@@ -64,6 +64,15 @@
                             <show_in_website>0</show_in_website>
                             <show_in_store>0</show_in_store>
                         </last_update>
+                        <feed_url>
+                            <label>Feed Url</label>
+                            <frontend_type>text</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_protected</backend_model>
+                            <sort_order>3</sort_order>
+                            <show_in_default>0</show_in_default>
+                            <show_in_website>0</show_in_website>
+                            <show_in_store>0</show_in_store>
+                        </feed_url>
                     </fields>
                 </adminnotification>
             </groups>
diff --git a/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php b/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
index 7fa0f72..8c2fd65 100644
--- a/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Api/Role/Grid/User.php
@@ -157,7 +157,7 @@ class Mage_Adminhtml_Block_Api_Role_Grid_User extends Mage_Adminhtml_Block_Widge
     protected function _getUsers($json=false)
     {
         if ( $this->getRequest()->getParam('in_role_user') != "" ) {
-            return $this->getRequest()->getParam('in_role_user');
+            return (int)$this->getRequest()->getParam('in_role_user');
         }
         $roleId = ( $this->getRequest()->getParam('rid') > 0 ) ? $this->getRequest()->getParam('rid') : Mage::registry('RID');
         $users  = Mage::getModel('api/roles')->setId($roleId)->getRoleUsers();
diff --git a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
index e1c2df9..1c9b3f1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
+++ b/app/code/core/Mage/Adminhtml/Block/Catalog/Product/Edit/Tab/Super/Config.php
@@ -155,6 +155,8 @@ class Mage_Adminhtml_Block_Catalog_Product_Edit_Tab_Super_Config extends Mage_Ad
             // Hide price if needed
             foreach ($attributes as &$attribute) {
                 $attribute['label'] = $this->escapeHtml($attribute['label']);
+                $attribute['frontend_label'] = $this->escapeHtml($attribute['frontend_label']);
+                $attribute['store_label'] = $this->escapeHtml($attribute['store_label']);
                 if (isset($attribute['values']) && is_array($attribute['values'])) {
                     foreach ($attribute['values'] as &$attributeValue) {
                         if (!$this->getCanReadPrice()) {
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
index ea78d54..ff437b3 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Queue/Preview.php
@@ -50,6 +50,12 @@ class Mage_Adminhtml_Block_Newsletter_Queue_Preview extends Mage_Adminhtml_Block
             $template->setTemplateText($this->getRequest()->getParam('text'));
             $template->setTemplateStyles($this->getRequest()->getParam('styles'));
         }
+        $template->setTemplateStyles(
+            $this->maliciousCodeFilter($template->getTemplateStyles())
+        );
+        $template->setTemplateText(
+            $this->maliciousCodeFilter($template->getTemplateText())
+        );
 
         $storeId = (int)$this->getRequest()->getParam('store_id');
         if(!$storeId) {
diff --git a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
index 2eeda67..fb58061 100644
--- a/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/Newsletter/Template/Preview.php
@@ -46,6 +46,12 @@ class Mage_Adminhtml_Block_Newsletter_Template_Preview extends Mage_Adminhtml_Bl
             $template->setTemplateText($this->getRequest()->getParam('text'));
             $template->setTemplateStyles($this->getRequest()->getParam('styles'));
         }
+        $template->setTemplateStyles(
+            $this->maliciousCodeFilter($template->getTemplateStyles())
+        );
+        $template->setTemplateText(
+            $this->maliciousCodeFilter($template->getTemplateText())
+        );
 
         $storeId = (int)$this->getRequest()->getParam('store_id');
         if(!$storeId) {
diff --git a/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php b/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
index 159773d..3b0a668 100644
--- a/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
+++ b/app/code/core/Mage/Adminhtml/Block/Permissions/Role/Grid/User.php
@@ -157,7 +157,7 @@ class Mage_Adminhtml_Block_Permissions_Role_Grid_User extends Mage_Adminhtml_Blo
     protected function _getUsers($json=false)
     {
         if ( $this->getRequest()->getParam('in_role_user') != "" ) {
-            return $this->getRequest()->getParam('in_role_user');
+            return (int)$this->getRequest()->getParam('in_role_user');
         }
         $roleId = ( $this->getRequest()->getParam('rid') > 0 ) ? $this->getRequest()->getParam('rid') : Mage::registry('RID');
         $users  = Mage::getModel('admin/roles')->setId($roleId)->getRoleUsers();
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
index d81c515..4c0001f 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Creditmemo/Grid.php
@@ -76,6 +76,7 @@ class Mage_Adminhtml_Block_Sales_Creditmemo_Grid extends Mage_Adminhtml_Block_Wi
             'header'    => Mage::helper('sales')->__('Order #'),
             'index'     => 'order_increment_id',
             'type'      => 'text',
+            'escape'    => true,
         ));
 
         $this->addColumn('order_created_at', array(
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
index c8a6598..59c38a1 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Invoice/Grid.php
@@ -77,6 +77,7 @@ class Mage_Adminhtml_Block_Sales_Invoice_Grid extends Mage_Adminhtml_Block_Widge
             'header'    => Mage::helper('sales')->__('Order #'),
             'index'     => 'order_increment_id',
             'type'      => 'text',
+            'escape'    => true,
         ));
 
         $this->addColumn('order_created_at', array(
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
index 9b18cba..169c8d6 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Create/Header.php
@@ -34,7 +34,10 @@ class Mage_Adminhtml_Block_Sales_Order_Create_Header extends Mage_Adminhtml_Bloc
     protected function _toHtml()
     {
         if ($this->_getSession()->getOrder()->getId()) {
-            return '<h3 class="icon-head head-sales-order">'.Mage::helper('sales')->__('Edit Order #%s', $this->_getSession()->getOrder()->getIncrementId()).'</h3>';
+            return '<h3 class="icon-head head-sales-order">' . Mage::helper('sales')->__(
+                'Edit Order #%s',
+                $this->escapeHtml($this->_getSession()->getOrder()->getIncrementId())
+            ) . '</h3>';
         }
 
         $customerId = $this->getCustomerId();
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
index e1e1c5b..a742055 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Creditmemo/Create.php
@@ -67,10 +67,15 @@ class Mage_Adminhtml_Block_Sales_Order_Creditmemo_Create extends Mage_Adminhtml_
     public function getHeaderText()
     {
         if ($this->getCreditmemo()->getInvoice()) {
-            $header = Mage::helper('sales')->__('New Credit Memo for Invoice #%s', $this->getCreditmemo()->getInvoice()->getIncrementId());
-        }
-        else {
-            $header = Mage::helper('sales')->__('New Credit Memo for Order #%s', $this->getCreditmemo()->getOrder()->getRealOrderId());
+            $header = Mage::helper('sales')->__(
+                'New Credit Memo for Invoice #%s',
+                $this->escapeHtml($this->getCreditmemo()->getInvoice()->getIncrementId())
+            );
+        } else {
+            $header = Mage::helper('sales')->__(
+                'New Credit Memo for Order #%s',
+                $this->escapeHtml($this->getCreditmemo()->getOrder()->getRealOrderId())
+            );
         }
 
         return $header;
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
index 43ba9cd..9787747 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Grid.php
@@ -65,10 +65,11 @@ class Mage_Adminhtml_Block_Sales_Order_Grid extends Mage_Adminhtml_Block_Widget_
     {
 
         $this->addColumn('real_order_id', array(
-            'header'=> Mage::helper('sales')->__('Order #'),
-            'width' => '80px',
-            'type'  => 'text',
-            'index' => 'increment_id',
+            'header' => Mage::helper('sales')->__('Order #'),
+            'width'  => '80px',
+            'type'   => 'text',
+            'index'  => 'increment_id',
+            'escape' => true,
         ));
 
         if (!Mage::app()->isSingleStoreMode()) {
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
index b3a152d..3528beb 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Invoice/Create.php
@@ -64,8 +64,14 @@ class Mage_Adminhtml_Block_Sales_Order_Invoice_Create extends Mage_Adminhtml_Blo
     public function getHeaderText()
     {
         return ($this->getInvoice()->getOrder()->getForcedDoShipmentWithInvoice())
-            ? Mage::helper('sales')->__('New Invoice and Shipment for Order #%s', $this->getInvoice()->getOrder()->getRealOrderId())
-            : Mage::helper('sales')->__('New Invoice for Order #%s', $this->getInvoice()->getOrder()->getRealOrderId());
+            ? Mage::helper('sales')->__(
+                'New Invoice and Shipment for Order #%s',
+                $this->escapeHtml($this->getInvoice()->getOrder()->getRealOrderId())
+            )
+            : Mage::helper('sales')->__(
+                'New Invoice for Order #%s',
+                $this->escapeHtml($this->getInvoice()->getOrder()->getRealOrderId())
+            );
     }
 
     /**
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
index e39ee02..21e581a 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/Shipment/Create.php
@@ -59,7 +59,10 @@ class Mage_Adminhtml_Block_Sales_Order_Shipment_Create extends Mage_Adminhtml_Bl
 
     public function getHeaderText()
     {
-        $header = Mage::helper('sales')->__('New Shipment for Order #%s', $this->getShipment()->getOrder()->getRealOrderId());
+        $header = Mage::helper('sales')->__(
+            'New Shipment for Order #%s',
+            $this->escapeHtml($this->getShipment()->getOrder()->getRealOrderId())
+        );
         return $header;
     }
 
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
index 0af75c7..ea97b98 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Order/View.php
@@ -315,6 +315,16 @@ class Mage_Adminhtml_Block_Sales_Order_View extends Mage_Adminhtml_Block_Widget_
     {
         return $this->getUrl('*/*/reviewPayment', array('action' => $action));
     }
+
+    /**
+     * Return header for view grid
+     *
+     * @return string
+     */
+    public function getHeaderHtml()
+    {
+        return '<h3 class="' . $this->getHeaderCssClass() . '">' . $this->escapeHtml($this->getHeaderText()) . '</h3>';
+    }
 //
 //    /**
 //     * Return URL for accept payment action
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
index 0676cb1..10324e5 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Shipment/Grid.php
@@ -88,6 +88,7 @@ class Mage_Adminhtml_Block_Sales_Shipment_Grid extends Mage_Adminhtml_Block_Widg
             'header'    => Mage::helper('sales')->__('Order #'),
             'index'     => 'order_increment_id',
             'type'      => 'text',
+            'escape'    => true,
         ));
 
         $this->addColumn('order_created_at', array(
diff --git a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
index cc107f6..5559512 100644
--- a/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
+++ b/app/code/core/Mage/Adminhtml/Block/Sales/Transactions/Grid.php
@@ -82,7 +82,8 @@ class Mage_Adminhtml_Block_Sales_Transactions_Grid extends Mage_Adminhtml_Block_
         $this->addColumn('increment_id', array(
             'header'    => Mage::helper('sales')->__('Order ID'),
             'index'     => 'increment_id',
-            'type'      => 'text'
+            'type'      => 'text',
+            'escape'    => true,
         ));
 
         $this->addColumn('txn_id', array(
diff --git a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
index 4b02ec0..03b732b 100644
--- a/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
+++ b/app/code/core/Mage/Adminhtml/Block/System/Email/Template/Preview.php
@@ -58,11 +58,12 @@ class Mage_Adminhtml_Block_System_Email_Template_Preview extends Mage_Adminhtml_
             $template->setTemplateStyles($this->getRequest()->getParam('styles'));
         }
 
-        /* @var $filter Mage_Core_Model_Input_Filter_MaliciousCode */
-        $filter = Mage::getSingleton('core/input_filter_maliciousCode');
+        $template->setTemplateStyles(
+            $this->maliciousCodeFilter($template->getTemplateStyles())
+        );
 
         $template->setTemplateText(
-            $filter->filter($template->getTemplateText())
+            $this->maliciousCodeFilter($template->getTemplateText())
         );
 
         Varien_Profiler::start("email_template_proccessing");
diff --git a/app/code/core/Mage/Adminhtml/Block/Template.php b/app/code/core/Mage/Adminhtml/Block/Template.php
index 08201f1..5629a4b 100644
--- a/app/code/core/Mage/Adminhtml/Block/Template.php
+++ b/app/code/core/Mage/Adminhtml/Block/Template.php
@@ -80,4 +80,15 @@ class Mage_Adminhtml_Block_Template extends Mage_Core_Block_Template
         Mage::dispatchEvent('adminhtml_block_html_before', array('block' => $this));
         return parent::_toHtml();
     }
+
+    /**
+     * Deleting script tags from string
+     *
+     * @param string $html
+     * @return string
+     */
+    public function maliciousCodeFilter($html)
+    {
+        return Mage::getSingleton('core/input_filter_maliciousCode')->filter($html);
+    }
 }
diff --git a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
index e884e05..05ce8fd 100644
--- a/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
+++ b/app/code/core/Mage/Adminhtml/Block/Widget/Grid/Column/Renderer/Abstract.php
@@ -114,9 +114,9 @@ abstract class Mage_Adminhtml_Block_Widget_Grid_Column_Renderer_Abstract
             }
             $out = '<a href="#" name="' . $this->getColumn()->getId() . '" title="' . $nDir
                    . '" class="' . $className . '"><span class="sort-title">'
-                   . $this->getColumn()->getHeader().'</span></a>';
+                   . $this->escapeHtml($this->getColumn()->getHeader()) . '</span></a>';
         } else {
-            $out = $this->getColumn()->getHeader();
+            $out = $this->escapeHtml($this->getColumn()->getHeader());
         }
         return $out;
     }
diff --git a/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php b/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
index 513fc9c..2a160e9 100644
--- a/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
+++ b/app/code/core/Mage/Adminhtml/Model/LayoutUpdate/Validator.php
@@ -180,8 +180,11 @@ class Mage_Adminhtml_Model_LayoutUpdate_Validator extends Zend_Validate_Abstract
     protected function _getXpathBlockValidationExpression() {
         $xpath = "";
         if (count($this->_disallowedBlock)) {
-            $xpath = "//block[@type='";
-            $xpath .= implode("'] | //block[@type='", $this->_disallowedBlock) . "']";
+            foreach ($this->_disallowedBlock as $key => $value) {
+                $xpath .= $key > 0 ? " | " : '';
+                $xpath .= "//block[translate(@type, 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz') = ";
+                $xpath .= "translate('$value', 'ABCDEFGHIJKLMNOPQRSTUVWXYZ', 'abcdefghijklmnopqrstuvwxyz')]";
+            }
         }
         return $xpath;
     }
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
index 55537c2..7247bf9 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Baseurl.php
@@ -36,6 +36,8 @@ class Mage_Adminhtml_Model_System_Config_Backend_Baseurl extends Mage_Core_Model
             $parsedUrl = parse_url($value);
             if (!isset($parsedUrl['scheme']) || !isset($parsedUrl['host'])) {
                 Mage::throwException(Mage::helper('core')->__('The %s you entered is invalid. Please make sure that it follows "http://domain.com/" format.', $this->getFieldConfig()->label));
+            } elseif (('https' != $parsedUrl['scheme']) && ('http' != $parsedUrl['scheme'])) {
+                Mage::throwException(Mage::helper('core')->__('Invalid URL scheme.'));
             }
         }
 
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
index 9ec0be2..04dcfd8 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Locale.php
@@ -34,6 +34,27 @@
  */
 class Mage_Adminhtml_Model_System_Config_Backend_Locale extends Mage_Core_Model_Config_Data
 {
+    /**
+     * Validate data before save data
+     *
+     * @return Mage_Core_Model_Abstract
+     * @throws Mage_Core_Exception
+     */
+    protected function _beforeSave()
+    {
+        $allCurrenciesOptions = Mage::getSingleton('adminhtml/system_config_source_locale_currency_all')
+            ->toOptionArray(true);
+
+        $allCurrenciesValues = array_column($allCurrenciesOptions, 'value');
+
+        foreach ($this->getValue() as $currency) {
+            if (!in_array($currency, $allCurrenciesValues)) {
+                Mage::throwException(Mage::helper('adminhtml')->__('Currency doesn\'t exist.'));
+            }
+        }
+
+        return parent::_beforeSave();
+    }
 
     /**
      * Enter description here...
diff --git a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
index fef80ea..a4529e4 100644
--- a/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
+++ b/app/code/core/Mage/Adminhtml/Model/System/Config/Backend/Serialized/Array.php
@@ -31,11 +31,19 @@
 class Mage_Adminhtml_Model_System_Config_Backend_Serialized_Array extends Mage_Adminhtml_Model_System_Config_Backend_Serialized
 {
     /**
-     * Unset array element with '__empty' key
+     * Check object existence in incoming data and unset array element with '__empty' key
      *
+     * @throws Mage_Core_Exception
+     * @return void
      */
     protected function _beforeSave()
     {
+        try {
+            Mage::helper('core/unserializeArray')->unserialize(serialize($this->getValue()));
+        } catch (Exception $e) {
+            Mage::throwException(Mage::helper('adminhtml')->__('Serialized data is incorrect'));
+        }
+
         $value = $this->getValue();
         if (is_array($value)) {
             unset($value['__empty']);
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
index 43cf415..c390a87 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/AttributeController.php
@@ -172,6 +172,7 @@ class Mage_Adminhtml_Catalog_Product_AttributeController extends Mage_Adminhtml_
             /** @var $helperCatalog Mage_Catalog_Helper_Data */
             $helperCatalog = Mage::helper('catalog');
             //labels
+            $data['frontend_label'] = (array) $data['frontend_label'];
             foreach ($data['frontend_label'] as & $value) {
                 if ($value) {
                     $value = $helperCatalog->stripTags($value);
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
index 4e5a97a..1976d3a 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/Product/ReviewController.php
@@ -41,6 +41,17 @@ class Mage_Adminhtml_Catalog_Product_ReviewController extends Mage_Adminhtml_Con
      */
     protected $_publicActions = array('edit');
 
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions(array('delete', 'massDelete'));
+        return parent::preDispatch();
+    }
+
     public function indexAction()
     {
         $this->_title($this->__('Catalog'))
diff --git a/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php b/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
index a38dd91..264f7f3 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Catalog/ProductController.php
@@ -550,7 +550,7 @@ class Mage_Adminhtml_Catalog_ProductController extends Mage_Adminhtml_Controller
         catch (Mage_Eav_Model_Entity_Attribute_Exception $e) {
             $response->setError(true);
             $response->setAttribute($e->getAttributeCode());
-            $response->setMessage($e->getMessage());
+            $response->setMessage(Mage::helper('core')->escapeHtml($e->getMessage()));
         } catch (Mage_Core_Exception $e) {
             $response->setError(true);
             $response->setMessage($e->getMessage());
diff --git a/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php b/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
index 98afaa2..8eaa164 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Checkout/AgreementController.php
@@ -33,6 +33,17 @@
  */
 class Mage_Adminhtml_Checkout_AgreementController extends Mage_Adminhtml_Controller_Action
 {
+    /**
+     * Controller predispatch method
+     *
+     * @return Mage_Adminhtml_Controller_Action
+     */
+    public function preDispatch()
+    {
+        $this->_setForcedFormKeyActions('delete');
+        return parent::preDispatch();
+    }
+
     public function indexAction()
     {
         $this->_title($this->__('Sales'))->_title($this->__('Terms and Conditions'));
diff --git a/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php b/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
index ed546c5..c28df8c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Newsletter/TemplateController.php
@@ -167,6 +167,11 @@ class Mage_Adminhtml_Newsletter_TemplateController extends Mage_Adminhtml_Contro
         }
 
         try {
+            $allowedHtmlTags = ['text', 'styles'];
+            if (Mage::helper('adminhtml')->hasTags($request->getParams(), $allowedHtmlTags)) {
+                Mage::throwException(Mage::helper('adminhtml')->__('Invalid template data.'));
+            }
+
             $template->addData($request->getParams())
                 ->setTemplateSubject($request->getParam('subject'))
                 ->setTemplateCode($request->getParam('code'))
diff --git a/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php b/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
index 9962530..1156592 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Promo/CatalogController.php
@@ -133,6 +133,9 @@ class Mage_Adminhtml_Promo_CatalogController extends Mage_Adminhtml_Controller_A
                     array('request' => $this->getRequest())
                 );
                 $data = $this->getRequest()->getPost();
+                if (Mage::helper('adminhtml')->hasTags($data['rule'], array('attribute'), false)) {
+                    Mage::throwException(Mage::helper('catalogrule')->__('Wrong rule specified'));
+                }
                 $data = $this->_filterDates($data, array('from_date', 'to_date'));
                 if ($id = $this->getRequest()->getParam('rule_id')) {
                     $model->load($id);
diff --git a/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php b/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
index e9b61cb..28c77cb 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Promo/QuoteController.php
@@ -133,6 +133,9 @@ class Mage_Adminhtml_Promo_QuoteController extends Mage_Adminhtml_Controller_Act
                     'adminhtml_controller_salesrule_prepare_save',
                     array('request' => $this->getRequest()));
                 $data = $this->getRequest()->getPost();
+                if (Mage::helper('adminhtml')->hasTags($data['rule'], array('attribute'), false)) {
+                    Mage::throwException(Mage::helper('catalogrule')->__('Wrong rule specified'));
+                }
                 $data = $this->_filterDates($data, array('from_date', 'to_date'));
                 $id = $this->getRequest()->getParam('rule_id');
                 if ($id) {
diff --git a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
index 5ac3079..c8ee9a9 100644
--- a/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/Sales/Order/CreateController.php
@@ -151,6 +151,13 @@ class Mage_Adminhtml_Sales_Order_CreateController extends Mage_Adminhtml_Control
          * Saving order data
          */
         if ($data = $this->getRequest()->getPost('order')) {
+            if (
+                array_key_exists('comment', $data)
+                && array_key_exists('reserved_order_id', $data['comment'])
+            ) {
+                unset($data['comment']['reserved_order_id']);
+            }
+
             $this->_getOrderCreateModel()->importPostData($data);
         }
 
@@ -477,10 +484,20 @@ class Mage_Adminhtml_Sales_Order_CreateController extends Mage_Adminhtml_Control
 
     /**
      * Saving quote and create order
+     *
+     * @throws Mage_Core_Exception
      */
     public function saveAction()
     {
         try {
+            $orderData = $this->getRequest()->getPost('order');
+            if (
+                array_key_exists('reserved_order_id', $orderData['comment'])
+                && Mage::helper('adminhtml/sales')->hasTags($orderData['comment']['reserved_order_id'])
+            ) {
+                Mage::throwException($this->__('Invalid order data.'));
+            }
+
             $this->_processActionData('save');
             $paymentData = $this->getRequest()->getPost('payment');
             if ($paymentData) {
diff --git a/app/code/core/Mage/Adminhtml/controllers/SitemapController.php b/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
index 9aba874..ec41ff1 100644
--- a/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/SitemapController.php
@@ -34,6 +34,11 @@
 class Mage_Adminhtml_SitemapController extends  Mage_Adminhtml_Controller_Action
 {
     /**
+     * Maximum sitemap name length
+     */
+    const MAXIMUM_SITEMAP_NAME_LENGTH = 32;
+
+    /**
      * Controller predispatch method
      *
      * @return Mage_Adminhtml_Controller_Action
@@ -141,6 +146,19 @@ class Mage_Adminhtml_SitemapController extends  Mage_Adminhtml_Controller_Action
             if (!empty($data['sitemap_filename']) && !empty($data['sitemap_path'])) {
                 $path = rtrim($data['sitemap_path'], '\\/')
                       . DS . $data['sitemap_filename'];
+
+                // check filename length
+                if (strlen($data['sitemap_filename']) > self::MAXIMUM_SITEMAP_NAME_LENGTH) {
+                    Mage::getSingleton('adminhtml/session')->addError(
+                        Mage::helper('sitemap')->__(
+                            'Please enter a sitemap name with at most %s characters.',
+                            self::MAXIMUM_SITEMAP_NAME_LENGTH
+                        ));
+                    $this->_redirect('*/*/edit', array(
+                        'sitemap_id' => $this->getRequest()->getParam('sitemap_id')
+                    ));
+                    return;
+                }
                 /** @var $validator Mage_Core_Model_File_Validator_AvailablePath */
                 $validator = Mage::getModel('core/file_validator_availablePath');
                 /** @var $helper Mage_Adminhtml_Helper_Catalog */
diff --git a/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php b/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
index 2bd9f96..4e3de6c 100644
--- a/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
+++ b/app/code/core/Mage/Adminhtml/controllers/System/Email/TemplateController.php
@@ -111,6 +111,8 @@ class Mage_Adminhtml_System_Email_TemplateController extends Mage_Adminhtml_Cont
 
     /**
      * Save action
+     *
+     * @throws Mage_Core_Exception
      */
     public function saveAction()
     {
@@ -127,6 +129,11 @@ class Mage_Adminhtml_System_Email_TemplateController extends Mage_Adminhtml_Cont
         }
 
         try {
+            $allowedHtmlTags = ['template_text', 'styles'];
+            if (Mage::helper('adminhtml')->hasTags($request->getParams(), $allowedHtmlTags)) {
+                Mage::throwException(Mage::helper('adminhtml')->__('Invalid template data.'));
+            }
+
             $template->setTemplateSubject($request->getParam('template_subject'))
                 ->setTemplateCode($request->getParam('template_code'))
                 ->setTemplateText($request->getParam('template_text'))
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost.php b/app/code/core/Mage/Authorizenet/Model/Directpost.php
index 5db0add..196f6d1 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost.php
@@ -389,9 +389,11 @@ class Mage_Authorizenet_Model_Directpost extends Mage_Paygate_Model_Authorizenet
     public function validateResponse()
     {
         $response = $this->getResponse();
-        //md5 check
-        if (!$this->getConfigData('trans_md5') || !$this->getConfigData('login') ||
-            !$response->isValidHash($this->getConfigData('trans_md5'), $this->getConfigData('login'))
+        $hashConfigKey = !empty($response->getData('x_SHA2_Hash')) ? 'signature_key' : 'trans_md5';
+
+        //hash check
+        if (!$this->getConfigData($hashConfigKey)
+            || !$response->isValidHash($this->getConfigData($hashConfigKey), $this->getConfigData('login'))
         ) {
             Mage::throwException(
                 Mage::helper('authorizenet')->__('Response hash validation failed. Transaction declined.')
@@ -499,7 +501,7 @@ class Mage_Authorizenet_Model_Directpost extends Mage_Paygate_Model_Authorizenet
      */
     public function checkTransId()
     {
-        if (!$this->getResponse()->getXTransId()) {
+        if (!$this->getResponse()->getXTransId() && ('0' !== $this->getResponse()->getXTransId())) {
             Mage::throwException(
                 Mage::helper('authorizenet')->__('Payment authorization error. Transacion id is empty.')
             );
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
index a8f85f9..09d5831 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Request.php
@@ -36,8 +36,15 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
     protected $_transKey = null;
 
     /**
+     * Hexadecimal signature key.
+     *
+     * @var string
+     */
+    protected $_signatureKey = '';
+
+    /**
      * Return merchant transaction key.
-     * Needed to generate sign.
+     * Needed to generate MD5 sign.
      *
      * @return string
      */
@@ -48,7 +55,7 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
 
     /**
      * Set merchant transaction key.
-     * Needed to generate sign.
+     * Needed to generate MD5 sign.
      *
      * @param string $transKey
      * @return Mage_Authorizenet_Model_Directpost_Request
@@ -60,7 +67,7 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
     }
 
     /**
-     * Generates the fingerprint for request.
+     * Generates the MD5 fingerprint for request.
      *
      * @param string $merchantApiLoginId
      * @param string $merchantTransactionKey
@@ -73,19 +80,19 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
     {
         if (phpversion() >= '5.1.2') {
             return hash_hmac("md5",
-                $merchantApiLoginId . "^" .
-                $fpSequence . "^" .
-                $fpTimestamp . "^" .
-                $amount . "^" .
+                $merchantApiLoginId . '^' .
+                $fpSequence . '^' .
+                $fpTimestamp . '^' .
+                $amount . '^' .
                 $currencyCode, $merchantTransactionKey
             );
         }
 
         return bin2hex(mhash(MHASH_MD5,
-            $merchantApiLoginId . "^" .
-            $fpSequence . "^" .
-            $fpTimestamp . "^" .
-            $amount . "^" .
+            $merchantApiLoginId . '^' .
+            $fpSequence . '^' .
+            $fpTimestamp . '^' .
+            $amount . '^' .
             $currencyCode, $merchantTransactionKey
         ));
     }
@@ -110,6 +117,7 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
             ->setXRelayUrl($paymentMethod->getRelayUrl());
 
         $this->_setTransactionKey($paymentMethod->getConfigData('trans_key'));
+        $this->_setSignatureKey($paymentMethod->getConfigData('signature_key'));
         return $this;
     }
 
@@ -178,16 +186,76 @@ class Mage_Authorizenet_Model_Directpost_Request extends Varien_Object
     public function signRequestData()
     {
         $fpTimestamp = time();
-        $hash = $this->generateRequestSign(
-            $this->getXLogin(),
-            $this->_getTransactionKey(),
-            $this->getXAmount(),
-            $this->getXCurrencyCode(),
-            $this->getXFpSequence(),
-            $fpTimestamp
-        );
+        if (!empty($this->_getSignatureKey())) {
+            $hash = $this->_generateSha2RequestSign(
+                $this->getXLogin(),
+                $this->_getSignatureKey(),
+                $this->getXAmount(),
+                $this->getXCurrencyCode(),
+                $this->getXFpSequence(),
+                $fpTimestamp
+            );
+        } else {
+            $hash = $this->generateRequestSign(
+                $this->getXLogin(),
+                $this->_getTransactionKey(),
+                $this->getXAmount(),
+                $this->getXCurrencyCode(),
+                $this->getXFpSequence(),
+                $fpTimestamp
+            );
+        }
         $this->setXFpTimestamp($fpTimestamp);
         $this->setXFpHash($hash);
         return $this;
     }
+
+    /**
+     * Generates the SHA2 fingerprint for request.
+     *
+     * @param string $merchantApiLoginId
+     * @param string $merchantSignatureKey
+     * @param string $amount
+     * @param string $currencyCode
+     * @param string $fpSequence An invoice number or random number.
+     * @param string $fpTimestamp
+     * @return string The fingerprint.
+     */
+    protected function _generateSha2RequestSign(
+        $merchantApiLoginId,
+        $merchantSignatureKey,
+        $amount,
+        $currencyCode,
+        $fpSequence,
+        $fpTimestamp
+    ) {
+        $message = $merchantApiLoginId . '^' . $fpSequence . '^' . $fpTimestamp . '^' . $amount . '^' . $currencyCode;
+
+        return strtoupper(hash_hmac('sha512', $message, pack('H*', $merchantSignatureKey)));
+    }
+
+    /**
+     * Return merchant hexadecimal signature key.
+     *
+     * Needed to generate SHA2 sign.
+     *
+     * @return string
+     */
+    protected function _getSignatureKey()
+    {
+        return $this->_signatureKey;
+    }
+
+    /**
+     * Set merchant hexadecimal signature key.
+     *
+     * Needed to generate SHA2 sign.
+     *
+     * @param string $signatureKey
+     * @return void
+     */
+    protected function _setSignatureKey($signatureKey)
+    {
+        $this->_signatureKey = $signatureKey;
+    }
 }
diff --git a/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php b/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
index 00cc05e..98bc80d 100644
--- a/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
+++ b/app/code/core/Mage/Authorizenet/Model/Directpost/Response.php
@@ -44,23 +44,31 @@ class Mage_Authorizenet_Model_Directpost_Response extends Varien_Object
      */
     public function generateHash($merchantMd5, $merchantApiLogin, $amount, $transactionId)
     {
-        if (!$amount) {
-            $amount = '0.00';
-        }
         return strtoupper(md5($merchantMd5 . $merchantApiLogin . $transactionId . $amount));
     }
 
     /**
      * Return if is valid order id.
      *
-     * @param string $merchantMd5
+     * @param string $storedHash
      * @param string $merchantApiLogin
      * @return bool
      */
-    public function isValidHash($merchantMd5, $merchantApiLogin)
+    public function isValidHash($storedHash, $merchantApiLogin)
     {
-        return $this->generateHash($merchantMd5, $merchantApiLogin, $this->getXAmount(), $this->getXTransId())
-            == $this->getData('x_MD5_Hash');
+        if (empty($this->getData('x_amount'))) {
+            $this->setData('x_amount', '0.00');
+        }
+
+        if (!empty($this->getData('x_SHA2_Hash'))) {
+            $hash = $this->generateSha2Hash($storedHash);
+            return $hash == $this->getData('x_SHA2_Hash');
+        } elseif (!empty($this->getData('x_MD5_Hash'))) {
+            $hash = $this->generateHash($storedHash, $merchantApiLogin, $this->getXAmount(), $this->getXTransId());
+            return $hash == $this->getData('x_MD5_Hash');
+        }
+
+        return false;
     }
 
     /**
@@ -72,4 +80,82 @@ class Mage_Authorizenet_Model_Directpost_Response extends Varien_Object
     {
         return $this->getXResponseCode() == Mage_Authorizenet_Model_Directpost::RESPONSE_CODE_APPROVED;
     }
+
+    /**
+     * Generates an SHA2 hash to compare against AuthNet's.
+     *
+     * @param string $signatureKey
+     * @return string
+     * @see https://support.authorize.net/s/article/MD5-Hash-End-of-Life-Signature-Key-Replacement
+     */
+    public function generateSha2Hash($signatureKey)
+    {
+        $hashFields = [
+            'x_trans_id',
+            'x_test_request',
+            'x_response_code',
+            'x_auth_code',
+            'x_cvv2_resp_code',
+            'x_cavv_response',
+            'x_avs_code',
+            'x_method',
+            'x_account_number',
+            'x_amount',
+            'x_company',
+            'x_first_name',
+            'x_last_name',
+            'x_address',
+            'x_city',
+            'x_state',
+            'x_zip',
+            'x_country',
+            'x_phone',
+            'x_fax',
+            'x_email',
+            'x_ship_to_company',
+            'x_ship_to_first_name',
+            'x_ship_to_last_name',
+            'x_ship_to_address',
+            'x_ship_to_city',
+            'x_ship_to_state',
+            'x_ship_to_zip',
+            'x_ship_to_country',
+            'x_invoice_num',
+        ];
+
+        $order = Mage::getModel('sales/order')->loadByIncrementId($this->getData('x_invoice_num'));
+        $billing = $order->getBillingAddress();
+        if (!empty($billing)) {
+            $this->setXFirstName(strval($billing->getFirstname()))
+                ->setXLastName(strval($billing->getLastname()))
+                ->setXCompany(strval($billing->getCompany()))
+                ->setXAddress(strval($billing->getStreet(1)))
+                ->setXCity(strval($billing->getCity()))
+                ->setXState(strval($billing->getRegion()))
+                ->setXZip(strval($billing->getPostcode()))
+                ->setXCountry(strval($billing->getCountry()))
+                ->setXPhone(strval($billing->getTelephone()))
+                ->setXFax(strval($billing->getFax()))
+                ->setXEmail(strval($order->getCustomerEmail()));
+        }
+        $shipping = $order->getShippingAddress();
+        if (!empty($shipping)) {
+            $this->setXShipToFirstName(strval($shipping->getFirstname()))
+                ->setXShipToLastName(strval($shipping->getLastname()))
+                ->setXShipToCompany(strval($shipping->getCompany()))
+                ->setXShipToAddress(strval($shipping->getStreet(1)))
+                ->setXShipToCity(strval($shipping->getCity()))
+                ->setXShipToState(strval($shipping->getRegion()))
+                ->setXShipToZip(strval($shipping->getPostcode()))
+                ->setXShipToCountry(strval($shipping->getCountry()));
+        }
+
+        $message = '^';
+        foreach ($hashFields as $field) {
+            $fieldData = $this->getData($field);
+            $message .= (isset($fieldData) ? $fieldData : '') . '^';
+        }
+
+        return strtoupper(hash_hmac('sha512', $message, pack('H*', $signatureKey)));
+    }
 }
diff --git a/app/code/core/Mage/Authorizenet/etc/config.xml b/app/code/core/Mage/Authorizenet/etc/config.xml
index 33f9834..1ab5c4e 100644
--- a/app/code/core/Mage/Authorizenet/etc/config.xml
+++ b/app/code/core/Mage/Authorizenet/etc/config.xml
@@ -150,6 +150,7 @@
                 <test>1</test>
                 <title>Credit Card Direct Post (Authorize.net)</title>
                 <trans_key backend_model="adminhtml/system_config_backend_encrypted"/>
+                <signature_key backend_model="adminhtml/system_config_backend_encrypted"/>
                 <trans_md5 backend_model="adminhtml/system_config_backend_encrypted"/>
                 <allowspecific>0</allowspecific>
                 <currency>USD</currency>
diff --git a/app/code/core/Mage/Authorizenet/etc/system.xml b/app/code/core/Mage/Authorizenet/etc/system.xml
index 369b25a..f2b1aa8 100644
--- a/app/code/core/Mage/Authorizenet/etc/system.xml
+++ b/app/code/core/Mage/Authorizenet/etc/system.xml
@@ -30,7 +30,7 @@
         <payment>
             <groups>
                 <authorizenet_directpost translate="label" module="authorizenet">
-                    <label>Authorize.net Direct Post</label>
+                    <label>Authorize.net Direct Post (Deprecated)</label>
                     <frontend_type>text</frontend_type>
                     <sort_order>34</sort_order>
                     <show_in_default>1</show_in_default>
@@ -81,6 +81,15 @@
                             <show_in_website>1</show_in_website>
                             <show_in_store>0</show_in_store>
                         </trans_key>
+                        <signature_key translate="label">
+                            <label>Signature Key</label>
+                            <frontend_type>obscure</frontend_type>
+                            <backend_model>adminhtml/system_config_backend_encrypted</backend_model>
+                            <sort_order>55</sort_order>
+                            <show_in_default>1</show_in_default>
+                            <show_in_website>1</show_in_website>
+                            <show_in_store>0</show_in_store>
+                        </signature_key>
                         <trans_md5 translate="label">
                             <label>Merchant MD5</label>
                             <frontend_type>obscure</frontend_type>
diff --git a/app/code/core/Mage/Catalog/Helper/Product.php b/app/code/core/Mage/Catalog/Helper/Product.php
index e9c0146..b62e34d 100644
--- a/app/code/core/Mage/Catalog/Helper/Product.php
+++ b/app/code/core/Mage/Catalog/Helper/Product.php
@@ -525,4 +525,41 @@ class Mage_Catalog_Helper_Product extends Mage_Core_Helper_Url
 
         return $qty;
     }
+
+    /**
+     * Get default product value by field name
+     *
+     * @param string $fieldName
+     * @param string $productType
+     * @return int
+     */
+    public function getDefaultProductValue($fieldName, $productType)
+    {
+        $fieldData = $this->getFieldset($fieldName) ? (array) $this->getFieldset($fieldName) : null;
+        if (
+            count($fieldData)
+            && array_key_exists($productType, $fieldData['product_type'])
+            && (bool)$fieldData['use_config']
+        ) {
+            return $fieldData['inventory'];
+        }
+        return self::DEFAULT_QTY;
+    }
+
+    /**
+     * Return array from config by fieldset name and area
+     *
+     * @param null|string $field
+     * @param string $fieldset
+     * @param string $area
+     * @return array|null
+     */
+    public function getFieldset($field = null, $fieldset = 'catalog_product_dataflow', $area = 'admin')
+    {
+        $fieldsetData = Mage::getConfig()->getFieldset($fieldset, $area);
+        if ($fieldsetData) {
+            return $fieldsetData ? $fieldsetData->$field : $fieldsetData;
+        }
+        return $fieldsetData;
+    }
 }
diff --git a/app/code/core/Mage/Catalog/controllers/Product/CompareController.php b/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
index 2be9c52..0984c2b 100644
--- a/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
+++ b/app/code/core/Mage/Catalog/controllers/Product/CompareController.php
@@ -80,7 +80,7 @@ class Mage_Catalog_Product_CompareController extends Mage_Core_Controller_Front_
         }
 
         $productId = (int) $this->getRequest()->getParam('product');
-        if ($productId
+        if ($this->isProductAvailable($productId)
             && (Mage::getSingleton('log/visitor')->getId() || Mage::getSingleton('customer/session')->isLoggedIn())
         ) {
             $product = Mage::getModel('catalog/product')
@@ -106,7 +106,8 @@ class Mage_Catalog_Product_CompareController extends Mage_Core_Controller_Front_
      */
     public function removeAction()
     {
-        if ($productId = (int) $this->getRequest()->getParam('product')) {
+        $productId = (int) $this->getRequest()->getParam('product');
+        if ($this->isProductAvailable($productId)) {
             $product = Mage::getModel('catalog/product')
                 ->setStoreId(Mage::app()->getStore()->getId())
                 ->load($productId);
@@ -184,4 +185,15 @@ class Mage_Catalog_Product_CompareController extends Mage_Core_Controller_Front_
         $this->_customerId = $id;
         return $this;
     }
+
+    /**
+     * Check if product is available
+     *
+     * @param int $productId
+     * @return bool
+     */
+    public function isProductAvailable($productId)
+    {
+        return Mage::getModel('catalog/product')->load($productId)->isAvailable();
+    }
 }
diff --git a/app/code/core/Mage/Checkout/Model/Session.php b/app/code/core/Mage/Checkout/Model/Session.php
index fc99aa6..dded466 100644
--- a/app/code/core/Mage/Checkout/Model/Session.php
+++ b/app/code/core/Mage/Checkout/Model/Session.php
@@ -120,13 +120,21 @@ class Mage_Checkout_Model_Session extends Mage_Core_Model_Session_Abstract
         if ($this->_quote === null) {
             /** @var $quote Mage_Sales_Model_Quote */
             $quote = Mage::getModel('sales/quote')->setStoreId(Mage::app()->getStore()->getId());
+            $customerSession = Mage::getSingleton('customer/session');
+
             if ($this->getQuoteId()) {
                 if ($this->_loadInactive) {
                     $quote->load($this->getQuoteId());
                 } else {
                     $quote->loadActive($this->getQuoteId());
                 }
-                if ($quote->getId()) {
+                if (
+                    $quote->getId()
+                    && (
+                        ($customerSession->isLoggedIn() && $customerSession->getId() == $quote->getCustomerId())
+                        || (!$customerSession->isLoggedIn() && !$quote->getCustomerId())
+                    )
+                ) {
                     /**
                      * If current currency code of quote is not equal current currency code of store,
                      * need recalculate totals of quote. It is possible if customer use currency switcher or
@@ -143,16 +151,16 @@ class Mage_Checkout_Model_Session extends Mage_Core_Model_Session_Abstract
                         $quote->load($this->getQuoteId());
                     }
                 } else {
+                    $quote->unsetData();
                     $this->setQuoteId(null);
                 }
             }
 
-            $customerSession = Mage::getSingleton('customer/session');
-
             if (!$this->getQuoteId()) {
                 if ($customerSession->isLoggedIn() || $this->_customer) {
                     $customer = ($this->_customer) ? $this->_customer : $customerSession->getCustomer();
                     $quote->loadByCustomer($customer);
+                    $quote->setCustomer($customer);
                     $this->setQuoteId($quote->getId());
                 } else {
                     $quote->setIsCheckoutCart(true);
diff --git a/app/code/core/Mage/Checkout/controllers/OnepageController.php b/app/code/core/Mage/Checkout/controllers/OnepageController.php
index 1e122fa..861b920 100644
--- a/app/code/core/Mage/Checkout/controllers/OnepageController.php
+++ b/app/code/core/Mage/Checkout/controllers/OnepageController.php
@@ -565,7 +565,7 @@ class Mage_Checkout_OnepageController extends Mage_Checkout_Controller_Action
      */
     public function saveOrderAction()
     {
-        if (!$this->_validateFormKey()) {
+        if ($this->isFormkeyValidationOnCheckoutEnabled() && !$this->_validateFormKey()) {
             $this->_redirect('*/*');
             return;
         }
diff --git a/app/code/core/Mage/Cms/Helper/Data.php b/app/code/core/Mage/Cms/Helper/Data.php
index 42b3b18..2b60322 100644
--- a/app/code/core/Mage/Cms/Helper/Data.php
+++ b/app/code/core/Mage/Cms/Helper/Data.php
@@ -37,6 +37,7 @@ class Mage_Cms_Helper_Data extends Mage_Core_Helper_Abstract
     const XML_NODE_PAGE_TEMPLATE_FILTER     = 'global/cms/page/tempate_filter';
     const XML_NODE_BLOCK_TEMPLATE_FILTER    = 'global/cms/block/tempate_filter';
     const XML_NODE_ALLOWED_STREAM_WRAPPERS  = 'global/cms/allowed_stream_wrappers';
+    const XML_NODE_ALLOWED_MEDIA_EXT_SWF    = 'adminhtml/cms/browser/extensions/media_allowed/swf';
 
     /**
      * Retrieve Template processor for Page Content
@@ -74,4 +75,19 @@ class Mage_Cms_Helper_Data extends Mage_Core_Helper_Abstract
 
         return is_array($allowedStreamWrappers) ? $allowedStreamWrappers : array();
     }
+
+    /**
+     * Check is swf file extension disabled
+     *
+     * @return bool
+     */
+    public function isSwfDisabled()
+    {
+        $statusSwf = Mage::getConfig()->getNode(self::XML_NODE_ALLOWED_MEDIA_EXT_SWF);
+        if ($statusSwf instanceof Mage_Core_Model_Config_Element) {
+            $statusSwf = $statusSwf->asArray()[0];
+        }
+
+        return $statusSwf ? false : true;
+    }
 }
diff --git a/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php b/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
index 471f10f..33c16b6 100644
--- a/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
+++ b/app/code/core/Mage/Cms/Model/Wysiwyg/Config.php
@@ -93,7 +93,8 @@ class Mage_Cms_Model_Wysiwyg_Config extends Varien_Object
             'content_css'                   =>
                 Mage::getBaseUrl('js').'mage/adminhtml/wysiwyg/tiny_mce/themes/advanced/skins/default/content.css',
             'width'                         => '100%',
-            'plugins'                       => array()
+            'plugins'                       => array(),
+            'media_disable_flash'           => Mage::helper('cms')->isSwfDisabled()
         ));
 
         $config->setData('directives_url_quoted', preg_quote($config->getData('directives_url')));
diff --git a/app/code/core/Mage/Cms/etc/config.xml b/app/code/core/Mage/Cms/etc/config.xml
index a75a7fb..7458f93 100644
--- a/app/code/core/Mage/Cms/etc/config.xml
+++ b/app/code/core/Mage/Cms/etc/config.xml
@@ -122,7 +122,7 @@
                     </image_allowed>
                     <media_allowed>
                         <flv>1</flv>
-                        <swf>1</swf>
+                        <swf>0</swf>
                         <avi>1</avi>
                         <mov>1</mov>
                         <rm>1</rm>
diff --git a/app/code/core/Mage/Compiler/Model/Process.php b/app/code/core/Mage/Compiler/Model/Process.php
index 1f7994e..73fd07e 100644
--- a/app/code/core/Mage/Compiler/Model/Process.php
+++ b/app/code/core/Mage/Compiler/Model/Process.php
@@ -43,6 +43,9 @@ class Mage_Compiler_Model_Process
 
     protected $_controllerFolders = array();
 
+    /** $_collectLibs library list array */
+    protected $_collectLibs = array();
+
     public function __construct($options=array())
     {
         if (isset($options['compile_dir'])) {
@@ -128,6 +131,9 @@ class Mage_Compiler_Model_Process
                 || !in_array(substr($source, strlen($source)-4, 4), array('.php'))) {
                 return $this;
             }
+            if (!$firstIteration && stripos($source, Mage::getBaseDir('lib') . DS) !== false) {
+                $this->_collectLibs[] = $target;
+            }
             copy($source, $target);
         }
         return $this;
@@ -341,6 +347,11 @@ class Mage_Compiler_Model_Process
     {
         $sortedClasses = array();
         foreach ($classes as $className) {
+            /** Skip iteration if this class has already been moved to the includes folder from the lib */
+            if (array_search($this->_includeDir . DS . $className . '.php', $this->_collectLibs)) {
+                continue;
+            }
+
             $implements = array_reverse(class_implements($className));
             foreach ($implements as $class) {
                 if (!in_array($class, $sortedClasses) && !in_array($class, $this->_processedClasses) && strstr($class, '_')) {
diff --git a/app/code/core/Mage/Core/Helper/Abstract.php b/app/code/core/Mage/Core/Helper/Abstract.php
index ea847e3..b122553 100644
--- a/app/code/core/Mage/Core/Helper/Abstract.php
+++ b/app/code/core/Mage/Core/Helper/Abstract.php
@@ -443,4 +443,42 @@ abstract class Mage_Core_Helper_Abstract
         }
         return $arr;
     }
+
+    /**
+     * Check for tags in multidimensional arrays
+     *
+     * @param string|array $data
+     * @param array $arrayKeys keys of the array being checked that are excluded and included in the check
+     * @param bool $skipTags skip transferred array keys, if false then check only them
+     * @return bool
+     */
+    public function hasTags($data, array $arrayKeys = array(), $skipTags = true)
+    {
+        if (is_array($data)) {
+            foreach ($data as $key => $item) {
+                if ($skipTags && in_array($key, $arrayKeys)) {
+                    continue;
+                }
+                if (is_array($item)) {
+                    if ($this->hasTags($item, $arrayKeys, $skipTags)) {
+                        return true;
+                    }
+                } elseif (
+                    (bool)strcmp($item, $this->removeTags($item))
+                    || (bool)strcmp($key, $this->removeTags($key))
+                ) {
+                    if (!$skipTags && !in_array($key, $arrayKeys)) {
+                        continue;
+                    }
+                    return true;
+                }
+            }
+            return false;
+        } elseif (is_string($data)) {
+            if ((bool)strcmp($data, $this->removeTags($data))) {
+                return true;
+            }
+        }
+        return false;
+    }
 }
diff --git a/app/code/core/Mage/Core/Helper/Data.php b/app/code/core/Mage/Core/Helper/Data.php
index e2e41b4..f4deb30 100644
--- a/app/code/core/Mage/Core/Helper/Data.php
+++ b/app/code/core/Mage/Core/Helper/Data.php
@@ -254,7 +254,7 @@ class Mage_Core_Helper_Data extends Mage_Core_Helper_Abstract
             $chars = self::CHARS_LOWERS . self::CHARS_UPPERS . self::CHARS_DIGITS;
         }
         for ($i = 0, $str = '', $lc = strlen($chars)-1; $i < $len; $i++) {
-            $str .= $chars[mt_rand(0, $lc)];
+            $str .= $chars[random_int(0, $lc)];
         }
         return $str;
     }
diff --git a/app/code/core/Mage/Core/Model/Design/Package.php b/app/code/core/Mage/Core/Model/Design/Package.php
index d0587e8..407524a 100644
--- a/app/code/core/Mage/Core/Model/Design/Package.php
+++ b/app/code/core/Mage/Core/Model/Design/Package.php
@@ -589,7 +589,11 @@ class Mage_Core_Model_Design_Package
             return false;
         }
 
-        $regexps = @unserialize($configValueSerialized);
+        try {
+            $regexps = Mage::helper('core/unserializeArray')->unserialize($configValueSerialized);
+        } catch (Exception $e) {
+            Mage::logException($e);
+        }
 
         if (empty($regexps)) {
             return false;
diff --git a/app/code/core/Mage/Core/Model/Email/Template/Filter.php b/app/code/core/Mage/Core/Model/Email/Template/Filter.php
index 2d64307..2dd2b2f 100644
--- a/app/code/core/Mage/Core/Model/Email/Template/Filter.php
+++ b/app/code/core/Mage/Core/Model/Email/Template/Filter.php
@@ -564,4 +564,24 @@ class Mage_Core_Model_Email_Template_Filter extends Varien_Filter_Template
         }
         return $value;
     }
+
+    /**
+     * Return variable value for var construction
+     *
+     * @param string $value raw parameters
+     * @param string $default default value
+     * @return string
+     */
+    protected function _getVariable($value, $default = '{no_value_defined}')
+    {
+        Mage::register('varProcessing', true);
+        try {
+            $result = parent::_getVariable($value, $default);
+        } catch (Exception $e) {
+            $result = '';
+            Mage::logException($e);
+        }
+        Mage::unregister('varProcessing');
+        return $result;
+    }
 }
diff --git a/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php b/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
index ca5a664..0a6ed4f 100644
--- a/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
+++ b/app/code/core/Mage/Core/Model/File/Validator/AvailablePath.php
@@ -230,8 +230,16 @@ class Mage_Core_Model_File_Validator_AvailablePath extends Zend_Validate_Abstrac
         }
 
         //validation
+        $protectedExtensions = Mage::helper('core/data')->getProtectedFileExtensions();
         $value = str_replace(array('/', '\\'), DS, $this->_value);
         $valuePathInfo = pathinfo(ltrim($value, '\\/'));
+        $fileNameExtension = pathinfo($valuePathInfo['filename'], PATHINFO_EXTENSION);
+
+        if (in_array($fileNameExtension, $protectedExtensions)) {
+            $this->_error(self::NOT_AVAILABLE_PATH, $this->_value);
+            return false;
+        }
+
         if ($valuePathInfo['dirname'] == '.' || $valuePathInfo['dirname'] == DS) {
             $valuePathInfo['dirname'] = '';
         }
diff --git a/app/code/core/Mage/Core/Model/Observer.php b/app/code/core/Mage/Core/Model/Observer.php
index 0d570be..ff562d8 100644
--- a/app/code/core/Mage/Core/Model/Observer.php
+++ b/app/code/core/Mage/Core/Model/Observer.php
@@ -125,4 +125,19 @@ class Mage_Core_Model_Observer
         Mage::app()->cleanCache($tags);
         return $this;
     }
+
+    /**
+     * Checks method availability for processing in variable
+     *
+     * @param Varien_Event_Observer $observer
+     * @throws Exception
+     * @return Mage_Core_Model_Observer
+     */
+    public function secureVarProcessing(Varien_Event_Observer $observer)
+    {
+        if (Mage::registry('varProcessing')) {
+            Mage::throwException(Mage::helper('core')->__('Disallowed template variable method.'));
+        }
+        return $this;
+    }
 }
diff --git a/app/code/core/Mage/Core/etc/config.xml b/app/code/core/Mage/Core/etc/config.xml
index d0b5293..7abca93 100644
--- a/app/code/core/Mage/Core/etc/config.xml
+++ b/app/code/core/Mage/Core/etc/config.xml
@@ -178,6 +178,22 @@
                     </security_domain_policy>
                 </observers>
             </controller_action_predispatch>
+            <model_save_before>
+                <observers>
+                    <secure_var_processing>
+                        <class>core/observer</class>
+                        <method>secureVarProcessing</method>
+                    </secure_var_processing>
+                </observers>
+            </model_save_before>
+            <model_delete_before>
+                <observers>
+                    <secure_var_processing>
+                        <class>core/observer</class>
+                        <method>secureVarProcessing</method>
+                    </secure_var_processing>
+                </observers>
+            </model_delete_before>
         </events>
     </global>
     <frontend>
diff --git a/app/code/core/Mage/Core/functions.php b/app/code/core/Mage/Core/functions.php
index 3def24e..fc6e837 100644
--- a/app/code/core/Mage/Core/functions.php
+++ b/app/code/core/Mage/Core/functions.php
@@ -397,3 +397,19 @@ if (!function_exists('hash_equals')) {
         return 0 === $result;
     }
 }
+
+if (version_compare(PHP_VERSION, '7.0.0', '<') && !function_exists('random_int')) {
+    /**
+     * Generates pseudo-random integers
+     *
+     * @param int $min
+     * @param int $max
+     * @return int Returns random integer in the range $min to $max, inclusive.
+     */
+    function random_int($min, $max)
+    {
+        mt_srand();
+
+        return mt_rand($min, $max);
+    }
+}
diff --git a/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php b/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
index d92bae1..31a2783 100644
--- a/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
+++ b/app/code/core/Mage/CurrencySymbol/Model/System/Currencysymbol.php
@@ -274,7 +274,11 @@ class Mage_CurrencySymbol_Model_System_Currencysymbol
         $result = array();
         $configData = (string)Mage::getStoreConfig($configPath, $storeId);
         if ($configData) {
-            $result = unserialize($configData);
+            try {
+                $result = Mage::helper('core/unserializeArray')->unserialize($configData);
+            } catch (Exception $e) {
+                Mage::logException($e);
+            }
         }
 
         return is_array($result) ? $result : array();
diff --git a/app/code/core/Mage/Downloadable/controllers/DownloadController.php b/app/code/core/Mage/Downloadable/controllers/DownloadController.php
index 180e013..07e7fe3 100644
--- a/app/code/core/Mage/Downloadable/controllers/DownloadController.php
+++ b/app/code/core/Mage/Downloadable/controllers/DownloadController.php
@@ -97,7 +97,12 @@ class Mage_Downloadable_DownloadController extends Mage_Core_Controller_Front_Ac
     {
         $sampleId = $this->getRequest()->getParam('sample_id', 0);
         $sample = Mage::getModel('downloadable/sample')->load($sampleId);
-        if ($sample->getId()) {
+        if (
+            $sample->getId()
+            && Mage::helper('catalog/product')
+                ->getProduct((int) $sample->getProductId(), Mage::app()->getStore()->getId(), 'id')
+                ->isAvailable()
+        ) {
             $resource = '';
             $resourceType = '';
             if ($sample->getSampleType() == Mage_Downloadable_Helper_Download::LINK_TYPE_URL) {
@@ -127,7 +132,12 @@ class Mage_Downloadable_DownloadController extends Mage_Core_Controller_Front_Ac
     {
         $linkId = $this->getRequest()->getParam('link_id', 0);
         $link = Mage::getModel('downloadable/link')->load($linkId);
-        if ($link->getId()) {
+        if (
+            $link->getId()
+            && Mage::helper('catalog/product')
+                ->getProduct((int) $link->getProductId(), Mage::app()->getStore()->getId(), 'id')
+                ->isAvailable()
+        ) {
             $resource = '';
             $resourceType = '';
             if ($link->getSampleType() == Mage_Downloadable_Helper_Download::LINK_TYPE_URL) {
diff --git a/app/code/core/Mage/Paygate/etc/system.xml b/app/code/core/Mage/Paygate/etc/system.xml
index f434526..7f3dd52 100644
--- a/app/code/core/Mage/Paygate/etc/system.xml
+++ b/app/code/core/Mage/Paygate/etc/system.xml
@@ -30,7 +30,7 @@
         <payment>
             <groups>
                 <authorizenet translate="label" module="paygate">
-                    <label>Authorize.net</label>
+                    <label>Authorize.net (Deprecated)</label>
                     <frontend_type>text</frontend_type>
                     <sort_order>34</sort_order>
                     <show_in_default>1</show_in_default>
diff --git a/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php b/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
index a9683a0..9df1732 100644
--- a/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
+++ b/app/code/core/Mage/SalesRule/Model/Coupon/Massgenerator.php
@@ -79,7 +79,7 @@ class Mage_SalesRule_Model_Coupon_Massgenerator extends Mage_Core_Model_Abstract
         $code = '';
         $charsetSize = count($charset);
         for ($i=0; $i<$length; $i++) {
-            $char = $charset[mt_rand(0, $charsetSize - 1)];
+            $char = $charset[random_int(0, $charsetSize - 1)];
             if ($split > 0 && ($i % $split) == 0 && $i != 0) {
                 $char = $splitChar . $char;
             }
diff --git a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
index bfda23b..f574602 100644
--- a/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
+++ b/app/code/core/Mage/SalesRule/Model/Resource/Report/Rule/Createdat.php
@@ -118,14 +118,14 @@ class Mage_SalesRule_Model_Resource_Report_Rule_Createdat extends Mage_Reports_M
                         $adapter->getIfNullSql('base_subtotal_refunded', 0). ') * base_to_global_rate)', 0),
 
                 'discount_amount_actual'  =>
-                    $adapter->getIfNullSql('SUM((base_discount_invoiced - ' .
+                    $adapter->getIfNullSql('SUM((ABS(base_discount_invoiced) - ' .
                         $adapter->getIfNullSql('base_discount_refunded', 0) . ')
                         * base_to_global_rate)', 0),
 
                 'total_amount_actual'     =>
                     $adapter->getIfNullSql('SUM((base_subtotal_invoiced - ' .
                         $adapter->getIfNullSql('base_subtotal_refunded', 0) . ' - ' .
-                        $adapter->getIfNullSql('base_discount_invoiced - ' .
+                        $adapter->getIfNullSql('ABS(base_discount_invoiced) - ' .
                         $adapter->getIfNullSql('base_discount_refunded', 0), 0) .
                         ') * base_to_global_rate)', 0),
             );
diff --git a/app/code/core/Mage/Sendfriend/etc/config.xml b/app/code/core/Mage/Sendfriend/etc/config.xml
index 5b21374..3ef8964 100644
--- a/app/code/core/Mage/Sendfriend/etc/config.xml
+++ b/app/code/core/Mage/Sendfriend/etc/config.xml
@@ -122,7 +122,7 @@
     <default>
         <sendfriend>
             <email>
-                <enabled>1</enabled>
+                <enabled>0</enabled>
                 <template>sendfriend_email_template</template>
                 <allow_guest>0</allow_guest>
                 <max_recipients>5</max_recipients>
diff --git a/app/code/core/Mage/Sendfriend/etc/system.xml b/app/code/core/Mage/Sendfriend/etc/system.xml
index 6f43d9c..2beaf38 100644
--- a/app/code/core/Mage/Sendfriend/etc/system.xml
+++ b/app/code/core/Mage/Sendfriend/etc/system.xml
@@ -52,6 +52,7 @@
                             <show_in_default>1</show_in_default>
                             <show_in_website>1</show_in_website>
                             <show_in_store>1</show_in_store>
+                            <comment><![CDATA[<strong style="color:red">Warning!</strong> This functionality is vulnerable and can be abused to distribute spam.]]></comment>
                         </enabled>
                         <template translate="label">
                             <label>Select Email Template</label>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
index 5452fe7..9d08a10 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/composite/fieldset/configurable.phtml
@@ -35,7 +35,7 @@
     <div class="product-options">
         <dl>
         <?php foreach($_attributes as $_attribute): ?>
-            <dt><label class="required"><em>*</em><?php echo $_attribute->getLabel() ?></label></dt>
+            <dt><label class="required"><em>*</em><?php echo $this->escapeHtml($_attribute->getLabel()) ?></label></dt>
             <dd<?php if ($_attribute->decoratedIsLast){?> class="last"<?php }?>>
                 <div class="input-box">
                     <select name="super_attribute[<?php echo $_attribute->getAttributeId() ?>]" id="attribute<?php echo $_attribute->getAttributeId() ?>" class="required-entry super-attribute-select">
diff --git a/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml b/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
index cc62210..5d31b62 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/helper/gallery.phtml
@@ -59,7 +59,7 @@ $_block = $this;
             <th><?php echo Mage::helper('catalog')->__('Label') ?></th>
             <th><?php echo Mage::helper('catalog')->__('Sort Order') ?></th>
             <?php foreach ($_block->getImageTypes() as $typeId => $type): ?>
-                <th><?php echo $this->escapeHtml($type['label']); ?></th>
+                <th><?php echo $this->escapeHtml($type['label'], array('br')); ?></th>
             <?php endforeach; ?>
             <th><?php echo Mage::helper('catalog')->__('Exclude') ?></th>
             <th class="last"><?php echo Mage::helper('catalog')->__('Remove') ?></th>
diff --git a/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml b/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
index a0fd72d..e05ecf3 100644
--- a/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
+++ b/app/design/adminhtml/default/default/template/catalog/product/tab/inventory.phtml
@@ -77,7 +77,7 @@
 
         <tr>
             <td class="label"><label for="inventory_min_sale_qty"><?php echo Mage::helper('catalog')->__('Minimum Qty Allowed in Shopping Cart') ?></label></td>
-            <td class="value"><input type="text" class="input-text validate-number" id="inventory_min_sale_qty" name="<?php echo $this->getFieldSuffix() ?>[stock_data][min_sale_qty]" value="<?php echo $this->getFieldValue('min_sale_qty')*1 ?>" <?php echo $_readonly;?>/>
+            <td class="value"><input type="text" class="input-text validate-number" id="inventory_min_sale_qty" name="<?php echo $this->getFieldSuffix() ?>[stock_data][min_sale_qty]" value="<?php echo (bool)$this->getProduct()->getId() ? (int)$this->getFieldValue('min_sale_qty') : Mage::helper('catalog/product')->getDefaultProductValue('min_sale_qty', $this->getProduct()->getTypeId()) ?>" <?php echo $_readonly ?>/>
 
             <?php $_checked = ($this->getFieldValue('use_config_min_sale_qty') || $this->IsNew()) ? 'checked="checked"' : '' ?>
             <input type="checkbox" id="inventory_use_config_min_sale_qty" name="<?php echo $this->getFieldSuffix() ?>[stock_data][use_config_min_sale_qty]" value="1" <?php echo $_checked ?> onclick="toggleValueElements(this, this.parentNode);" class="checkbox" <?php echo $_readonly;?> />
diff --git a/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml b/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
index 597f641..5a77623 100644
--- a/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
+++ b/app/design/adminhtml/default/default/template/currencysymbol/grid.phtml
@@ -66,12 +66,12 @@
                             <?php foreach($this->getCurrencySymbolsData() as $code => $data): ?>
                             <tr>
                                 <td class="label">
-                                <label for="custom_currency_symbol<?php echo $code; ?>"><?php echo $code; ?> (<?php echo $data['displayName']; ?>)</label>
+                                <label for="custom_currency_symbol<?php echo $this->escapeHtml($code); ?>"><?php echo $this->escapeHtml($code); ?> (<?php echo $this->escapeHtml($data['displayName']); ?>)</label>
                                 </td>
                                 <td class="value">
-                                    <input id="custom_currency_symbol<?php echo $code; ?>" class=" required-entry input-text" type="text" value="<?php echo Mage::helper('core')->quoteEscape($data['displaySymbol']); ?>"<?php echo $data['inherited'] ? ' disabled="disabled"' : '';?> name="custom_currency_symbol[<?php echo $code; ?>]">
-                                    &nbsp; <input id="custom_currency_symbol_inherit<?php echo $code; ?>" class="checkbox config-inherit" type="checkbox" onclick="toggleUseDefault(<?php echo '\'' . $code . '\',\'' . Mage::helper('core')->quoteEscape($data['parentSymbol'], true) . '\''; ?>)"<?php echo $data['inherited'] ? ' checked="checked"' : ''; ?> value="1" name="inherit_custom_currency_symbol[<?php echo $code; ?>]">
-                                    <label class="inherit" title="" for="custom_currency_symbol_inherit<?php echo $code; ?>"><?php echo $this->getInheritText(); ?></label>
+                                    <input id="custom_currency_symbol<?php echo $this->escapeHtml($code); ?>" class=" required-entry input-text" type="text" value="<?php echo Mage::helper('core')->quoteEscape($this->escapeHtml($data['displaySymbol'])); ?>"<?php echo $data['inherited'] ? ' disabled="disabled"' : '';?> name="custom_currency_symbol[<?php echo $this->escapeHtml($code); ?>]">
+                                    &nbsp; <input id="custom_currency_symbol_inherit<?php echo $this->escapeHtml($code); ?>" class="checkbox config-inherit" type="checkbox" onclick="toggleUseDefault(<?php echo '\'' . $this->escapeHtml($code) . '\',\'' . Mage::helper('core')->quoteEscape($data['parentSymbol'], true) . '\''; ?>)"<?php echo $data['inherited'] ? ' checked="checked"' : ''; ?> value="1" name="inherit_custom_currency_symbol[<?php echo $this->escapeHtml($code); ?>]">
+                                    <label class="inherit" title="" for="custom_currency_symbol_inherit<?php echo $this->escapeHtml($code); ?>"><?php echo $this->getInheritText(); ?></label>
                                 </td>
                             </tr>
                             <?php endforeach; ?>
diff --git a/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml b/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
index 4e41e32..c5f793c 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/addresses.phtml
@@ -46,7 +46,7 @@
             </a>
             <?php endif;?>
             <address>
-                <?php echo $_address->format('html') ?>
+                <?php echo $this->maliciousCodeFilter($_address->format('html')) ?>
             </address>
             <div class="address-type">
                 <span class="address-type-line">
diff --git a/app/design/adminhtml/default/default/template/customer/tab/view.phtml b/app/design/adminhtml/default/default/template/customer/tab/view.phtml
index cd23a75..ea0dd19 100644
--- a/app/design/adminhtml/default/default/template/customer/tab/view.phtml
+++ b/app/design/adminhtml/default/default/template/customer/tab/view.phtml
@@ -75,7 +75,7 @@ $createDateStore    = $this->getStoreCreateDate();
         </table>
         <address class="box-right">
             <strong><?php echo $this->__('Default Billing Address') ?></strong><br/>
-            <?php echo $this->getBillingAddressHtml() ?>
+            <?php echo $this->maliciousCodeFilter($this->getBillingAddressHtml()) ?>
         </address>
     </fieldset>
 </div>
diff --git a/app/design/adminhtml/default/default/template/notification/window.phtml b/app/design/adminhtml/default/default/template/notification/window.phtml
index 1590005..1397492 100644
--- a/app/design/adminhtml/default/default/template/notification/window.phtml
+++ b/app/design/adminhtml/default/default/template/notification/window.phtml
@@ -68,7 +68,7 @@
     </div>
     <div class="message-popup-content">
         <div class="message">
-            <span class="message-icon message-<?php echo $this->getSeverityText();?>" style="background-image:url(<?php echo $this->getSeverityIconsUrl() ?>);"><?php echo $this->getSeverityText();?></span>
+            <span class="message-icon message-<?php echo $this->getSeverityText(); ?>" style="background-image:url(<?php echo $this->escapeUrl($this->getSeverityIconsUrl()); ?>);"><?php echo $this->getSeverityText(); ?></span>
             <p class="message-text"><?php echo $this->getNoticeMessageText(); ?></p>
         </div>
         <p class="read-more"><a href="<?php echo $this->getNoticeMessageUrl(); ?>" onclick="this.target='_blank';"><?php echo $this->getReadDetailsText(); ?></a></p>
diff --git a/app/design/adminhtml/default/default/template/sales/order/create/data.phtml b/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
index 82f8a66..d648bae 100644
--- a/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/create/data.phtml
@@ -33,7 +33,9 @@
     <?php endforeach; ?>
 </select>
 </p>
-<script type="text/javascript">order.setCurrencySymbol('<?php echo $this->getCurrencySymbol($this->getCurrentCurrencyCode()) ?>')</script>
+    <script type="text/javascript">
+        order.setCurrencySymbol('<?php echo Mage::helper('core')->jsQuoteEscape($this->getCurrencySymbol($this->getCurrentCurrencyCode())) ?>')
+    </script>
 <table cellspacing="0" width="100%">
 <tr>
     <?php if($this->getCustomerId()): ?>
diff --git a/app/design/adminhtml/default/default/template/sales/order/view/info.phtml b/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
index dcf7d6a..4bdeabc 100644
--- a/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
+++ b/app/design/adminhtml/default/default/template/sales/order/view/info.phtml
@@ -39,9 +39,9 @@ $orderStoreDate = $this->formatDate($_order->getCreatedAtStoreDate(), 'medium',
         endif; ?>
         <div class="entry-edit-head">
         <?php if ($this->getNoUseOrderLink()): ?>
-            <h4 class="icon-head head-account"><?php echo Mage::helper('sales')->__('Order # %s', $_order->getRealOrderId()) ?> (<?php echo $_email ?>)</h4>
+            <h4 class="icon-head head-account"><?php echo Mage::helper('sales')->__('Order # %s', $this->escapeHtml($_order->getRealOrderId())) ?> (<?php echo $_email ?>)</h4>
         <?php else: ?>
-            <a href="<?php echo $this->getViewUrl($_order->getId()) ?>"><?php echo Mage::helper('sales')->__('Order # %s', $_order->getRealOrderId()) ?></a>
+            <a href="<?php echo $this->getViewUrl($_order->getId()) ?>"><?php echo Mage::helper('sales')->__('Order # %s', $this->escapeHtml($_order->getRealOrderId())) ?></a>
             <strong>(<?php echo $_email ?>)</strong>
         <?php endif; ?>
         </div>
@@ -69,7 +69,7 @@ $orderStoreDate = $this->formatDate($_order->getCreatedAtStoreDate(), 'medium',
             <tr>
                 <td class="label"><label><?php echo Mage::helper('sales')->__('Link to the New Order') ?></label></td>
                 <td class="value"><a href="<?php echo $this->getViewUrl($_order->getRelationChildId()) ?>">
-                    <?php echo $_order->getRelationChildRealId() ?>
+                    <?php echo $this->escapeHtml($_order->getRelationChildRealId()) ?>
                 </a></td>
             </tr>
             <?php endif; ?>
@@ -77,7 +77,7 @@ $orderStoreDate = $this->formatDate($_order->getCreatedAtStoreDate(), 'medium',
             <tr>
                 <td class="label"><label><?php echo Mage::helper('sales')->__('Link to the Previous Order') ?></label></td>
                 <td class="value"><a href="<?php echo $this->getViewUrl($_order->getRelationParentId()) ?>">
-                    <?php echo $_order->getRelationParentRealId() ?>
+                    <?php echo $this->escapeHtml($_order->getRelationParentRealId()) ?>
                 </a></td>
             </tr>
             <?php endif; ?>
@@ -154,7 +154,7 @@ $orderStoreDate = $this->formatDate($_order->getCreatedAtStoreDate(), 'medium',
             <div class="tools"><?php echo $this->getAddressEditLink($_order->getBillingAddress())?></div>
         </div>
         <fieldset>
-            <address><?php echo $_order->getBillingAddress()->getFormated(true) ?></address>
+            <address><?php echo $this->maliciousCodeFilter($_order->getBillingAddress()->getFormated(true)) ?></address>
         </fieldset>
     </div>
 </div>
@@ -167,7 +167,7 @@ $orderStoreDate = $this->formatDate($_order->getCreatedAtStoreDate(), 'medium',
             <div class="tools"><?php echo $this->getAddressEditLink($_order->getShippingAddress())?></div>
         </div>
         <fieldset>
-            <address><?php echo $_order->getShippingAddress()->getFormated(true) ?></address>
+            <address><?php echo $this->maliciousCodeFilter($_order->getShippingAddress()->getFormated(true)) ?></address>
         </fieldset>
     </div>
 </div>
diff --git a/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml b/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
index 744e6ab..3e72f55 100644
--- a/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
+++ b/app/design/adminhtml/default/default/template/system/currency/rate/matrix.phtml
@@ -38,7 +38,7 @@ $_rates = ( $_newRates ) ? $_newRates : $_oldRates;
             <tr class="headings">
                 <th class="a-right">&nbsp;</th>
                 <?php $_i = 0; foreach( $this->getAllowedCurrencies() as $_currencyCode ): ?>
-                    <th class="<?php echo (( ++$_i == (sizeof($this->getAllowedCurrencies())) ) ? 'last' : '' ) ?> a-right"><strong><?php echo $_currencyCode ?><strong></th>
+                    <th class="<?php echo (( ++$_i == (sizeof($this->getAllowedCurrencies())) ) ? 'last' : '' ) ?> a-right"><strong><?php echo $this->escapeHtml($_currencyCode) ?><strong></th>
                 <?php endforeach; ?>
             </tr>
         </thead>
@@ -47,16 +47,16 @@ $_rates = ( $_newRates ) ? $_newRates : $_oldRates;
             <?php if( isset($_rates[$_currencyCode]) && is_array($_rates[$_currencyCode])): ?>
                 <?php foreach( $_rates[$_currencyCode] as $_rate => $_value ): ?>
                     <?php if( ++$_j == 1 ): ?>
-                        <td class="a-right"><strong><?php echo $_currencyCode ?></strong></td>
+                        <td class="a-right"><strong><?php echo $this->escapeHtml($_currencyCode) ?></strong></td>
                         <td class="a-right">
-                            <input type="text" name="rate[<?php echo $_currencyCode ?>][<?php echo $_rate ?>]" value="<?php echo ( $_currencyCode == $_rate ) ? '1.0000' : ($_value>0 ? $_value : (isset($_oldRates[$_currencyCode][$_rate]) ? $_oldRates[$_currencyCode][$_rate] : '')) ?>" <?php echo ( $_currencyCode == $_rate ) ? 'class="input-text input-text-disabled" readonly="true"' : 'class="input-text"' ?> />
+                            <input type="text" name="rate[<?php echo $this->escapeHtml($_currencyCode) ?>][<?php echo $this->escapeHtml($_rate) ?>]" value="<?php echo ( $_currencyCode == $_rate ) ? '1.0000' : ($_value>0 ? $_value : (isset($_oldRates[$_currencyCode][$_rate]) ? $_oldRates[$_currencyCode][$_rate] : '')) ?>" <?php echo ( $_currencyCode == $_rate ) ? 'class="input-text input-text-disabled" readonly="true"' : 'class="input-text"' ?> />
                             <?php if( isset($_newRates) && $_currencyCode != $_rate && isset($_oldRates[$_currencyCode][$_rate]) ): ?>
                             <br /><span class="old-rate"><?php echo $this->__('Old rate:') ?> <?php echo $_oldRates[$_currencyCode][$_rate] ?></span>
                             <?php endif; ?>
                         </td>
                     <?php else: ?>
                         <td class="a-right">
-                            <input type="text" name="rate[<?php echo $_currencyCode ?>][<?php echo $_rate ?>]" value="<?php echo ( $_currencyCode == $_rate ) ? '1.0000' : ($_value>0 ? $_value : (isset($_oldRates[$_currencyCode][$_rate]) ? $_oldRates[$_currencyCode][$_rate] : '')) ?>" <?php echo ( $_currencyCode == $_rate ) ? 'class="input-text input-text-disabled" readonly="true"' : 'class="input-text"' ?> />
+                            <input type="text" name="rate[<?php echo $this->escapeHtml($_currencyCode) ?>][<?php echo $this->escapeHtml($_rate) ?>]" value="<?php echo ( $_currencyCode == $_rate ) ? '1.0000' : ($_value>0 ? $_value : (isset($_oldRates[$_currencyCode][$_rate]) ? $_oldRates[$_currencyCode][$_rate] : '')) ?>" <?php echo ( $_currencyCode == $_rate ) ? 'class="input-text input-text-disabled" readonly="true"' : 'class="input-text"' ?> />
                             <?php if( isset($_newRates)  && $_currencyCode != $_rate && isset($_oldRates[$_currencyCode][$_rate]) ): ?>
                             <br /><span class="old-rate"><?php echo $this->__('Old rate:') ?> <?php echo $_oldRates[$_currencyCode][$_rate] ?></span>
                             <?php endif; ?>
diff --git a/app/design/adminhtml/default/default/template/widget/instance/js.phtml b/app/design/adminhtml/default/default/template/widget/instance/js.phtml
index d0322d6..8774a41 100644
--- a/app/design/adminhtml/default/default/template/widget/instance/js.phtml
+++ b/app/design/adminhtml/default/default/template/widget/instance/js.phtml
@@ -27,18 +27,18 @@
 <script type="text/javascript">
 //<![CDATA[
 function setSettings(urlTemplate, typeElement, packageThemeElement) {
-    if (!editForm.validate()) {
+    if (editForm.validator && editForm.validator.validate()) {
+        typeElement = $F(typeElement).replace(/\//g, '-');
+        packageThemeElement = $F(packageThemeElement).split(/\//g);
+
+        setLocation(new Template(urlTemplate, /(^|.|\r|\n)({{(\w+)}})/).evaluate({
+            'type': typeElement,
+            'package': packageThemeElement[0],
+            'theme': packageThemeElement[1]
+        }));
+    } else {
         return false;
     }
-
-    typeElement = $F(typeElement).replace(/\//g, '-');
-    packageThemeElement = $F(packageThemeElement).split(/\//g);
-
-    setLocation(new Template(urlTemplate, /(^|.|\r|\n)({{(\w+)}})/).evaluate({
-        'type':    typeElement,
-        'package': packageThemeElement[0],
-        'theme':   packageThemeElement[1]
-    }));
 }
 
 function saveAndContinueEdit() {
diff --git a/app/locale/en_US/Mage_Adminhtml.csv b/app/locale/en_US/Mage_Adminhtml.csv
index 08b087b..9202250 100644
--- a/app/locale/en_US/Mage_Adminhtml.csv
+++ b/app/locale/en_US/Mage_Adminhtml.csv
@@ -41,7 +41,7 @@
 "<h1 class=""page-heading"">404 Error</h1><p>Page not found.</p>","<h1 class=""page-heading"">404 Error</h1><p>Page not found.</p>"
 "<strong>%s</strong> requests access to your account","<strong>%s</strong> requests access to your account"
 "<strong>Attention</strong>: Captcha is case sensitive.","<strong>Attention</strong>: Captcha is case sensitive."
-"A user with the same user name or email aleady exists.","A user with the same user name or email aleady exists."
+"A user with the same user name or email already exists.","A user with the same user name or email already exists."
 "API Key","API Key"
 "API Key Confirmation","API Key Confirmation"
 "ASCII","ASCII"
@@ -273,6 +273,7 @@
 "Currency ""%s"" is used as %s in %s.","Currency ""%s"" is used as %s in %s."
 "Currency Information","Currency Information"
 "Currency Setup Section","Currency Setup Section"
+"Currency doesn\'t exist.","Currency doesn\'t exist."
 "Current Admin Password","Current Admin Password"
 "Current Configuration Scope:","Current Configuration Scope:"
 "Current Month","Current Month"
@@ -499,6 +500,7 @@
 "Invalid password reset token.","Invalid password reset token."
 "Invalid response","Invalid response"
 "Invalid sender name ""%s"". Please use only visible characters and spaces.","Invalid sender name ""%s"". Please use only visible characters and spaces."
+"Invalid template data.","Invalid template data."
 "Invalid template path used in layout update.","Invalid template path used in layout update."
 "Invalid timezone","Invalid timezone"
 "Invalidated","Invalidated"
@@ -936,6 +938,7 @@
 "Self-assigned roles cannot be deleted.","Self-assigned roles cannot be deleted."
 "Sender","Sender"
 "Separate Email","Separate Email"
+"Serialized data is incorrect","Serialized data is incorrect"
 "Shipment #%s comment added","Shipment #%s comment added"
 "Shipment #%s created","Shipment #%s created"
 "Shipment Comments","Shipment Comments"
diff --git a/app/locale/en_US/Mage_Authorizenet.csv b/app/locale/en_US/Mage_Authorizenet.csv
index 4b8644d..47bc920 100644
--- a/app/locale/en_US/Mage_Authorizenet.csv
+++ b/app/locale/en_US/Mage_Authorizenet.csv
@@ -3,6 +3,7 @@
 "Accepted Currency","Accepted Currency"
 "Amount of %s approved by payment gateway. Transaction ID: ""%s"".","Amount of %s approved by payment gateway. Transaction ID: ""%s""."
 "Authorize.net Direct Post","Authorize.net Direct Post"
+"Authorize.net Direct Post (Deprecated)","Authorize.net Direct Post (Deprecated)"
 "Card Verification Number","Card Verification Number"
 "Card Verification Number Visual Reference","Card Verification Number Visual Reference"
 "Close","Close"
diff --git a/app/locale/en_US/Mage_CatalogRule.csv b/app/locale/en_US/Mage_CatalogRule.csv
index 17124ed..6c27f37 100644
--- a/app/locale/en_US/Mage_CatalogRule.csv
+++ b/app/locale/en_US/Mage_CatalogRule.csv
@@ -60,5 +60,6 @@
 "Update product's %s %s: %s","Update product's %s %s: %s"
 "Website","Website"
 "Websites","Websites"
+"Wrong rule specified","Wrong rule specified"
 "Wrong rule specified.","Wrong rule specified."
 "Yes","Yes"
diff --git a/app/locale/en_US/Mage_Core.csv b/app/locale/en_US/Mage_Core.csv
index 607dc45..b77a1d8 100644
--- a/app/locale/en_US/Mage_Core.csv
+++ b/app/locale/en_US/Mage_Core.csv
@@ -112,6 +112,7 @@
 "Developer Client Restrictions","Developer Client Restrictions"
 "Disable Email Communications","Disable Email Communications"
 "Disable Modules Output","Disable Modules Output"
+"Disallowed template variable method.","Disallowed template variable method."
 "Display Demo Store Notice","Display Demo Store Notice"
 "Duplicate Of Template Name","Duplicate Of Template Name"
 "Edit Design Change","Edit Design Change"
diff --git a/app/locale/en_US/Mage_Paygate.csv b/app/locale/en_US/Mage_Paygate.csv
index 853b077..c869b19 100644
--- a/app/locale/en_US/Mage_Paygate.csv
+++ b/app/locale/en_US/Mage_Paygate.csv
@@ -8,6 +8,7 @@
 "Authorize and Capture","Authorize and Capture"
 "Authorize.Net Transaction ID %s","Authorize.Net Transaction ID %s"
 "Authorize.net","Authorize.net"
+"Authorize.net (Deprecated)","Authorize.net (Deprecated)"
 "Cancel","Cancel"
 "Centinel API URL","Centinel API URL"
 "Credit Card Types","Credit Card Types"
diff --git a/app/locale/en_US/Mage_Sales.csv b/app/locale/en_US/Mage_Sales.csv
index 5f4a7c6..979837a 100644
--- a/app/locale/en_US/Mage_Sales.csv
+++ b/app/locale/en_US/Mage_Sales.csv
@@ -288,6 +288,7 @@
 "Invalid draw line data. Please define ""lines"" array.","Invalid draw line data. Please define ""lines"" array."
 "Invalid entity model","Invalid entity model"
 "Invalid item option format.","Invalid item option format."
+"Invalid order data.","Invalid order data."
 "Invalid qty to invoice item ""%s""","Invalid qty to invoice item ""%s"""
 "Invalid qty to refund item ""%s""","Invalid qty to refund item ""%s"""
 "Invalid qty to ship for item ""%s""","Invalid qty to ship for item ""%s"""
diff --git a/app/locale/en_US/Mage_Sitemap.csv b/app/locale/en_US/Mage_Sitemap.csv
index 8ae5a94..9af7d8e 100644
--- a/app/locale/en_US/Mage_Sitemap.csv
+++ b/app/locale/en_US/Mage_Sitemap.csv
@@ -25,6 +25,7 @@
 "Path","Path"
 "Please create the specified folder ""%s"" before saving the sitemap.","Please create the specified folder ""%s"" before saving the sitemap."
 "Please define correct path","Please define correct path"
+"Please enter a sitemap name with at most %s characters.","Please enter a sitemap name with at most %s characters."
 "Please make sure that ""%s"" is writable by web-server.","Please make sure that ""%s"" is writable by web-server."
 "Please use only letters (a-z or A-Z), numbers (0-9) or underscore (_) in the filename. No spaces or other characters are allowed.","Please use only letters (a-z or A-Z), numbers (0-9) or underscore (_) in the filename. No spaces or other characters are allowed."
 "Priority","Priority"
diff --git a/dev/tests/functional/credentials.xml.dist b/dev/tests/functional/credentials.xml.dist
index df9001e..efc119b 100644
--- a/dev/tests/functional/credentials.xml.dist
+++ b/dev/tests/functional/credentials.xml.dist
@@ -75,6 +75,7 @@
 
     <field path="section/payment_authorizenet_directpost_login/value" value=""/>
     <field path="section/payment_authorizenet_directpost_trans_key/value" value=""/>
+    <field path="section/payment_authorizenet_directpost_signature_key/value" value=""/>
     <field path="section/payment_authorizenet_directpost_trans_md5/value" value=""/>
     <field path="section/payment_authorizenet_directpost_cgi_url/value" value=""/>
 
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
index 48c9b1a..870b6ae 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/CreateAdminUserEntityTest.xml
@@ -68,7 +68,6 @@
             <data name="user/data/role_id/dataset" xsi:type="string">administrators</data>
             <data name="duplicatedParam" xsi:type="string">username</data>
             <data name="user/data/current_password" xsi:type="string">123123q</data>
-            <data name="issue" xsi:type="string">Bug: MPERF-6585: Typo mistake in User already exists error message.</data>
             <constraint name="Mage\Admin\Test\Constraint\AssertUserDuplicateMessage" />
         </variation>
         <variation name="CreateAdminUserEntityTestVariation4" firstConstraint="Mage\Admin\Test\Constraint\AssertUserDuplicateMessage" method="test">
@@ -82,7 +81,6 @@
             <data name="user/data/role_id/dataset" xsi:type="string">administrators</data>
             <data name="duplicatedParam" xsi:type="string">email</data>
             <data name="user/data/current_password" xsi:type="string">123123q</data>
-            <data name="issue" xsi:type="string">Bug: MPERF-6585: Typo mistake in User already exists error message.</data>
             <constraint name="Mage\Admin\Test\Constraint\AssertUserDuplicateMessage" />
         </variation>
         <variation name="CreateAdminUserEntityTestVariation5" firstConstraint="Mage\Admin\Test\Constraint\AssertUserSuccessSaveMessage" method="test">
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
index 6076c3a..6c44cdb 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.php
@@ -132,7 +132,7 @@ class UseAclRoleWithRestrictedGwsScopeTest extends Injectable
     {
         $userData = $user->getData();
         $userData['role_id'] = ['role' => $role];
-        unset($userData['user_id']);
+        unset($userData['user_id'], $userData['password'], $userData['password_confirmation']);
 
         return $this->fixtureFactory->createByCode('user', ['data' => $userData]);
     }
diff --git a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
index adc4a9a..822fe30 100644
--- a/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Admin/Test/TestCase/UseAclRoleWithRestrictedGwsScopeTest.xml
@@ -28,7 +28,6 @@
 <config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../vendor/magento/mtf/etc/variations.xsd">
     <testCase name="Mage\Admin\Test\TestCase\UseAclRoleWithRestrictedGwsScopeTest" summary="UseAclRoleWithRestrictedGwsScopeTest">
         <variation name="UseAclRoleWithRestrictedGwsScopeTestVariation1" method="test">
-            <data name="issue" xsi:type="string">Bug: MPERF-8851: Admin cannot create new admin user with any password which have been used earlier.</data>
             <constraint name="Mage\Admin\Test\Constraint\AssertUserSuccessLogin" />
             <constraint name="Mage\Admin\Test\Constraint\AssertUserWithRestrictedResources" />
         </variation>
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
index 96e90de..b1fb170 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/Block/System/Store/Delete/Website.php
@@ -34,6 +34,13 @@ use Magento\Mtf\Block\Form;
 class Website extends Form
 {
     /**
+     * Action buttons container.
+     *
+     * @var string
+     */
+    protected $buttonContainer = '.content-footer';
+
+    /**
      * 'Delete Website' button css selector.
      *
      * @var string
@@ -51,4 +58,14 @@ class Website extends Form
         $this->_fill($mapping);
         $this->_rootElement->find($this->delete)->click();
     }
+
+    /**
+     * Check whether element is visible
+     *
+     * @return bool
+     */
+    public function isVisible()
+    {
+        return $this->_rootElement->find($this->buttonContainer)->isVisible();
+    }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
index d55405b..de0045f 100644
--- a/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
+++ b/dev/tests/functional/tests/app/Mage/Adminhtml/Test/TestStep/DeleteWebsiteStep.php
@@ -94,7 +94,10 @@ class DeleteWebsiteStep implements TestStepInterface
             $this->storeIndex->open();
             $this->storeIndex->getStoreGrid()->openWebsite($websiteName);
             $this->editWebsite->getFormPageActions()->delete();
-            $this->deleteWebsite->getForm()->delete();
+            $deleteWebsiteForm = $this->deleteWebsite->getForm();
+            if ($deleteWebsiteForm->isVisible()) {
+                $deleteWebsiteForm->delete();
+            }
         }
     }
 }
diff --git a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
index 0aaa07c..89f5d5d 100644
--- a/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
+++ b/dev/tests/functional/tests/app/Mage/Authorizenet/Test/Repository/ConfigData.xml
@@ -175,6 +175,12 @@
                 <item name="label" xsi:type="string"/>
                 <item name="value" xsi:type="string"/>
             </field>
+            <field name="payment/authorizenet_directpost/signature_key" xsi:type="array">
+                <item name="scope" xsi:type="string">payment</item>
+                <item name="scope_id" xsi:type="number">1</item>
+                <item name="label" xsi:type="string"/>
+                <item name="value" xsi:type="string"/>
+            </field>
             <field name="payment/authorizenet_directpost/trans_md5" xsi:type="array">
                 <item name="scope" xsi:type="string">payment</item>
                 <item name="scope_id" xsi:type="number">1</item>
@@ -239,6 +245,12 @@
                 <item name="label" xsi:type="string"/>
                 <item name="value" xsi:type="string"/>
             </field>
+            <field name="payment/authorizenet_directpost/signature_key" xsi:type="array">
+                <item name="scope" xsi:type="string">payment</item>
+                <item name="scope_id" xsi:type="number">1</item>
+                <item name="label" xsi:type="string"/>
+                <item name="value" xsi:type="string"/>
+            </field>
             <field name="payment/authorizenet_directpost/trans_md5" xsi:type="array">
                 <item name="scope" xsi:type="string">payment</item>
                 <item name="scope_id" xsi:type="number">1</item>
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
index 047e213..cf36f54 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/Constraint/AssertProductSpecialPriceNotLargerActual.php
@@ -41,7 +41,7 @@ class AssertProductSpecialPriceNotLargerActual extends AbstractConstraint
     /**
      * Text value to be checked.
      */
-    const ERROR_MESSAGE = 'The Special Price is active only when lower than the Actual Price';
+    const ERROR_MESSAGE = 'The Special Price is active only when lower than the Actual Price.';
 
     /**
      * Assert that special price can't be larger, than actual.
@@ -53,7 +53,7 @@ class AssertProductSpecialPriceNotLargerActual extends AbstractConstraint
     public function processAssert(CatalogProductNew $productPage, InjectableFixture $product)
     {
         $errorMessages = $productPage->getProductForm()->getRequireNoticeAttributes($product);
-        \PHPUnit_Framework_Assert::assertEquals(self::ERROR_MESSAGE, $errorMessages['special_price']);
+        \PHPUnit_Framework_Assert::assertEquals(self::ERROR_MESSAGE, $errorMessages['prices']['specialprice']);
     }
 
     /**
diff --git a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
index 968d8ed..dfc44d9 100644
--- a/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
+++ b/dev/tests/functional/tests/app/Mage/Catalog/Test/TestCase/Product/CreateSimpleProductEntityTest.xml
@@ -252,7 +252,6 @@
             <data name="product/data/stock_data/qty" xsi:type="string">658</data>
             <data name="product/data/stock_data/is_in_stock" xsi:type="string">In Stock</data>
             <data name="configData" xsi:type="string">-</data>
-            <data name="issue" xsi:type="string">Bug: MPERF-5976: Special Price can be larger than Actual Price</data>
             <constraint name="Mage\Catalog\Test\Constraint\AssertProductSpecialPriceNotLargerActual" />
         </variation>
         <variation name="CreateSimpleProductEntityTestVariation11" firstConstraint="Mage\Catalog\Test\Constraint\AssertProductSaveMessage" method="test">
diff --git a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
index 6e1e25c..dbd55df 100644
--- a/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
+++ b/dev/tests/functional/tests/app/Mage/Cms/Test/TestCase/CreateCmsPageEntityTest.php
@@ -148,7 +148,11 @@ class CreateCmsPageEntityTest extends Injectable
                 $this->storeIndex->open();
                 $this->storeIndex->getStoreGrid()->openStore($store);
                 $this->editStore->getFormPageActions()->delete();
-                $this->deleteStore->getFormPageActions()->delete();
+                $deleteStoreFormPageActions = $this->deleteStore->getFormPageActions();
+                if ($deleteStoreFormPageActions->isVisible()) {
+                    $this->deleteStore->getForm()->fillForm();
+                    $deleteStoreFormPageActions->delete();
+                }
             }
         }
     }
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
index 2b605da..b677a1a 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/Cc.xml
@@ -26,7 +26,7 @@
  */
 -->
 <config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../vendor/magento/mtf/etc/fixture.xsd">
-    <fixture name="Cc" module="Mage_Payment" type="flat" repository_class="Mage\Payment\Test\Repository\Cc" class="Mage\Payment\Test\Fixture\Cc">
+    <fixture name="cc" module="Mage_Payment" type="flat" repository_class="Mage\Payment\Test\Repository\Cc" class="Mage\Payment\Test\Fixture\Cc">
         <field name="cc_type"/>
         <field name="cc_number"/>
         <field name="cc_exp_month"/>
diff --git a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
index 40f968c..2e391f2 100644
--- a/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
+++ b/dev/tests/functional/tests/app/Mage/Payment/Test/Fixture/ValidationPassword.xml
@@ -26,7 +26,7 @@
  */
 -->
 <config xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:noNamespaceSchemaLocation="../../../../../../vendor/magento/mtf/etc/fixture.xsd">
-    <fixture name="ValidationPassword" module="Mage_Payment" type="flat" repository_class="Mage\Payment\Test\Repository\ValidationPassword" class="Mage\Payment\Test\Fixture\ValidationPassword">
+    <fixture name="validationPassword" module="Mage_Payment" type="flat" repository_class="Mage\Payment\Test\Repository\ValidationPassword" class="Mage\Payment\Test\Fixture\ValidationPassword">
         <field name="validationPassword"/>
     </fixture>
 </config>
diff --git a/downloader/Maged/Controller.php b/downloader/Maged/Controller.php
index 6707ccd..0778b90 100644
--- a/downloader/Maged/Controller.php
+++ b/downloader/Maged/Controller.php
@@ -1074,7 +1074,7 @@ final class Maged_Controller
             'major'     => '1',
             'minor'     => '9',
             'revision'  => '4',
-            'patch'     => '1',
+            'patch'     => '2',
             'stability' => '',
             'number'    => '',
         );
diff --git a/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js b/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
index 88c6f7d..8fb09cf 100644
--- a/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
+++ b/js/mage/adminhtml/wysiwyg/tiny_mce/setup.js
@@ -365,6 +365,7 @@ tinyMceWysiwygSetup.prototype =
             theme_advanced_resizing : true,
             convert_urls : false,
             relative_urls : false,
+            media_disable_flash : this.config.media_disable_flash,
             content_css: this.config.content_css,
             custom_popup_css: this.config.popup_css,
             magentowidget_url: this.config.widget_window_url,
diff --git a/js/tiny_mce/plugins/media/js/media.js b/js/tiny_mce/plugins/media/js/media.js
index 89cea2a..b3f7e99 100644
--- a/js/tiny_mce/plugins/media/js/media.js
+++ b/js/tiny_mce/plugins/media/js/media.js
@@ -483,7 +483,7 @@
 			html += '<select id="media_type" name="media_type" onchange="Media.formToData(\'type\');">';
 			html += option("video");
 			html += option("audio");
-			html += option("flash", "object");
+			html += editor.getParam("media_disable_flash") ? '' : option("flash", "object");
 			html += option("quicktime", "object");
 			html += option("shockwave", "object");
 			html += option("windowsmedia", "object");
diff --git a/js/varien/js.js b/js/varien/js.js
index 2e0b253..064029f 100644
--- a/js/varien/js.js
+++ b/js/varien/js.js
@@ -717,3 +717,40 @@ if ((typeof Range != "undefined") && !Range.prototype.createContextualFragment)
         return frag;
     };
 }
+
+/**
+ * Create form element. Set parameters into it and send
+ *
+ * @param url
+ * @param parametersArray
+ * @param method
+ */
+Varien.formCreator = Class.create();
+Varien.formCreator.prototype = {
+    initialize : function(url, parametersArray, method) {
+        this.url = url;
+        this.parametersArray = JSON.parse(parametersArray);
+        this.method = method;
+        this.form = '';
+
+        this.createForm();
+        this.setFormData();
+    },
+    createForm : function() {
+        this.form = new Element('form', { 'method': this.method, action: this.url });
+    },
+    setFormData : function () {
+        for (var key in this.parametersArray) {
+            Element.insert(
+                this.form,
+                new Element('input', { name: key, value: this.parametersArray[key], type: 'hidden' })
+            );
+        }
+    }
+};
+
+function customFormSubmit(url, parametersArray, method) {
+    var createdForm = new Varien.formCreator(url, parametersArray, method);
+    Element.insert($$('body')[0], createdForm.form);
+    createdForm.form.submit();
+}
diff --git a/lib/phpseclib/PHP/Compat/Function/array_fill.php b/lib/phpseclib/PHP/Compat/Function/array_fill.php
index 79b5312..7eb231a 100644
--- a/lib/phpseclib/PHP/Compat/Function/array_fill.php
+++ b/lib/phpseclib/PHP/Compat/Function/array_fill.php
@@ -14,6 +14,7 @@
  * @version     $Revision: 1.1 $
  * @since       PHP 4.2.0
  */
+/*
 function php_compat_array_fill($start_index, $num, $value)
 {
     if ($num <= 0) {
@@ -39,3 +40,4 @@ if (!function_exists('array_fill')) {
         return php_compat_array_fill($start_index, $num, $value);
     }
 }
+*/
diff --git a/lib/phpseclib/PHP/Compat/Function/bcpowmod.php b/lib/phpseclib/PHP/Compat/Function/bcpowmod.php
index 4c162b8..0366fef 100644
--- a/lib/phpseclib/PHP/Compat/Function/bcpowmod.php
+++ b/lib/phpseclib/PHP/Compat/Function/bcpowmod.php
@@ -15,6 +15,7 @@
  * @since       PHP 5.0.0
  * @require     PHP 4.0.0 (user_error)
  */
+/*
 function php_compat_bcpowmod($x, $y, $modulus, $scale = 0)
 {
     // Sanity check
@@ -64,3 +65,4 @@ if (!function_exists('bcpowmod')) {
         return php_compat_bcpowmod($x, $y, $modulus, $scale);
     }
 }
+*/
diff --git a/lib/phpseclib/PHP/Compat/Function/str_split.php b/lib/phpseclib/PHP/Compat/Function/str_split.php
index 8f5179b..607e5ca 100644
--- a/lib/phpseclib/PHP/Compat/Function/str_split.php
+++ b/lib/phpseclib/PHP/Compat/Function/str_split.php
@@ -12,6 +12,7 @@
  * @since       PHP 5
  * @require     PHP 4.0.0 (user_error)
  */
+/*
 function php_compat_str_split($string, $split_length = 1)
 {
     if (!is_scalar($split_length)) {
@@ -57,3 +58,4 @@ if (!function_exists('str_split')) {
         return php_compat_str_split($string, $split_length);
     }
 }
+*/
diff --git a/var/package/Cm_RedisSession-1.9.4.1.xml b/var/package/Cm_RedisSession-1.9.4.1.xml
deleted file mode 100644
index 77f4ff1..0000000
--- a/var/package/Cm_RedisSession-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Cm_RedisSession</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Redis session</summary>
-    <description>Redis seesion</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:40</time>
-    <contents><target name="magecommunity"><dir name="Cm"><dir name="RedisSession"><dir name="Model"><file name="Session.php" hash="8a751a32ac85da38237012f6c4ac9077"/></dir><dir name="etc"><file name="config.xml" hash="6b32aa3b331c4504c44a7c01a24a0d3d"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Cm_RedisSession.xml" hash="f36278d589fa562d20d5182c8864a3dd"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Cm_RedisSession-1.9.4.2.xml b/var/package/Cm_RedisSession-1.9.4.2.xml
new file mode 100644
index 0000000..334d28f
--- /dev/null
+++ b/var/package/Cm_RedisSession-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Cm_RedisSession</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Redis session</summary>
+    <description>Redis seesion</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:57:59</time>
+    <contents><target name="magecommunity"><dir name="Cm"><dir name="RedisSession"><dir name="Model"><file name="Session.php" hash="8a751a32ac85da38237012f6c4ac9077"/></dir><dir name="etc"><file name="config.xml" hash="6b32aa3b331c4504c44a7c01a24a0d3d"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Cm_RedisSession.xml" hash="f36278d589fa562d20d5182c8864a3dd"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Adminhtml_Default-1.9.4.1.xml b/var/package/Interface_Adminhtml_Default-1.9.4.1.xml
deleted file mode 100644
index 722653a..0000000
--- a/var/package/Interface_Adminhtml_Default-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Adminhtml_Default</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Adminhtml</summary>
-    <description>Default interface for Adminhtml</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:40</time>
-    <contents><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="admin.xml" hash="dabe4a475e4bf891511520bb6127f887"/><file name="adminnotification.xml" hash="e3256c86976aac2056639c32001e8a0e"/><file name="api2.xml" hash="efa54fd6c59a1363bbe94c2bb8cfa890"/><file name="authorizenet.xml" hash="d7271b7b3fc35527209a3b04d57faff8"/><file name="bundle.xml" hash="b0b01c2c65ecf1bdcbcf14e28652b6f5"/><file name="captcha.xml" hash="b6a1b4b09245c75f1241b9c99686ee01"/><file name="catalog.xml" hash="63e9d4a5a4e684ce8d5f15407bd7e86b"/><file name="cms.xml" hash="0f94e157fc39272346cd117bf03f11d5"/><file name="connect.xml" hash="8e42fad0013633415525519d1d552fe4"/><file name="currencysymbol.xml" hash="956e1b2151a6c4fd61cf9978a5f8bc1c"/><file name="customer.xml" hash="27af64a8a5056032b918c95b9ff6f9f3"/><file name="dataflow.xml" hash="258e1380e65a62933ea37307d28ed23f"/><file name="downloadable.xml" hash="57bd6002f68c57cb4167290c92334216"/><file name="giftmessage.xml" hash="0954ee5081b424d41f7e168c232a8447"/><file name="importexport.xml" hash="5519e7dc10ee490f202f4927382e2b23"/><file name="index.xml" hash="c59a9d2f223297d33415d843c5ea4846"/><file name="main.xml" hash="27918ac6cb9dfaf1cba090cb800e83a4"/><file name="newsletter.xml" hash="eabb130f32301344970d65dc77fe9599"/><file name="oauth.xml" hash="3cc70c9ac89bbfacbd3a9f3289e26b9b"/><file name="pagecache.xml" hash="f33b8e37be4ab1dc681acbe7ffbe139e"/><file name="promo.xml" hash="20fd585dcaa9e830e09afb24212099ad"/><file name="report.xml" hash="cce97c488e21e10541e0a3d64bcf7b6b"/><file name="rss.xml" hash="604fb320683986266541ba4ff50e3ae7"/><file name="sales.xml" hash="afe4642654d3f556305a647805602861"/><file name="search.xml" hash="bea5b486b22bfd3ee84fc0e21826a88f"/><file name="tag.xml" hash="6fbf0da651787c6a8de2ea803db2c637"/><file name="tax.xml" hash="ed660cff4c94190b2825e41840731c19"/><file name="widget.xml" hash="6be580bc1ac273a9a0ccfe75f468e587"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="735c9ec66d1309f1206294f075fdcdd1"/></dir></dir><dir name="template"><file name="access_denied.phtml" hash="ff7e7628c69f5a6faf22ddb1c319ab55"/><dir name="api"><file name="role_users_grid_js.phtml" hash="bfd03f411c01f8c1eb8f60811afc65a6"/><file name="roleinfo.phtml" hash="ddb5db43337c1054fbee387945a91109"/><file name="roles.phtml" hash="420fbd2e487d332b71dddc3189a72ac3"/><file name="rolesedit.phtml" hash="236eec97598cfcabefe5694a08eb442c"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="e50593a7a375c0674b57c60b84bd294a"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="api2"><dir name="attribute"><file name="buttons.phtml" hash="b211cd2ef5c0515190f089fb70faef0e"/><file name="resource.phtml" hash="82b6b6062beb93e8d0f80e64b618a1b6"/></dir><dir name="permissions"><dir name="user"><dir name="edit"><dir name="tab"><dir name="roles"><file name="js.phtml" hash="19a9dee2c3675077d20d20b2fe9b7081"/></dir></dir></dir></dir></dir><dir name="role"><file name="buttons.phtml" hash="48f39c0ff4d551453dbaf74b38dfed97"/><file name="users_grid_js.phtml" hash="5b38183975d7068df675d2e74f32f944"/></dir></dir><dir name="authorizenet"><dir name="directpost"><file name="iframe.phtml" hash="ee7d99c196525961e4426023ed1f71d6"/><file name="info.phtml" hash="7af4958ced9ed0b820e31414712314e1"/></dir></dir><dir name="backup"><file name="dialogs.phtml" hash="1ab3bd9dd2d0dc4fe71e3ec05929bdfa"/><file name="left.phtml" hash="28abce5769ea95892ee4ffc0954e2682"/><file name="list.phtml" hash="3c5d531e2c6da63fd4f7628308f08051"/></dir><dir name="bundle"><dir name="product"><dir name="composite"><dir name="fieldset"><dir name="options"><file name="bundle.phtml" hash="13c049c3858aede8d9ec9c8d5bd93932"/><dir name="type"><file name="checkbox.phtml" hash="4a974f8962410393537df2bf89491e1e"/><file name="multi.phtml" hash="cb36c7cde9c2ded0f33583c201f22afa"/><file name="radio.phtml" hash="3307fc3c8236e3ea839c6d4d4ddeac95"/><file name="select.phtml" hash="860ff711964c822b79c7dbc70d408fdf"/></dir></dir></dir></dir><dir name="edit"><dir name="bundle"><dir name="option"><file name="search.phtml" hash="bed7e4793be8b2bfc39e68c6b4b7ea1f"/><file name="selection.phtml" hash="f13bd0f783f8711ed6434b1efdd37f19"/></dir><file name="option.phtml" hash="03a318c5cc7a7809ef301bdbf1e01cb7"/></dir><file name="bundle.phtml" hash="3c8c62637fe159dbea88b1f8f976f82d"/></dir></dir><dir name="sales"><dir name="creditmemo"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="bc57544cf9d1f53e0ba710cc12101ba9"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="3d68d4b17b2e26011f0b6b5839ceacb0"/></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="28d880e36253cbae2ba60f412b8ffe3b"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="197d154a2d0c1f464541037cf0131ad3"/></dir></dir></dir><dir name="order"><dir name="view"><dir name="items"><file name="renderer.phtml" hash="cb3cec0a08b12d62638c74b3da7cea69"/></dir></dir></dir><dir name="shipment"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="f97295be3a736aa634b241a804be43ea"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="998a2d676d93700cc8afa0465b8fa9ab"/></dir></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="37ca694eb77403ac744aab9101349c92"/></dir><dir name="catalog"><dir name="category"><dir name="checkboxes"><file name="tree.phtml" hash="95c7468be3636ff49a744228e47edcc8"/></dir><dir name="edit"><file name="form.phtml" hash="f17abf89515af569399d88388a94ef55"/></dir><file name="edit.phtml" hash="a4a0e994436988e9401d7f0ceb3ffd23"/><file name="tree.phtml" hash="76f3bcf4b961c262b33b09df17345f39"/><dir name="widget"><file name="tree.phtml" hash="4c079c7a8d860d5ff36fef46eada257d"/></dir></dir><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="d17e50690d1e14f9caaf5105d2b3d187"/></dir></dir></dir><dir name="product"><dir name="attribute"><file name="js.phtml" hash="fbcfb6db2da0c52ebd01a70f61b6ac5e"/><dir name="new"><file name="created.phtml" hash="f814e5ce1bf951e11a4370be354766e7"/></dir><file name="options.phtml" hash="b8a61b9f8a0817446f0d52cf739b3fb5"/><dir name="set"><dir name="main"><dir name="tree"><file name="attribute.phtml" hash="1cd780abd50e66840498ef241416ef6b"/><file name="group.phtml" hash="bc852da8df505f611965d2585972853b"/></dir></dir><file name="main.phtml" hash="a10ebf167915cbeb8aed5d76ba47d9b2"/><dir name="toolbar"><file name="add.phtml" hash="ce3c6895929df71e017ebc00c3183d78"/><file name="main.phtml" hash="615ca584ea71f9b7b8add861488894aa"/></dir></dir></dir><dir name="composite"><file name="configure.phtml" hash="31c28cd626e1059ee0d05b78df28fdea"/><dir name="fieldset"><file name="configurable.phtml" hash="571775f59c56c59a4ff6bea485b73710"/><file name="grouped.phtml" hash="843069b3d59fc05f86a2014177212569"/><dir name="options"><file name="js.phtml" hash="9c907b5b54ed2cd8ad1ec4afc45115f8"/><dir name="type"><file name="date.phtml" hash="75d46189d0e23f6aee5dbcc7ce5651c8"/><file name="default.phtml" hash="718bc5a7bd3013f43d544d3fe8ea8a77"/><file name="file.phtml" hash="00c647c6eb343bd8565f0b88ab392a39"/><file name="select.phtml" hash="277c942f79c0eb7a7b53b04643c9593d"/><file name="text.phtml" hash="acd27eac2f69153fec4e1865c787ea59"/></dir></dir><file name="options.phtml" hash="1df8f7845611e80a3f13c494b1b839ec"/><file name="qty.phtml" hash="4d0c8e4434be8c259435346d673a6dd0"/></dir></dir><file name="created.phtml" hash="1ed62146a00291e9c2b0230804f84fb7"/><dir name="edit"><dir name="action"><file name="attribute.phtml" hash="27488ec6201dc9d6820f9a788a1ada4f"/><file name="inventory.phtml" hash="52d619872155e6944f9e235111408ef7"/><file name="websites.phtml" hash="98bcd6fa5f51a0dfb57a3023272a27d2"/></dir><file name="categories.phtml" hash="81f284d1f0d81f1fa0d768cf8df4648c"/><dir name="options"><file name="option.phtml" hash="685f57480169653dde66b661bab9fe96"/><dir name="type"><file name="date.phtml" hash="d920b195727a51dac13285cc236927f7"/><file name="file.phtml" hash="c2f994dc12c6beb6fc585d6968f37e6e"/><file name="select.phtml" hash="d26e6090862d21f0d9c9cc2da834908e"/><file name="text.phtml" hash="99e1c0b3be182e27eba6a02e27c254a7"/></dir></dir><file name="options.phtml" hash="860eeb5fc3b47284ea970feb48d530a3"/><dir name="price"><file name="group.phtml" hash="aa91ad4e0d4cbe2059fd8f71a76d2e90"/><file name="tier.phtml" hash="11caea53a3f27beece051f05ebb2a8ae"/></dir><file name="serializer.phtml" hash="cc36239d24eb9233499aa8668504b9d0"/><dir name="super"><file name="config.phtml" hash="91024f4002467a6198884913e29f8da6"/></dir><file name="websites.phtml" hash="9b748765b6602c9b0ab7a6e710e96dfd"/></dir><file name="edit.phtml" hash="77abbac755fc5e40aa8d1a512f39e12c"/><dir name="helper"><file name="gallery.phtml" hash="9b662f0f2b7fa50aae506801877c319e"/></dir><file name="js.phtml" hash="fd68a3d0aa7de457a161512247d39012"/><file name="price.phtml" hash="c7950bff8c69ef04f373e05a05eaeeac"/><dir name="tab"><file name="alert.phtml" hash="2ca71d372fd28105043613448194a05a"/><file name="inventory.phtml" hash="33b3d392060951c904d71a474e898d01"/></dir><dir name="widget"><dir name="chooser"><file name="container.phtml" hash="898bcd75e7f5bc7b9ff9ef23578447c9"/></dir></dir></dir><file name="product.phtml" hash="3100e755e72f3e0459ec415076d6c2b8"/><dir name="wysiwyg"><file name="js.phtml" hash="200fe68eaccb7e5e1f1ab9f5fdb0d764"/></dir></dir><dir name="cms"><dir name="browser"><dir name="content"><file name="files.phtml" hash="edab20c3d693785605c339c829bc85bf"/><file name="newfolder.phtml" hash="d92a8c8b996e3052205465501f823d38"/><file name="uploader.phtml" hash="70f3a760ced2fe0fedd408790c808256"/></dir><file name="content.phtml" hash="911c2c7575b3697ddfbe5b54003b0480"/><file name="js.phtml" hash="3f793d09811f41ea12ab24e1d21004b7"/><file name="tree.phtml" hash="0d8036e58dc67a85c29d99ae51b24480"/></dir><dir name="page"><dir name="edit"><dir name="form"><dir name="renderer"><file name="content.phtml" hash="aa53277015b94a3632ff65600a2c132e"/></dir></dir></dir></dir></dir><file name="coming.phtml" hash="9d68f7d168d84f45f09dca6c8d5c57bb"/><dir name="connect"><dir name="extension"><dir name="custom"><file name="authors.phtml" hash="1c1e2ce7fe39bf549fea3fbb1fa25342"/><file name="contents.phtml" hash="4207fb35993aec2a4f0d2eb0fb50e587"/><file name="depends.phtml" hash="21a7c1f8a954b0bd706653776164b2c0"/><file name="load.phtml" hash="1ecf32a6aafbb1b7b79e10a7a980029a"/><file name="package.phtml" hash="f993c90b7b158b468533d7c591cc0537"/><file name="release.phtml" hash="0f17de2b77a9adc5a057f0018e5310dc"/></dir></dir></dir><dir name="currencysymbol"><file name="grid.phtml" hash="8faa3bbe598bc6bcf9e2ff2408effcc5"/></dir><dir name="customer"><dir name="edit"><file name="js.phtml" hash="a4981632e863b82ed494ccc99f3752c0"/><dir name="tab"><dir name="account"><dir name="form"><dir name="renderer"><file name="group.phtml" hash="77d7cb5f2f95ef643e0286a4605aeab8"/></dir></dir></dir><dir name="view"><dir name="grid"><file name="item.phtml" hash="204c9cd7d9b5237bf863659f2a132139"/></dir></dir></dir></dir><file name="online.phtml" hash="69ff950bec24490ffaf2831eea866169"/><dir name="sales"><dir name="order"><dir name="create"><dir name="address"><dir name="form"><dir name="renderer"><file name="vat.phtml" hash="6c63263ac2eed95d563ce140ce873b3e"/></dir></dir></dir></dir></dir></dir><dir name="system"><dir name="config"><file name="validatevat.phtml" hash="4bb7a42ea5a9a3b16bd4cfbd0c637828"/></dir></dir><dir name="tab"><file name="addresses.phtml" hash="a51dde4e46b0a6811e9db2090c23b04c"/><file name="cart.phtml" hash="517478d69773066a4ab664e08aba35d2"/><file name="newsletter.phtml" hash="3945cde3ca22107243119551245c233e"/><dir name="view"><file name="sales.phtml" hash="ce7336ea6b2f4d6daf50b88918b0dda2"/></dir><file name="view.phtml" hash="087b9d3222bcd38cb82b9be2dfc173bd"/><file name="wishlist.phtml" hash="6dee8733fd9c915efad6cb0cdb71e167"/></dir></dir><dir name="dashboard"><dir name="graph"><file name="disabled.phtml" hash="0210c1ddde1b52ad0f9a671fe84e81e0"/></dir><file name="graph.phtml" hash="e753293e33068c24515e6051a4856bc2"/><file name="grid.phtml" hash="4334e2a5bcab21ac44c0151bd9a51bf3"/><file name="index.phtml" hash="b1a268bcb5f2efb76022d68714f7f6fb"/><file name="salebar.phtml" hash="7860149f9449a9f4fd5cbccefd415d6b"/><file name="searches.phtml" hash="55227aa009d49c194950087f950041f5"/><dir name="store"><file name="switcher.phtml" hash="f0b25bc75ea67e63576a557bfe820797"/></dir><file name="totalbar.phtml" hash="5a4cd54f0075f07bec88efc9b5c47051"/></dir><dir name="directory"><dir name="js"><file name="optional_zip_countries.phtml" hash="836c6ea23ae98a076f38da313197ba08"/></dir></dir><dir name="downloadable"><dir name="product"><dir name="composite"><dir name="fieldset"><file name="downloadable.phtml" hash="5ef5535b8ce8e4bbe7659d444898f20d"/></dir></dir><dir name="edit"><dir name="downloadable"><file name="links.phtml" hash="b587b76cf094109587ac967f4e5a8120"/><file name="samples.phtml" hash="a73bf52f2ed419ad8668e57a1e3dc4ba"/></dir><file name="downloadable.phtml" hash="b66ab0dda0d0a7e096857b7e7c052174"/></dir></dir><dir name="sales"><dir name="items"><dir name="column"><dir name="downloadable"><dir name="creditmemo"><file name="name.phtml" hash="16588112504f00eec8cf47e4ce5da0d7"/></dir><dir name="invoice"><file name="name.phtml" hash="492f04ce08f8d68bd5388030ffd0d914"/></dir><file name="name.phtml" hash="187811540e032dd12b6feffd0bc598f9"/></dir></dir></dir><dir name="order"><dir name="creditmemo"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="95b422bd8627c1a8b45a1d4491d1bd93"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="3677d1c7be1a53b23a6b9f400a2935ef"/></dir></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="90bad224de57564dd250c37570595a21"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="9976312d106cd236ba87262d0a0cf54d"/></dir></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="c4ecbc15d7481fed9903b3dde6cb76d1"/></dir></dir></dir></dir></dir></dir><dir name="eav"><dir name="attribute"><dir name="edit"><file name="js.phtml" hash="1cd780abd50e66840498ef241416ef6b"/></dir><file name="options.phtml" hash="b62b35584ad6044df0a267434728892b"/></dir></dir><dir name="email"><dir name="order"><file name="items.phtml" hash="c13bc0e0bd288da910dbb2fd84a9ce58"/></dir></dir><file name="empty.phtml" hash="0aba206a799ac0a515730f28b8ac123e"/><file name="example.phtml" hash="a17fa4912638a68fbb3877f9bc220863"/><file name="forgotpassword.phtml" hash="2761d703cab381e6569ea17f1fda83cc"/><file name="formkey.phtml" hash="a9064df4a81e204582839b8edf2aed28"/><dir name="giftmessage"><file name="form.phtml" hash="e1868bbf88971067a158cd961a289a8d"/><file name="giftoptionsform.phtml" hash="5c0ef03699b2c2508e4eb9bfd5fc3443"/><file name="helper.phtml" hash="04e9edd7d8478a71e621bfad87865f7b"/><file name="popup.phtml" hash="e5c0a9152f647cecff3b604a7e061741"/><dir name="sales"><dir name="order"><dir name="create"><file name="giftoptions.phtml" hash="ae9310c826dc5935b140c2a8d9e5fd73"/><file name="items.phtml" hash="2802f85e9f389d59e69606540285f4ef"/></dir><dir name="view"><file name="giftoptions.phtml" hash="63382086c4c32d588796f1ab21adc147"/><file name="items.phtml" hash="69fdd1217ae8b3812310a5362c219e5b"/></dir></dir></dir></dir><dir name="googlebase"><file name="captcha.phtml" hash="d77c18f68c4abd9a1bb1c19de1d53c1b"/><file name="items.phtml" hash="c885e705bda18cc3bbf90dddb94918aa"/><dir name="types"><dir name="edit"><file name="attributes.phtml" hash="4795d282786fd7700b28a53e89eaa5aa"/></dir></dir></dir><dir name="importexport"><file name="busy.phtml" hash="f9f89cd954a79ca5f279a0d4fdb6b5d5"/><dir name="export"><dir name="form"><file name="after.phtml" hash="b7f2e5154d620c04f04499feabb63bd7"/><file name="before.phtml" hash="c3f67125078e60f4dfd40e844f9acb9a"/></dir></dir><dir name="import"><dir name="form"><file name="after.phtml" hash="b42f0f4cf9c476ce84ed9962e97fc248"/><file name="before.phtml" hash="4155be820c93e301c7de2801e44fe3ed"/></dir><dir name="frame"><file name="result.phtml" hash="0c5d520411595f63ba45ed502adca5a7"/></dir></dir></dir><dir name="index"><file name="notifications.phtml" hash="fa648c216c2aefb82e2634cf657abdf7"/></dir><file name="login.phtml" hash="d263b066415db4f2a2f4eaddc4845896"/><dir name="media"><file name="editor.phtml" hash="86638654991aa6836230755dd3077527"/><file name="uploader.phtml" hash="4a5de3593d5d3ab0a117b0c04c9fc520"/></dir><dir name="newsletter"><dir name="preview"><file name="iframeswitcher.phtml" hash="11d9f85bb1aca38f02ed619f5c2494b7"/><file name="store.phtml" hash="f2acb163734214fe61b00bfa64fcab94"/></dir><dir name="problem"><file name="list.phtml" hash="b8de157e83d8c9a84b769e834029ff80"/></dir><dir name="queue"><file name="edit.phtml" hash="3f9016faa03f1873a123e6294e265624"/><file name="list.phtml" hash="0771254da01ac42a7c19cffd21916598"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir><dir name="subscriber"><file name="list.phtml" hash="dc927044644ed99d71e9f94f6c6054d2"/></dir><dir name="template"><file name="edit.phtml" hash="5cdb64a34fa36c6fe2696a8a139b9468"/><file name="list.phtml" hash="88495852292533931dd9ccc1297c22cd"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir></dir><dir name="notification"><file name="baseurl.phtml" hash="ace29ea97f986e6af7f68ff769024a08"/><file name="curl.phtml" hash="4d6bb471fc24d2fac093f5a6ba54eb2b"/><file name="formkey.phtml" hash="10cefd4b04d9167dc36b15d146d67792"/><file name="security.phtml" hash="09f80eb2e65d5f3eb864b69a8de0bb7b"/><file name="survey.phtml" hash="e81aa7a0204d2af52937c2179b3226a0"/><file name="symlink.phtml" hash="1a44ab56d54fb00ff8aa9174fbd5aacd"/><file name="toolbar.phtml" hash="c81daccdcaa9752fd63b40965991bb40"/><file name="window.phtml" hash="cc3ac0b29613c6c70262db9100c41f96"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="dabf9325f335361b849aa50056c24f94"/><file name="button.phtml" hash="d9e9b183d42e52a250ce0c5e1aa51a2d"/><file name="confirm-simple.phtml" hash="65e940cd75ab146adf369de3b6900ef5"/><file name="confirm.phtml" hash="3fd54b782715757eb7e6d94cb85ec207"/><dir name="form"><file name="login-simple.phtml" hash="2f1989f21643335d93da793c5048b40c"/><file name="login.phtml" hash="311ecd3b9fe3ac1b34a5c685754fab9a"/></dir><file name="head-simple.phtml" hash="9b1d56c7b532c4b5249df0ad5654634b"/><file name="reject-simple.phtml" hash="b424a12924735b3579d1a99f02c40779"/><file name="reject.phtml" hash="e39aeff75e3b8ddfc88dca8323e6e954"/></dir></dir><file name="overlay_popup.phtml" hash="93042aacbf5f63ac20d73af7529adb9e"/><dir name="page"><file name="footer.phtml" hash="66b29c98ee96825c589df8eb448f5c7d"/><file name="head.phtml" hash="21ef5cb055b23d9e539cd470c6227569"/><file name="header.phtml" hash="18653a55fab64c9b173bfca72ded1c93"/><dir name="js"><file name="calendar.phtml" hash="05ad9d43d629be8c5e328d40b97725b1"/><file name="translate.phtml" hash="9a4a8ff517585fae47478d963e6012c6"/></dir><file name="menu.phtml" hash="e7a10b2a4c8ac756d36c1925e54e4ccf"/><file name="notices.phtml" hash="1da5145293a029071c77817fbda3736c"/></dir><file name="page.phtml" hash="b83ddcffabe164c96979fa9f761f0e52"/><dir name="pagecache"><dir name="cache"><file name="additional.phtml" hash="fbc4928f817e21a76a876510c04134f7"/></dir></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="f30991c8c4ffe39a426e7a18b67a357e"/></dir><dir name="info"><file name="cc.phtml" hash="c07e6426f4b89547d95b7971cd40df24"/><file name="pdf.phtml" hash="44b8fe88a963653eac67d3e7e18a7e06"/></dir></dir><dir name="payment"><dir name="form"><file name="banktransfer.phtml" hash="365b2e7ad83c8fc3579fb10e21000e43"/><file name="cashondelivery.phtml" hash="9ee032367a799e485e9490300d50f923"/><file name="cc.phtml" hash="a9e654db08418dd198b1ddad0481836d"/><file name="ccsave.phtml" hash="a88ffde3b02d476b5ef8c302616662b3"/><file name="checkmo.phtml" hash="6e9a71f5bc7d249839487adcdea9e1a6"/><file name="purchaseorder.phtml" hash="6991195785bb67b47e3aaf2b19906e8e"/></dir><dir name="info"><file name="banktransfer.phtml" hash="57bf7dc47f93db636e4669dd0a13db15"/><file name="checkmo.phtml" hash="0844a4de163d70530af55a89ff4fee1a"/><file name="default.phtml" hash="34760442900ba7b17d52d6bc8d6e8732"/><dir name="pdf"><file name="checkmo.phtml" hash="331eb71760b1b91013a242adc2e7850c"/><file name="default.phtml" hash="3dbdf5ee79c5835d3e8a68bf896fe7f0"/><file name="purchaseorder.phtml" hash="b72078c393f9fc8a72469cb4f60cf740"/></dir><file name="purchaseorder.phtml" hash="66328b8bd3bffcf251e83b190aa1674c"/></dir></dir><dir name="paypal"><dir name="system"><dir name="config"><file name="api_wizard.phtml" hash="d1dcd0ac566a48d087a02d9fb5aa7681"/><file name="bml_api_wizard.phtml" hash="1edb19592c4fec6213fed297a8a7a68b"/><dir name="fieldset"><file name="global.phtml" hash="32e284583341b991d9db598d0f20562f"/><file name="hint.phtml" hash="749bdb7e9a11df10ad5ba07f1296a6d0"/><file name="store.phtml" hash="ff8de41b3fc398c7ca56f2d977c243a9"/></dir><dir name="payflowlink"><file name="advanced.phtml" hash="61e36b2fb2436c279361a8bf0a912095"/><file name="info.phtml" hash="bc613c199e8f8d876e673383a2265a17"/></dir></dir></dir></dir><dir name="permissions"><file name="role_users_grid_js.phtml" hash="039d1507a9d84a5e2afdf5d8621d54e3"/><file name="roleinfo.phtml" hash="8df7874910110a250fec05fc56e9b98e"/><file name="roles.phtml" hash="a2f4af140d0ce98fb93c7a59e13a89ef"/><file name="rolesedit.phtml" hash="d576cb5bb8ba92748cd0c63bc6d6bc2f"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="8187202fb98a78f90337e321c1d26bef"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="poll"><dir name="answers"><file name="list.phtml" hash="ab3de09500ac824dbdfa531ccc8b5148"/></dir></dir><file name="popup.phtml" hash="85b7139ff08a023f58c95469513ba241"/><dir name="promo"><file name="fieldset.phtml" hash="88f350e4aeafab8d60adbf812ebb5882"/><file name="form.phtml" hash="de3b47937cd0734513668d65a1685192"/><file name="js.phtml" hash="f583f3d25029a4e6e5543f8ef9fd4e1d"/><file name="salesrulejs.phtml" hash="59b1be9b748c984ec700d5db96cf9b4c"/></dir><dir name="rating"><file name="detailed.phtml" hash="eecfd5103a29cc884cd7769353249c3c"/><file name="options.phtml" hash="91e48ca064c209467a95ebb4106098d3"/><dir name="stars"><file name="detailed.phtml" hash="425a39a4861305eb7d488557d1f29b1f"/><file name="summary.phtml" hash="81f09d08d8f13602dbb6fc47c9e0c4dc"/></dir></dir><dir name="report"><dir name="grid"><file name="container.phtml" hash="492edaeb36c99759e601f69d09d8ce63"/></dir><file name="grid.phtml" hash="4df44d5bfe605dcf1f4de209c3251d3a"/><dir name="refresh"><file name="statistics.phtml" hash="0134889b333e23b21dd9338b5a8c672f"/></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="97ff2bbd0264f2f48655b85c31ec42d5"/></dir><file name="switcher.phtml" hash="6d59b52c5c4b637186877c1b64081733"/></dir><file name="wishlist.phtml" hash="3763e4bc8859b4dde13a882433400112"/></dir><file name="resetforgottenpassword.phtml" hash="7f718933a22551f4448477d3482d5119"/><dir name="review"><file name="add.phtml" hash="e259fc69d280b3d4f89516be872292a3"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="form.phtml" hash="38dd2395d72f2485bebe46b154e36567"/><dir name="view"><file name="form.phtml" hash="4e5530d7218b4e29fdb657f3afdd32be"/><dir name="tab"><file name="info.phtml" hash="1980a461df367b8917a1334d73e67f61"/></dir></dir></dir></dir><dir name="items"><dir name="column"><file name="name.phtml" hash="bde8b8b434583ba4a17234232b4b436d"/><file name="qty.phtml" hash="df2ef73497c3145b42497e0be0b0ac6a"/></dir><dir name="renderer"><file name="default.phtml" hash="8e6bdcd0a0e30f8bf1ff6a4a68321183"/></dir></dir><dir name="order"><dir name="address"><file name="form.phtml" hash="8d8997f272ff6f7704ae8da2309e5c26"/></dir><dir name="comments"><file name="view.phtml" hash="3e593f32eb91950ada970136e635039a"/></dir><dir name="create"><file name="abstract.phtml" hash="450fd33745d12b718eadb477cb97169a"/><dir name="billing"><dir name="method"><file name="form.phtml" hash="f373edeac1e14f15cc192104b3c06799"/></dir></dir><file name="comment.phtml" hash="89d6f617055bcaf9f017ac3325153b9d"/><dir name="coupons"><file name="form.phtml" hash="22d58a1fdece0789f9fb075d12f7655f"/></dir><file name="data.phtml" hash="844bb85968eca4ce2899a81f571a69a2"/><dir name="form"><file name="account.phtml" hash="ae06153e8c74cbf90b9192ae1cf73f3a"/><file name="address.phtml" hash="6869a9b9cafd7172eebcbbb260624f70"/></dir><file name="form.phtml" hash="91bae87423c95fa1feee87f39533c186"/><file name="giftmessage.phtml" hash="d060ea7a368d682336160e2c3a6de71e"/><dir name="items"><file name="grid.phtml" hash="1cd6c75f076b5157ec50a44870ea17b1"/></dir><file name="items.phtml" hash="81eac8351d529461343eaf3ccdd0dd75"/><file name="js.phtml" hash="57a05543973a5f3b3dc9604d7681dd61"/><dir name="newsletter"><file name="form.phtml" hash="bd490b0117568c4338318ced6558fe84"/></dir><dir name="shipping"><dir name="method"><file name="form.phtml" hash="69ab67e875d5c69f19da9200488fdbd4"/></dir></dir><dir name="sidebar"><file name="items.phtml" hash="52ef961d1108ba56b8fbd95ee6fc99b5"/></dir><file name="sidebar.phtml" hash="1491271d8b4b001e27e024072dd425d4"/><dir name="store"><file name="select.phtml" hash="b4e047779e15d495e99b71420c87b476"/></dir><dir name="totals"><file name="default.phtml" hash="e0dae5956e25f189f645d644b9bd61db"/><file name="grandtotal.phtml" hash="76c14c414df70b9e0fc2e7a1efe83ed0"/><file name="shipping.phtml" hash="8e7d48743a790b46137bcaf7adf46c4f"/><file name="subtotal.phtml" hash="75ba127e657699c654a6e32c6065a56f"/><file name="tax.phtml" hash="74594996a9b8e9f829f0e0e4177f0e09"/></dir><file name="totals.phtml" hash="7b23f88369b46bc4ab5038ec95ef83e0"/></dir><dir name="creditmemo"><dir name="create"><file name="form.phtml" hash="6c0de85b0b6f77bad60444775b1838b6"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="a082ae2d22e324e83fec20f26051f533"/><file name="default.phtml" hash="1704c99d6351e2e1abd6c330332b2cce"/></dir></dir><file name="items.phtml" hash="fa8f2d1b0b7f1a518e09a4c98b45398d"/><dir name="totals"><file name="adjustments.phtml" hash="d07ae2fccc399b065421afabb53e225d"/></dir></dir><dir name="view"><file name="form.phtml" hash="a3dee338f777091321c67d051794ac8d"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="2e13d26b8abf2c1ec41f4e934c45ff3e"/><file name="default.phtml" hash="f5d7b87ab43b377628f5f0c654ecfb75"/></dir></dir><file name="items.phtml" hash="db0d0fdfbb092d62668517474e73ab9d"/></dir></dir><file name="giftoptions.phtml" hash="af9be7a4c53bc915eafdb8c36363d4f9"/><dir name="invoice"><dir name="create"><file name="form.phtml" hash="a1c5e849f07ac623de58c44ee5bb788b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="59cb8f69057a081397a7d08b1d44de03"/><file name="default.phtml" hash="4e066e654dd4905f9248cb58e6202dc7"/></dir></dir><file name="items.phtml" hash="b59bc8cbdf561361ec74b64e57e3d6a9"/><file name="tracking.phtml" hash="e267501bbb03bcbbf0c95a0e19b2a161"/></dir><dir name="view"><file name="form.phtml" hash="670a59453a48856bf7dba0d7e3841e4b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="f3fd595909d713740f78fcc18bb165d4"/><file name="default.phtml" hash="efa3a5f3b0544d4b3453e54c511a7bdc"/></dir></dir><file name="items.phtml" hash="0b0174f23e9694f4ffb6bd4639ff222f"/></dir></dir><dir name="shipment"><dir name="create"><file name="form.phtml" hash="4b2d19de5e5522bcba94ae76f13077fe"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="47a7a02503e6ce8185f220ec014b616c"/><file name="default.phtml" hash="cb6088852de61af50134bfddfc9aadfd"/></dir></dir><file name="items.phtml" hash="2b6c3e9982fa8ec9a5986c1094ab4b37"/><file name="tracking.phtml" hash="adaaa3f1debf0abbd8369328762007e8"/></dir><dir name="packaging"><file name="grid.phtml" hash="c7149c55a5c36f0ed429484a47d12447"/><file name="packed.phtml" hash="f4f5982a47487915b4f0e281cc52ac5a"/><file name="popup.phtml" hash="781f87de153aedc68d87e918f0489505"/></dir><dir name="tracking"><file name="info.phtml" hash="936830f51a16c0304d0f5cf8440cd214"/></dir><dir name="view"><file name="form.phtml" hash="f00f611ae348eb4296063cec99e08535"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="c1088e05631ed09666d9b3027e51020b"/><file name="default.phtml" hash="14f57ff7e16a97169be8dca512309e4a"/></dir></dir><file name="items.phtml" hash="1e5e39056014e0b7c4264203a8156c95"/><file name="tracking.phtml" hash="6cfca1785d2a0023ebd96f8d822b2339"/></dir></dir><file name="totalbar.phtml" hash="9dd03f8ece3dc8a066182a63e750d3bb"/><dir name="totals"><file name="discount.phtml" hash="fe5af2981c988ee51a156066e0a5d30e"/><file name="due.phtml" hash="a8bb79f030ee27f4cc5fbd3a945aee84"/><file name="footer.phtml" hash="7a3146c9823d4412bb0431a9eb880208"/><file name="grand.phtml" hash="c42431c3da562b0c7f87717bf234de86"/><file name="item.phtml" hash="ef9cb2aa093c6b55a22d137d1798a958"/><file name="main.phtml" hash="75720ac86b02cf404f76051b29ce3e34"/><file name="paid.phtml" hash="011dd3a39e180f1ffcb10921ae6f08e3"/><file name="refunded.phtml" hash="d846f8f28c34d745e7e79c8c108286e7"/><file name="shipping.phtml" hash="729980faf9c31e1bfe5821a3378430cd"/><file name="subtotal.phtml" hash="2a87b7f269291096bd3500f6b56e357d"/><file name="tax.phtml" hash="68edfed16527ef713812dc6c8d5815ea"/></dir><file name="totals.phtml" hash="f5ea5e7f19419b72297a24a9860e9e0c"/><dir name="view"><file name="form.phtml" hash="b2ae23cf63e436a00dab747a32209d41"/><file name="giftmessage.phtml" hash="c6f8701e8c220cf71cd465310b576b36"/><file name="history.phtml" hash="fa87a814656708aaea4eaa863e22bf11"/><file name="info.phtml" hash="3aef9dc16a51f414442a59c690e573a4"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="3d3def9dad4e5842bdc182c756f0d9a3"/></dir></dir><file name="items.phtml" hash="e71776c9f5d744c972304706cb5477b6"/><dir name="tab"><file name="history.phtml" hash="801abf66aff3f3036fd9ad7ac1731fbe"/><file name="info.phtml" hash="2a7132e5976c34bab03a7fb8996fb910"/></dir><file name="tracking.phtml" hash="faf1ca869164dbd44513ca9e8a267434"/></dir></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="ad004e28a0852b50f068d37915d4d903"/></dir></dir></dir><dir name="recurring"><dir name="profile"><dir name="view"><file name="info.phtml" hash="7324c965675a482a0b0c3c7ac8e822ff"/></dir><file name="view.phtml" hash="879c3de013c31794597198feeea52531"/></dir></dir><dir name="transactions"><file name="detail.phtml" hash="9e3fa2b5112e90db65172a9a13d22574"/></dir></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="938ea5cf69346302b37a36d2a494fab2"/><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="0374f50a623b74df54a48010e5a0b587"/></dir><file name="fieldset.phtml" hash="c91fe72f4eaac1944751201191fe79a6"/></dir></dir></dir><file name="switcher.phtml" hash="1b7165f0fcee6aa73a83d369faef0aae"/></dir><dir name="system"><file name="autocomplete.phtml" hash="7decf3f54f0ed293448ca2a84ec826c7"/><dir name="cache"><file name="additional.phtml" hash="f55be32d13e9ca88bc5ad05359ac594c"/><file name="edit.phtml" hash="392cc02350f73d675ae8f6b65811bfc8"/><file name="notifications.phtml" hash="a019d0760ea6cfdd4e2c93665f5f019a"/></dir><dir name="config"><file name="edit.phtml" hash="5f971d7aca8e1a70103f34ea2f8e16e0"/><dir name="form"><dir name="field"><file name="array.phtml" hash="50ce1dd35ed11a8db3d3ad59e515b0bf"/></dir></dir><file name="js.phtml" hash="874834fe0b24c249efc0a0adb19e32eb"/><file name="switcher.phtml" hash="5a899f08580bc511f7cb308ad5434a0f"/><dir name="system"><dir name="storage"><dir name="media"><file name="synchronize.phtml" hash="79259b6b21df8a122050099622badbc8"/></dir></dir></dir><file name="tabs.phtml" hash="090b7d99c6f946ec07797a3de3ed9357"/></dir><dir name="convert"><dir name="profile"><file name="process.phtml" hash="e9728649b4581052be5f66bbe38107d6"/><file name="run.phtml" hash="67ccdf7c3b9558a1136e182f61466f00"/><file name="upload.phtml" hash="2a4eaa90c21f90f8dd397077a1995a81"/><file name="wizard.phtml" hash="e8aaabfac5406b86cbeae1f2dbfbcbab"/></dir></dir><dir name="currency"><dir name="rate"><file name="matrix.phtml" hash="022728817b25592125cd5aea0589be59"/><file name="services.phtml" hash="fd18998930424daa0dba5eb946accc48"/></dir><file name="rates.phtml" hash="bd8cba7764024b9d4f81e70b92d379ee"/></dir><dir name="design"><file name="edit.phtml" hash="a6748502e84e6f8c1ce7a7b6fb3fd3f5"/><file name="index.phtml" hash="d4d25161838ba0272e01b70031a54702"/></dir><dir name="email"><dir name="template"><file name="edit.phtml" hash="d791749a092eae1c401456f5e50b8215"/><file name="list.phtml" hash="4bd2cfbe71edbb3924dc49cbc4c5b909"/><file name="preview.phtml" hash="5790831f8fcca232e851b8fb3ddf1a82"/></dir></dir><file name="info.phtml" hash="d350dcbdd09f2bed44c3b663c40b514c"/><dir name="shipping"><file name="applicable_country.phtml" hash="1662a0971b90b4f392bf7f36fe036a92"/><file name="ups.phtml" hash="cebcd62310d874f6ed19940ddc95fc2e"/></dir><dir name="store"><file name="cell.phtml" hash="70aca9a7aaf50e07a2cb446b32dae429"/><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="tree.phtml" hash="5c3d3ccfbbed1b062a0d78eed7e2ca74"/></dir><dir name="variable"><file name="js.phtml" hash="3e5e5f42e64fb8534d830b271cb934a1"/></dir></dir><dir name="tag"><dir name="edit"><file name="container.phtml" hash="d16c22231434354b1a08ce9cb04e5bb5"/></dir><file name="index.phtml" hash="4b4e9eb77ef2a3f503c478ebc301ab55"/></dir><dir name="tax"><dir name="class"><dir name="page"><file name="edit.phtml" hash="f7c55192b773349cc38cad7258624fcc"/></dir></dir><file name="importExport.phtml" hash="561e99d910bf37bb5e887e626dade6ba"/><file name="notifications.phtml" hash="dd5cb30e2fa2f269848bbb0b235c97a3"/><dir name="rate"><file name="form.phtml" hash="b5ef7d7e4990797250fbf332cf548085"/><file name="title.phtml" hash="2021a60ac40d770ae2f50907d6357e86"/></dir><dir name="toolbar"><dir name="class"><file name="add.phtml" hash="ef10a2d566c82bad8cd9c48873ec6e67"/><file name="save.phtml" hash="f27f7178cbb164d5fca297a1b4ae1fd6"/></dir><dir name="rate"><file name="add.phtml" hash="8b2172962f50b656d6a11b1a0d9fc8c8"/><file name="save.phtml" hash="787a3b092e394ebd99479c69f3e6cd5d"/></dir><dir name="rule"><file name="add.phtml" hash="ba96d2206f0a6b14c04dca48fc6b0e1f"/><file name="save.phtml" hash="9fd8b6602eaa2f8ee60c617de66c633f"/></dir></dir></dir><dir name="urlrewrite"><file name="categories.phtml" hash="0114448eaaebd4f9e9f9bd7dd7b5863e"/><file name="edit.phtml" hash="4eba179dbd4543f97066b99a17becf28"/><file name="selector.phtml" hash="585e7778cd87ec02d3d75a402f1485b9"/></dir><dir name="usa"><dir name="dhl"><file name="unitofmeasure.phtml" hash="1ad7c6f0001c1429f0185ff86e6fb7f9"/></dir></dir><dir name="weee"><dir name="renderer"><file name="tax.phtml" hash="4d51f086a09c7b32da91fdc9b7c5bd0a"/></dir></dir><dir name="widget"><file name="accordion.phtml" hash="f337eec9f160cc17c11d286426ce8afe"/><file name="breadcrumbs.phtml" hash="991d357316a969714c23258a66a1488a"/><dir name="form"><file name="container.phtml" hash="2aacc340af12481a12a1345e78598037"/><dir name="element"><file name="gallery.phtml" hash="6b750f7c975a7911d77194f9aa79d390"/></dir><file name="element.phtml" hash="a163cbf6f7252551f04e552fd5271c16"/><dir name="renderer"><file name="element.phtml" hash="709a892360b1544df89694feaa71793c"/><dir name="fieldset"><file name="element.phtml" hash="024b35eaad113635230eef181c04ad90"/></dir><file name="fieldset.phtml" hash="9155081d516a44ae8b030e9b206bd8c9"/></dir></dir><file name="form.phtml" hash="681abe7da55410a5ee1eb45fa0c778d5"/><dir name="grid"><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="massaction.phtml" hash="f374ea890a3ccde0a03d9255f93d744d"/><file name="serializer.phtml" hash="db5ddba9dd04c804f40d56a08600239d"/></dir><file name="grid.phtml" hash="c64266d252f382825455fc1b5bcd9fe2"/><dir name="instance"><dir name="edit"><file name="layout.phtml" hash="85d914937a630b43e8d866e00b5ce474"/></dir><file name="js.phtml" hash="f98ce37698081930093320eefe9e11ff"/></dir><file name="tabs.phtml" hash="30dbd04b9cd29abf06f3c10dc607eca7"/><file name="tabshoriz.phtml" hash="6f4b7df458502430d1711aa1b8eec3fc"/><file name="tabsleft.phtml" hash="1ed0a68afd01801d1667e4ae5907a9ec"/><dir name="view"><file name="container.phtml" hash="2765ba04c97ff6f78219f296bf479ae3"/></dir></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><file name="below_ie7.css" hash="a9c27fe40eb9d5e3a722be488edd7309"/><file name="boxes.css" hash="a479266072fcf8f86316d2ee59dc1029"/><file name="custom.css" hash="56ea43791cd4ae989b797928019aa7f2"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="ie7.css" hash="bee9b016e93c1a478c0f8c62303421fe"/><file name="iestyles.css" hash="86ac157e19adb69da98938158173aed1"/><dir name="images"><file name="accordion_close.gif" hash="875409122fc82f5f6705e20dd801fd3d"/><file name="accordion_close.png" hash="6213698b5f69bb2907a5c7bb94b5fe8d"/><file name="accordion_open.gif" hash="d9d50e220b0b676094c6134a9708194e"/><file name="accordion_open.png" hash="9fbc3aba23ce5e0465e4d1cf3f6a7aee"/><file name="add_btn_icon-disabled.gif" hash="c8f6a5cfb455ef121efb56a747821f82"/><file name="add_btn_icon.gif" hash="7300097305b577ee564dc49102822d16"/><file name="address_list_li.gif" hash="79b917b514e35ce0a7833a5e268fd9f7"/><file name="address_list_on_arrow.gif" hash="3a2884ddcc87ebd48883662530b9de1b"/><file name="address_list_over_arrow.gif" hash="e826883c71b1184bd4f29433e39c18ad"/><file name="address_list_over_bg.gif" hash="56291480cc89de9d817205a5f23b66dd"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="ajax-loader.gif" hash="e2a38f1e23288e315af3c55416bc1ce7"/><file name="application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="arrow_sort_move.gif" hash="f5ac151a2b0cb1f07d6e771b8aee0ea7"/><file name="bg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bg_create_order_totals.gif" hash="ff6ab75c050b959c539cc6a6fdff2934"/><file name="bg_notifications.gif" hash="a365594725a83585d989f722b3d8c458"/><file name="bg_window_mask.png" hash="93d6efad062d24c94c105802b138b6a5"/><file name="bkg_btn-close.gif" hash="df3f2332f0bad01e031deb22b81f630c"/><file name="bkg_btn-close2.gif" hash="822457d78fb3c21dc12e9777d83eb4f1"/><file name="bkg_config-advanced.png" hash="b898594a9f1849bf386c06979ef613a8"/><file name="bkg_config-nested.png" hash="7b0fdbf98746c3c916b432c37321ccc4"/><file name="bkg_config-shaddow.png" hash="9ee4318e3f4afc446d26e7f66d01cfbd"/><file name="bkg_tooltip.png" hash="56cfed3ed8a65b19f8de88946d1a0a01"/><file name="blank.gif" hash="5722d7bd0f1e1379d0a2005a0a9ea401"/><file name="box_bg.gif" hash="4c501bd6db9d361c18780f106a809b03"/><file name="breadcrumb_bg.gif" hash="72c4adf6c75b4640ca8f7cadffa42266"/><file name="btn_add-image_icon.gif" hash="1d42210fd29fc534d9ed6b41e811d40f"/><file name="btn_add-variable_icon.gif" hash="a2db02e318d107d5b57b444c8d80b8f8"/><file name="btn_add-widget_icon.gif" hash="b4f66ca7f6097fbafd672e0b3f076ef4"/><file name="btn_add-widget_icon2.gif" hash="467acd3a14fb8be37191f5d2ec5a5b13"/><file name="btn_back_bg.gif" hash="8be512788b8044fe31aa8d00cc16ba7b"/><file name="btn_bare_bg.gif" hash="ddbbab8c0d201c3e502d50e7d4a3d64b"/><file name="btn_bg-disabled.gif" hash="079971a9d2c385fe353d35716ec9f26b"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="btn_bg.png" hash="6e3b7003381f919e8f6533444afaa978"/><file name="btn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="btn_delete_bg.gif" hash="ad740d0c16f2f6603c8ef023004d6539"/><file name="btn_go.gif" hash="1bd787868713767cc205e2ee25e41f62"/><file name="btn_gr_bg.gif" hash="6cc324b79a512150fee24fb3517d22cb"/><file name="btn_gr_on.gif" hash="820c134df02f7bc12efa5a9ac3b4d3dd"/><file name="btn_gr_over.gif" hash="d4c8b807d64c1f493d17c6c9d2bab69a"/><file name="btn_loading-icon.gif" hash="45f500105be432a12c78fed2b4592cf9"/><file name="btn_login.gif" hash="79fa32d49d3f4e39d3fbf8327f9229e1"/><file name="btn_on_bg.gif" hash="709cf5b0be137db1ef8427688503bf37"/><file name="btn_over_bg.gif" hash="f91641168454c03d1fa72731ec97a2b3"/><file name="btn_show-hide_icon.gif" hash="0238c509b33ba56c25df9513bb48f804"/><file name="btn_task_bg.gif" hash="5e0594bd9cbfcc1e32ffa918d7f9c812"/><file name="button-close.png" hash="04d0907b2d7fc3240693497b199f64f5"/><file name="cancel_btn_active_bg.gif" hash="91ce403d286eef2b4e0c13733875882f"/><file name="cancel_btn_bg.gif" hash="26749cf4949ac27c30f597434d3bde65"/><file name="cancel_btn_icon.gif" hash="97e0cd94ed31d6f2a1181f627e60e9a3"/><file name="cancel_btn_over_bg.gif" hash="45eb4e883b17375961672f5390387c31"/><file name="cancel_icon.gif" hash="70a23b78353f0a7b9b118a937fcb7ea9"/><file name="config_tab_dt_bg.gif" hash="a33f71077ca4078caa794cae01d9fca7"/><file name="dashboard-close.gif" hash="5ae5afd61e937fcd2d5b84641255ee4d"/><file name="db-graph-bg.gif" hash="5d76efb7c3244f5684df2566782124ea"/><file name="db-graph-bottom-bg.gif" hash="b58ced87a38a10891106329ae882aa1c"/><file name="db-graph-line-bg.gif" hash="f16bb08e040c2c0a3e23b3f35c54b79b"/><file name="db-graph-line2-bg.gif" hash="744ebfdba20d050f4d252afc216394be"/><file name="db-graph-x-bg.png" hash="d5c26510718a78d22083916d80ef7a22"/><file name="db-header-bg.png" hash="3976cb6351e167686a501a85cf3a68e9"/><file name="db-menu-bg-hov.gif" hash="34ea76a6d105d90fcb63bf105aadb8f7"/><file name="db-menu-bg-up.gif" hash="b0f754872dff5f2f0dc57ba193fdfa4c"/><file name="db-menu-bg.gif" hash="ea534c3c09bb309e566b6ae876655e13"/><file name="db-menu-sep-last.gif" hash="a01fe34854e1187e466fd58d462c4106"/><file name="db-menu-sep.gif" hash="7c5ae1cd59a189261cc3244358d5c1ad"/><file name="db-menu-start.gif" hash="aa5cac2194d937cc7fa904ccfce70ecc"/><file name="db-scroll-bg.gif" hash="06d2411e3b5f350ab21b625439d2d69d"/><file name="db-scroll-but-bot-roll.png" hash="6bc5e482f3f6d8fb1fc5014ddea43706"/><file name="db-scroll-but-bot.png" hash="25c0181e76ff8ceb3c0ec59071b8c72c"/><file name="db-scroll-but-top-roll.png" hash="b7961f2a3b5b641694a9b0b30d58e46b"/><file name="db-scroll-but-top.png" hash="de7df96e961596be9ff556924259b98b"/><file name="db-scroll-roller.png" hash="e01dde7bd096c52179acf29a425a29e5"/><file name="db-tab-bottom-left-bg.gif" hash="124388d44ac58b029377c6311a4782d5"/><file name="db-tab-bottom-mid-bg.gif" hash="9c48f33aa8907cfcb227bc779c2e1dce"/><file name="db-tab-bottom-right-bg.gif" hash="1db45e6fd8abc67d59f96a676607b412"/><file name="db-tab-footer.gif" hash="cac8928acba75bc1edd73186ced78e5c"/><file name="db-tab-header-sep.gif" hash="580312af7441b6a62f7e32081c40fb0f"/><file name="db-tab-header.gif" hash="fdf493b9477fcff7e7be98405effc33d"/><file name="db-tab-left.gif" hash="3fe3c55267dbbdd1db2ff959ccc9e0be"/><file name="db-tab-right.gif" hash="b7a32c8b03efe2fbdb63215d0446e3be"/><file name="dotted_divider_dark.gif" hash="8bf1de196d9ea048bfb25155cedd2e9e"/><file name="dotted_divider_light.gif" hash="92e562bf2070110f6b0a15e29b845445"/><file name="edit_icon.gif" hash="dbda31751c78d964c04394e9d8533187"/><file name="entry_edit_head_arrow_down.gif" hash="985c3ce4439fbf8bb2216fc7e73a3f0b"/><file name="entry_edit_head_arrow_down2.gif" hash="d68dd0fbc2819858a26ea2835c05df77"/><file name="entry_edit_head_arrow_up.gif" hash="d2b90a1823fff9f3917f19b427410144"/><file name="entry_edit_head_bg.gif" hash="1086b7196e8b33c4f46e49fecef0f35f"/><file name="error-msg.png" hash="3cd27b642416dacdc28907c89d934886"/><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="fam_account.gif" hash="c910fd1ff41b940d71b0835e02fc143e"/><file name="fam_application_form_delete.png" hash="972c2d998fc19572dd64af6b5e2e898e"/><file name="fam_application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="fam_asterisk_orange.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="fam_bin.gif" hash="2fb388bc9f1d32d3802db8e91dc238bc"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="fam_bullet_disk.gif" hash="9fe82691d960c18d3d315c3f9164af4f"/><file name="fam_bullet_error.gif" hash="008802f44288b732b59cfe9fdbfecefe"/><file name="fam_bullet_success.gif" hash="465a056a3ba3d94367f51c3c0b751391"/><file name="fam_calendar.gif" hash="0614207ce4e3e0a9bd631b39e7692e3c"/><file name="fam_cart.gif" hash="1f2fd2c8ac6574488ea78302b6856191"/><file name="fam_comment.gif" hash="5138f9a4b6019a5b14b8ff9a32a3cb89"/><file name="fam_creditcards.gif" hash="b75b8ce2f4fceb58f8082c48344560c7"/><file name="fam_folder_database.gif" hash="e86175ff0f389ade1fc7bf15e03346eb"/><file name="fam_folder_palette.gif" hash="c0941b9145e06d53cc0d17ac4c151764"/><file name="fam_folder_table.gif" hash="e2914ba75944acd2a9e2d338fa339e16"/><file name="fam_group.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="fam_help.gif" hash="2b5ed4c13a8e24456207b757826c7b2c"/><file name="fam_house.gif" hash="8eb2d580c5a40b7974f4263ca64fb94a"/><file name="fam_layout.gif" hash="5366a5f02260d3a860ef0c4787282ad6"/><file name="fam_leaf.png" hash="078d4f24683331b4557356a59e67b125"/><file name="fam_link.gif" hash="78590d5d8375d1baabe7b66d7b9ceb7d"/><file name="fam_lorry.gif" hash="174e86e45e76e7008fa3510cefa85047"/><file name="fam_money.gif" hash="6996bad465222fb6487cab94b4607846"/><file name="fam_money_add.gif" hash="70ceed401fe9913305f2362f7e26225d"/><file name="fam_monitor.gif" hash="f3bc806ff9d0907320b03018ba2d00ea"/><file name="fam_newspaper.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="fam_newspaper_delete.gif" hash="41acabfc19102be92d3ccbc66d1fede3"/><file name="fam_newspaper_error.gif" hash="009bfa425298e1d2e44e38e58cd97938"/><file name="fam_newspaper_go.gif" hash="eb43105f8e13e3a752d7ca33bb086831"/><file name="fam_package.gif" hash="bf9be09ef64d006455baa211b7c03983"/><file name="fam_package_go.gif" hash="e4f8d380c2f8e5a7345e360293433764"/><file name="fam_page_white.gif" hash="26940eb67826c5af72b6048c7c5a8335"/><file name="fam_page_white_edit.gif" hash="a4f88300b74ad592a5c47ed54ff07af9"/><file name="fam_rainbow.gif" hash="e8b04cc945b3582a181d4ddbc2d2325f"/><file name="fam_refresh.gif" hash="01bbef614023c0890812e76bc7ecf7e0"/><file name="fam_server_database.gif" hash="7901fa06ffd68ed730cf43bb560756fd"/><file name="fam_status_online.gif" hash="a80019ffa3a573f709772ed1099343fc"/><file name="fam_tag_orange.gif" hash="6ce735a0e590bda040b6e1614c42e58a"/><file name="fam_user.gif" hash="63bbdd6d9d7a27591907a7b87898e259"/><file name="fam_user_comment.gif" hash="014dfd31d9af40e3d5960b2b0d900da3"/><file name="fam_user_edit.gif" hash="f5b36e803060c6b82e639a4fad57b9f7"/><file name="filter_row_bg.gif" hash="013a0929a7b2ddc6823bdda17d08acc0"/><file name="footer_bg.gif" hash="7724711d3ca07a5e46a6030e86743a71"/><file name="gift-message-collapse.gif" hash="5b710f5faa9c7352a39c10e3ebbee6fc"/><file name="gift-message-expand.gif" hash="fd53a70cbb1ea048754657a63787e9cb"/><file name="gift-message-grid-column-bg.gif" hash="97a8a9b8cc4ab68e7404ccf1320f50a6"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="grid_sort_asc.gif" hash="b78c3a1a27ac9672a31b7d1bbac60322"/><file name="grid_sort_desc.gif" hash="d958b946eba3dba863d724530a0dba1a"/><file name="grid_th_bg.gif" hash="8f4349fac728858374e17edf03390977"/><file name="grid_th_onclick_bg.gif" hash="7bf331e2a41e5331c4210bdc6adc4383"/><file name="grouped_to_order_icon.png" hash="4bdae9a6199655027b8b8aeee8f80ce4"/><file name="header_bg.gif" hash="cbe510856afa5cb0c32642c1f9a8eceb"/><file name="header_top_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="horiz_tabs_ul_bg.gif" hash="58dbd9c45f76993346c2bb788896248e"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_question-mark.png" hash="23201b7ac207eebd9be0776ea44098a4"/><file name="ico_success.gif" hash="0afb20898a704a106cb4c598868abf32"/><file name="icon-enabled.png" hash="5fa7c06b312cbea3675e844686e434af"/><file name="icon-tooltip.png" hash="5767601cd66b23d0b6fe8defc10dd48d"/><file name="icon_btn_add.gif" hash="7300097305b577ee564dc49102822d16"/><file name="icon_btn_back.gif" hash="89ed97cede3f68241446a62c96e3ce4c"/><file name="icon_btn_delete.gif" hash="dbde0b76d36cfd624bf0de166d0a265e"/><file name="icon_btn_save.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="icon_edit_address.gif" hash="d1ca2bb3a5c86afd379f25d9fc4352e3"/><file name="icon_export.gif" hash="9a13f20c6a17b41b9c357545c2da5636"/><file name="icon_export.png" hash="fb299dd13df666516eabe16f59193383"/><file name="icon_feed.gif" hash="0366583ed6e285d028442fcdebb05072"/><file name="icon_feed.png" hash="8537f6f88fcff4aac793247143d14e42"/><file name="icon_note_list.gif" hash="8d25ba225ca09b687a78bff510df5d10"/><file name="icon_remove_address.gif" hash="2de2b3d02c19adfb93e9e43a392db178"/><file name="login_box_bg.gif" hash="e4654826eaa8d5ebc0ab18e9bee71e1d"/><file name="login_box_bg.jpg" hash="404e37f4ee9f4ff9bfcb638741c7581d"/><file name="login_box_bg_auth.jpg" hash="d90a81db1064ec37b0cc92436725c24b"/><file name="login_box_bottom.jpg" hash="038f15261e74bc381484f2fcfa45a73b"/><file name="login_box_legal_bg.gif" hash="528ac4dd480c4fc00ac808bf17394c05"/><file name="login_logo.gif" hash="a15f85d59684e1ec548b758fb6165469"/><file name="logo-large.gif" hash="b938979c790d4aba4170054fc4a060be"/><file name="logo.gif" hash="c7e9f290d965f707e4c4a61bfdab58cb"/><file name="logo_email.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="massaction_bg.gif" hash="8b5f4db3ab3ea09cd5bd0164d67c4f0d"/><file name="massaction_button_bg.gif" hash="4c8262817e48d007237124ce0e7f4d18"/><file name="massaction_links_delimiter.gif" hash="9a0337183b5b67c0eed75993d7f14d10"/><file name="middle_bg.gif" hash="ba4f176d2c553201ebab4aba5c6d3d20"/><file name="more_arrow.gif" hash="38bb4c0e9270250151486d0bb36c476f"/><file name="nav1_active.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_bg.gif" hash="a1d4ef5b590ce0a425dc04e45ed06cbe"/><file name="nav1_off.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav1_on.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_over.gif" hash="2c70d6175f1c965c27dda0598a67e63c"/><file name="nav1_sep.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav2_last_li_bg.png" hash="279935c9799679fc5894337eaabc7cf0"/><file name="nav2_last_li_over_bg.png" hash="39536f00824293d11242888a76f40a5f"/><file name="nav2_li_bg.gif" hash="0a4f34b0e4436c519d31203f19503b83"/><file name="nav2_li_bg.png" hash="2fad219d162324e9a19f2745d5b6d562"/><file name="nav2_li_over_bg.png" hash="dc37c4a4aab40ea2ae44dea5ea133a9d"/><file name="nav2_link_bg.gif" hash="dce00ddad351e72e83bc87274cbaa54a"/><file name="nav2_parent_arrow.gif" hash="60e012a14a077bd2257343facc369c0c"/><file name="nav3_bg.png" hash="2bc7af80ad8886013da38401b63ab6df"/><file name="nav_bg.gif" hash="1b857c7d35f35ef9f6cae9e03a4e3dff"/><file name="nav_list_bg.gif" hash="7a4e2bdb887c12d8a1152bbcc8c02a3c"/><file name="nav_nest_link_bg.gif" hash="1d0c6b374bf02ac4b5aa012955c431de"/><file name="nav_nest_link_over_bg.gif" hash="fae3c579a4d432503b1f4f929d070609"/><file name="nav_on_bg.gif" hash="ac624b580cae5a76f6c92abc5a44191d"/><file name="nav_parent_arrow.gif" hash="3a95559263e569dc1c8065cb2d9b3f2c"/><file name="note_bg.gif" hash="105967d7c15ab4610726eea52d862a97"/><file name="note_cell_bg.gif" hash="71e656d42f8ba8c2d477c6866c499b71"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="notice-msg.png" hash="9cd1dfebccec8a2123d543fa49b17bd7"/><file name="pager_arrow_left.gif" hash="6e44f608dac8eb8be1d1ebee5a3285aa"/><file name="pager_arrow_left_off.gif" hash="30f5e56195ab3546b36f4016db5254be"/><file name="pager_arrow_right.gif" hash="cc79526156b7e0c8abce61fad3d53f77"/><file name="pager_arrow_right_off.gif" hash="f01b7dad9acf0180b5c62edbd7ea9939"/><dir name="paypal"><file name="logo-paypal.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="pp-allinone.png" hash="c457fe4bfe28a18c90d0abd36fe3f880"/><file name="pp-alt.png" hash="37a166931ca15c465bd86311d15e0422"/><file name="pp-gateways.png" hash="90acb72c2f46fa131351efe0492d52cf"/><file name="pp-uk.png" hash="e0830ccb14533051b8b0340471744228"/></dir><file name="paypal_logo.gif" hash="871e205a64292121f4c893373acfb581"/><file name="paypal_section.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="paypal_tick.gif" hash="e8685c1fb7c4c106ae4fd24e9bbf5a27"/><dir name="placeholder"><file name="thumbnail.jpg" hash="5c73b5aa515b1719f7b398f5131f91a8"/></dir><file name="process_spinner.gif" hash="345b30b4d0b6088d0151ecfbdf48c036"/><file name="product_rating_blank_star.gif" hash="5e20a299c0ff16168be38b6dde580eda"/><file name="product_rating_full_star.gif" hash="dd5aae332178d928a7f49dea7691b5f6"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><file name="rule-ajax-loader.gif" hash="32dc1f5901143d36fbd7a6df3950819f"/><file name="rule_chooser_trigger.gif" hash="9c498e789c3ce734f5301c2475e2a04c"/><file name="rule_component_add.gif" hash="7914e57701ca26f5c8bf23c6bc3e1f25"/><file name="rule_component_apply.gif" hash="3f9b9025551da6963a9ecf8d184a204a"/><file name="rule_component_remove.gif" hash="4d785bcecfbe716fa4d749d20738a8f0"/><file name="save_btn_icon.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="sec_nav_bg.gif" hash="99c6741591cdb2a2a128668a1d32d668"/><file name="section_menu_bg.gif" hash="f9edd44c92743a0c9ae9535a7992d6b1"/><file name="section_menu_bottom.gif" hash="167d2ef46ff80158c807b4b916501b28"/><file name="section_menu_link_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="section_menu_link_over_bg.gif" hash="7da7e56567633aab279cf3aec6f49d8d"/><file name="section_menu_over_span_bg.gif" hash="f5ea5292f15ed62b99f0f51d9fff2c66"/><file name="section_menu_span_bg.gif" hash="dbf3916358e794ee809b4cf33903af2c"/><file name="section_menu_ul_bg.gif" hash="3aea6e5452f548438ca34e17954a9d6b"/><file name="side_col_bg.gif" hash="b3691fd62663457af39eaf71dd8cda5a"/><file name="simple_container_bg.gif" hash="56f1ac91169eb4896b8c91384fc8bf15"/><file name="sort-arrow-down.gif" hash="fc2cd9f756ce510c4470478d720f81cd"/><file name="sort-arrow-down.png" hash="dc65160d9d4d6cdd6bfe1b397a931975"/><file name="sort-arrow-up.gif" hash="39026b0ff1f0c18091caa60384491163"/><file name="sort-arrow-up.png" hash="da54e5306bdce67551aa415f5d7f7ea7"/><file name="sort_heading_bg.gif" hash="6066d09f237f556b0a4770e4788e7598"/><file name="sort_on_bg.gif" hash="0cb36788ed4fbf19e657acbc75a3f1b8"/><file name="sort_row_bg.gif" hash="f2e1c5cb26b9f5211419b99d30745244"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="sub_button_bg.gif" hash="e3f66dd60510f9f7e937e2e55442c30a"/><file name="success-msg.png" hash="c64cb2acc3d0eeba48fdea83620913ed"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="tabs_link_bg.gif" hash="34447929f5e6591ba9b5795b983fdfd4"/><file name="tabs_link_over_bg.gif" hash="2cf3f56884096055fb0bdf9474f280c9"/><file name="tabs_span_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="tag_blue_edit.gif" hash="b2163ac3baf7d822b48593342846645a"/><file name="tn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="tooltip_bg.gif" hash="0aa4b866fc067a75f27ab749c1dabf74"/><file name="tooltip_corner.gif" hash="71146534671d5e0751505640b7c59859"/><file name="tooltip_top.gif" hash="032ff52a6ff5714cbdf6c1f62abaf7e5"/><dir name="tree_icons"><file name="join.gif" hash="4d5d614e0da056df815a4306d6368692"/><file name="joinbottom.gif" hash="4b3daa7f2cc584f1aac0d142275d7cba"/><file name="line.gif" hash="63ab38a6203262f15ca46c631232ea2c"/><file name="minus.gif" hash="d647fbbd0ec410b8f3bb3357b62eedcf"/><file name="minusbottom.gif" hash="b09d684cca7135ef728141aaf2464baa"/><file name="nolines_minus.gif" hash="eb2243a354ffcfac93ba0fe948f7167d"/><file name="nolines_plus.gif" hash="ec92b634b63608fb4b0dbf114e3b89e1"/></dir><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="varien_logo.gif" hash="6f10d0fe572cb012947c164217e9e428"/><file name="warning_msg_icon.gif" hash="4cf6ec7f59ab09f9c18b3a4301714c6d"/><dir name="widget"><file name="catalog__category_widget_link.gif" hash="8435943009f1f774bbd6a4809c719eb8"/><file name="catalog__product_widget_link.gif" hash="62f2d7020143f98ba7514469eb612a7f"/><file name="catalog__product_widget_new.gif" hash="37a5af9f98ae73e180ad0cca05c95324"/><file name="cms__widget_block.gif" hash="b7b0b1517cc38b18b92841b33b312190"/><file name="cms__widget_page_link.gif" hash="b839dee210e61850a5858cc8634cbccd"/><file name="default.gif" hash="684143ae5531aa6ba22215f4fadeea6c"/><file name="reports__product_widget_compared.gif" hash="bd3e5a5015eb2c5c64f1d11835166dc4"/><file name="reports__product_widget_viewed.gif" hash="44d5cd71e4fb7235f9cff0c7e2b2f531"/></dir><file name="widget_placeholder.gif" hash="2bd8d72cf12f8d7d0a6a3268f97786ff"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/><file name="window_content.png" hash="08361df29783d46a2493cf0d8ad733a7"/><file name="window_top.png" hash="555a8db5efa3a252c2ead3d3dadd1075"/><dir name="wysiwyg"><file name="skin_image.png" hash="a521b0c60b001de4a3405e73c4a6cd4a"/></dir></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="27083525fe48622ce931f01c0dcdfcc7"/></dir></dir></dir></dir><file name="menu.css" hash="a1dea5350cfe01b4e27c2606a27762cd"/><file name="oauth-simple.css" hash="08c16d55aef90c4668473326fa11f86a"/><file name="print.css" hash="0003cbfda260e9eee2fefbaf45e8d40f"/><file name="reset.css" hash="e1cccd2f5ec4178349bde538b1f3fb30"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Adminhtml_Default-1.9.4.2.xml b/var/package/Interface_Adminhtml_Default-1.9.4.2.xml
new file mode 100644
index 0000000..586cafd
--- /dev/null
+++ b/var/package/Interface_Adminhtml_Default-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Adminhtml_Default</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Adminhtml</summary>
+    <description>Default interface for Adminhtml</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:57:59</time>
+    <contents><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="admin.xml" hash="dabe4a475e4bf891511520bb6127f887"/><file name="adminnotification.xml" hash="e3256c86976aac2056639c32001e8a0e"/><file name="api2.xml" hash="efa54fd6c59a1363bbe94c2bb8cfa890"/><file name="authorizenet.xml" hash="d7271b7b3fc35527209a3b04d57faff8"/><file name="bundle.xml" hash="b0b01c2c65ecf1bdcbcf14e28652b6f5"/><file name="captcha.xml" hash="b6a1b4b09245c75f1241b9c99686ee01"/><file name="catalog.xml" hash="63e9d4a5a4e684ce8d5f15407bd7e86b"/><file name="cms.xml" hash="0f94e157fc39272346cd117bf03f11d5"/><file name="connect.xml" hash="8e42fad0013633415525519d1d552fe4"/><file name="currencysymbol.xml" hash="956e1b2151a6c4fd61cf9978a5f8bc1c"/><file name="customer.xml" hash="27af64a8a5056032b918c95b9ff6f9f3"/><file name="dataflow.xml" hash="258e1380e65a62933ea37307d28ed23f"/><file name="downloadable.xml" hash="57bd6002f68c57cb4167290c92334216"/><file name="giftmessage.xml" hash="0954ee5081b424d41f7e168c232a8447"/><file name="importexport.xml" hash="5519e7dc10ee490f202f4927382e2b23"/><file name="index.xml" hash="c59a9d2f223297d33415d843c5ea4846"/><file name="main.xml" hash="27918ac6cb9dfaf1cba090cb800e83a4"/><file name="newsletter.xml" hash="eabb130f32301344970d65dc77fe9599"/><file name="oauth.xml" hash="3cc70c9ac89bbfacbd3a9f3289e26b9b"/><file name="pagecache.xml" hash="f33b8e37be4ab1dc681acbe7ffbe139e"/><file name="promo.xml" hash="20fd585dcaa9e830e09afb24212099ad"/><file name="report.xml" hash="cce97c488e21e10541e0a3d64bcf7b6b"/><file name="rss.xml" hash="604fb320683986266541ba4ff50e3ae7"/><file name="sales.xml" hash="afe4642654d3f556305a647805602861"/><file name="search.xml" hash="bea5b486b22bfd3ee84fc0e21826a88f"/><file name="tag.xml" hash="6fbf0da651787c6a8de2ea803db2c637"/><file name="tax.xml" hash="ed660cff4c94190b2825e41840731c19"/><file name="widget.xml" hash="6be580bc1ac273a9a0ccfe75f468e587"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="735c9ec66d1309f1206294f075fdcdd1"/></dir></dir><dir name="template"><file name="access_denied.phtml" hash="ff7e7628c69f5a6faf22ddb1c319ab55"/><dir name="api"><file name="role_users_grid_js.phtml" hash="bfd03f411c01f8c1eb8f60811afc65a6"/><file name="roleinfo.phtml" hash="ddb5db43337c1054fbee387945a91109"/><file name="roles.phtml" hash="420fbd2e487d332b71dddc3189a72ac3"/><file name="rolesedit.phtml" hash="236eec97598cfcabefe5694a08eb442c"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="e50593a7a375c0674b57c60b84bd294a"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="api2"><dir name="attribute"><file name="buttons.phtml" hash="b211cd2ef5c0515190f089fb70faef0e"/><file name="resource.phtml" hash="82b6b6062beb93e8d0f80e64b618a1b6"/></dir><dir name="permissions"><dir name="user"><dir name="edit"><dir name="tab"><dir name="roles"><file name="js.phtml" hash="19a9dee2c3675077d20d20b2fe9b7081"/></dir></dir></dir></dir></dir><dir name="role"><file name="buttons.phtml" hash="48f39c0ff4d551453dbaf74b38dfed97"/><file name="users_grid_js.phtml" hash="5b38183975d7068df675d2e74f32f944"/></dir></dir><dir name="authorizenet"><dir name="directpost"><file name="iframe.phtml" hash="ee7d99c196525961e4426023ed1f71d6"/><file name="info.phtml" hash="7af4958ced9ed0b820e31414712314e1"/></dir></dir><dir name="backup"><file name="dialogs.phtml" hash="1ab3bd9dd2d0dc4fe71e3ec05929bdfa"/><file name="left.phtml" hash="28abce5769ea95892ee4ffc0954e2682"/><file name="list.phtml" hash="3c5d531e2c6da63fd4f7628308f08051"/></dir><dir name="bundle"><dir name="product"><dir name="composite"><dir name="fieldset"><dir name="options"><file name="bundle.phtml" hash="13c049c3858aede8d9ec9c8d5bd93932"/><dir name="type"><file name="checkbox.phtml" hash="4a974f8962410393537df2bf89491e1e"/><file name="multi.phtml" hash="cb36c7cde9c2ded0f33583c201f22afa"/><file name="radio.phtml" hash="3307fc3c8236e3ea839c6d4d4ddeac95"/><file name="select.phtml" hash="860ff711964c822b79c7dbc70d408fdf"/></dir></dir></dir></dir><dir name="edit"><dir name="bundle"><dir name="option"><file name="search.phtml" hash="bed7e4793be8b2bfc39e68c6b4b7ea1f"/><file name="selection.phtml" hash="f13bd0f783f8711ed6434b1efdd37f19"/></dir><file name="option.phtml" hash="03a318c5cc7a7809ef301bdbf1e01cb7"/></dir><file name="bundle.phtml" hash="3c8c62637fe159dbea88b1f8f976f82d"/></dir></dir><dir name="sales"><dir name="creditmemo"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="bc57544cf9d1f53e0ba710cc12101ba9"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="3d68d4b17b2e26011f0b6b5839ceacb0"/></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="28d880e36253cbae2ba60f412b8ffe3b"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="197d154a2d0c1f464541037cf0131ad3"/></dir></dir></dir><dir name="order"><dir name="view"><dir name="items"><file name="renderer.phtml" hash="cb3cec0a08b12d62638c74b3da7cea69"/></dir></dir></dir><dir name="shipment"><dir name="create"><dir name="items"><file name="renderer.phtml" hash="f97295be3a736aa634b241a804be43ea"/></dir></dir><dir name="view"><dir name="items"><file name="renderer.phtml" hash="998a2d676d93700cc8afa0465b8fa9ab"/></dir></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="37ca694eb77403ac744aab9101349c92"/></dir><dir name="catalog"><dir name="category"><dir name="checkboxes"><file name="tree.phtml" hash="95c7468be3636ff49a744228e47edcc8"/></dir><dir name="edit"><file name="form.phtml" hash="f17abf89515af569399d88388a94ef55"/></dir><file name="edit.phtml" hash="a4a0e994436988e9401d7f0ceb3ffd23"/><file name="tree.phtml" hash="76f3bcf4b961c262b33b09df17345f39"/><dir name="widget"><file name="tree.phtml" hash="4c079c7a8d860d5ff36fef46eada257d"/></dir></dir><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="d17e50690d1e14f9caaf5105d2b3d187"/></dir></dir></dir><dir name="product"><dir name="attribute"><file name="js.phtml" hash="fbcfb6db2da0c52ebd01a70f61b6ac5e"/><dir name="new"><file name="created.phtml" hash="f814e5ce1bf951e11a4370be354766e7"/></dir><file name="options.phtml" hash="b8a61b9f8a0817446f0d52cf739b3fb5"/><dir name="set"><dir name="main"><dir name="tree"><file name="attribute.phtml" hash="1cd780abd50e66840498ef241416ef6b"/><file name="group.phtml" hash="bc852da8df505f611965d2585972853b"/></dir></dir><file name="main.phtml" hash="a10ebf167915cbeb8aed5d76ba47d9b2"/><dir name="toolbar"><file name="add.phtml" hash="ce3c6895929df71e017ebc00c3183d78"/><file name="main.phtml" hash="615ca584ea71f9b7b8add861488894aa"/></dir></dir></dir><dir name="composite"><file name="configure.phtml" hash="31c28cd626e1059ee0d05b78df28fdea"/><dir name="fieldset"><file name="configurable.phtml" hash="68567032b9eefa5f645c98d151d2e912"/><file name="grouped.phtml" hash="843069b3d59fc05f86a2014177212569"/><dir name="options"><file name="js.phtml" hash="9c907b5b54ed2cd8ad1ec4afc45115f8"/><dir name="type"><file name="date.phtml" hash="75d46189d0e23f6aee5dbcc7ce5651c8"/><file name="default.phtml" hash="718bc5a7bd3013f43d544d3fe8ea8a77"/><file name="file.phtml" hash="00c647c6eb343bd8565f0b88ab392a39"/><file name="select.phtml" hash="277c942f79c0eb7a7b53b04643c9593d"/><file name="text.phtml" hash="acd27eac2f69153fec4e1865c787ea59"/></dir></dir><file name="options.phtml" hash="1df8f7845611e80a3f13c494b1b839ec"/><file name="qty.phtml" hash="4d0c8e4434be8c259435346d673a6dd0"/></dir></dir><file name="created.phtml" hash="1ed62146a00291e9c2b0230804f84fb7"/><dir name="edit"><dir name="action"><file name="attribute.phtml" hash="27488ec6201dc9d6820f9a788a1ada4f"/><file name="inventory.phtml" hash="52d619872155e6944f9e235111408ef7"/><file name="websites.phtml" hash="98bcd6fa5f51a0dfb57a3023272a27d2"/></dir><file name="categories.phtml" hash="81f284d1f0d81f1fa0d768cf8df4648c"/><dir name="options"><file name="option.phtml" hash="685f57480169653dde66b661bab9fe96"/><dir name="type"><file name="date.phtml" hash="d920b195727a51dac13285cc236927f7"/><file name="file.phtml" hash="c2f994dc12c6beb6fc585d6968f37e6e"/><file name="select.phtml" hash="d26e6090862d21f0d9c9cc2da834908e"/><file name="text.phtml" hash="99e1c0b3be182e27eba6a02e27c254a7"/></dir></dir><file name="options.phtml" hash="860eeb5fc3b47284ea970feb48d530a3"/><dir name="price"><file name="group.phtml" hash="aa91ad4e0d4cbe2059fd8f71a76d2e90"/><file name="tier.phtml" hash="11caea53a3f27beece051f05ebb2a8ae"/></dir><file name="serializer.phtml" hash="cc36239d24eb9233499aa8668504b9d0"/><dir name="super"><file name="config.phtml" hash="91024f4002467a6198884913e29f8da6"/></dir><file name="websites.phtml" hash="9b748765b6602c9b0ab7a6e710e96dfd"/></dir><file name="edit.phtml" hash="77abbac755fc5e40aa8d1a512f39e12c"/><dir name="helper"><file name="gallery.phtml" hash="3a341fc5667f1327d504f748c196230a"/></dir><file name="js.phtml" hash="fd68a3d0aa7de457a161512247d39012"/><file name="price.phtml" hash="c7950bff8c69ef04f373e05a05eaeeac"/><dir name="tab"><file name="alert.phtml" hash="2ca71d372fd28105043613448194a05a"/><file name="inventory.phtml" hash="2f043028fdd18bb4aef2dba52d841cd8"/></dir><dir name="widget"><dir name="chooser"><file name="container.phtml" hash="898bcd75e7f5bc7b9ff9ef23578447c9"/></dir></dir></dir><file name="product.phtml" hash="3100e755e72f3e0459ec415076d6c2b8"/><dir name="wysiwyg"><file name="js.phtml" hash="200fe68eaccb7e5e1f1ab9f5fdb0d764"/></dir></dir><dir name="cms"><dir name="browser"><dir name="content"><file name="files.phtml" hash="edab20c3d693785605c339c829bc85bf"/><file name="newfolder.phtml" hash="d92a8c8b996e3052205465501f823d38"/><file name="uploader.phtml" hash="70f3a760ced2fe0fedd408790c808256"/></dir><file name="content.phtml" hash="911c2c7575b3697ddfbe5b54003b0480"/><file name="js.phtml" hash="3f793d09811f41ea12ab24e1d21004b7"/><file name="tree.phtml" hash="0d8036e58dc67a85c29d99ae51b24480"/></dir><dir name="page"><dir name="edit"><dir name="form"><dir name="renderer"><file name="content.phtml" hash="aa53277015b94a3632ff65600a2c132e"/></dir></dir></dir></dir></dir><file name="coming.phtml" hash="9d68f7d168d84f45f09dca6c8d5c57bb"/><dir name="connect"><dir name="extension"><dir name="custom"><file name="authors.phtml" hash="1c1e2ce7fe39bf549fea3fbb1fa25342"/><file name="contents.phtml" hash="4207fb35993aec2a4f0d2eb0fb50e587"/><file name="depends.phtml" hash="21a7c1f8a954b0bd706653776164b2c0"/><file name="load.phtml" hash="1ecf32a6aafbb1b7b79e10a7a980029a"/><file name="package.phtml" hash="f993c90b7b158b468533d7c591cc0537"/><file name="release.phtml" hash="0f17de2b77a9adc5a057f0018e5310dc"/></dir></dir></dir><dir name="currencysymbol"><file name="grid.phtml" hash="b934989bd485a6e7deeb1c461e499d02"/></dir><dir name="customer"><dir name="edit"><file name="js.phtml" hash="a4981632e863b82ed494ccc99f3752c0"/><dir name="tab"><dir name="account"><dir name="form"><dir name="renderer"><file name="group.phtml" hash="77d7cb5f2f95ef643e0286a4605aeab8"/></dir></dir></dir><dir name="view"><dir name="grid"><file name="item.phtml" hash="204c9cd7d9b5237bf863659f2a132139"/></dir></dir></dir></dir><file name="online.phtml" hash="69ff950bec24490ffaf2831eea866169"/><dir name="sales"><dir name="order"><dir name="create"><dir name="address"><dir name="form"><dir name="renderer"><file name="vat.phtml" hash="6c63263ac2eed95d563ce140ce873b3e"/></dir></dir></dir></dir></dir></dir><dir name="system"><dir name="config"><file name="validatevat.phtml" hash="4bb7a42ea5a9a3b16bd4cfbd0c637828"/></dir></dir><dir name="tab"><file name="addresses.phtml" hash="1218f498d073a4125f6bf5eaf3bdf7c4"/><file name="cart.phtml" hash="517478d69773066a4ab664e08aba35d2"/><file name="newsletter.phtml" hash="3945cde3ca22107243119551245c233e"/><dir name="view"><file name="sales.phtml" hash="ce7336ea6b2f4d6daf50b88918b0dda2"/></dir><file name="view.phtml" hash="cd905bde3308599627a0aea20e5f8c92"/><file name="wishlist.phtml" hash="6dee8733fd9c915efad6cb0cdb71e167"/></dir></dir><dir name="dashboard"><dir name="graph"><file name="disabled.phtml" hash="0210c1ddde1b52ad0f9a671fe84e81e0"/></dir><file name="graph.phtml" hash="e753293e33068c24515e6051a4856bc2"/><file name="grid.phtml" hash="4334e2a5bcab21ac44c0151bd9a51bf3"/><file name="index.phtml" hash="b1a268bcb5f2efb76022d68714f7f6fb"/><file name="salebar.phtml" hash="7860149f9449a9f4fd5cbccefd415d6b"/><file name="searches.phtml" hash="55227aa009d49c194950087f950041f5"/><dir name="store"><file name="switcher.phtml" hash="f0b25bc75ea67e63576a557bfe820797"/></dir><file name="totalbar.phtml" hash="5a4cd54f0075f07bec88efc9b5c47051"/></dir><dir name="directory"><dir name="js"><file name="optional_zip_countries.phtml" hash="836c6ea23ae98a076f38da313197ba08"/></dir></dir><dir name="downloadable"><dir name="product"><dir name="composite"><dir name="fieldset"><file name="downloadable.phtml" hash="5ef5535b8ce8e4bbe7659d444898f20d"/></dir></dir><dir name="edit"><dir name="downloadable"><file name="links.phtml" hash="b587b76cf094109587ac967f4e5a8120"/><file name="samples.phtml" hash="a73bf52f2ed419ad8668e57a1e3dc4ba"/></dir><file name="downloadable.phtml" hash="b66ab0dda0d0a7e096857b7e7c052174"/></dir></dir><dir name="sales"><dir name="items"><dir name="column"><dir name="downloadable"><dir name="creditmemo"><file name="name.phtml" hash="16588112504f00eec8cf47e4ce5da0d7"/></dir><dir name="invoice"><file name="name.phtml" hash="492f04ce08f8d68bd5388030ffd0d914"/></dir><file name="name.phtml" hash="187811540e032dd12b6feffd0bc598f9"/></dir></dir></dir><dir name="order"><dir name="creditmemo"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="95b422bd8627c1a8b45a1d4491d1bd93"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="3677d1c7be1a53b23a6b9f400a2935ef"/></dir></dir></dir></dir><dir name="invoice"><dir name="create"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="90bad224de57564dd250c37570595a21"/></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="9976312d106cd236ba87262d0a0cf54d"/></dir></dir></dir></dir><dir name="view"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="c4ecbc15d7481fed9903b3dde6cb76d1"/></dir></dir></dir></dir></dir></dir><dir name="eav"><dir name="attribute"><dir name="edit"><file name="js.phtml" hash="1cd780abd50e66840498ef241416ef6b"/></dir><file name="options.phtml" hash="b62b35584ad6044df0a267434728892b"/></dir></dir><dir name="email"><dir name="order"><file name="items.phtml" hash="c13bc0e0bd288da910dbb2fd84a9ce58"/></dir></dir><file name="empty.phtml" hash="0aba206a799ac0a515730f28b8ac123e"/><file name="example.phtml" hash="a17fa4912638a68fbb3877f9bc220863"/><file name="forgotpassword.phtml" hash="2761d703cab381e6569ea17f1fda83cc"/><file name="formkey.phtml" hash="a9064df4a81e204582839b8edf2aed28"/><dir name="giftmessage"><file name="form.phtml" hash="e1868bbf88971067a158cd961a289a8d"/><file name="giftoptionsform.phtml" hash="5c0ef03699b2c2508e4eb9bfd5fc3443"/><file name="helper.phtml" hash="04e9edd7d8478a71e621bfad87865f7b"/><file name="popup.phtml" hash="e5c0a9152f647cecff3b604a7e061741"/><dir name="sales"><dir name="order"><dir name="create"><file name="giftoptions.phtml" hash="ae9310c826dc5935b140c2a8d9e5fd73"/><file name="items.phtml" hash="2802f85e9f389d59e69606540285f4ef"/></dir><dir name="view"><file name="giftoptions.phtml" hash="63382086c4c32d588796f1ab21adc147"/><file name="items.phtml" hash="69fdd1217ae8b3812310a5362c219e5b"/></dir></dir></dir></dir><dir name="googlebase"><file name="captcha.phtml" hash="d77c18f68c4abd9a1bb1c19de1d53c1b"/><file name="items.phtml" hash="c885e705bda18cc3bbf90dddb94918aa"/><dir name="types"><dir name="edit"><file name="attributes.phtml" hash="4795d282786fd7700b28a53e89eaa5aa"/></dir></dir></dir><dir name="importexport"><file name="busy.phtml" hash="f9f89cd954a79ca5f279a0d4fdb6b5d5"/><dir name="export"><dir name="form"><file name="after.phtml" hash="b7f2e5154d620c04f04499feabb63bd7"/><file name="before.phtml" hash="c3f67125078e60f4dfd40e844f9acb9a"/></dir></dir><dir name="import"><dir name="form"><file name="after.phtml" hash="b42f0f4cf9c476ce84ed9962e97fc248"/><file name="before.phtml" hash="4155be820c93e301c7de2801e44fe3ed"/></dir><dir name="frame"><file name="result.phtml" hash="0c5d520411595f63ba45ed502adca5a7"/></dir></dir></dir><dir name="index"><file name="notifications.phtml" hash="fa648c216c2aefb82e2634cf657abdf7"/></dir><file name="login.phtml" hash="d263b066415db4f2a2f4eaddc4845896"/><dir name="media"><file name="editor.phtml" hash="86638654991aa6836230755dd3077527"/><file name="uploader.phtml" hash="4a5de3593d5d3ab0a117b0c04c9fc520"/></dir><dir name="newsletter"><dir name="preview"><file name="iframeswitcher.phtml" hash="11d9f85bb1aca38f02ed619f5c2494b7"/><file name="store.phtml" hash="f2acb163734214fe61b00bfa64fcab94"/></dir><dir name="problem"><file name="list.phtml" hash="b8de157e83d8c9a84b769e834029ff80"/></dir><dir name="queue"><file name="edit.phtml" hash="3f9016faa03f1873a123e6294e265624"/><file name="list.phtml" hash="0771254da01ac42a7c19cffd21916598"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir><dir name="subscriber"><file name="list.phtml" hash="dc927044644ed99d71e9f94f6c6054d2"/></dir><dir name="template"><file name="edit.phtml" hash="5cdb64a34fa36c6fe2696a8a139b9468"/><file name="list.phtml" hash="88495852292533931dd9ccc1297c22cd"/><file name="preview.phtml" hash="b1a63cee2f9173aecdd27b0ddb4225e3"/></dir></dir><dir name="notification"><file name="baseurl.phtml" hash="ace29ea97f986e6af7f68ff769024a08"/><file name="curl.phtml" hash="4d6bb471fc24d2fac093f5a6ba54eb2b"/><file name="formkey.phtml" hash="10cefd4b04d9167dc36b15d146d67792"/><file name="security.phtml" hash="09f80eb2e65d5f3eb864b69a8de0bb7b"/><file name="survey.phtml" hash="e81aa7a0204d2af52937c2179b3226a0"/><file name="symlink.phtml" hash="1a44ab56d54fb00ff8aa9174fbd5aacd"/><file name="toolbar.phtml" hash="c81daccdcaa9752fd63b40965991bb40"/><file name="window.phtml" hash="744cead3650baac01cfd6d9cd1cb4ada"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="dabf9325f335361b849aa50056c24f94"/><file name="button.phtml" hash="d9e9b183d42e52a250ce0c5e1aa51a2d"/><file name="confirm-simple.phtml" hash="65e940cd75ab146adf369de3b6900ef5"/><file name="confirm.phtml" hash="3fd54b782715757eb7e6d94cb85ec207"/><dir name="form"><file name="login-simple.phtml" hash="2f1989f21643335d93da793c5048b40c"/><file name="login.phtml" hash="311ecd3b9fe3ac1b34a5c685754fab9a"/></dir><file name="head-simple.phtml" hash="9b1d56c7b532c4b5249df0ad5654634b"/><file name="reject-simple.phtml" hash="b424a12924735b3579d1a99f02c40779"/><file name="reject.phtml" hash="e39aeff75e3b8ddfc88dca8323e6e954"/></dir></dir><file name="overlay_popup.phtml" hash="93042aacbf5f63ac20d73af7529adb9e"/><dir name="page"><file name="footer.phtml" hash="66b29c98ee96825c589df8eb448f5c7d"/><file name="head.phtml" hash="21ef5cb055b23d9e539cd470c6227569"/><file name="header.phtml" hash="18653a55fab64c9b173bfca72ded1c93"/><dir name="js"><file name="calendar.phtml" hash="05ad9d43d629be8c5e328d40b97725b1"/><file name="translate.phtml" hash="9a4a8ff517585fae47478d963e6012c6"/></dir><file name="menu.phtml" hash="e7a10b2a4c8ac756d36c1925e54e4ccf"/><file name="notices.phtml" hash="1da5145293a029071c77817fbda3736c"/></dir><file name="page.phtml" hash="b83ddcffabe164c96979fa9f761f0e52"/><dir name="pagecache"><dir name="cache"><file name="additional.phtml" hash="fbc4928f817e21a76a876510c04134f7"/></dir></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="f30991c8c4ffe39a426e7a18b67a357e"/></dir><dir name="info"><file name="cc.phtml" hash="c07e6426f4b89547d95b7971cd40df24"/><file name="pdf.phtml" hash="44b8fe88a963653eac67d3e7e18a7e06"/></dir></dir><dir name="payment"><dir name="form"><file name="banktransfer.phtml" hash="365b2e7ad83c8fc3579fb10e21000e43"/><file name="cashondelivery.phtml" hash="9ee032367a799e485e9490300d50f923"/><file name="cc.phtml" hash="a9e654db08418dd198b1ddad0481836d"/><file name="ccsave.phtml" hash="a88ffde3b02d476b5ef8c302616662b3"/><file name="checkmo.phtml" hash="6e9a71f5bc7d249839487adcdea9e1a6"/><file name="purchaseorder.phtml" hash="6991195785bb67b47e3aaf2b19906e8e"/></dir><dir name="info"><file name="banktransfer.phtml" hash="57bf7dc47f93db636e4669dd0a13db15"/><file name="checkmo.phtml" hash="0844a4de163d70530af55a89ff4fee1a"/><file name="default.phtml" hash="34760442900ba7b17d52d6bc8d6e8732"/><dir name="pdf"><file name="checkmo.phtml" hash="331eb71760b1b91013a242adc2e7850c"/><file name="default.phtml" hash="3dbdf5ee79c5835d3e8a68bf896fe7f0"/><file name="purchaseorder.phtml" hash="b72078c393f9fc8a72469cb4f60cf740"/></dir><file name="purchaseorder.phtml" hash="66328b8bd3bffcf251e83b190aa1674c"/></dir></dir><dir name="paypal"><dir name="system"><dir name="config"><file name="api_wizard.phtml" hash="d1dcd0ac566a48d087a02d9fb5aa7681"/><file name="bml_api_wizard.phtml" hash="1edb19592c4fec6213fed297a8a7a68b"/><dir name="fieldset"><file name="global.phtml" hash="32e284583341b991d9db598d0f20562f"/><file name="hint.phtml" hash="749bdb7e9a11df10ad5ba07f1296a6d0"/><file name="store.phtml" hash="ff8de41b3fc398c7ca56f2d977c243a9"/></dir><dir name="payflowlink"><file name="advanced.phtml" hash="61e36b2fb2436c279361a8bf0a912095"/><file name="info.phtml" hash="bc613c199e8f8d876e673383a2265a17"/></dir></dir></dir></dir><dir name="permissions"><file name="role_users_grid_js.phtml" hash="039d1507a9d84a5e2afdf5d8621d54e3"/><file name="roleinfo.phtml" hash="8df7874910110a250fec05fc56e9b98e"/><file name="roles.phtml" hash="a2f4af140d0ce98fb93c7a59e13a89ef"/><file name="rolesedit.phtml" hash="d576cb5bb8ba92748cd0c63bc6d6bc2f"/><file name="rolesusers.phtml" hash="6dcf66979972089d7a9ef0ca916e1328"/><file name="user_roles_grid_js.phtml" hash="8187202fb98a78f90337e321c1d26bef"/><file name="userinfo.phtml" hash="28d1cdc64efa318b2c5b9dcf2aac11a5"/><file name="usernroles.phtml" hash="ba15b18cd8aea5c822ef6cc4b7d9dbf1"/><file name="userroles.phtml" hash="cba05a2a6ab73a5e7cd6727c10f9f17b"/><file name="users.phtml" hash="f8dd4e988ff70de30a3ee7961bdbaf9c"/></dir><dir name="poll"><dir name="answers"><file name="list.phtml" hash="ab3de09500ac824dbdfa531ccc8b5148"/></dir></dir><file name="popup.phtml" hash="85b7139ff08a023f58c95469513ba241"/><dir name="promo"><file name="fieldset.phtml" hash="88f350e4aeafab8d60adbf812ebb5882"/><file name="form.phtml" hash="de3b47937cd0734513668d65a1685192"/><file name="js.phtml" hash="f583f3d25029a4e6e5543f8ef9fd4e1d"/><file name="salesrulejs.phtml" hash="59b1be9b748c984ec700d5db96cf9b4c"/></dir><dir name="rating"><file name="detailed.phtml" hash="eecfd5103a29cc884cd7769353249c3c"/><file name="options.phtml" hash="91e48ca064c209467a95ebb4106098d3"/><dir name="stars"><file name="detailed.phtml" hash="425a39a4861305eb7d488557d1f29b1f"/><file name="summary.phtml" hash="81f09d08d8f13602dbb6fc47c9e0c4dc"/></dir></dir><dir name="report"><dir name="grid"><file name="container.phtml" hash="492edaeb36c99759e601f69d09d8ce63"/></dir><file name="grid.phtml" hash="4df44d5bfe605dcf1f4de209c3251d3a"/><dir name="refresh"><file name="statistics.phtml" hash="0134889b333e23b21dd9338b5a8c672f"/></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="97ff2bbd0264f2f48655b85c31ec42d5"/></dir><file name="switcher.phtml" hash="6d59b52c5c4b637186877c1b64081733"/></dir><file name="wishlist.phtml" hash="3763e4bc8859b4dde13a882433400112"/></dir><file name="resetforgottenpassword.phtml" hash="7f718933a22551f4448477d3482d5119"/><dir name="review"><file name="add.phtml" hash="e259fc69d280b3d4f89516be872292a3"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="form.phtml" hash="38dd2395d72f2485bebe46b154e36567"/><dir name="view"><file name="form.phtml" hash="4e5530d7218b4e29fdb657f3afdd32be"/><dir name="tab"><file name="info.phtml" hash="1980a461df367b8917a1334d73e67f61"/></dir></dir></dir></dir><dir name="items"><dir name="column"><file name="name.phtml" hash="bde8b8b434583ba4a17234232b4b436d"/><file name="qty.phtml" hash="df2ef73497c3145b42497e0be0b0ac6a"/></dir><dir name="renderer"><file name="default.phtml" hash="8e6bdcd0a0e30f8bf1ff6a4a68321183"/></dir></dir><dir name="order"><dir name="address"><file name="form.phtml" hash="8d8997f272ff6f7704ae8da2309e5c26"/></dir><dir name="comments"><file name="view.phtml" hash="3e593f32eb91950ada970136e635039a"/></dir><dir name="create"><file name="abstract.phtml" hash="450fd33745d12b718eadb477cb97169a"/><dir name="billing"><dir name="method"><file name="form.phtml" hash="f373edeac1e14f15cc192104b3c06799"/></dir></dir><file name="comment.phtml" hash="89d6f617055bcaf9f017ac3325153b9d"/><dir name="coupons"><file name="form.phtml" hash="22d58a1fdece0789f9fb075d12f7655f"/></dir><file name="data.phtml" hash="ceadda3d3575a6f8ad4c4d1691f22386"/><dir name="form"><file name="account.phtml" hash="ae06153e8c74cbf90b9192ae1cf73f3a"/><file name="address.phtml" hash="6869a9b9cafd7172eebcbbb260624f70"/></dir><file name="form.phtml" hash="91bae87423c95fa1feee87f39533c186"/><file name="giftmessage.phtml" hash="d060ea7a368d682336160e2c3a6de71e"/><dir name="items"><file name="grid.phtml" hash="1cd6c75f076b5157ec50a44870ea17b1"/></dir><file name="items.phtml" hash="81eac8351d529461343eaf3ccdd0dd75"/><file name="js.phtml" hash="57a05543973a5f3b3dc9604d7681dd61"/><dir name="newsletter"><file name="form.phtml" hash="bd490b0117568c4338318ced6558fe84"/></dir><dir name="shipping"><dir name="method"><file name="form.phtml" hash="69ab67e875d5c69f19da9200488fdbd4"/></dir></dir><dir name="sidebar"><file name="items.phtml" hash="52ef961d1108ba56b8fbd95ee6fc99b5"/></dir><file name="sidebar.phtml" hash="1491271d8b4b001e27e024072dd425d4"/><dir name="store"><file name="select.phtml" hash="b4e047779e15d495e99b71420c87b476"/></dir><dir name="totals"><file name="default.phtml" hash="e0dae5956e25f189f645d644b9bd61db"/><file name="grandtotal.phtml" hash="76c14c414df70b9e0fc2e7a1efe83ed0"/><file name="shipping.phtml" hash="8e7d48743a790b46137bcaf7adf46c4f"/><file name="subtotal.phtml" hash="75ba127e657699c654a6e32c6065a56f"/><file name="tax.phtml" hash="74594996a9b8e9f829f0e0e4177f0e09"/></dir><file name="totals.phtml" hash="7b23f88369b46bc4ab5038ec95ef83e0"/></dir><dir name="creditmemo"><dir name="create"><file name="form.phtml" hash="6c0de85b0b6f77bad60444775b1838b6"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="a082ae2d22e324e83fec20f26051f533"/><file name="default.phtml" hash="1704c99d6351e2e1abd6c330332b2cce"/></dir></dir><file name="items.phtml" hash="fa8f2d1b0b7f1a518e09a4c98b45398d"/><dir name="totals"><file name="adjustments.phtml" hash="d07ae2fccc399b065421afabb53e225d"/></dir></dir><dir name="view"><file name="form.phtml" hash="a3dee338f777091321c67d051794ac8d"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="2e13d26b8abf2c1ec41f4e934c45ff3e"/><file name="default.phtml" hash="f5d7b87ab43b377628f5f0c654ecfb75"/></dir></dir><file name="items.phtml" hash="db0d0fdfbb092d62668517474e73ab9d"/></dir></dir><file name="giftoptions.phtml" hash="af9be7a4c53bc915eafdb8c36363d4f9"/><dir name="invoice"><dir name="create"><file name="form.phtml" hash="a1c5e849f07ac623de58c44ee5bb788b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="59cb8f69057a081397a7d08b1d44de03"/><file name="default.phtml" hash="4e066e654dd4905f9248cb58e6202dc7"/></dir></dir><file name="items.phtml" hash="b59bc8cbdf561361ec74b64e57e3d6a9"/><file name="tracking.phtml" hash="e267501bbb03bcbbf0c95a0e19b2a161"/></dir><dir name="view"><file name="form.phtml" hash="670a59453a48856bf7dba0d7e3841e4b"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="f3fd595909d713740f78fcc18bb165d4"/><file name="default.phtml" hash="efa3a5f3b0544d4b3453e54c511a7bdc"/></dir></dir><file name="items.phtml" hash="0b0174f23e9694f4ffb6bd4639ff222f"/></dir></dir><dir name="shipment"><dir name="create"><file name="form.phtml" hash="4b2d19de5e5522bcba94ae76f13077fe"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="47a7a02503e6ce8185f220ec014b616c"/><file name="default.phtml" hash="cb6088852de61af50134bfddfc9aadfd"/></dir></dir><file name="items.phtml" hash="2b6c3e9982fa8ec9a5986c1094ab4b37"/><file name="tracking.phtml" hash="adaaa3f1debf0abbd8369328762007e8"/></dir><dir name="packaging"><file name="grid.phtml" hash="c7149c55a5c36f0ed429484a47d12447"/><file name="packed.phtml" hash="f4f5982a47487915b4f0e281cc52ac5a"/><file name="popup.phtml" hash="781f87de153aedc68d87e918f0489505"/></dir><dir name="tracking"><file name="info.phtml" hash="936830f51a16c0304d0f5cf8440cd214"/></dir><dir name="view"><file name="form.phtml" hash="f00f611ae348eb4296063cec99e08535"/><dir name="items"><dir name="renderer"><file name="configurable.phtml" hash="c1088e05631ed09666d9b3027e51020b"/><file name="default.phtml" hash="14f57ff7e16a97169be8dca512309e4a"/></dir></dir><file name="items.phtml" hash="1e5e39056014e0b7c4264203a8156c95"/><file name="tracking.phtml" hash="6cfca1785d2a0023ebd96f8d822b2339"/></dir></dir><file name="totalbar.phtml" hash="9dd03f8ece3dc8a066182a63e750d3bb"/><dir name="totals"><file name="discount.phtml" hash="fe5af2981c988ee51a156066e0a5d30e"/><file name="due.phtml" hash="a8bb79f030ee27f4cc5fbd3a945aee84"/><file name="footer.phtml" hash="7a3146c9823d4412bb0431a9eb880208"/><file name="grand.phtml" hash="c42431c3da562b0c7f87717bf234de86"/><file name="item.phtml" hash="ef9cb2aa093c6b55a22d137d1798a958"/><file name="main.phtml" hash="75720ac86b02cf404f76051b29ce3e34"/><file name="paid.phtml" hash="011dd3a39e180f1ffcb10921ae6f08e3"/><file name="refunded.phtml" hash="d846f8f28c34d745e7e79c8c108286e7"/><file name="shipping.phtml" hash="729980faf9c31e1bfe5821a3378430cd"/><file name="subtotal.phtml" hash="2a87b7f269291096bd3500f6b56e357d"/><file name="tax.phtml" hash="68edfed16527ef713812dc6c8d5815ea"/></dir><file name="totals.phtml" hash="f5ea5e7f19419b72297a24a9860e9e0c"/><dir name="view"><file name="form.phtml" hash="b2ae23cf63e436a00dab747a32209d41"/><file name="giftmessage.phtml" hash="c6f8701e8c220cf71cd465310b576b36"/><file name="history.phtml" hash="fa87a814656708aaea4eaa863e22bf11"/><file name="info.phtml" hash="225d8cd3bec626754feb109fc0d45d3f"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="3d3def9dad4e5842bdc182c756f0d9a3"/></dir></dir><file name="items.phtml" hash="e71776c9f5d744c972304706cb5477b6"/><dir name="tab"><file name="history.phtml" hash="801abf66aff3f3036fd9ad7ac1731fbe"/><file name="info.phtml" hash="2a7132e5976c34bab03a7fb8996fb910"/></dir><file name="tracking.phtml" hash="faf1ca869164dbd44513ca9e8a267434"/></dir></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="ad004e28a0852b50f068d37915d4d903"/></dir></dir></dir><dir name="recurring"><dir name="profile"><dir name="view"><file name="info.phtml" hash="7324c965675a482a0b0c3c7ac8e822ff"/></dir><file name="view.phtml" hash="879c3de013c31794597198feeea52531"/></dir></dir><dir name="transactions"><file name="detail.phtml" hash="9e3fa2b5112e90db65172a9a13d22574"/></dir></dir><dir name="store"><dir name="switcher"><file name="enhanced.phtml" hash="938ea5cf69346302b37a36d2a494fab2"/><dir name="form"><dir name="renderer"><dir name="fieldset"><file name="element.phtml" hash="0374f50a623b74df54a48010e5a0b587"/></dir><file name="fieldset.phtml" hash="c91fe72f4eaac1944751201191fe79a6"/></dir></dir></dir><file name="switcher.phtml" hash="1b7165f0fcee6aa73a83d369faef0aae"/></dir><dir name="system"><file name="autocomplete.phtml" hash="7decf3f54f0ed293448ca2a84ec826c7"/><dir name="cache"><file name="additional.phtml" hash="f55be32d13e9ca88bc5ad05359ac594c"/><file name="edit.phtml" hash="392cc02350f73d675ae8f6b65811bfc8"/><file name="notifications.phtml" hash="a019d0760ea6cfdd4e2c93665f5f019a"/></dir><dir name="config"><file name="edit.phtml" hash="5f971d7aca8e1a70103f34ea2f8e16e0"/><dir name="form"><dir name="field"><file name="array.phtml" hash="50ce1dd35ed11a8db3d3ad59e515b0bf"/></dir></dir><file name="js.phtml" hash="874834fe0b24c249efc0a0adb19e32eb"/><file name="switcher.phtml" hash="5a899f08580bc511f7cb308ad5434a0f"/><dir name="system"><dir name="storage"><dir name="media"><file name="synchronize.phtml" hash="79259b6b21df8a122050099622badbc8"/></dir></dir></dir><file name="tabs.phtml" hash="090b7d99c6f946ec07797a3de3ed9357"/></dir><dir name="convert"><dir name="profile"><file name="process.phtml" hash="e9728649b4581052be5f66bbe38107d6"/><file name="run.phtml" hash="67ccdf7c3b9558a1136e182f61466f00"/><file name="upload.phtml" hash="2a4eaa90c21f90f8dd397077a1995a81"/><file name="wizard.phtml" hash="e8aaabfac5406b86cbeae1f2dbfbcbab"/></dir></dir><dir name="currency"><dir name="rate"><file name="matrix.phtml" hash="3ee08eb7f3f294691d5403afee27bc73"/><file name="services.phtml" hash="fd18998930424daa0dba5eb946accc48"/></dir><file name="rates.phtml" hash="bd8cba7764024b9d4f81e70b92d379ee"/></dir><dir name="design"><file name="edit.phtml" hash="a6748502e84e6f8c1ce7a7b6fb3fd3f5"/><file name="index.phtml" hash="d4d25161838ba0272e01b70031a54702"/></dir><dir name="email"><dir name="template"><file name="edit.phtml" hash="d791749a092eae1c401456f5e50b8215"/><file name="list.phtml" hash="4bd2cfbe71edbb3924dc49cbc4c5b909"/><file name="preview.phtml" hash="5790831f8fcca232e851b8fb3ddf1a82"/></dir></dir><file name="info.phtml" hash="d350dcbdd09f2bed44c3b663c40b514c"/><dir name="shipping"><file name="applicable_country.phtml" hash="1662a0971b90b4f392bf7f36fe036a92"/><file name="ups.phtml" hash="cebcd62310d874f6ed19940ddc95fc2e"/></dir><dir name="store"><file name="cell.phtml" hash="70aca9a7aaf50e07a2cb446b32dae429"/><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="tree.phtml" hash="5c3d3ccfbbed1b062a0d78eed7e2ca74"/></dir><dir name="variable"><file name="js.phtml" hash="3e5e5f42e64fb8534d830b271cb934a1"/></dir></dir><dir name="tag"><dir name="edit"><file name="container.phtml" hash="d16c22231434354b1a08ce9cb04e5bb5"/></dir><file name="index.phtml" hash="4b4e9eb77ef2a3f503c478ebc301ab55"/></dir><dir name="tax"><dir name="class"><dir name="page"><file name="edit.phtml" hash="f7c55192b773349cc38cad7258624fcc"/></dir></dir><file name="importExport.phtml" hash="561e99d910bf37bb5e887e626dade6ba"/><file name="notifications.phtml" hash="dd5cb30e2fa2f269848bbb0b235c97a3"/><dir name="rate"><file name="form.phtml" hash="b5ef7d7e4990797250fbf332cf548085"/><file name="title.phtml" hash="2021a60ac40d770ae2f50907d6357e86"/></dir><dir name="toolbar"><dir name="class"><file name="add.phtml" hash="ef10a2d566c82bad8cd9c48873ec6e67"/><file name="save.phtml" hash="f27f7178cbb164d5fca297a1b4ae1fd6"/></dir><dir name="rate"><file name="add.phtml" hash="8b2172962f50b656d6a11b1a0d9fc8c8"/><file name="save.phtml" hash="787a3b092e394ebd99479c69f3e6cd5d"/></dir><dir name="rule"><file name="add.phtml" hash="ba96d2206f0a6b14c04dca48fc6b0e1f"/><file name="save.phtml" hash="9fd8b6602eaa2f8ee60c617de66c633f"/></dir></dir></dir><dir name="urlrewrite"><file name="categories.phtml" hash="0114448eaaebd4f9e9f9bd7dd7b5863e"/><file name="edit.phtml" hash="4eba179dbd4543f97066b99a17becf28"/><file name="selector.phtml" hash="585e7778cd87ec02d3d75a402f1485b9"/></dir><dir name="usa"><dir name="dhl"><file name="unitofmeasure.phtml" hash="1ad7c6f0001c1429f0185ff86e6fb7f9"/></dir></dir><dir name="weee"><dir name="renderer"><file name="tax.phtml" hash="4d51f086a09c7b32da91fdc9b7c5bd0a"/></dir></dir><dir name="widget"><file name="accordion.phtml" hash="f337eec9f160cc17c11d286426ce8afe"/><file name="breadcrumbs.phtml" hash="991d357316a969714c23258a66a1488a"/><dir name="form"><file name="container.phtml" hash="2aacc340af12481a12a1345e78598037"/><dir name="element"><file name="gallery.phtml" hash="6b750f7c975a7911d77194f9aa79d390"/></dir><file name="element.phtml" hash="a163cbf6f7252551f04e552fd5271c16"/><dir name="renderer"><file name="element.phtml" hash="709a892360b1544df89694feaa71793c"/><dir name="fieldset"><file name="element.phtml" hash="024b35eaad113635230eef181c04ad90"/></dir><file name="fieldset.phtml" hash="9155081d516a44ae8b030e9b206bd8c9"/></dir></dir><file name="form.phtml" hash="681abe7da55410a5ee1eb45fa0c778d5"/><dir name="grid"><file name="container.phtml" hash="831d548529bef61d883b077ee4e09c28"/><file name="massaction.phtml" hash="f374ea890a3ccde0a03d9255f93d744d"/><file name="serializer.phtml" hash="db5ddba9dd04c804f40d56a08600239d"/></dir><file name="grid.phtml" hash="c64266d252f382825455fc1b5bcd9fe2"/><dir name="instance"><dir name="edit"><file name="layout.phtml" hash="85d914937a630b43e8d866e00b5ce474"/></dir><file name="js.phtml" hash="a69ee58cc2f7d7d740ad4efafb7b0ca3"/></dir><file name="tabs.phtml" hash="30dbd04b9cd29abf06f3c10dc607eca7"/><file name="tabshoriz.phtml" hash="6f4b7df458502430d1711aa1b8eec3fc"/><file name="tabsleft.phtml" hash="1ed0a68afd01801d1667e4ae5907a9ec"/><dir name="view"><file name="container.phtml" hash="2765ba04c97ff6f78219f296bf479ae3"/></dir></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><file name="below_ie7.css" hash="a9c27fe40eb9d5e3a722be488edd7309"/><file name="boxes.css" hash="a479266072fcf8f86316d2ee59dc1029"/><file name="custom.css" hash="56ea43791cd4ae989b797928019aa7f2"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="ie7.css" hash="bee9b016e93c1a478c0f8c62303421fe"/><file name="iestyles.css" hash="86ac157e19adb69da98938158173aed1"/><dir name="images"><file name="accordion_close.gif" hash="875409122fc82f5f6705e20dd801fd3d"/><file name="accordion_close.png" hash="6213698b5f69bb2907a5c7bb94b5fe8d"/><file name="accordion_open.gif" hash="d9d50e220b0b676094c6134a9708194e"/><file name="accordion_open.png" hash="9fbc3aba23ce5e0465e4d1cf3f6a7aee"/><file name="add_btn_icon-disabled.gif" hash="c8f6a5cfb455ef121efb56a747821f82"/><file name="add_btn_icon.gif" hash="7300097305b577ee564dc49102822d16"/><file name="address_list_li.gif" hash="79b917b514e35ce0a7833a5e268fd9f7"/><file name="address_list_on_arrow.gif" hash="3a2884ddcc87ebd48883662530b9de1b"/><file name="address_list_over_arrow.gif" hash="e826883c71b1184bd4f29433e39c18ad"/><file name="address_list_over_bg.gif" hash="56291480cc89de9d817205a5f23b66dd"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="ajax-loader.gif" hash="e2a38f1e23288e315af3c55416bc1ce7"/><file name="application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="arrow_sort_move.gif" hash="f5ac151a2b0cb1f07d6e771b8aee0ea7"/><file name="bg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bg_create_order_totals.gif" hash="ff6ab75c050b959c539cc6a6fdff2934"/><file name="bg_notifications.gif" hash="a365594725a83585d989f722b3d8c458"/><file name="bg_window_mask.png" hash="93d6efad062d24c94c105802b138b6a5"/><file name="bkg_btn-close.gif" hash="df3f2332f0bad01e031deb22b81f630c"/><file name="bkg_btn-close2.gif" hash="822457d78fb3c21dc12e9777d83eb4f1"/><file name="bkg_config-advanced.png" hash="b898594a9f1849bf386c06979ef613a8"/><file name="bkg_config-nested.png" hash="7b0fdbf98746c3c916b432c37321ccc4"/><file name="bkg_config-shaddow.png" hash="9ee4318e3f4afc446d26e7f66d01cfbd"/><file name="bkg_tooltip.png" hash="56cfed3ed8a65b19f8de88946d1a0a01"/><file name="blank.gif" hash="5722d7bd0f1e1379d0a2005a0a9ea401"/><file name="box_bg.gif" hash="4c501bd6db9d361c18780f106a809b03"/><file name="breadcrumb_bg.gif" hash="72c4adf6c75b4640ca8f7cadffa42266"/><file name="btn_add-image_icon.gif" hash="1d42210fd29fc534d9ed6b41e811d40f"/><file name="btn_add-variable_icon.gif" hash="a2db02e318d107d5b57b444c8d80b8f8"/><file name="btn_add-widget_icon.gif" hash="b4f66ca7f6097fbafd672e0b3f076ef4"/><file name="btn_add-widget_icon2.gif" hash="467acd3a14fb8be37191f5d2ec5a5b13"/><file name="btn_back_bg.gif" hash="8be512788b8044fe31aa8d00cc16ba7b"/><file name="btn_bare_bg.gif" hash="ddbbab8c0d201c3e502d50e7d4a3d64b"/><file name="btn_bg-disabled.gif" hash="079971a9d2c385fe353d35716ec9f26b"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="btn_bg.png" hash="6e3b7003381f919e8f6533444afaa978"/><file name="btn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="btn_delete_bg.gif" hash="ad740d0c16f2f6603c8ef023004d6539"/><file name="btn_go.gif" hash="1bd787868713767cc205e2ee25e41f62"/><file name="btn_gr_bg.gif" hash="6cc324b79a512150fee24fb3517d22cb"/><file name="btn_gr_on.gif" hash="820c134df02f7bc12efa5a9ac3b4d3dd"/><file name="btn_gr_over.gif" hash="d4c8b807d64c1f493d17c6c9d2bab69a"/><file name="btn_loading-icon.gif" hash="45f500105be432a12c78fed2b4592cf9"/><file name="btn_login.gif" hash="79fa32d49d3f4e39d3fbf8327f9229e1"/><file name="btn_on_bg.gif" hash="709cf5b0be137db1ef8427688503bf37"/><file name="btn_over_bg.gif" hash="f91641168454c03d1fa72731ec97a2b3"/><file name="btn_show-hide_icon.gif" hash="0238c509b33ba56c25df9513bb48f804"/><file name="btn_task_bg.gif" hash="5e0594bd9cbfcc1e32ffa918d7f9c812"/><file name="button-close.png" hash="04d0907b2d7fc3240693497b199f64f5"/><file name="cancel_btn_active_bg.gif" hash="91ce403d286eef2b4e0c13733875882f"/><file name="cancel_btn_bg.gif" hash="26749cf4949ac27c30f597434d3bde65"/><file name="cancel_btn_icon.gif" hash="97e0cd94ed31d6f2a1181f627e60e9a3"/><file name="cancel_btn_over_bg.gif" hash="45eb4e883b17375961672f5390387c31"/><file name="cancel_icon.gif" hash="70a23b78353f0a7b9b118a937fcb7ea9"/><file name="config_tab_dt_bg.gif" hash="a33f71077ca4078caa794cae01d9fca7"/><file name="dashboard-close.gif" hash="5ae5afd61e937fcd2d5b84641255ee4d"/><file name="db-graph-bg.gif" hash="5d76efb7c3244f5684df2566782124ea"/><file name="db-graph-bottom-bg.gif" hash="b58ced87a38a10891106329ae882aa1c"/><file name="db-graph-line-bg.gif" hash="f16bb08e040c2c0a3e23b3f35c54b79b"/><file name="db-graph-line2-bg.gif" hash="744ebfdba20d050f4d252afc216394be"/><file name="db-graph-x-bg.png" hash="d5c26510718a78d22083916d80ef7a22"/><file name="db-header-bg.png" hash="3976cb6351e167686a501a85cf3a68e9"/><file name="db-menu-bg-hov.gif" hash="34ea76a6d105d90fcb63bf105aadb8f7"/><file name="db-menu-bg-up.gif" hash="b0f754872dff5f2f0dc57ba193fdfa4c"/><file name="db-menu-bg.gif" hash="ea534c3c09bb309e566b6ae876655e13"/><file name="db-menu-sep-last.gif" hash="a01fe34854e1187e466fd58d462c4106"/><file name="db-menu-sep.gif" hash="7c5ae1cd59a189261cc3244358d5c1ad"/><file name="db-menu-start.gif" hash="aa5cac2194d937cc7fa904ccfce70ecc"/><file name="db-scroll-bg.gif" hash="06d2411e3b5f350ab21b625439d2d69d"/><file name="db-scroll-but-bot-roll.png" hash="6bc5e482f3f6d8fb1fc5014ddea43706"/><file name="db-scroll-but-bot.png" hash="25c0181e76ff8ceb3c0ec59071b8c72c"/><file name="db-scroll-but-top-roll.png" hash="b7961f2a3b5b641694a9b0b30d58e46b"/><file name="db-scroll-but-top.png" hash="de7df96e961596be9ff556924259b98b"/><file name="db-scroll-roller.png" hash="e01dde7bd096c52179acf29a425a29e5"/><file name="db-tab-bottom-left-bg.gif" hash="124388d44ac58b029377c6311a4782d5"/><file name="db-tab-bottom-mid-bg.gif" hash="9c48f33aa8907cfcb227bc779c2e1dce"/><file name="db-tab-bottom-right-bg.gif" hash="1db45e6fd8abc67d59f96a676607b412"/><file name="db-tab-footer.gif" hash="cac8928acba75bc1edd73186ced78e5c"/><file name="db-tab-header-sep.gif" hash="580312af7441b6a62f7e32081c40fb0f"/><file name="db-tab-header.gif" hash="fdf493b9477fcff7e7be98405effc33d"/><file name="db-tab-left.gif" hash="3fe3c55267dbbdd1db2ff959ccc9e0be"/><file name="db-tab-right.gif" hash="b7a32c8b03efe2fbdb63215d0446e3be"/><file name="dotted_divider_dark.gif" hash="8bf1de196d9ea048bfb25155cedd2e9e"/><file name="dotted_divider_light.gif" hash="92e562bf2070110f6b0a15e29b845445"/><file name="edit_icon.gif" hash="dbda31751c78d964c04394e9d8533187"/><file name="entry_edit_head_arrow_down.gif" hash="985c3ce4439fbf8bb2216fc7e73a3f0b"/><file name="entry_edit_head_arrow_down2.gif" hash="d68dd0fbc2819858a26ea2835c05df77"/><file name="entry_edit_head_arrow_up.gif" hash="d2b90a1823fff9f3917f19b427410144"/><file name="entry_edit_head_bg.gif" hash="1086b7196e8b33c4f46e49fecef0f35f"/><file name="error-msg.png" hash="3cd27b642416dacdc28907c89d934886"/><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="fam_account.gif" hash="c910fd1ff41b940d71b0835e02fc143e"/><file name="fam_application_form_delete.png" hash="972c2d998fc19572dd64af6b5e2e898e"/><file name="fam_application_view_tile.gif" hash="f595a133bf466cb91be23d9686fe6281"/><file name="fam_asterisk_orange.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="fam_bin.gif" hash="2fb388bc9f1d32d3802db8e91dc238bc"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="fam_bullet_disk.gif" hash="9fe82691d960c18d3d315c3f9164af4f"/><file name="fam_bullet_error.gif" hash="008802f44288b732b59cfe9fdbfecefe"/><file name="fam_bullet_success.gif" hash="465a056a3ba3d94367f51c3c0b751391"/><file name="fam_calendar.gif" hash="0614207ce4e3e0a9bd631b39e7692e3c"/><file name="fam_cart.gif" hash="1f2fd2c8ac6574488ea78302b6856191"/><file name="fam_comment.gif" hash="5138f9a4b6019a5b14b8ff9a32a3cb89"/><file name="fam_creditcards.gif" hash="b75b8ce2f4fceb58f8082c48344560c7"/><file name="fam_folder_database.gif" hash="e86175ff0f389ade1fc7bf15e03346eb"/><file name="fam_folder_palette.gif" hash="c0941b9145e06d53cc0d17ac4c151764"/><file name="fam_folder_table.gif" hash="e2914ba75944acd2a9e2d338fa339e16"/><file name="fam_group.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="fam_help.gif" hash="2b5ed4c13a8e24456207b757826c7b2c"/><file name="fam_house.gif" hash="8eb2d580c5a40b7974f4263ca64fb94a"/><file name="fam_layout.gif" hash="5366a5f02260d3a860ef0c4787282ad6"/><file name="fam_leaf.png" hash="078d4f24683331b4557356a59e67b125"/><file name="fam_link.gif" hash="78590d5d8375d1baabe7b66d7b9ceb7d"/><file name="fam_lorry.gif" hash="174e86e45e76e7008fa3510cefa85047"/><file name="fam_money.gif" hash="6996bad465222fb6487cab94b4607846"/><file name="fam_money_add.gif" hash="70ceed401fe9913305f2362f7e26225d"/><file name="fam_monitor.gif" hash="f3bc806ff9d0907320b03018ba2d00ea"/><file name="fam_newspaper.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="fam_newspaper_delete.gif" hash="41acabfc19102be92d3ccbc66d1fede3"/><file name="fam_newspaper_error.gif" hash="009bfa425298e1d2e44e38e58cd97938"/><file name="fam_newspaper_go.gif" hash="eb43105f8e13e3a752d7ca33bb086831"/><file name="fam_package.gif" hash="bf9be09ef64d006455baa211b7c03983"/><file name="fam_package_go.gif" hash="e4f8d380c2f8e5a7345e360293433764"/><file name="fam_page_white.gif" hash="26940eb67826c5af72b6048c7c5a8335"/><file name="fam_page_white_edit.gif" hash="a4f88300b74ad592a5c47ed54ff07af9"/><file name="fam_rainbow.gif" hash="e8b04cc945b3582a181d4ddbc2d2325f"/><file name="fam_refresh.gif" hash="01bbef614023c0890812e76bc7ecf7e0"/><file name="fam_server_database.gif" hash="7901fa06ffd68ed730cf43bb560756fd"/><file name="fam_status_online.gif" hash="a80019ffa3a573f709772ed1099343fc"/><file name="fam_tag_orange.gif" hash="6ce735a0e590bda040b6e1614c42e58a"/><file name="fam_user.gif" hash="63bbdd6d9d7a27591907a7b87898e259"/><file name="fam_user_comment.gif" hash="014dfd31d9af40e3d5960b2b0d900da3"/><file name="fam_user_edit.gif" hash="f5b36e803060c6b82e639a4fad57b9f7"/><file name="filter_row_bg.gif" hash="013a0929a7b2ddc6823bdda17d08acc0"/><file name="footer_bg.gif" hash="7724711d3ca07a5e46a6030e86743a71"/><file name="gift-message-collapse.gif" hash="5b710f5faa9c7352a39c10e3ebbee6fc"/><file name="gift-message-expand.gif" hash="fd53a70cbb1ea048754657a63787e9cb"/><file name="gift-message-grid-column-bg.gif" hash="97a8a9b8cc4ab68e7404ccf1320f50a6"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="grid_sort_asc.gif" hash="b78c3a1a27ac9672a31b7d1bbac60322"/><file name="grid_sort_desc.gif" hash="d958b946eba3dba863d724530a0dba1a"/><file name="grid_th_bg.gif" hash="8f4349fac728858374e17edf03390977"/><file name="grid_th_onclick_bg.gif" hash="7bf331e2a41e5331c4210bdc6adc4383"/><file name="grouped_to_order_icon.png" hash="4bdae9a6199655027b8b8aeee8f80ce4"/><file name="header_bg.gif" hash="cbe510856afa5cb0c32642c1f9a8eceb"/><file name="header_top_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="horiz_tabs_ul_bg.gif" hash="58dbd9c45f76993346c2bb788896248e"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_question-mark.png" hash="23201b7ac207eebd9be0776ea44098a4"/><file name="ico_success.gif" hash="0afb20898a704a106cb4c598868abf32"/><file name="icon-enabled.png" hash="5fa7c06b312cbea3675e844686e434af"/><file name="icon-tooltip.png" hash="5767601cd66b23d0b6fe8defc10dd48d"/><file name="icon_btn_add.gif" hash="7300097305b577ee564dc49102822d16"/><file name="icon_btn_back.gif" hash="89ed97cede3f68241446a62c96e3ce4c"/><file name="icon_btn_delete.gif" hash="dbde0b76d36cfd624bf0de166d0a265e"/><file name="icon_btn_save.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="icon_edit_address.gif" hash="d1ca2bb3a5c86afd379f25d9fc4352e3"/><file name="icon_export.gif" hash="9a13f20c6a17b41b9c357545c2da5636"/><file name="icon_export.png" hash="fb299dd13df666516eabe16f59193383"/><file name="icon_feed.gif" hash="0366583ed6e285d028442fcdebb05072"/><file name="icon_feed.png" hash="8537f6f88fcff4aac793247143d14e42"/><file name="icon_note_list.gif" hash="8d25ba225ca09b687a78bff510df5d10"/><file name="icon_remove_address.gif" hash="2de2b3d02c19adfb93e9e43a392db178"/><file name="login_box_bg.gif" hash="e4654826eaa8d5ebc0ab18e9bee71e1d"/><file name="login_box_bg.jpg" hash="404e37f4ee9f4ff9bfcb638741c7581d"/><file name="login_box_bg_auth.jpg" hash="d90a81db1064ec37b0cc92436725c24b"/><file name="login_box_bottom.jpg" hash="038f15261e74bc381484f2fcfa45a73b"/><file name="login_box_legal_bg.gif" hash="528ac4dd480c4fc00ac808bf17394c05"/><file name="login_logo.gif" hash="a15f85d59684e1ec548b758fb6165469"/><file name="logo-large.gif" hash="b938979c790d4aba4170054fc4a060be"/><file name="logo.gif" hash="c7e9f290d965f707e4c4a61bfdab58cb"/><file name="logo_email.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="massaction_bg.gif" hash="8b5f4db3ab3ea09cd5bd0164d67c4f0d"/><file name="massaction_button_bg.gif" hash="4c8262817e48d007237124ce0e7f4d18"/><file name="massaction_links_delimiter.gif" hash="9a0337183b5b67c0eed75993d7f14d10"/><file name="middle_bg.gif" hash="ba4f176d2c553201ebab4aba5c6d3d20"/><file name="more_arrow.gif" hash="38bb4c0e9270250151486d0bb36c476f"/><file name="nav1_active.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_bg.gif" hash="a1d4ef5b590ce0a425dc04e45ed06cbe"/><file name="nav1_off.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav1_on.gif" hash="a7f9ec7689a65c6b796f0d9b97582d01"/><file name="nav1_over.gif" hash="2c70d6175f1c965c27dda0598a67e63c"/><file name="nav1_sep.gif" hash="5286cbd5ac9ec1b6c027d5b48a74bdab"/><file name="nav2_last_li_bg.png" hash="279935c9799679fc5894337eaabc7cf0"/><file name="nav2_last_li_over_bg.png" hash="39536f00824293d11242888a76f40a5f"/><file name="nav2_li_bg.gif" hash="0a4f34b0e4436c519d31203f19503b83"/><file name="nav2_li_bg.png" hash="2fad219d162324e9a19f2745d5b6d562"/><file name="nav2_li_over_bg.png" hash="dc37c4a4aab40ea2ae44dea5ea133a9d"/><file name="nav2_link_bg.gif" hash="dce00ddad351e72e83bc87274cbaa54a"/><file name="nav2_parent_arrow.gif" hash="60e012a14a077bd2257343facc369c0c"/><file name="nav3_bg.png" hash="2bc7af80ad8886013da38401b63ab6df"/><file name="nav_bg.gif" hash="1b857c7d35f35ef9f6cae9e03a4e3dff"/><file name="nav_list_bg.gif" hash="7a4e2bdb887c12d8a1152bbcc8c02a3c"/><file name="nav_nest_link_bg.gif" hash="1d0c6b374bf02ac4b5aa012955c431de"/><file name="nav_nest_link_over_bg.gif" hash="fae3c579a4d432503b1f4f929d070609"/><file name="nav_on_bg.gif" hash="ac624b580cae5a76f6c92abc5a44191d"/><file name="nav_parent_arrow.gif" hash="3a95559263e569dc1c8065cb2d9b3f2c"/><file name="note_bg.gif" hash="105967d7c15ab4610726eea52d862a97"/><file name="note_cell_bg.gif" hash="71e656d42f8ba8c2d477c6866c499b71"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="notice-msg.png" hash="9cd1dfebccec8a2123d543fa49b17bd7"/><file name="pager_arrow_left.gif" hash="6e44f608dac8eb8be1d1ebee5a3285aa"/><file name="pager_arrow_left_off.gif" hash="30f5e56195ab3546b36f4016db5254be"/><file name="pager_arrow_right.gif" hash="cc79526156b7e0c8abce61fad3d53f77"/><file name="pager_arrow_right_off.gif" hash="f01b7dad9acf0180b5c62edbd7ea9939"/><dir name="paypal"><file name="logo-paypal.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="pp-allinone.png" hash="c457fe4bfe28a18c90d0abd36fe3f880"/><file name="pp-alt.png" hash="37a166931ca15c465bd86311d15e0422"/><file name="pp-gateways.png" hash="90acb72c2f46fa131351efe0492d52cf"/><file name="pp-uk.png" hash="e0830ccb14533051b8b0340471744228"/></dir><file name="paypal_logo.gif" hash="871e205a64292121f4c893373acfb581"/><file name="paypal_section.png" hash="d032551b47e48dced277c4fa344ac7f6"/><file name="paypal_tick.gif" hash="e8685c1fb7c4c106ae4fd24e9bbf5a27"/><dir name="placeholder"><file name="thumbnail.jpg" hash="5c73b5aa515b1719f7b398f5131f91a8"/></dir><file name="process_spinner.gif" hash="345b30b4d0b6088d0151ecfbdf48c036"/><file name="product_rating_blank_star.gif" hash="5e20a299c0ff16168be38b6dde580eda"/><file name="product_rating_full_star.gif" hash="dd5aae332178d928a7f49dea7691b5f6"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><file name="rule-ajax-loader.gif" hash="32dc1f5901143d36fbd7a6df3950819f"/><file name="rule_chooser_trigger.gif" hash="9c498e789c3ce734f5301c2475e2a04c"/><file name="rule_component_add.gif" hash="7914e57701ca26f5c8bf23c6bc3e1f25"/><file name="rule_component_apply.gif" hash="3f9b9025551da6963a9ecf8d184a204a"/><file name="rule_component_remove.gif" hash="4d785bcecfbe716fa4d749d20738a8f0"/><file name="save_btn_icon.gif" hash="f5da95ac65efff5f5cf9c8830202764d"/><file name="sec_nav_bg.gif" hash="99c6741591cdb2a2a128668a1d32d668"/><file name="section_menu_bg.gif" hash="f9edd44c92743a0c9ae9535a7992d6b1"/><file name="section_menu_bottom.gif" hash="167d2ef46ff80158c807b4b916501b28"/><file name="section_menu_link_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="section_menu_link_over_bg.gif" hash="7da7e56567633aab279cf3aec6f49d8d"/><file name="section_menu_over_span_bg.gif" hash="f5ea5292f15ed62b99f0f51d9fff2c66"/><file name="section_menu_span_bg.gif" hash="dbf3916358e794ee809b4cf33903af2c"/><file name="section_menu_ul_bg.gif" hash="3aea6e5452f548438ca34e17954a9d6b"/><file name="side_col_bg.gif" hash="b3691fd62663457af39eaf71dd8cda5a"/><file name="simple_container_bg.gif" hash="56f1ac91169eb4896b8c91384fc8bf15"/><file name="sort-arrow-down.gif" hash="fc2cd9f756ce510c4470478d720f81cd"/><file name="sort-arrow-down.png" hash="dc65160d9d4d6cdd6bfe1b397a931975"/><file name="sort-arrow-up.gif" hash="39026b0ff1f0c18091caa60384491163"/><file name="sort-arrow-up.png" hash="da54e5306bdce67551aa415f5d7f7ea7"/><file name="sort_heading_bg.gif" hash="6066d09f237f556b0a4770e4788e7598"/><file name="sort_on_bg.gif" hash="0cb36788ed4fbf19e657acbc75a3f1b8"/><file name="sort_row_bg.gif" hash="f2e1c5cb26b9f5211419b99d30745244"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="sub_button_bg.gif" hash="e3f66dd60510f9f7e937e2e55442c30a"/><file name="success-msg.png" hash="c64cb2acc3d0eeba48fdea83620913ed"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="tabs_link_bg.gif" hash="34447929f5e6591ba9b5795b983fdfd4"/><file name="tabs_link_over_bg.gif" hash="2cf3f56884096055fb0bdf9474f280c9"/><file name="tabs_span_bg.gif" hash="bcabd4fea0d67b181f21779564c2284b"/><file name="tag_blue_edit.gif" hash="b2163ac3baf7d822b48593342846645a"/><file name="tn_cancel_bg.gif" hash="fcb3506858fcfa8d1778b0683dc89f54"/><file name="tooltip_bg.gif" hash="0aa4b866fc067a75f27ab749c1dabf74"/><file name="tooltip_corner.gif" hash="71146534671d5e0751505640b7c59859"/><file name="tooltip_top.gif" hash="032ff52a6ff5714cbdf6c1f62abaf7e5"/><dir name="tree_icons"><file name="join.gif" hash="4d5d614e0da056df815a4306d6368692"/><file name="joinbottom.gif" hash="4b3daa7f2cc584f1aac0d142275d7cba"/><file name="line.gif" hash="63ab38a6203262f15ca46c631232ea2c"/><file name="minus.gif" hash="d647fbbd0ec410b8f3bb3357b62eedcf"/><file name="minusbottom.gif" hash="b09d684cca7135ef728141aaf2464baa"/><file name="nolines_minus.gif" hash="eb2243a354ffcfac93ba0fe948f7167d"/><file name="nolines_plus.gif" hash="ec92b634b63608fb4b0dbf114e3b89e1"/></dir><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="varien_logo.gif" hash="6f10d0fe572cb012947c164217e9e428"/><file name="warning_msg_icon.gif" hash="4cf6ec7f59ab09f9c18b3a4301714c6d"/><dir name="widget"><file name="catalog__category_widget_link.gif" hash="8435943009f1f774bbd6a4809c719eb8"/><file name="catalog__product_widget_link.gif" hash="62f2d7020143f98ba7514469eb612a7f"/><file name="catalog__product_widget_new.gif" hash="37a5af9f98ae73e180ad0cca05c95324"/><file name="cms__widget_block.gif" hash="b7b0b1517cc38b18b92841b33b312190"/><file name="cms__widget_page_link.gif" hash="b839dee210e61850a5858cc8634cbccd"/><file name="default.gif" hash="684143ae5531aa6ba22215f4fadeea6c"/><file name="reports__product_widget_compared.gif" hash="bd3e5a5015eb2c5c64f1d11835166dc4"/><file name="reports__product_widget_viewed.gif" hash="44d5cd71e4fb7235f9cff0c7e2b2f531"/></dir><file name="widget_placeholder.gif" hash="2bd8d72cf12f8d7d0a6a3268f97786ff"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/><file name="window_content.png" hash="08361df29783d46a2493cf0d8ad733a7"/><file name="window_top.png" hash="555a8db5efa3a252c2ead3d3dadd1075"/><dir name="wysiwyg"><file name="skin_image.png" hash="a521b0c60b001de4a3405e73c4a6cd4a"/></dir></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="27083525fe48622ce931f01c0dcdfcc7"/></dir></dir></dir></dir><file name="menu.css" hash="a1dea5350cfe01b4e27c2606a27762cd"/><file name="oauth-simple.css" hash="08c16d55aef90c4668473326fa11f86a"/><file name="print.css" hash="0003cbfda260e9eee2fefbaf45e8d40f"/><file name="reset.css" hash="e1cccd2f5ec4178349bde538b1f3fb30"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml
deleted file mode 100644
index 32728a8..0000000
--- a/var/package/Interface_Frontend_Base_Default-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Base_Default</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This is a Magento themes base</summary>
-    <description>This is a Magento themes base</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:40</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="etc"><file name="theme.xml" hash="1b3f57d0a5774c3ee81f1647dd726a07"/><file name="widget.xml" hash="1b115ea6ec3f8c6db45e36760706be65"/></dir><dir name="layout"><file name="authorizenet.xml" hash="855c24dbd6d10c3ba28c17a8ce23601a"/><file name="bml.xml" hash="24d1888c05d081f537c3f57b9a29c4aa"/><file name="bundle.xml" hash="ee537028ca8d08e4c13ec6a4b3fbffb3"/><file name="captcha.xml" hash="428f52561c29ce5476468d41693b23cd"/><file name="catalog.xml" hash="284510e876c6f8e94fdcd1e00b1acd81"/><file name="catalog_msrp.xml" hash="cffdf3f5839375aa454f900093675ba8"/><file name="cataloginventory.xml" hash="06296ed114aa7c924a6aab916e6255aa"/><file name="catalogsearch.xml" hash="ddf280146c63bac6fff420c441845fab"/><file name="checkout.xml" hash="db3054a77255f3abf914545019160cfa"/><file name="cms.xml" hash="23faafff4439ede1d8a16e679e57d89c"/><file name="contacts.xml" hash="1eab2e4a72bf322f2233a22ece428fed"/><file name="core.xml" hash="f148469b0dbf2d204bb65312da9c301d"/><file name="customer.xml" hash="ab5cb799d48a7d7f1e51cbc05730eda9"/><file name="directory.xml" hash="2405153a0f2c424ca4fc1d076ad04631"/><file name="downloadable.xml" hash="491be3217bc4b128edf3cd7928fedd38"/><file name="googleanalytics.xml" hash="51aaaecaa23e340e5175d4bd6340f671"/><file name="newsletter.xml" hash="acf4cdc3756727420cc5151a60c059fe"/><file name="oauth.xml" hash="be99a8e31ef178e9cbd15b23027888a1"/><file name="page.xml" hash="795fa23724151dd8a7601b83aa45840b"/><file name="pagecache.xml" hash="bd3f4873b9dc907304e3161d8d026a0d"/><file name="payment.xml" hash="59b2f3f0947d2baae8cee91b96927a72"/><file name="paypal.xml" hash="e8cef6dbfd787dc0c7706ae6573253b2"/><file name="paypaluk.xml" hash="b374285cf042a5cc0e0a092568912c6a"/><file name="persistent.xml" hash="0bccb7bc4884346c44d91cd333cc3cda"/><file name="poll.xml" hash="176c92c32872efbf8175d8b02b5c9077"/><file name="productalert.xml" hash="6e7c0fff4fd537bcfa031fc088b6f3e7"/><file name="reports.xml" hash="764393665f03973464133dbc50a0a248"/><file name="review.xml" hash="378afb80fec6d583a0e8450a20495cb0"/><file name="rss.xml" hash="92d39fcc26eb6d590abc36661441ce03"/><dir name="sales"><file name="billing_agreement.xml" hash="5411e2c9dcf1681917db2cedb11ec5de"/><file name="recurring_profile.xml" hash="dab9149e5fd8fb3923165ca88de4ad74"/></dir><file name="sales.xml" hash="e3031185eae6df20c1ee281206bbfa9c"/><file name="sendfriend.xml" hash="eb574c649d054ffb9eef58e704f6ed2c"/><file name="shipping.xml" hash="96441af87095085b4f40c628b9dcc6de"/><file name="tag.xml" hash="e502cb505ee72082ca8d72cb8a3e5762"/><file name="weee.xml" hash="5c9f1bd15a6c8245071bcc13d7943c0b"/><file name="wishlist.xml" hash="593d574973f72aa189321a794d4af0f9"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="00f7a6eba53a3a693566ec7285fcafbd"/><file name="iframe.phtml" hash="ae37639a5bfc9361080156be19957bce"/><file name="info.phtml" hash="7d70e1b79f91cf902d66f2b14722da85"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="list"><file name="partof.phtml" hash="b19a017f8ca29e890244c35b8d94f6a9"/></dir><file name="price.phtml" hash="aa614de35a91fb7f70a02270771ff3dd"/><dir name="view"><file name="option_tierprices.phtml" hash="94e43618af517cb5a72094b59599f4cd"/><dir name="options"><file name="notice.phtml" hash="ade99bac4130350e9ddc572374704e4e"/></dir><file name="price.phtml" hash="a87dfbf46fbe9e3da8ffcdc6957f79a0"/><file name="tierprices.phtml" hash="6d3b049e6f2febbf5dbbf1f508bf9de5"/><dir name="type"><dir name="bundle"><dir name="option"><file name="checkbox.phtml" hash="6e63147acaf0e63969d7f0056dac34c7"/><file name="multi.phtml" hash="a8a4aebc5dc270253baba340272bcf63"/><file name="radio.phtml" hash="e453d2c5f3da4d74c3862c8cde6acb6f"/><file name="select.phtml" hash="8d12adecc1335ab12d573d1ed15b9129"/></dir><file name="options.phtml" hash="a26af0c38ea071f890137e475c4a17da"/></dir><file name="bundle.phtml" hash="b9ffd5141b2913ff07ea855d8a7f93dd"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="895472cc9effc91924cce1dd6dfd9281"/></dir><dir name="invoice"><file name="default.phtml" hash="55998534e0e4e4902ce6af2bf353ae1c"/></dir><dir name="order"><file name="default.phtml" hash="b07e5afb8efedbf59175fcd77627e9f7"/></dir><dir name="shipment"><file name="default.phtml" hash="04ab3570798d203a0b42f97b19ee3dae"/></dir></dir></dir></dir><dir name="rss"><dir name="catalog"><dir name="product"><file name="price.phtml" hash="4cfcfe5be3f454977ec20ea6018b336c"/></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><file name="renderer.phtml" hash="61a8ed5607b9666c529e032e9546f4c9"/></dir></dir><dir name="invoice"><dir name="items"><file name="renderer.phtml" hash="2388aa265abe8acfd42b20fae31ec8c9"/></dir></dir><dir name="items"><file name="renderer.phtml" hash="c333af80eeb8d3f4391b2469494a0eab"/></dir><dir name="shipment"><dir name="items"><file name="renderer.phtml" hash="4c29f3aa573ebf5957824efd12ab34d6"/></dir></dir></dir></dir></dir><dir name="callouts"><file name="left_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/><file name="right_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/></dir><dir name="captcha"><file name="zend.phtml" hash="4ad7facdc381d1989da09ca588a08a48"/></dir><dir name="catalog"><dir name="category"><file name="page.phtml" hash="3e0e8f84c473bdfef97df156b170b23f"/><file name="view.phtml" hash="c3d126426f18f3851c9166bac7633475"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="0ecdcde11fc703fe21b2a57959440d7a"/><file name="link_inline.phtml" hash="038c644f25cf294d9f25ee5948c934fb"/></dir></dir></dir><dir name="layer"><file name="filter.phtml" hash="9daa0a45ccb872fe0a81b5d557c61d1d"/><file name="state.phtml" hash="142da1859cc91dce318b3d0914bb937d"/><file name="view.phtml" hash="dc3784fa579a95756170ec2e2ca6b4b7"/></dir><dir name="msrp"><file name="popup.phtml" hash="e74b3a4515baf615434e344194eb6157"/></dir><dir name="navigation"><file name="left.phtml" hash="7c9b95894ae693ea0091d85351c2708d"/><file name="top.phtml" hash="12672ad077c0c77b75b5fcf61c5752bf"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="f95646d2609bd187ff238e9f0f5c577b"/><file name="sidebar.phtml" hash="73d8e6ff3a49e0e13b903cab88511869"/></dir><file name="gallery.phtml" hash="50522f1290b268c72ac01c52fc150ba8"/><dir name="list"><file name="related.phtml" hash="7214653e8f19a685422064404435efff"/><file name="toolbar.phtml" hash="d1c66674abe8d65b884973fe58aa16d6"/><file name="upsell.phtml" hash="ffadd368be3cdf5033c1ca64de7ee5ad"/></dir><file name="list.phtml" hash="59b34c8c4b1a541029779c1581be2c71"/><file name="new.phtml" hash="7242fa0ea560a5fef7412d5d7f263200"/><file name="price.phtml" hash="d1a72f0b86a3fd002f70f952a0efe712"/><file name="price_msrp.phtml" hash="eb5f9dea211d5a136895920bb24aa504"/><file name="price_msrp_item.phtml" hash="0752e07eca2b095097048cc4673d737a"/><file name="price_msrp_noform.phtml" hash="150d188b6569613bda1486aba82345fe"/><file name="price_msrp_rss.phtml" hash="458e3fc5ff8d78da7aecc310c6d3356d"/><dir name="view"><file name="additional.phtml" hash="8bf11962c3c417b8fc337b79ccb96613"/><file name="addto.phtml" hash="c08c21c0a4593b9f20ced4660800e6b1"/><file name="addtocart.phtml" hash="12f6abb6c764fb87fa82bff3cb3a5069"/><file name="attributes.phtml" hash="b63af5e2aa6016dbee380c97bab61663"/><file name="description.phtml" hash="baf5465eea9b60f61e7b5ffc35ebad59"/><file name="media.phtml" hash="ceab5af9d9c32ef24352644a3f2bd154"/><dir name="options"><file name="js.phtml" hash="9fa94005f0cce3e3c194cb4e8dced133"/><dir name="type"><file name="date.phtml" hash="db6bbf3bdcc0a3680f259ad8d19c75fb"/><file name="default.phtml" hash="a54bc2bd868275275b2de2bf0a2c9686"/><file name="file.phtml" hash="f405962e8758758aced946f39988a1a3"/><file name="select.phtml" hash="1a0b802c9144abfb7bac5718e740aa46"/><file name="text.phtml" hash="39ba731885d8033ccfde950532be0827"/></dir><dir name="wrapper"><file name="bottom.phtml" hash="99622405f360fc6b1f69be608a18cf59"/></dir><file name="wrapper.phtml" hash="a10b15930010e7b0b94368f74ee07d24"/></dir><file name="options.phtml" hash="185b4376b5c8f926534f5522ef817176"/><file name="price.phtml" hash="3f14660f164c43324c765f6e5fb769b1"/><file name="price_clone.phtml" hash="7a8daa84610660f1be752cf0df60ed30"/><file name="tierprices.phtml" hash="886a860c22f8bd46bd83b19e93a6c776"/><dir name="type"><file name="configurable.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="default.phtml" hash="e06292be7becf92e2c8f55b10e7ca3c0"/><file name="grouped.phtml" hash="ba9e60156e779e4dad7fcffd0fb1ebe9"/><dir name="options"><file name="configurable.phtml" hash="6c64bea4fd84db79072866ccb8ae424a"/></dir><file name="simple.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="virtual.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/></dir></dir><file name="view.phtml" hash="d3eb40754189b82eb38f5f599b1fde9e"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="9a806959c5c414720e46469ef6834763"/><file name="link_inline.phtml" hash="514176db5de5c36abb618521d24cb237"/></dir><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="c57acf54bea4e724780bc970ebd028f7"/><file name="new_images_list.phtml" hash="0551ac1792e6b0803577f2108ffca082"/><file name="new_names_list.phtml" hash="20160816ea5bf6e94d66edc0c2bcb5aa"/></dir><dir name="content"><file name="new_grid.phtml" hash="dbfe8328eab155033191b84efd2f3152"/><file name="new_list.phtml" hash="6b6f1197393ac2af8e34e79553614fe6"/></dir></dir></dir></dir><dir name="rss"><dir name="product"><file name="price.phtml" hash="b2a96e4dfb6b818313fdb0eb493ecb9e"/></dir></dir><dir name="seo"><dir name="sitemap"><file name="container.phtml" hash="e64087817a512c8060d35dba48d1fef1"/></dir><file name="sitemap.phtml" hash="7b6518bb6846ed7e43fc6cc0d52b237b"/><file name="tree.phtml" hash="9176ae4df84a0356870d879a2e65fe60"/></dir></dir><dir name="cataloginventory"><file name="qtyincrements.phtml" hash="54afce4d3ba1bbead406befdf06ed7f1"/><dir name="stockqty"><file name="composite.phtml" hash="99e78924ebc0290f6fb39cef21a909c0"/><file name="default.phtml" hash="f12fd9722adfd128b1efcaa3c50aabf7"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5dd4260177e17ae350d2a283678deee4"/><file name="result.phtml" hash="125e8d77b8ab634da046a243f093ca93"/></dir><file name="form.mini.phtml" hash="3ca70be7e95f9c64415c5366968ba681"/><file name="result.phtml" hash="fbc91d34b804e97f30e1c2713def14b0"/><file name="term.phtml" hash="900bec348bfc6331c53832a176cb684a"/></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="4e2adcaa7e3ef72d26df8831c799e929"/><file name="crosssell.phtml" hash="0e7a1a545636daabf9f6f44fbd914500"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="925b6697f3edd41e52896feedbe212d8"/></dir><file name="default.phtml" hash="667a6fff0e50e2c5d9eeff32d421cc69"/></dir><file name="noItems.phtml" hash="72ba12d8a6ac165241910bf56d5b382f"/><dir name="render"><file name="default.phtml" hash="35a21249ea35f9fbb9fe9fbc5c01da00"/><file name="simple.phtml" hash="7eddd5db12cdc96213fcf2d69e567b03"/></dir><file name="shipping.phtml" hash="f1bfd43ef0e1b2d2d56c6c2beffbfb45"/><dir name="sidebar"><file name="default.phtml" hash="3aa4196c077f9b6c9137f45771df0118"/></dir><file name="sidebar.phtml" hash="bfa1f7e53dc361b68da14cf5edea3572"/><file name="totals.phtml" hash="bcf0133b72d8e70eb5a9285c0aae582a"/></dir><file name="cart.phtml" hash="8f4a6f818d6c29d3cccd8b92c94febf2"/><dir name="multishipping"><dir name="address"><file name="select.phtml" hash="d4400f34a601c4792fae8a694a9fb72b"/></dir><file name="addresses.phtml" hash="b00f072f232a89e3922432549db65c4b"/><file name="agreements.phtml" hash="a97c13b4fcf0bf31dc30b47f4ec9a3b4"/><dir name="billing"><file name="items.phtml" hash="0e2f790555e36eeca4c752fb10477266"/></dir><file name="billing.phtml" hash="356b1d85f7e78e4453fa4b2afd702b42"/><dir name="item"><file name="default.phtml" hash="9834befaf665771cd0aa24d67949da57"/></dir><file name="link.phtml" hash="4171ed501b67a73a8643de4fd24cb371"/><dir name="overview"><file name="item.phtml" hash="9d7d07a2fed6c207060bcf06547dbb5e"/></dir><file name="overview.phtml" hash="fdd94e42a0d861f25a2883c4ea0d2392"/><file name="shipping.phtml" hash="12eb547e08175d83bc66db197e2e958a"/><file name="state.phtml" hash="162bc8518f21c5ec0ad9716f8f628c34"/><file name="success.phtml" hash="d0fa6a04db0648f16ad740547a7381c0"/></dir><dir name="onepage"><file name="agreements.phtml" hash="9fe1c65c816b7857225d03646ed513d8"/><file name="billing.phtml" hash="f394e9db32ca986c31d1e2de5a4a4ba9"/><file name="failure.phtml" hash="7fef71bf3d691da514d9938099dd4a4a"/><file name="link.phtml" hash="744c5e6417fc1f16480ff47683cd059c"/><file name="login.phtml" hash="d20b228d44f3a8ecd1705dca4d711991"/><dir name="payment"><file name="info.phtml" hash="f4ae4c946643de8812b3b3af03687845"/><file name="methods.phtml" hash="86b3b5650883324fc50bd0ff8de5218a"/></dir><file name="payment.phtml" hash="35463d9e41512ff417899cfceae4948a"/><dir name="progress"><file name="billing.phtml" hash="b25fa3a5543ae6a35100881fc332e5d5"/><file name="payment.phtml" hash="f519b6de231333174e0ada183b1cd770"/><file name="shipping.phtml" hash="56c67f2192e305173616cf2e2a845947"/><file name="shipping_method.phtml" hash="afd02339abd3acfb3494fcfd5da14079"/></dir><file name="progress.phtml" hash="11557f64819329b4c71ac6997c071389"/><dir name="review"><file name="button.phtml" hash="096f57ab7f1ae1a7d68df2958dc15588"/><file name="info.phtml" hash="1928ceec84a3c06a180e4b3a3d4ee4eb"/><file name="item.phtml" hash="0c8e678f45f04e7bacb3ed2b8acdd638"/><file name="totals.phtml" hash="26a8fb780ca6c1204c77e8c051e63d2d"/></dir><file name="review.phtml" hash="c40cd3703b88209ef63294149246d1f8"/><file name="shipping.phtml" hash="5a8989220ddfbb1baeec0f5d27baea3d"/><dir name="shipping_method"><file name="additional.phtml" hash="cc1af94a4a57113165cc011f424cb574"/><file name="available.phtml" hash="f409ce94cd1958ab53ec45883869dfd5"/></dir><file name="shipping_method.phtml" hash="23304175b52b98d396c45118bcab359f"/></dir><file name="onepage.phtml" hash="b01aa8ccbd44412d9ff311053be4dcee"/><file name="success.phtml" hash="54532084f1ca5254cdbde78ff59e2f8b"/><dir name="total"><file name="default.phtml" hash="11a5b62ed106db4aa77787581139d0e2"/><file name="nominal.phtml" hash="76954822adebe842f7a104f3a9b62c50"/><file name="tax.phtml" hash="d4c20b40f89fae2c062073cf77e177a1"/></dir></dir><dir name="cms"><file name="content.phtml" hash="0f2efd3647a9319dbe0b17f6642d132b"/><file name="content_heading.phtml" hash="2726376d588d681b6cd02d4d58057fb3"/><dir name="default"><file name="home.phtml" hash="2b57f402d6ca4b4b54c993145bd44521"/><file name="no-route.phtml" hash="2983ed00d24504860951a2eb6ce7050f"/></dir><file name="meta.phtml" hash="061437b39a71a620f5d8dfcd2d87ae48"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="82b815707a48370c6690e74e67fe4a6c"/><file name="link_inline.phtml" hash="3abf5400edfc202f744059eacf62e0ce"/></dir><dir name="static_block"><file name="default.phtml" hash="2fc86aba2c9ef60b71743e47dcfd1d59"/></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="4714b3b5ea1eda3feb0e5ad54b085e72"/></dir><dir name="core"><file name="formkey.phtml" hash="263e41286f028b6dec2947a1a446bf2a"/><file name="link.phtml" hash="e03350191ace122fa9c34063312c6533"/><file name="messages.phtml" hash="bd8667f1ffc239439e6190e9ffc52ef9"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="333ea98610f509bdc359cb303ca70c3e"/><file name="hello.phtml" hash="29ba7a5aa97b26f28a6665b4f8392634"/><file name="info.phtml" hash="b5ee86beb72aa339fd026bc6748349d2"/><file name="newsletter.phtml" hash="5c68dee01a377e4201978d8cf4048916"/></dir><file name="dashboard.phtml" hash="bcb9a7f6f277bf9d85e3cdb8ae3cc9a7"/><dir name="link"><file name="back.phtml" hash="1e0faa823b7711804fd2f50cdc978636"/></dir><file name="navigation.phtml" hash="7e44a6f6764060f0d56f431cc68c2ee3"/></dir><dir name="address"><file name="book.phtml" hash="bbf5537e3faee9e2dfadbae868567520"/><file name="edit.phtml" hash="79b653bb2839ff572f0ebe9bd234031b"/></dir><file name="address.phtml" hash="9349365bab7abce0fe817a3b94155560"/><file name="balance.phtml" hash="94ead5465bce64fc7a692c18fcf680a9"/><dir name="form"><file name="address.phtml" hash="d7fa999f35bc97823a8f84f3ef497427"/><file name="changepassword.phtml" hash="e425ef79f0c97812959b2c608b71b785"/><file name="confirmation.phtml" hash="6e6a828f0ad7d3a5e3445c58ab3a52de"/><file name="edit.phtml" hash="f1fd6e9aed48d95c66a31e7ca2cf8758"/><file name="forgotpassword.phtml" hash="6de384b06caaa526b5de1f1b68630696"/><file name="login.phtml" hash="d3e0f02c693e80d328c7b60d440bb3dc"/><file name="mini.login.phtml" hash="cdfbbe341600e29628231922773b0af8"/><file name="newsletter.phtml" hash="ceeb846b27b8d3f9297955f656735543"/><file name="register.phtml" hash="d348abc82b9dbc571f113b00d06eaeef"/><file name="resetforgottenpassword.phtml" hash="c010c0765b372fc8c48f540cdf2fbd4a"/></dir><file name="logout.phtml" hash="172f5347d5a023d4334abef1aa3977c6"/><file name="orders.phtml" hash="4c303879cb23f65e9cd0e9bb8b65865d"/><dir name="widget"><file name="dob.phtml" hash="e372ec9d277b7088f8b48896ec08b962"/><file name="gender.phtml" hash="05a1a495e023e3319198353bfd50fc0e"/><file name="name.phtml" hash="ea23821e17d5a1597a2fc1e2555d9a14"/><file name="taxvat.phtml" hash="5c4aa1b4750d65d2c7e74374ddd5202b"/></dir><file name="wishlist.phtml" hash="d44319f1d59bfa6211bf8952424c5aea"/></dir><dir name="directory"><dir name="currency"><file name="switch.phtml" hash="1c0932731812287fb4a0e18e8fc29c3b"/></dir><file name="currency.phtml" hash="3ef16e68def3da63e57a41e6839e1a39"/><dir name="js"><file name="optional_zip_countries.phtml" hash="b0f6c136b0783e63285ba517530f60ce"/></dir></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="links.phtml" hash="1fb175f4fbe1826e4bcd12fe6c6a8980"/><file name="samples.phtml" hash="9e792010ec01db0fd604aa17d2d237e6"/><file name="type.phtml" hash="94ab0f22d76fd27678ce37f645c7b0b7"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="4b77efdabe1268e1ec996bf98f824eb0"/></dir></dir><dir name="multishipping"><dir name="item"><file name="downloadable.phtml" hash="862d25f45190fb92f6a8333a2bad83ce"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="7a964953ef437a72fa32a5fff4fe5cb3"/></dir></dir><file name="success.phtml" hash="71222f7927a32e2e9c0c070e00c90c73"/></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="10c18a118ab581ffc7dbd4f933cfbf7d"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="8705f11767570de48d6c16012a92817b"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="e797c59867ae63bd075181ccd94841a4"/></dir><dir name="order"><file name="downloadable.phtml" hash="e50b2cd8bd961025158da7cd2da42d0e"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="88755e0b50f6228ec22cdd09b1f8bc6e"/></dir></dir></dir><dir name="invoice"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="2f2e6ad8ac5d978294209486352e353d"/></dir></dir></dir><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="4b0868954102488e967d021f5acda87a"/></dir></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="bf74b493051105c3e282e06a50d7a2ed"/></dir><dir name="invoice"><file name="items.phtml" hash="8ee940f84f087f750afc4b80ef957d8a"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="invoice"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="order"><file name="default.phtml" hash="958a64e81514aecccc097e3e8552aba1"/></dir><dir name="shipment"><file name="default.phtml" hash="9715115d536ad893920c6f622ce70a55"/></dir></dir><file name="items.phtml" hash="dee5bcb1bc9cdac1919418d8a34d7412"/><dir name="shipment"><file name="items.phtml" hash="ee1f86874c4229314da7a220118529b9"/><file name="track.phtml" hash="13512e2e87b8fc119bbd837bfafe4b52"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="e9933387271aa3e59b8016c8ff9f269e"/><file name="stock.phtml" hash="9fa439a220bb26cab1245424a08fa7ab"/></dir></dir><dir name="giftmessage"><file name="inline.phtml" hash="b20d3bd8564ce077895d1764ba01a592"/></dir><dir name="googleanalytics"><file name="ga.phtml" hash="ce5cf1c86947107320e017cab90de120"/></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4cb081a98d6976c9609b143dded5ebcb"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="4e92348c8c54671c5bc76850bced0fbb"/><file name="button.phtml" hash="e3f4c8d69e0c017d129d93856095d865"/><file name="confirm-simple.phtml" hash="96f18bcb396a06899d067aea4cd63c28"/><file name="confirm.phtml" hash="80fe79fb81267d1c28f105f162b9a1cd"/><dir name="form"><file name="login-simple.phtml" hash="781d9df03ec9f1a5b2cc591317234ef9"/><file name="login.phtml" hash="46e9874b2d4be3fa27a6d74d8a420ea8"/></dir><file name="head-simple.phtml" hash="66437fdd869089b7fb0a860153cd9b2a"/><file name="reject-simple.phtml" hash="d2571e0e80575b9cc53a0e40f9eea1d9"/><file name="reject.phtml" hash="61bb4df718751608c863733ecb5de83a"/></dir><dir name="customer"><dir name="token"><file name="list.phtml" hash="d43d12d9c756d067cae01a0ed1669408"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="2f28b8bc1312b1b11ba7d2f1f2b78a66"/><file name="2columns-left.phtml" hash="0024fe5305585fc0cf4cf7ae80d5838e"/><file name="2columns-right.phtml" hash="75488f0c01877445567482cedb2c6006"/><file name="3columns.phtml" hash="e6a8b6357a1da225a490826eb9cc8827"/><file name="empty.phtml" hash="5aca0a348771071491dd500a558c091f"/><dir name="html"><file name="breadcrumbs.phtml" hash="52cd1f3a07db32ce024a3116d617e273"/><file name="cookienotice.phtml" hash="0428982e6c5a266ec20eca5f2d2035d2"/><file name="footer.phtml" hash="0d97b569b6915b4be53b6c6724d5d7b1"/><file name="head.phtml" hash="85bcd92a83e87f598cb4c7d15867b3e0"/><file name="header.phtml" hash="f19b0f01d5677952f508ac93e4098d8e"/><file name="notices.phtml" hash="9b7c04f5a19179d38a211e5dba5e3910"/><file name="pager.phtml" hash="1a2ca93836f4b551bf2dd05cee7edd7b"/><file name="top.links.phtml" hash="433dec7d3cccaaf8703ceb829545505e"/><file name="topmenu.phtml" hash="d03d5c9c89a7f8ce75d6e5d8c00848fa"/><file name="wrapper.phtml" hash="d70ba3d18317da939220eeb6378b8b9d"/></dir><dir name="js"><file name="calendar.phtml" hash="079523259fc194567d43e7aa27489cd2"/><file name="cookie.phtml" hash="a77c76484cb5872fecebda2602a37fe5"/></dir><file name="popup.phtml" hash="4306400c2744bc9eb7af3b1a83f89b50"/><file name="print.phtml" hash="a4c90428aacb75ada2d139b4e7a88fff"/><file name="redirect.phtml" hash="5a0a5d49735977c2c7f8cc0520e0f2e0"/><dir name="switch"><file name="flags.phtml" hash="3773969d016ca51cb38430f9e0ba68b3"/><file name="languages.phtml" hash="6fd9c35bbae31f38c7c55361371d44c0"/><file name="stores.phtml" hash="25a9c815893021fcc60dcaa75c779407"/></dir><dir name="template"><file name="container.phtml" hash="d345b0dac282eaf0bcf5f536d6755dc3"/><file name="links.phtml" hash="234bd8290e8c7ef4dab851a8d0c4c1f7"/><file name="linksblock.phtml" hash="969adc4a616d8df917ff14d4eb13b892"/></dir></dir><dir name="pagecache"><file name="cookie.phtml" hash="035507d94de53497b159469e55ee78f3"/></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="84192eecd8722839916f93ae90829564"/></dir><dir name="info"><file name="cc.phtml" hash="9a2f8d4396e1f578518ada1bda138f59"/></dir></dir><dir name="payment"><dir name="catalog"><dir name="product"><dir name="view"><dir name="profile"><file name="options.phtml" hash="d3dcef75cedeeef895b9f04de11b5a9a"/><file name="schedule.phtml" hash="2d85bb574937a22e66f47614261e7bb2"/></dir></dir></dir></dir><dir name="form"><file name="banktransfer.phtml" hash="0fda9a3b383e988ab6ced55acf987aff"/><file name="cashondelivery.phtml" hash="3e746cfdcbd77990765f7c80ca43f1f6"/><file name="cc.phtml" hash="26c3112455ecbbb1052b993047ff5e52"/><file name="ccsave.phtml" hash="20c0c2c4ec5be56b1799e964d573e45a"/><file name="checkmo.phtml" hash="2ac027643d66cc553a6927b79cea3dff"/><file name="purchaseorder.phtml" hash="b95359c73d4c2d81c16da09e78e227a9"/></dir><dir name="info"><file name="banktransfer.phtml" hash="6614593500cde5800dbd3842a3c7d6b1"/><file name="checkmo.phtml" hash="5e7604185b017eb617cb1eabf627d78f"/><file name="default.phtml" hash="e75249dc084ebd439de93fd9a953c6ee"/><file name="purchaseorder.phtml" hash="d51db6b3bc18bace55bd9ab7deddb5ad"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="662bf3cbce3dcae68832bc9074c3195d"/><dir name="express"><dir name="review"><file name="details.phtml" hash="7b2f9803b98ac6f9977ac46c30a056b0"/><dir name="shipping"><file name="method.phtml" hash="76b33e8c603b7bbf473a0abd33d2b50c"/></dir></dir><file name="review.phtml" hash="8d3751d9ee6ac6db76c978f2116c78f2"/><file name="shortcut.phtml" hash="718cea497013c53b26a2751d48e3d366"/></dir><dir name="hss"><file name="form.phtml" hash="9757d18296d999b5f5d34fa71f44a3ff"/><file name="iframe.phtml" hash="7517f586ac595f3ba52b92075298a71c"/><file name="info.phtml" hash="d00f850302d1eaaccacc297504b4ec8b"/><file name="js.phtml" hash="26a2aeeda31c99bf6b193e74fbd9e947"/><file name="redirect.phtml" hash="c7e6e7db49037161f51ef2df05e84813"/><dir name="review"><file name="button.phtml" hash="b2b1512b59d6870274a6e73389c831ca"/></dir></dir><dir name="partner"><file name="logo.phtml" hash="61ea270c13e8a38f9f42d79c5e185050"/><file name="us_logo.phtml" hash="7be14fa277b2ef84b2e5e152065f4e97"/></dir><dir name="payflowadvanced"><file name="iframe.phtml" hash="36abe5417ed7365ade7f54f2fb4d247b"/><file name="info.phtml" hash="d2c950064b208f2e03c731a3075a758f"/><file name="redirect.phtml" hash="92de41b8668ef48fe42a4c4665ae7f8b"/></dir><dir name="payflowlink"><file name="iframe.phtml" hash="9b9d0dfa78662761224ae3864e1539c0"/><file name="info.phtml" hash="8543012e16288427d8bd1de4538f467e"/><file name="redirect.phtml" hash="3cdc6f86f7a276766ff88a35bc04ab6a"/></dir><dir name="payment"><file name="mark.phtml" hash="201878accb60de622de7d468a2c510c6"/><file name="redirect.phtml" hash="19ac3d145545dd3c6db5f768db272574"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="6f03626c2f5d45f234110070a13510fe"/><file name="login.phtml" hash="330d57a2225b9debac9cc5c1be6149de"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="1dba15f3adf7043f6f9fdc51c126c049"/><file name="register.phtml" hash="131701dde1353b2e156fc066c91996bb"/></dir></dir><file name="remember_me.phtml" hash="15f59793748c3e36ddc5b0f16509466b"/><file name="remember_me_tooltip.phtml" hash="8bd2b026e64d4786d53d3a77d9d7fc79"/></dir><dir name="poll"><file name="active.phtml" hash="60079807bb8714bfb0e0ca521e6aec5d"/><file name="result.phtml" hash="15bbe5e8c12747db4f4ef50c896001fd"/></dir><dir name="productalert"><file name="price.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/><dir name="product"><file name="view.phtml" hash="b3ce17535d2f2e83066935b961702b9a"/></dir><file name="stock.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/></dir><dir name="rating"><file name="detailed.phtml" hash="b66b269ba801555012062fd02d001a33"/><file name="empty.phtml" hash="6aa7cab7575d4edc00a3285df5dab5c2"/></dir><dir name="reports"><file name="home_product_compared.phtml" hash="8cfa1979d8192d1a45312710de87d7be"/><file name="home_product_viewed.phtml" hash="6c58c4e73cfef7b83583feeb602b9e26"/><file name="product_compared.phtml" hash="47370bb002b5c02d1d4450ad1caeb1d7"/><file name="product_viewed.phtml" hash="d52c81400b12ee44a435dfe5fb394b25"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="819711aca802f1d53a13c4537cb94c63"/><file name="compared_images_list.phtml" hash="2087786b92aa18dd722a6ad90f2e6eda"/><file name="compared_names_list.phtml" hash="0243a47a11b4c096fdeebccbfd235b27"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fc2cd5910b11ac5080e2672f8461dcea"/><file name="compared_list.phtml" hash="7863917524e8fb63b8d7724fd73e3e73"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="a111917f600af1d54dd52710d65086b2"/><file name="viewed_images_list.phtml" hash="229134e29a14e2add151ba73ecf5ccd3"/><file name="viewed_names_list.phtml" hash="73e1ad6c721e2b0ddfb45ec0f250ecda"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="0b9293c8169bf230785d09042381eea0"/><file name="viewed_list.phtml" hash="14a998690bb5f37c44ad7543ff524b03"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="list.phtml" hash="21a0b2f11c06bf8a0e0af918a36486ec"/><file name="recent.phtml" hash="4c7eb30f707e02ed19ebfd0e48b59d92"/><file name="view.phtml" hash="7fc63fc197b7f69255ee6dd7176c1309"/></dir><file name="form.phtml" hash="19504d5f6405e47775eb821653e584fd"/><dir name="helper"><file name="summary.phtml" hash="8af5150b4c2c147bde4a06436e297b68"/><file name="summary_short.phtml" hash="2cbc486cb472266f3139a5cd281d8d4e"/></dir><dir name="product"><dir name="view"><file name="count.phtml" hash="09dcc9c9e9dc860f7f94415f6632d405"/><file name="list.phtml" hash="db87f4af149979c0c2b6211b94951b3b"/><file name="other.phtml" hash="454e2d215bc06773e73137623ad69a03"/></dir></dir><file name="view.phtml" hash="9071f84c610db079a9ca1470c250106f"/></dir><dir name="rss"><file name="list.phtml" hash="38fa9c4fb95737eeaa00fd0489411401"/><file name="nofeed.phtml" hash="92e1a1121f0608ed8438a89346f335d3"/><dir name="order"><file name="details.phtml" hash="30700dffcdc96558e89ae4f4ac5d062b"/></dir></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="ca55c7d479961dd005c0d839e2646e05"/></dir><file name="agreements.phtml" hash="ee98549f1b7e1fb42afa537ba8de8818"/></dir><dir name="guest"><file name="form.phtml" hash="509b6ba571fc7aff64565379ffd542ad"/></dir><dir name="order"><file name="comments.phtml" hash="cdc875ed3a37727d5cc403c342eab1bb"/><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="83eacbdf4dd635e5f9c94dbd97cf6793"/></dir></dir><file name="items.phtml" hash="7c9205260c4f0c8e16d3192b97033715"/></dir><file name="creditmemo.phtml" hash="082f3e41013326307878edefae9f12fa"/><file name="details.phtml" hash="427260fa04f2f412197fa4ab30949c07"/><file name="history.phtml" hash="081e7f1104707953c5a4ac5ebd901b09"/><dir name="info"><file name="buttons.phtml" hash="f4396a7de6170b8d920859ffb8e9a259"/></dir><file name="info.phtml" hash="6c44ca5d08b0dff46a0429fe92e7f057"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="61bac326041daebb7781db3a33d2223e"/></dir></dir><file name="items.phtml" hash="b76c99d2ef43a028b16a334a42a79b15"/></dir><file name="invoice.phtml" hash="d9f96a0911418669b76d7a579de0f45a"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="552e7453d0da2449f3720aaf18e768ba"/></dir></dir><file name="items.phtml" hash="531cdacc2b7b99f7e74978d83e6f9c99"/><dir name="print"><file name="creditmemo.phtml" hash="bea90d3be8eaa01131eda35dec526192"/><file name="invoice.phtml" hash="6631161daf44f42e5876f85a35882b1b"/><file name="shipment.phtml" hash="87ec2797d4fb4e965ed2b3c12fdcb747"/></dir><file name="print.phtml" hash="67b90f2d6512c83b44b16d1eb75685b6"/><file name="recent.phtml" hash="ea339a8cea8f1dfda8a9e6dc22f68e73"/><dir name="shipment"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="081db6648f65fd6b0fb34abd7fa16441"/></dir></dir><file name="items.phtml" hash="d64f6bb38b064d6b111482a99594d158"/></dir><file name="shipment.phtml" hash="8e56ba664cd9cdc01bf19f4dd6b0b783"/><file name="totals.phtml" hash="9ac8837db67bcd5a49197b5a00720df5"/><file name="trackinginfo.phtml" hash="d0eb20dd14a19d1185c5d61a67ebfb3e"/><file name="view.phtml" hash="580d296f4fd1c049cc061852d6f122a2"/></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="2006888669e168052d61ec198f38ee6b"/></dir></dir></dir><dir name="recurring"><file name="grid.phtml" hash="58261dc0e83512ffff4d5b076317b1f8"/><dir name="profile"><dir name="view"><file name="info.phtml" hash="614ba6f33d50ef89026b9cee0e0c30bd"/></dir><file name="view.phtml" hash="34a224e0cfec4e5716f0f86fe12fb0e7"/></dir><file name="profiles.phtml" hash="e91a9c209303c1702dae8ed09604e76d"/></dir><dir name="reorder"><file name="sidebar.phtml" hash="bf0a4c9ea18df3377d83b4273cde7149"/></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="38e6e2aff228a2aad3b0437e61bb5522"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="f0a055a14b97e0e6b4d38e310021a5b3"/></dir><dir name="shipping"><dir name="tracking"><file name="ajax.phtml" hash="e3b41fd33ba626ae7b9bfb7f23c07e93"/><file name="popup.phtml" hash="131eafbe3bb46b4ed6af3f6aff33a6b4"/></dir></dir><dir name="tag"><file name="cloud.phtml" hash="62c7ffab99fec479b343b21fea0fde3b"/><dir name="customer"><file name="recent.phtml" hash="8050f20856a9785fc37d0d6c5379020a"/><file name="tags.phtml" hash="e2a84aef98e491e2b36071757249a3d5"/><file name="view.phtml" hash="db81e635e46ef0cc5170ca0c64ff07d9"/></dir><file name="list.phtml" hash="dca4ad345072f43496e9870582b490f1"/><file name="popular.phtml" hash="093fad41b8786721d484400ab9bc8557"/></dir><dir name="tax"><dir name="checkout"><file name="discount.phtml" hash="168322a5454576d07c7597ffe24164db"/><file name="grandtotal.phtml" hash="153eeee2fc47d7d9b89cef439c676d23"/><file name="shipping.phtml" hash="f54b101deb4b0245a166ccdac5dd43f1"/><file name="subtotal.phtml" hash="1457075b05ef9d9bdfcad36095af71bc"/><file name="tax.phtml" hash="06f54cf61021e9e6e9495cab97c22bc0"/></dir><dir name="order"><file name="tax.phtml" hash="06c5f3b434b69e766bc508b5c527bda0"/></dir></dir><dir name="wishlist"><dir name="button"><file name="share.phtml" hash="335c1ca165cb0dd3789f64ea036096a8"/><file name="tocart.phtml" hash="68cc0db51b5a5c44fa477f049d85b970"/><file name="update.phtml" hash="0cbff9376749be9f6e8779b59a17e4d5"/></dir><dir name="email"><file name="items.phtml" hash="29344b6abfa99373e582db5a00fb5966"/><file name="rss.phtml" hash="f6df3dcfdb66431aff62d364c36f6467"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="39d152a5424161fbbb1e08d69e3955b2"/><file name="image.phtml" hash="c2fa04784d650dbe8663bde989ea206b"/><file name="info.phtml" hash="276b4e69a507fd4ec5b9a9980eac61d1"/><file name="remove.phtml" hash="09bc779e5db907482a09ec7fd6b95aa9"/></dir><dir name="configure"><file name="addto.phtml" hash="1e2c74806897a11bcbdc29dec4a34a30"/></dir><file name="list.phtml" hash="c6c3b95119f22f2a5fcf6599d2f468fa"/></dir><file name="options_list.phtml" hash="29585958c2328f45c62fad5192b83276"/><dir name="render"><dir name="item"><file name="price.phtml" hash="027e4f748e6039217b32de1455bf8a97"/><file name="price_msrp_item.phtml" hash="9ea3988c02dd93121dfcd12179d5c9d0"/><file name="price_msrp_rss.phtml" hash="59057882123117bea1169d3bac674164"/></dir></dir><file name="shared.phtml" hash="ce133ff86ad7ccbb5f380dbf36367a79"/><file name="sharing.phtml" hash="234fc41c319bcb050d32804cff0baebc"/><file name="sidebar.phtml" hash="3c91d09df73be7dd00a307fdb74ae4be"/><file name="view.phtml" hash="41ff38bf278e110732b4b05a5deb8328"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="css"><file name="email-inline.css" hash="72d47d85352353f347dd2b0f8c0104ac"/><file name="email-non-inline.css" hash="e889edd400833a1b5841b26a0a4b61eb"/><file name="widgets.css" hash="c1f91d1c4f18176ad2e95c8f79b1b435"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><dir name="cookies"><file name="firefox.png" hash="425e1b2ddc38c0bba431fb54357c66a4"/><file name="ie6-1.gif" hash="5c27700e245762bc89ed8c3ee7183f21"/><file name="ie6-2.gif" hash="d8c55e15e1f711e5c259300a9c19551b"/><file name="ie7-1.gif" hash="d61edcc8a514a3c81ea116b7d38ddcb6"/><file name="ie7-2.gif" hash="0526a654e94c54866cad977c0a47d3e5"/><file name="ie7-3.gif" hash="4fb142def3f6cfd8d8d23e1315528a1e"/><file name="ie7-4.gif" hash="575c276231c6a91e28935ec98215e146"/><file name="ie7-5.gif" hash="3ae5fcc11fe89da91674d183872337c1"/><file name="ie7-6.gif" hash="95a4981a41785a8cde273c9b2edbfbc7"/><file name="opera.png" hash="34070d92180d4ee0e37b1dd8bb731cd7"/></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><dir name="widgets"><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_widget-link.gif" hash="1bf753578171f147f0203e7b13bdd0c4"/><file name="i_widget-new.gif" hash="a75377ffed51b711cbc608ffaa1a2e7d"/></dir><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/></dir><dir name="js"><file name="bundle.js" hash="2f2bf27d13a85d6ebc665880c9dfb05c"/><dir name="checkout"><file name="review.js" hash="5582b2d213070aa9ad488f9e69516574"/></dir><file name="giftmessage.js" hash="57f753b9e257228017a835b899d4979f"/><file name="ie6.js" hash="c6c7baa57cdad02f56d6e72945fcebdd"/><file name="msrp.js" hash="72e4385e32df5e2c07ab56f40bcfce76"/><file name="opcheckout.js" hash="60ed6e7c4c6d5f01a7b8447931fdc875"/></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="cdb89dfeea9f6bb9c87e1abd1d8660f5"/></dir></dir></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Base_Default-1.9.4.2.xml b/var/package/Interface_Frontend_Base_Default-1.9.4.2.xml
new file mode 100644
index 0000000..091561c
--- /dev/null
+++ b/var/package/Interface_Frontend_Base_Default-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Base_Default</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This is a Magento themes base</summary>
+    <description>This is a Magento themes base</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:00</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="etc"><file name="theme.xml" hash="1b3f57d0a5774c3ee81f1647dd726a07"/><file name="widget.xml" hash="1b115ea6ec3f8c6db45e36760706be65"/></dir><dir name="layout"><file name="authorizenet.xml" hash="855c24dbd6d10c3ba28c17a8ce23601a"/><file name="bml.xml" hash="24d1888c05d081f537c3f57b9a29c4aa"/><file name="bundle.xml" hash="ee537028ca8d08e4c13ec6a4b3fbffb3"/><file name="captcha.xml" hash="428f52561c29ce5476468d41693b23cd"/><file name="catalog.xml" hash="284510e876c6f8e94fdcd1e00b1acd81"/><file name="catalog_msrp.xml" hash="cffdf3f5839375aa454f900093675ba8"/><file name="cataloginventory.xml" hash="06296ed114aa7c924a6aab916e6255aa"/><file name="catalogsearch.xml" hash="ddf280146c63bac6fff420c441845fab"/><file name="checkout.xml" hash="db3054a77255f3abf914545019160cfa"/><file name="cms.xml" hash="23faafff4439ede1d8a16e679e57d89c"/><file name="contacts.xml" hash="1eab2e4a72bf322f2233a22ece428fed"/><file name="core.xml" hash="f148469b0dbf2d204bb65312da9c301d"/><file name="customer.xml" hash="ab5cb799d48a7d7f1e51cbc05730eda9"/><file name="directory.xml" hash="2405153a0f2c424ca4fc1d076ad04631"/><file name="downloadable.xml" hash="491be3217bc4b128edf3cd7928fedd38"/><file name="googleanalytics.xml" hash="51aaaecaa23e340e5175d4bd6340f671"/><file name="newsletter.xml" hash="acf4cdc3756727420cc5151a60c059fe"/><file name="oauth.xml" hash="be99a8e31ef178e9cbd15b23027888a1"/><file name="page.xml" hash="795fa23724151dd8a7601b83aa45840b"/><file name="pagecache.xml" hash="bd3f4873b9dc907304e3161d8d026a0d"/><file name="payment.xml" hash="59b2f3f0947d2baae8cee91b96927a72"/><file name="paypal.xml" hash="e8cef6dbfd787dc0c7706ae6573253b2"/><file name="paypaluk.xml" hash="b374285cf042a5cc0e0a092568912c6a"/><file name="persistent.xml" hash="0bccb7bc4884346c44d91cd333cc3cda"/><file name="poll.xml" hash="176c92c32872efbf8175d8b02b5c9077"/><file name="productalert.xml" hash="6e7c0fff4fd537bcfa031fc088b6f3e7"/><file name="reports.xml" hash="764393665f03973464133dbc50a0a248"/><file name="review.xml" hash="378afb80fec6d583a0e8450a20495cb0"/><file name="rss.xml" hash="92d39fcc26eb6d590abc36661441ce03"/><dir name="sales"><file name="billing_agreement.xml" hash="5411e2c9dcf1681917db2cedb11ec5de"/><file name="recurring_profile.xml" hash="dab9149e5fd8fb3923165ca88de4ad74"/></dir><file name="sales.xml" hash="e3031185eae6df20c1ee281206bbfa9c"/><file name="sendfriend.xml" hash="eb574c649d054ffb9eef58e704f6ed2c"/><file name="shipping.xml" hash="96441af87095085b4f40c628b9dcc6de"/><file name="tag.xml" hash="e502cb505ee72082ca8d72cb8a3e5762"/><file name="weee.xml" hash="5c9f1bd15a6c8245071bcc13d7943c0b"/><file name="wishlist.xml" hash="593d574973f72aa189321a794d4af0f9"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="00f7a6eba53a3a693566ec7285fcafbd"/><file name="iframe.phtml" hash="ae37639a5bfc9361080156be19957bce"/><file name="info.phtml" hash="7d70e1b79f91cf902d66f2b14722da85"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="list"><file name="partof.phtml" hash="b19a017f8ca29e890244c35b8d94f6a9"/></dir><file name="price.phtml" hash="aa614de35a91fb7f70a02270771ff3dd"/><dir name="view"><file name="option_tierprices.phtml" hash="94e43618af517cb5a72094b59599f4cd"/><dir name="options"><file name="notice.phtml" hash="ade99bac4130350e9ddc572374704e4e"/></dir><file name="price.phtml" hash="a87dfbf46fbe9e3da8ffcdc6957f79a0"/><file name="tierprices.phtml" hash="6d3b049e6f2febbf5dbbf1f508bf9de5"/><dir name="type"><dir name="bundle"><dir name="option"><file name="checkbox.phtml" hash="6e63147acaf0e63969d7f0056dac34c7"/><file name="multi.phtml" hash="a8a4aebc5dc270253baba340272bcf63"/><file name="radio.phtml" hash="e453d2c5f3da4d74c3862c8cde6acb6f"/><file name="select.phtml" hash="8d12adecc1335ab12d573d1ed15b9129"/></dir><file name="options.phtml" hash="a26af0c38ea071f890137e475c4a17da"/></dir><file name="bundle.phtml" hash="b9ffd5141b2913ff07ea855d8a7f93dd"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="895472cc9effc91924cce1dd6dfd9281"/></dir><dir name="invoice"><file name="default.phtml" hash="55998534e0e4e4902ce6af2bf353ae1c"/></dir><dir name="order"><file name="default.phtml" hash="b07e5afb8efedbf59175fcd77627e9f7"/></dir><dir name="shipment"><file name="default.phtml" hash="04ab3570798d203a0b42f97b19ee3dae"/></dir></dir></dir></dir><dir name="rss"><dir name="catalog"><dir name="product"><file name="price.phtml" hash="4cfcfe5be3f454977ec20ea6018b336c"/></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><file name="renderer.phtml" hash="61a8ed5607b9666c529e032e9546f4c9"/></dir></dir><dir name="invoice"><dir name="items"><file name="renderer.phtml" hash="2388aa265abe8acfd42b20fae31ec8c9"/></dir></dir><dir name="items"><file name="renderer.phtml" hash="c333af80eeb8d3f4391b2469494a0eab"/></dir><dir name="shipment"><dir name="items"><file name="renderer.phtml" hash="4c29f3aa573ebf5957824efd12ab34d6"/></dir></dir></dir></dir></dir><dir name="callouts"><file name="left_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/><file name="right_col.phtml" hash="8a54b545bd7513c5be3dc51fe64e0318"/></dir><dir name="captcha"><file name="zend.phtml" hash="4ad7facdc381d1989da09ca588a08a48"/></dir><dir name="catalog"><dir name="category"><file name="page.phtml" hash="3e0e8f84c473bdfef97df156b170b23f"/><file name="view.phtml" hash="c3d126426f18f3851c9166bac7633475"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="0ecdcde11fc703fe21b2a57959440d7a"/><file name="link_inline.phtml" hash="038c644f25cf294d9f25ee5948c934fb"/></dir></dir></dir><dir name="layer"><file name="filter.phtml" hash="9daa0a45ccb872fe0a81b5d557c61d1d"/><file name="state.phtml" hash="142da1859cc91dce318b3d0914bb937d"/><file name="view.phtml" hash="dc3784fa579a95756170ec2e2ca6b4b7"/></dir><dir name="msrp"><file name="popup.phtml" hash="e74b3a4515baf615434e344194eb6157"/></dir><dir name="navigation"><file name="left.phtml" hash="7c9b95894ae693ea0091d85351c2708d"/><file name="top.phtml" hash="12672ad077c0c77b75b5fcf61c5752bf"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="f95646d2609bd187ff238e9f0f5c577b"/><file name="sidebar.phtml" hash="73d8e6ff3a49e0e13b903cab88511869"/></dir><file name="gallery.phtml" hash="50522f1290b268c72ac01c52fc150ba8"/><dir name="list"><file name="related.phtml" hash="7214653e8f19a685422064404435efff"/><file name="toolbar.phtml" hash="d1c66674abe8d65b884973fe58aa16d6"/><file name="upsell.phtml" hash="ffadd368be3cdf5033c1ca64de7ee5ad"/></dir><file name="list.phtml" hash="59b34c8c4b1a541029779c1581be2c71"/><file name="new.phtml" hash="7242fa0ea560a5fef7412d5d7f263200"/><file name="price.phtml" hash="d1a72f0b86a3fd002f70f952a0efe712"/><file name="price_msrp.phtml" hash="eb5f9dea211d5a136895920bb24aa504"/><file name="price_msrp_item.phtml" hash="0752e07eca2b095097048cc4673d737a"/><file name="price_msrp_noform.phtml" hash="150d188b6569613bda1486aba82345fe"/><file name="price_msrp_rss.phtml" hash="458e3fc5ff8d78da7aecc310c6d3356d"/><dir name="view"><file name="additional.phtml" hash="8bf11962c3c417b8fc337b79ccb96613"/><file name="addto.phtml" hash="c08c21c0a4593b9f20ced4660800e6b1"/><file name="addtocart.phtml" hash="12f6abb6c764fb87fa82bff3cb3a5069"/><file name="attributes.phtml" hash="b63af5e2aa6016dbee380c97bab61663"/><file name="description.phtml" hash="baf5465eea9b60f61e7b5ffc35ebad59"/><file name="media.phtml" hash="ceab5af9d9c32ef24352644a3f2bd154"/><dir name="options"><file name="js.phtml" hash="9fa94005f0cce3e3c194cb4e8dced133"/><dir name="type"><file name="date.phtml" hash="db6bbf3bdcc0a3680f259ad8d19c75fb"/><file name="default.phtml" hash="a54bc2bd868275275b2de2bf0a2c9686"/><file name="file.phtml" hash="f405962e8758758aced946f39988a1a3"/><file name="select.phtml" hash="1a0b802c9144abfb7bac5718e740aa46"/><file name="text.phtml" hash="39ba731885d8033ccfde950532be0827"/></dir><dir name="wrapper"><file name="bottom.phtml" hash="99622405f360fc6b1f69be608a18cf59"/></dir><file name="wrapper.phtml" hash="a10b15930010e7b0b94368f74ee07d24"/></dir><file name="options.phtml" hash="185b4376b5c8f926534f5522ef817176"/><file name="price.phtml" hash="3f14660f164c43324c765f6e5fb769b1"/><file name="price_clone.phtml" hash="7a8daa84610660f1be752cf0df60ed30"/><file name="tierprices.phtml" hash="886a860c22f8bd46bd83b19e93a6c776"/><dir name="type"><file name="configurable.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="default.phtml" hash="e06292be7becf92e2c8f55b10e7ca3c0"/><file name="grouped.phtml" hash="ba9e60156e779e4dad7fcffd0fb1ebe9"/><dir name="options"><file name="configurable.phtml" hash="6c64bea4fd84db79072866ccb8ae424a"/></dir><file name="simple.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/><file name="virtual.phtml" hash="5c2ae5eae2a94d6d5cda220a52e28771"/></dir></dir><file name="view.phtml" hash="d3eb40754189b82eb38f5f599b1fde9e"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="9a806959c5c414720e46469ef6834763"/><file name="link_inline.phtml" hash="514176db5de5c36abb618521d24cb237"/></dir><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="c57acf54bea4e724780bc970ebd028f7"/><file name="new_images_list.phtml" hash="0551ac1792e6b0803577f2108ffca082"/><file name="new_names_list.phtml" hash="20160816ea5bf6e94d66edc0c2bcb5aa"/></dir><dir name="content"><file name="new_grid.phtml" hash="dbfe8328eab155033191b84efd2f3152"/><file name="new_list.phtml" hash="6b6f1197393ac2af8e34e79553614fe6"/></dir></dir></dir></dir><dir name="rss"><dir name="product"><file name="price.phtml" hash="b2a96e4dfb6b818313fdb0eb493ecb9e"/></dir></dir><dir name="seo"><dir name="sitemap"><file name="container.phtml" hash="e64087817a512c8060d35dba48d1fef1"/></dir><file name="sitemap.phtml" hash="7b6518bb6846ed7e43fc6cc0d52b237b"/><file name="tree.phtml" hash="9176ae4df84a0356870d879a2e65fe60"/></dir></dir><dir name="cataloginventory"><file name="qtyincrements.phtml" hash="54afce4d3ba1bbead406befdf06ed7f1"/><dir name="stockqty"><file name="composite.phtml" hash="99e78924ebc0290f6fb39cef21a909c0"/><file name="default.phtml" hash="f12fd9722adfd128b1efcaa3c50aabf7"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5dd4260177e17ae350d2a283678deee4"/><file name="result.phtml" hash="125e8d77b8ab634da046a243f093ca93"/></dir><file name="form.mini.phtml" hash="3ca70be7e95f9c64415c5366968ba681"/><file name="result.phtml" hash="fbc91d34b804e97f30e1c2713def14b0"/><file name="term.phtml" hash="900bec348bfc6331c53832a176cb684a"/></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="4e2adcaa7e3ef72d26df8831c799e929"/><file name="crosssell.phtml" hash="0e7a1a545636daabf9f6f44fbd914500"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="925b6697f3edd41e52896feedbe212d8"/></dir><file name="default.phtml" hash="667a6fff0e50e2c5d9eeff32d421cc69"/></dir><file name="noItems.phtml" hash="72ba12d8a6ac165241910bf56d5b382f"/><dir name="render"><file name="default.phtml" hash="35a21249ea35f9fbb9fe9fbc5c01da00"/><file name="simple.phtml" hash="7eddd5db12cdc96213fcf2d69e567b03"/></dir><file name="shipping.phtml" hash="f1bfd43ef0e1b2d2d56c6c2beffbfb45"/><dir name="sidebar"><file name="default.phtml" hash="3aa4196c077f9b6c9137f45771df0118"/></dir><file name="sidebar.phtml" hash="bfa1f7e53dc361b68da14cf5edea3572"/><file name="totals.phtml" hash="bcf0133b72d8e70eb5a9285c0aae582a"/></dir><file name="cart.phtml" hash="8f4a6f818d6c29d3cccd8b92c94febf2"/><dir name="multishipping"><dir name="address"><file name="select.phtml" hash="d4400f34a601c4792fae8a694a9fb72b"/></dir><file name="addresses.phtml" hash="b00f072f232a89e3922432549db65c4b"/><file name="agreements.phtml" hash="a97c13b4fcf0bf31dc30b47f4ec9a3b4"/><dir name="billing"><file name="items.phtml" hash="0e2f790555e36eeca4c752fb10477266"/></dir><file name="billing.phtml" hash="356b1d85f7e78e4453fa4b2afd702b42"/><dir name="item"><file name="default.phtml" hash="9834befaf665771cd0aa24d67949da57"/></dir><file name="link.phtml" hash="4171ed501b67a73a8643de4fd24cb371"/><dir name="overview"><file name="item.phtml" hash="9d7d07a2fed6c207060bcf06547dbb5e"/></dir><file name="overview.phtml" hash="fdd94e42a0d861f25a2883c4ea0d2392"/><file name="shipping.phtml" hash="12eb547e08175d83bc66db197e2e958a"/><file name="state.phtml" hash="162bc8518f21c5ec0ad9716f8f628c34"/><file name="success.phtml" hash="d0fa6a04db0648f16ad740547a7381c0"/></dir><dir name="onepage"><file name="agreements.phtml" hash="9fe1c65c816b7857225d03646ed513d8"/><file name="billing.phtml" hash="f394e9db32ca986c31d1e2de5a4a4ba9"/><file name="failure.phtml" hash="7fef71bf3d691da514d9938099dd4a4a"/><file name="link.phtml" hash="744c5e6417fc1f16480ff47683cd059c"/><file name="login.phtml" hash="d20b228d44f3a8ecd1705dca4d711991"/><dir name="payment"><file name="info.phtml" hash="f4ae4c946643de8812b3b3af03687845"/><file name="methods.phtml" hash="86b3b5650883324fc50bd0ff8de5218a"/></dir><file name="payment.phtml" hash="35463d9e41512ff417899cfceae4948a"/><dir name="progress"><file name="billing.phtml" hash="b25fa3a5543ae6a35100881fc332e5d5"/><file name="payment.phtml" hash="f519b6de231333174e0ada183b1cd770"/><file name="shipping.phtml" hash="56c67f2192e305173616cf2e2a845947"/><file name="shipping_method.phtml" hash="afd02339abd3acfb3494fcfd5da14079"/></dir><file name="progress.phtml" hash="11557f64819329b4c71ac6997c071389"/><dir name="review"><file name="button.phtml" hash="096f57ab7f1ae1a7d68df2958dc15588"/><file name="info.phtml" hash="1928ceec84a3c06a180e4b3a3d4ee4eb"/><file name="item.phtml" hash="0c8e678f45f04e7bacb3ed2b8acdd638"/><file name="totals.phtml" hash="26a8fb780ca6c1204c77e8c051e63d2d"/></dir><file name="review.phtml" hash="c40cd3703b88209ef63294149246d1f8"/><file name="shipping.phtml" hash="5a8989220ddfbb1baeec0f5d27baea3d"/><dir name="shipping_method"><file name="additional.phtml" hash="cc1af94a4a57113165cc011f424cb574"/><file name="available.phtml" hash="f409ce94cd1958ab53ec45883869dfd5"/></dir><file name="shipping_method.phtml" hash="23304175b52b98d396c45118bcab359f"/></dir><file name="onepage.phtml" hash="b01aa8ccbd44412d9ff311053be4dcee"/><file name="success.phtml" hash="54532084f1ca5254cdbde78ff59e2f8b"/><dir name="total"><file name="default.phtml" hash="11a5b62ed106db4aa77787581139d0e2"/><file name="nominal.phtml" hash="76954822adebe842f7a104f3a9b62c50"/><file name="tax.phtml" hash="d4c20b40f89fae2c062073cf77e177a1"/></dir></dir><dir name="cms"><file name="content.phtml" hash="0f2efd3647a9319dbe0b17f6642d132b"/><file name="content_heading.phtml" hash="2726376d588d681b6cd02d4d58057fb3"/><dir name="default"><file name="home.phtml" hash="2b57f402d6ca4b4b54c993145bd44521"/><file name="no-route.phtml" hash="2983ed00d24504860951a2eb6ce7050f"/></dir><file name="meta.phtml" hash="061437b39a71a620f5d8dfcd2d87ae48"/><dir name="widget"><dir name="link"><file name="link_block.phtml" hash="82b815707a48370c6690e74e67fe4a6c"/><file name="link_inline.phtml" hash="3abf5400edfc202f744059eacf62e0ce"/></dir><dir name="static_block"><file name="default.phtml" hash="2fc86aba2c9ef60b71743e47dcfd1d59"/></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="4714b3b5ea1eda3feb0e5ad54b085e72"/></dir><dir name="core"><file name="formkey.phtml" hash="263e41286f028b6dec2947a1a446bf2a"/><file name="link.phtml" hash="e03350191ace122fa9c34063312c6533"/><file name="messages.phtml" hash="bd8667f1ffc239439e6190e9ffc52ef9"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="333ea98610f509bdc359cb303ca70c3e"/><file name="hello.phtml" hash="29ba7a5aa97b26f28a6665b4f8392634"/><file name="info.phtml" hash="b5ee86beb72aa339fd026bc6748349d2"/><file name="newsletter.phtml" hash="5c68dee01a377e4201978d8cf4048916"/></dir><file name="dashboard.phtml" hash="bcb9a7f6f277bf9d85e3cdb8ae3cc9a7"/><dir name="link"><file name="back.phtml" hash="1e0faa823b7711804fd2f50cdc978636"/></dir><file name="navigation.phtml" hash="7e44a6f6764060f0d56f431cc68c2ee3"/></dir><dir name="address"><file name="book.phtml" hash="bbf5537e3faee9e2dfadbae868567520"/><file name="edit.phtml" hash="79b653bb2839ff572f0ebe9bd234031b"/></dir><file name="address.phtml" hash="9349365bab7abce0fe817a3b94155560"/><file name="balance.phtml" hash="94ead5465bce64fc7a692c18fcf680a9"/><dir name="form"><file name="address.phtml" hash="d7fa999f35bc97823a8f84f3ef497427"/><file name="changepassword.phtml" hash="e425ef79f0c97812959b2c608b71b785"/><file name="confirmation.phtml" hash="6e6a828f0ad7d3a5e3445c58ab3a52de"/><file name="edit.phtml" hash="f1fd6e9aed48d95c66a31e7ca2cf8758"/><file name="forgotpassword.phtml" hash="6de384b06caaa526b5de1f1b68630696"/><file name="login.phtml" hash="d3e0f02c693e80d328c7b60d440bb3dc"/><file name="mini.login.phtml" hash="cdfbbe341600e29628231922773b0af8"/><file name="newsletter.phtml" hash="ceeb846b27b8d3f9297955f656735543"/><file name="register.phtml" hash="d348abc82b9dbc571f113b00d06eaeef"/><file name="resetforgottenpassword.phtml" hash="c010c0765b372fc8c48f540cdf2fbd4a"/></dir><file name="logout.phtml" hash="172f5347d5a023d4334abef1aa3977c6"/><file name="orders.phtml" hash="4c303879cb23f65e9cd0e9bb8b65865d"/><dir name="widget"><file name="dob.phtml" hash="e372ec9d277b7088f8b48896ec08b962"/><file name="gender.phtml" hash="05a1a495e023e3319198353bfd50fc0e"/><file name="name.phtml" hash="ea23821e17d5a1597a2fc1e2555d9a14"/><file name="taxvat.phtml" hash="5c4aa1b4750d65d2c7e74374ddd5202b"/></dir><file name="wishlist.phtml" hash="d44319f1d59bfa6211bf8952424c5aea"/></dir><dir name="directory"><dir name="currency"><file name="switch.phtml" hash="1c0932731812287fb4a0e18e8fc29c3b"/></dir><file name="currency.phtml" hash="3ef16e68def3da63e57a41e6839e1a39"/><dir name="js"><file name="optional_zip_countries.phtml" hash="b0f6c136b0783e63285ba517530f60ce"/></dir></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="links.phtml" hash="1fb175f4fbe1826e4bcd12fe6c6a8980"/><file name="samples.phtml" hash="9e792010ec01db0fd604aa17d2d237e6"/><file name="type.phtml" hash="94ab0f22d76fd27678ce37f645c7b0b7"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="4b77efdabe1268e1ec996bf98f824eb0"/></dir></dir><dir name="multishipping"><dir name="item"><file name="downloadable.phtml" hash="862d25f45190fb92f6a8333a2bad83ce"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="7a964953ef437a72fa32a5fff4fe5cb3"/></dir></dir><file name="success.phtml" hash="71222f7927a32e2e9c0c070e00c90c73"/></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="10c18a118ab581ffc7dbd4f933cfbf7d"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="8705f11767570de48d6c16012a92817b"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="e797c59867ae63bd075181ccd94841a4"/></dir><dir name="order"><file name="downloadable.phtml" hash="e50b2cd8bd961025158da7cd2da42d0e"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="88755e0b50f6228ec22cdd09b1f8bc6e"/></dir></dir></dir><dir name="invoice"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="2f2e6ad8ac5d978294209486352e353d"/></dir></dir></dir><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="4b0868954102488e967d021f5acda87a"/></dir></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="bf74b493051105c3e282e06a50d7a2ed"/></dir><dir name="invoice"><file name="items.phtml" hash="8ee940f84f087f750afc4b80ef957d8a"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="invoice"><file name="default.phtml" hash="aa84eb7f331e2b90e03bb89ca946fa10"/></dir><dir name="order"><file name="default.phtml" hash="958a64e81514aecccc097e3e8552aba1"/></dir><dir name="shipment"><file name="default.phtml" hash="9715115d536ad893920c6f622ce70a55"/></dir></dir><file name="items.phtml" hash="dee5bcb1bc9cdac1919418d8a34d7412"/><dir name="shipment"><file name="items.phtml" hash="ee1f86874c4229314da7a220118529b9"/><file name="track.phtml" hash="13512e2e87b8fc119bbd837bfafe4b52"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="e9933387271aa3e59b8016c8ff9f269e"/><file name="stock.phtml" hash="9fa439a220bb26cab1245424a08fa7ab"/></dir></dir><dir name="giftmessage"><file name="inline.phtml" hash="b20d3bd8564ce077895d1764ba01a592"/></dir><dir name="googleanalytics"><file name="ga.phtml" hash="ce5cf1c86947107320e017cab90de120"/></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4cb081a98d6976c9609b143dded5ebcb"/></dir><dir name="oauth"><dir name="authorize"><file name="button-simple.phtml" hash="4e92348c8c54671c5bc76850bced0fbb"/><file name="button.phtml" hash="e3f4c8d69e0c017d129d93856095d865"/><file name="confirm-simple.phtml" hash="96f18bcb396a06899d067aea4cd63c28"/><file name="confirm.phtml" hash="80fe79fb81267d1c28f105f162b9a1cd"/><dir name="form"><file name="login-simple.phtml" hash="781d9df03ec9f1a5b2cc591317234ef9"/><file name="login.phtml" hash="46e9874b2d4be3fa27a6d74d8a420ea8"/></dir><file name="head-simple.phtml" hash="66437fdd869089b7fb0a860153cd9b2a"/><file name="reject-simple.phtml" hash="d2571e0e80575b9cc53a0e40f9eea1d9"/><file name="reject.phtml" hash="61bb4df718751608c863733ecb5de83a"/></dir><dir name="customer"><dir name="token"><file name="list.phtml" hash="d43d12d9c756d067cae01a0ed1669408"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="2f28b8bc1312b1b11ba7d2f1f2b78a66"/><file name="2columns-left.phtml" hash="0024fe5305585fc0cf4cf7ae80d5838e"/><file name="2columns-right.phtml" hash="75488f0c01877445567482cedb2c6006"/><file name="3columns.phtml" hash="e6a8b6357a1da225a490826eb9cc8827"/><file name="empty.phtml" hash="5aca0a348771071491dd500a558c091f"/><dir name="html"><file name="breadcrumbs.phtml" hash="52cd1f3a07db32ce024a3116d617e273"/><file name="cookienotice.phtml" hash="0428982e6c5a266ec20eca5f2d2035d2"/><file name="footer.phtml" hash="0d97b569b6915b4be53b6c6724d5d7b1"/><file name="head.phtml" hash="85bcd92a83e87f598cb4c7d15867b3e0"/><file name="header.phtml" hash="f19b0f01d5677952f508ac93e4098d8e"/><file name="notices.phtml" hash="9b7c04f5a19179d38a211e5dba5e3910"/><file name="pager.phtml" hash="1a2ca93836f4b551bf2dd05cee7edd7b"/><file name="top.links.phtml" hash="433dec7d3cccaaf8703ceb829545505e"/><file name="topmenu.phtml" hash="d03d5c9c89a7f8ce75d6e5d8c00848fa"/><file name="wrapper.phtml" hash="d70ba3d18317da939220eeb6378b8b9d"/></dir><dir name="js"><file name="calendar.phtml" hash="079523259fc194567d43e7aa27489cd2"/><file name="cookie.phtml" hash="a77c76484cb5872fecebda2602a37fe5"/></dir><file name="popup.phtml" hash="4306400c2744bc9eb7af3b1a83f89b50"/><file name="print.phtml" hash="a4c90428aacb75ada2d139b4e7a88fff"/><file name="redirect.phtml" hash="5a0a5d49735977c2c7f8cc0520e0f2e0"/><dir name="switch"><file name="flags.phtml" hash="3773969d016ca51cb38430f9e0ba68b3"/><file name="languages.phtml" hash="6fd9c35bbae31f38c7c55361371d44c0"/><file name="stores.phtml" hash="25a9c815893021fcc60dcaa75c779407"/></dir><dir name="template"><file name="container.phtml" hash="d345b0dac282eaf0bcf5f536d6755dc3"/><file name="links.phtml" hash="234bd8290e8c7ef4dab851a8d0c4c1f7"/><file name="linksblock.phtml" hash="969adc4a616d8df917ff14d4eb13b892"/></dir></dir><dir name="pagecache"><file name="cookie.phtml" hash="035507d94de53497b159469e55ee78f3"/></dir><dir name="paygate"><dir name="form"><file name="cc.phtml" hash="84192eecd8722839916f93ae90829564"/></dir><dir name="info"><file name="cc.phtml" hash="9a2f8d4396e1f578518ada1bda138f59"/></dir></dir><dir name="payment"><dir name="catalog"><dir name="product"><dir name="view"><dir name="profile"><file name="options.phtml" hash="d3dcef75cedeeef895b9f04de11b5a9a"/><file name="schedule.phtml" hash="2d85bb574937a22e66f47614261e7bb2"/></dir></dir></dir></dir><dir name="form"><file name="banktransfer.phtml" hash="0fda9a3b383e988ab6ced55acf987aff"/><file name="cashondelivery.phtml" hash="3e746cfdcbd77990765f7c80ca43f1f6"/><file name="cc.phtml" hash="26c3112455ecbbb1052b993047ff5e52"/><file name="ccsave.phtml" hash="20c0c2c4ec5be56b1799e964d573e45a"/><file name="checkmo.phtml" hash="2ac027643d66cc553a6927b79cea3dff"/><file name="purchaseorder.phtml" hash="b95359c73d4c2d81c16da09e78e227a9"/></dir><dir name="info"><file name="banktransfer.phtml" hash="6614593500cde5800dbd3842a3c7d6b1"/><file name="checkmo.phtml" hash="5e7604185b017eb617cb1eabf627d78f"/><file name="default.phtml" hash="e75249dc084ebd439de93fd9a953c6ee"/><file name="purchaseorder.phtml" hash="d51db6b3bc18bace55bd9ab7deddb5ad"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="662bf3cbce3dcae68832bc9074c3195d"/><dir name="express"><dir name="review"><file name="details.phtml" hash="7b2f9803b98ac6f9977ac46c30a056b0"/><dir name="shipping"><file name="method.phtml" hash="76b33e8c603b7bbf473a0abd33d2b50c"/></dir></dir><file name="review.phtml" hash="8d3751d9ee6ac6db76c978f2116c78f2"/><file name="shortcut.phtml" hash="718cea497013c53b26a2751d48e3d366"/></dir><dir name="hss"><file name="form.phtml" hash="9757d18296d999b5f5d34fa71f44a3ff"/><file name="iframe.phtml" hash="7517f586ac595f3ba52b92075298a71c"/><file name="info.phtml" hash="d00f850302d1eaaccacc297504b4ec8b"/><file name="js.phtml" hash="26a2aeeda31c99bf6b193e74fbd9e947"/><file name="redirect.phtml" hash="c7e6e7db49037161f51ef2df05e84813"/><dir name="review"><file name="button.phtml" hash="b2b1512b59d6870274a6e73389c831ca"/></dir></dir><dir name="partner"><file name="logo.phtml" hash="61ea270c13e8a38f9f42d79c5e185050"/><file name="us_logo.phtml" hash="7be14fa277b2ef84b2e5e152065f4e97"/></dir><dir name="payflowadvanced"><file name="iframe.phtml" hash="36abe5417ed7365ade7f54f2fb4d247b"/><file name="info.phtml" hash="d2c950064b208f2e03c731a3075a758f"/><file name="redirect.phtml" hash="92de41b8668ef48fe42a4c4665ae7f8b"/></dir><dir name="payflowlink"><file name="iframe.phtml" hash="9b9d0dfa78662761224ae3864e1539c0"/><file name="info.phtml" hash="8543012e16288427d8bd1de4538f467e"/><file name="redirect.phtml" hash="3cdc6f86f7a276766ff88a35bc04ab6a"/></dir><dir name="payment"><file name="mark.phtml" hash="201878accb60de622de7d468a2c510c6"/><file name="redirect.phtml" hash="19ac3d145545dd3c6db5f768db272574"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="6f03626c2f5d45f234110070a13510fe"/><file name="login.phtml" hash="330d57a2225b9debac9cc5c1be6149de"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="1dba15f3adf7043f6f9fdc51c126c049"/><file name="register.phtml" hash="131701dde1353b2e156fc066c91996bb"/></dir></dir><file name="remember_me.phtml" hash="15f59793748c3e36ddc5b0f16509466b"/><file name="remember_me_tooltip.phtml" hash="8bd2b026e64d4786d53d3a77d9d7fc79"/></dir><dir name="poll"><file name="active.phtml" hash="60079807bb8714bfb0e0ca521e6aec5d"/><file name="result.phtml" hash="15bbe5e8c12747db4f4ef50c896001fd"/></dir><dir name="productalert"><file name="price.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/><dir name="product"><file name="view.phtml" hash="b3ce17535d2f2e83066935b961702b9a"/></dir><file name="stock.phtml" hash="577ae08f48f16fe9338461afd057d2ce"/></dir><dir name="rating"><file name="detailed.phtml" hash="b66b269ba801555012062fd02d001a33"/><file name="empty.phtml" hash="6aa7cab7575d4edc00a3285df5dab5c2"/></dir><dir name="reports"><file name="home_product_compared.phtml" hash="8cfa1979d8192d1a45312710de87d7be"/><file name="home_product_viewed.phtml" hash="6c58c4e73cfef7b83583feeb602b9e26"/><file name="product_compared.phtml" hash="47370bb002b5c02d1d4450ad1caeb1d7"/><file name="product_viewed.phtml" hash="d52c81400b12ee44a435dfe5fb394b25"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="819711aca802f1d53a13c4537cb94c63"/><file name="compared_images_list.phtml" hash="2087786b92aa18dd722a6ad90f2e6eda"/><file name="compared_names_list.phtml" hash="0243a47a11b4c096fdeebccbfd235b27"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fc2cd5910b11ac5080e2672f8461dcea"/><file name="compared_list.phtml" hash="7863917524e8fb63b8d7724fd73e3e73"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="a111917f600af1d54dd52710d65086b2"/><file name="viewed_images_list.phtml" hash="229134e29a14e2add151ba73ecf5ccd3"/><file name="viewed_names_list.phtml" hash="73e1ad6c721e2b0ddfb45ec0f250ecda"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="0b9293c8169bf230785d09042381eea0"/><file name="viewed_list.phtml" hash="14a998690bb5f37c44ad7543ff524b03"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="list.phtml" hash="21a0b2f11c06bf8a0e0af918a36486ec"/><file name="recent.phtml" hash="4c7eb30f707e02ed19ebfd0e48b59d92"/><file name="view.phtml" hash="7fc63fc197b7f69255ee6dd7176c1309"/></dir><file name="form.phtml" hash="19504d5f6405e47775eb821653e584fd"/><dir name="helper"><file name="summary.phtml" hash="8af5150b4c2c147bde4a06436e297b68"/><file name="summary_short.phtml" hash="2cbc486cb472266f3139a5cd281d8d4e"/></dir><dir name="product"><dir name="view"><file name="count.phtml" hash="09dcc9c9e9dc860f7f94415f6632d405"/><file name="list.phtml" hash="db87f4af149979c0c2b6211b94951b3b"/><file name="other.phtml" hash="454e2d215bc06773e73137623ad69a03"/></dir></dir><file name="view.phtml" hash="9071f84c610db079a9ca1470c250106f"/></dir><dir name="rss"><file name="list.phtml" hash="38fa9c4fb95737eeaa00fd0489411401"/><file name="nofeed.phtml" hash="92e1a1121f0608ed8438a89346f335d3"/><dir name="order"><file name="details.phtml" hash="30700dffcdc96558e89ae4f4ac5d062b"/></dir></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="ca55c7d479961dd005c0d839e2646e05"/></dir><file name="agreements.phtml" hash="ee98549f1b7e1fb42afa537ba8de8818"/></dir><dir name="guest"><file name="form.phtml" hash="509b6ba571fc7aff64565379ffd542ad"/></dir><dir name="order"><file name="comments.phtml" hash="cdc875ed3a37727d5cc403c342eab1bb"/><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="83eacbdf4dd635e5f9c94dbd97cf6793"/></dir></dir><file name="items.phtml" hash="7c9205260c4f0c8e16d3192b97033715"/></dir><file name="creditmemo.phtml" hash="082f3e41013326307878edefae9f12fa"/><file name="details.phtml" hash="427260fa04f2f412197fa4ab30949c07"/><file name="history.phtml" hash="081e7f1104707953c5a4ac5ebd901b09"/><dir name="info"><file name="buttons.phtml" hash="f4396a7de6170b8d920859ffb8e9a259"/></dir><file name="info.phtml" hash="6c44ca5d08b0dff46a0429fe92e7f057"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="61bac326041daebb7781db3a33d2223e"/></dir></dir><file name="items.phtml" hash="b76c99d2ef43a028b16a334a42a79b15"/></dir><file name="invoice.phtml" hash="d9f96a0911418669b76d7a579de0f45a"/><dir name="items"><dir name="renderer"><file name="default.phtml" hash="552e7453d0da2449f3720aaf18e768ba"/></dir></dir><file name="items.phtml" hash="531cdacc2b7b99f7e74978d83e6f9c99"/><dir name="print"><file name="creditmemo.phtml" hash="bea90d3be8eaa01131eda35dec526192"/><file name="invoice.phtml" hash="6631161daf44f42e5876f85a35882b1b"/><file name="shipment.phtml" hash="87ec2797d4fb4e965ed2b3c12fdcb747"/></dir><file name="print.phtml" hash="67b90f2d6512c83b44b16d1eb75685b6"/><file name="recent.phtml" hash="ea339a8cea8f1dfda8a9e6dc22f68e73"/><dir name="shipment"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="081db6648f65fd6b0fb34abd7fa16441"/></dir></dir><file name="items.phtml" hash="d64f6bb38b064d6b111482a99594d158"/></dir><file name="shipment.phtml" hash="8e56ba664cd9cdc01bf19f4dd6b0b783"/><file name="totals.phtml" hash="9ac8837db67bcd5a49197b5a00720df5"/><file name="trackinginfo.phtml" hash="d0eb20dd14a19d1185c5d61a67ebfb3e"/><file name="view.phtml" hash="580d296f4fd1c049cc061852d6f122a2"/></dir><dir name="payment"><dir name="form"><dir name="billing"><file name="agreement.phtml" hash="2006888669e168052d61ec198f38ee6b"/></dir></dir></dir><dir name="recurring"><file name="grid.phtml" hash="58261dc0e83512ffff4d5b076317b1f8"/><dir name="profile"><dir name="view"><file name="info.phtml" hash="614ba6f33d50ef89026b9cee0e0c30bd"/></dir><file name="view.phtml" hash="34a224e0cfec4e5716f0f86fe12fb0e7"/></dir><file name="profiles.phtml" hash="e91a9c209303c1702dae8ed09604e76d"/></dir><dir name="reorder"><file name="sidebar.phtml" hash="bf0a4c9ea18df3377d83b4273cde7149"/></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="38e6e2aff228a2aad3b0437e61bb5522"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="f0a055a14b97e0e6b4d38e310021a5b3"/></dir><dir name="shipping"><dir name="tracking"><file name="ajax.phtml" hash="e3b41fd33ba626ae7b9bfb7f23c07e93"/><file name="popup.phtml" hash="131eafbe3bb46b4ed6af3f6aff33a6b4"/></dir></dir><dir name="tag"><file name="cloud.phtml" hash="62c7ffab99fec479b343b21fea0fde3b"/><dir name="customer"><file name="recent.phtml" hash="8050f20856a9785fc37d0d6c5379020a"/><file name="tags.phtml" hash="e2a84aef98e491e2b36071757249a3d5"/><file name="view.phtml" hash="db81e635e46ef0cc5170ca0c64ff07d9"/></dir><file name="list.phtml" hash="dca4ad345072f43496e9870582b490f1"/><file name="popular.phtml" hash="093fad41b8786721d484400ab9bc8557"/></dir><dir name="tax"><dir name="checkout"><file name="discount.phtml" hash="168322a5454576d07c7597ffe24164db"/><file name="grandtotal.phtml" hash="153eeee2fc47d7d9b89cef439c676d23"/><file name="shipping.phtml" hash="f54b101deb4b0245a166ccdac5dd43f1"/><file name="subtotal.phtml" hash="1457075b05ef9d9bdfcad36095af71bc"/><file name="tax.phtml" hash="06f54cf61021e9e6e9495cab97c22bc0"/></dir><dir name="order"><file name="tax.phtml" hash="06c5f3b434b69e766bc508b5c527bda0"/></dir></dir><dir name="wishlist"><dir name="button"><file name="share.phtml" hash="335c1ca165cb0dd3789f64ea036096a8"/><file name="tocart.phtml" hash="68cc0db51b5a5c44fa477f049d85b970"/><file name="update.phtml" hash="0cbff9376749be9f6e8779b59a17e4d5"/></dir><dir name="email"><file name="items.phtml" hash="29344b6abfa99373e582db5a00fb5966"/><file name="rss.phtml" hash="f6df3dcfdb66431aff62d364c36f6467"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="39d152a5424161fbbb1e08d69e3955b2"/><file name="image.phtml" hash="c2fa04784d650dbe8663bde989ea206b"/><file name="info.phtml" hash="276b4e69a507fd4ec5b9a9980eac61d1"/><file name="remove.phtml" hash="09bc779e5db907482a09ec7fd6b95aa9"/></dir><dir name="configure"><file name="addto.phtml" hash="1e2c74806897a11bcbdc29dec4a34a30"/></dir><file name="list.phtml" hash="c6c3b95119f22f2a5fcf6599d2f468fa"/></dir><file name="options_list.phtml" hash="29585958c2328f45c62fad5192b83276"/><dir name="render"><dir name="item"><file name="price.phtml" hash="027e4f748e6039217b32de1455bf8a97"/><file name="price_msrp_item.phtml" hash="9ea3988c02dd93121dfcd12179d5c9d0"/><file name="price_msrp_rss.phtml" hash="59057882123117bea1169d3bac674164"/></dir></dir><file name="shared.phtml" hash="ce133ff86ad7ccbb5f380dbf36367a79"/><file name="sharing.phtml" hash="234fc41c319bcb050d32804cff0baebc"/><file name="sidebar.phtml" hash="3c91d09df73be7dd00a307fdb74ae4be"/><file name="view.phtml" hash="41ff38bf278e110732b4b05a5deb8328"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="css"><file name="email-inline.css" hash="72d47d85352353f347dd2b0f8c0104ac"/><file name="email-non-inline.css" hash="e889edd400833a1b5841b26a0a4b61eb"/><file name="widgets.css" hash="c1f91d1c4f18176ad2e95c8f79b1b435"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><dir name="cookies"><file name="firefox.png" hash="425e1b2ddc38c0bba431fb54357c66a4"/><file name="ie6-1.gif" hash="5c27700e245762bc89ed8c3ee7183f21"/><file name="ie6-2.gif" hash="d8c55e15e1f711e5c259300a9c19551b"/><file name="ie7-1.gif" hash="d61edcc8a514a3c81ea116b7d38ddcb6"/><file name="ie7-2.gif" hash="0526a654e94c54866cad977c0a47d3e5"/><file name="ie7-3.gif" hash="4fb142def3f6cfd8d8d23e1315528a1e"/><file name="ie7-4.gif" hash="575c276231c6a91e28935ec98215e146"/><file name="ie7-5.gif" hash="3ae5fcc11fe89da91674d183872337c1"/><file name="ie7-6.gif" hash="95a4981a41785a8cde273c9b2edbfbc7"/><file name="opera.png" hash="34070d92180d4ee0e37b1dd8bb731cd7"/></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="reload.png" hash="84cc4883f78ef850814ea9b53989b2a7"/><dir name="widgets"><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_widget-link.gif" hash="1bf753578171f147f0203e7b13bdd0c4"/><file name="i_widget-new.gif" hash="a75377ffed51b711cbc608ffaa1a2e7d"/></dir><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/></dir><dir name="js"><file name="bundle.js" hash="2f2bf27d13a85d6ebc665880c9dfb05c"/><dir name="checkout"><file name="review.js" hash="5582b2d213070aa9ad488f9e69516574"/></dir><file name="giftmessage.js" hash="57f753b9e257228017a835b899d4979f"/><file name="ie6.js" hash="c6c7baa57cdad02f56d6e72945fcebdd"/><file name="msrp.js" hash="72e4385e32df5e2c07ab56f40bcfce76"/><file name="opcheckout.js" hash="60ed6e7c4c6d5f01a7b8447931fdc875"/></dir><dir name="lib"><dir name="prototype"><dir name="windows"><dir name="themes"><dir name="magento"><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="content_bg.gif" hash="21278ea0da2d4256f4ced96b6080ba2e"/><file name="top_bg.gif" hash="26f28090de87d64f9b01bf624f89bfe2"/><file name="window_close.png" hash="3af14f053f360bf31f8ba2df73ec7f1e"/></dir><file name="magento.css" hash="cdb89dfeea9f6bb9c87e1abd1d8660f5"/></dir></dir></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Default-1.9.4.1.xml
deleted file mode 100644
index b1dfe7f..0000000
--- a/var/package/Interface_Frontend_Default-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Default</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Frontend</summary>
-    <description>Default interface for Frontend</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:41</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/><file name="widget.xml" hash="7770e002017593cf180f6f7cdff4fb61"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="793e1ff86039f24caff6fad87a094fa1"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="default"><dir name="default"><dir name="css"><file name="oauth-simple.css" hash="8ffcc427e25d192ed04fdb70a344ac2a"/><file name="print.css" hash="d07ecb64ce91e4eb3e9b14e1e47e4399"/><file name="styles-ie.css" hash="4a2b6232a15bf9e8a65fcd39e94bf5b3"/><file name="styles.css" hash="6f175060983a46cdb217cead35b8cd9f"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="best_selling_tr_even_bg.gif" hash="5022d648379090e306f00cd64738b146"/><file name="best_selling_tr_odd_bg.gif" hash="926622704f53796801bb5d097e116c8e"/><file name="bkg_account_box.gif" hash="dd98174b6e3e5605a3f9551a59c66841"/><file name="bkg_block-actions.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_block-currency.gif" hash="bfaad1b64557c05ad6f4b124ad3d3532"/><file name="bkg_block-layered-dd.gif" hash="6ae6f8184e87de496fb74eeec65737c9"/><file name="bkg_block-layered-dt.gif" hash="ba8229068657b80f2c42111c5a1a307e"/><file name="bkg_block-layered-label.gif" hash="14687dfa3921cfd12d2149c1497d9765"/><file name="bkg_block-layered-li.gif" hash="753ebb76a4fc2b5b6915c536fcf4d487"/><file name="bkg_block-layered-title.gif" hash="c92e29b30af7abf4e0bc3f714a246f55"/><file name="bkg_block-layered1.gif" hash="607167f198572e83a0e728b6b9383a70"/><file name="bkg_block-title-account.gif" hash="a64f1df5a7e3d0f6a58b017f74311cb1"/><file name="bkg_block-title.gif" hash="f8c1f130ad69464fe7aff2f589b2ec75"/><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_buttons-set1.gif" hash="2c641e927bc83156b7004ea37920513c"/><file name="bkg_checkout.gif" hash="11258fe49feff5513c9608f2ea486776"/><file name="bkg_collapse-gm.gif" hash="37418f23e65006dcfde07ce9b249e057"/><file name="bkg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bkg_divider1.gif" hash="260ebae91ffb1b7c663906b29a069925"/><file name="bkg_form-search.gif" hash="2ca36eb80ea705e063409153f3821f78"/><file name="bkg_grand-total.gif" hash="10f1c3d82d78170706fa3e9c4baa7e04"/><file name="bkg_grid.gif" hash="a6f64fedbac51fb1b86184cd488cc4e6"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_login-box.gif" hash="5538675d7f1c35d96a2b8013948f42a6"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="bkg_nav0.jpg" hash="f9ac3f31e293cf075471d2d3fe07353a"/><file name="bkg_nav1.gif" hash="f4e26840c8cca0e74aba5b810341c5c0"/><file name="bkg_nav2.gif" hash="a64c8f5165b239e432d26a62ae5f79b6"/><file name="bkg_opc-title-off.gif" hash="f69b40b5331ab3760f54d038daf287eb"/><file name="bkg_pipe1.gif" hash="7852290f6a443000ead96b8cec5cd7c7"/><file name="bkg_pipe2.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="bkg_pipe3.gif" hash="11bfac1e590f0c77fb12f37d7f05cd3c"/><file name="bkg_product-view.gif" hash="7078a7f2827156d5ae0a1cb59da3c418"/><file name="bkg_product_collateral.gif" hash="1d4d6b22e5108aefae52709d3934f397"/><file name="bkg_rating.gif" hash="0a8777c815350ddf1e316a537ad0c335"/><file name="bkg_sp-methods.gif" hash="17d68b5449adaa87dafc62ae0afa1b9a"/><file name="bkg_tfoot.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_th-v.gif" hash="b0d17555dfc6060941e0c067718189df"/><file name="bkg_th.gif" hash="f249911b08f2822fc0b561b7f98575d2"/><file name="bkg_toolbar.gif" hash="fb7ed019476eaa1643af922b59ede4fb"/><file name="btn_checkout.gif" hash="d2060501e14e86c29e28137130e5726e"/><file name="btn_edit.gif" hash="df3565eb4e4d0dc578201df60de54b47"/><file name="btn_gm-close.gif" hash="346e26eece27449a2f224aef76ae372e"/><file name="btn_google_checkout.gif" hash="843d75249ce05b5d87ca5419f37b1c3b"/><file name="btn_paypal_checkout.gif" hash="6edd61270b7b5632eafad10557129114"/><file name="btn_place_order.gif" hash="d35219f86ae2c983ee1a31557e37b612"/><file name="btn_previous.gif" hash="63473a1520a73bb0c9b47b685d17cd21"/><file name="btn_proceed_to_checkout.gif" hash="4daac687b514fecfd1068539500ac3d7"/><file name="btn_proceed_to_checkout_dis.gif" hash="9e152c01d5d88f690dc52cb62428f3b6"/><file name="btn_remove.gif" hash="6182e723aa2a253dc6cf334a3dfaaa84"/><file name="btn_remove2.gif" hash="234bddc4c5878c5ef16407a944824236"/><file name="btn_search.gif" hash="2d93b43c0a1c1182358677661e26a978"/><file name="btn_trash.gif" hash="bcb22f558a0eb32243a2a36645189e9f"/><file name="btn_window_close.gif" hash="c83f3cbbb2aedfc580dff78d5cfb63ed"/><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="cvv.jpg" hash="e27210d810bbab732935d9410936ef87"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="free_shipping_callout.jpg" hash="cbf2e494ef7ca50acf8826321d739559"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="home_left_callout.jpg" hash="ee99a5586cf52e85c986d1275958a7da"/><file name="home_main_callout.jpg" hash="e6d1c119d5b24a5916fe394cb4b5cdc3"/><file name="i_arrow-top.gif" hash="3dbb0584e8eb1d96cc3d3c40c17d7aaf"/><file name="i_asc_arrow.gif" hash="40aa554212d6a1f60593c27d78d85fa3"/><file name="i_availability_only.gif" hash="bca1f00a50864171ad98317b778e869c"/><file name="i_availability_only_arrow.gif" hash="0cf32b72fefc94b89b74e4f3f02c2e93"/><file name="i_block-cart.gif" hash="cc19e21f9c89b70cc10354ff588ca8ab"/><file name="i_block-currency.gif" hash="643024bcae5ece554fdbbc041aeb297c"/><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_block-poll.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="i_block-related.gif" hash="4e277173b6372b1a90b0f19e0388ad54"/><file name="i_block-subscribe.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="i_block-tags.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-viewed.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-wishlist.gif" hash="8f8cda89ca20ba4a9b2f8c91f73fdff9"/><file name="i_desc_arrow.gif" hash="92fd194bfae4ce5ae3354e1e47d7ac7d"/><file name="i_discount.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="i_folder-table.gif" hash="bf006ddb591d8ac95d2e895bf2fdbc8d"/><file name="i_ma-info.gif" hash="91259557447ee80eb1110fe0c85cb3b5"/><file name="i_ma-reviews.gif" hash="859c97695ec396c0b284a0c3c7c416ad"/><file name="i_ma-tags.gif" hash="1e83e3b0b677c92b3aa8a252268f7b86"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_page1.gif" hash="704f7d4eccbdf9cabbad7770f18856ff"/><file name="i_page2.gif" hash="57a04ca584e05e28dc94c7e68f0af62e"/><file name="i_pager-next.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="i_pager-prev.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="i_print.gif" hash="0aed138181495642e9ab29e55d194d40"/><file name="i_rss-big.png" hash="6cf70e7c52a3f3d7b833ccadb041a555"/><file name="i_rss.gif" hash="e5bbc388d818c142868b4a1df0b48793"/><file name="i_search_criteria.gif" hash="cf67b9cc5c311ae3f99e68cd29ae17be"/><file name="i_shipping.gif" hash="91a0d2cc2eb2391f90ec8a75c04b3183"/><file name="i_tag_add.gif" hash="a736baa992aa55b6fb71e8742a04dc82"/><file name="i_tier.gif" hash="c5189e25afeb7c1a8c4902a42832593e"/><file name="i_type_grid.gif" hash="a1e5d8ac36fb2891ea16e729b95c552c"/><file name="i_type_list.gif" hash="61333d383ec142b8d270abe77324aa5d"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="logo_email.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="logo_print.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="magnifier_handle.gif" hash="238fbdd7959f517db11c6f57ee4daaf4"/><file name="map_popup_arrow.gif" hash="6383b40a9e7bd3c95260bef4fbb1b163"/><dir name="media"><file name="404_callout1.jpg" hash="834e53a03e2921a2fd3c135c0c7189df"/><file name="404_callout2.jpg" hash="016984b4a1579df34147f9407098db73"/><file name="about_us_img.jpg" hash="726f36dd75b5a709a1a14acab1660188"/><file name="best_selling_img01.jpg" hash="5e7337a4061a636df8ee4bf979a092ac"/><file name="best_selling_img02.jpg" hash="b9a49c0964938ec72fb834cb166b9352"/><file name="best_selling_img03.jpg" hash="e3581487fb4589baecc553f2ce8d5247"/><file name="best_selling_img04.jpg" hash="7e59bf99f5f813e327595c52d3320174"/><file name="best_selling_img05.jpg" hash="e396892daec7ffcf7244082b3e596911"/><file name="best_selling_img06.jpg" hash="2702839637efbe0fd0a4bad41cd6a551"/><file name="cell_phone_landing_banner1.jpg" hash="b25562360fc470f1091ca7ea014a3290"/><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="electronics_cellphones.jpg" hash="8f6badbc32ce806c6109c788df6ef5e9"/><file name="electronics_digitalcameras.jpg" hash="953b8d7db6f0bdcd53b1d6b1386962b9"/><file name="electronics_laptops.jpg" hash="e050e92d72000e6bdc763a7b5888ec8a"/><file name="furniture_callout_spot.jpg" hash="28edc7d72486ab2362324995550d87af"/><file name="furnitures_bed_room.jpg" hash="b8616c5bffc23a92d2a1c97dae57b262"/><file name="furnitures_living_room.jpg" hash="2663737f3997cb1a49ce24d07dc8aefb"/><file name="head_electronics_cellphones.gif" hash="a69425966444ea597fb7c629114d5165"/><file name="head_electronics_digicamera.gif" hash="bde3cec3fc16b2d0ae57e7783eb00652"/><file name="head_electronics_laptops.gif" hash="b2c55387ffa92277315bdedeb4cb9b8f"/><file name="laptop_callout_mid1.jpg" hash="4ffb50bd3b7b32a78fd059b1571c202e"/><file name="laptop_callout_mid2.jpg" hash="662cf3881b06b090e9500496b19b03e4"/><file name="laptop_callout_mid3.jpg" hash="22aa71ecfe0aa9b6936a1eddb62d889e"/><file name="laptop_callout_spot.jpg" hash="2e469d1bd871355eaef6076487a973db"/><file name="shirts_landing_banner1.jpg" hash="4acc8620b009d835e5c25587671ea25d"/></dir><file name="np_cart_thumb.gif" hash="e9fdd943e0947e15f0638506f477e358"/><file name="np_more_img.gif" hash="ace357bfe3e81ffb62137cd5b25ae5e1"/><file name="np_product_main.gif" hash="d0cccda76de50efa025215ce85dacb1c"/><file name="np_thumb.gif" hash="e46270c89358ecc8341d1565c14644b8"/><file name="np_thumb2.gif" hash="8502866cdabc5c74aca7d7bd32a06a03"/><file name="opc-ajax-loader.gif" hash="e805ea7eca1f34c75ba0f93780d32d38"/><file name="pager_arrow_left.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="pager_arrow_right.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="ph_callout_left_rebel.jpg" hash="0ce8ad0026d8b8a83ed7acdf6209129b"/><file name="ph_callout_left_top.gif" hash="f17a036d75e5065eb76bafbb2c8ad7ff"/><file name="product_zoom_overlay_magnif.gif" hash="83834893e162221d6d9257fe67847370"/><file name="slider_bg.gif" hash="87bc1b46d87de4f6252c7216216627c3"/><file name="slider_btn_zoom_in.gif" hash="ef0fc67f77f30827ee67f4e744b60781"/><file name="slider_btn_zoom_out.gif" hash="68b3d1c28dc5aec4f6b64d70a6996b6f"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/><dir name="xmlconnect"><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Default-1.9.4.2.xml b/var/package/Interface_Frontend_Default-1.9.4.2.xml
new file mode 100644
index 0000000..2c861ef
--- /dev/null
+++ b/var/package/Interface_Frontend_Default-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Default</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Frontend</summary>
+    <description>Default interface for Frontend</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:00</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/><file name="widget.xml" hash="7770e002017593cf180f6f7cdff4fb61"/></dir><dir name="locale"><dir name="en_US"><file name="translate.csv" hash="793e1ff86039f24caff6fad87a094fa1"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="default"><dir name="default"><dir name="css"><file name="oauth-simple.css" hash="8ffcc427e25d192ed04fdb70a344ac2a"/><file name="print.css" hash="d07ecb64ce91e4eb3e9b14e1e47e4399"/><file name="styles-ie.css" hash="4a2b6232a15bf9e8a65fcd39e94bf5b3"/><file name="styles.css" hash="6f175060983a46cdb217cead35b8cd9f"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="best_selling_tr_even_bg.gif" hash="5022d648379090e306f00cd64738b146"/><file name="best_selling_tr_odd_bg.gif" hash="926622704f53796801bb5d097e116c8e"/><file name="bkg_account_box.gif" hash="dd98174b6e3e5605a3f9551a59c66841"/><file name="bkg_block-actions.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_block-currency.gif" hash="bfaad1b64557c05ad6f4b124ad3d3532"/><file name="bkg_block-layered-dd.gif" hash="6ae6f8184e87de496fb74eeec65737c9"/><file name="bkg_block-layered-dt.gif" hash="ba8229068657b80f2c42111c5a1a307e"/><file name="bkg_block-layered-label.gif" hash="14687dfa3921cfd12d2149c1497d9765"/><file name="bkg_block-layered-li.gif" hash="753ebb76a4fc2b5b6915c536fcf4d487"/><file name="bkg_block-layered-title.gif" hash="c92e29b30af7abf4e0bc3f714a246f55"/><file name="bkg_block-layered1.gif" hash="607167f198572e83a0e728b6b9383a70"/><file name="bkg_block-title-account.gif" hash="a64f1df5a7e3d0f6a58b017f74311cb1"/><file name="bkg_block-title.gif" hash="f8c1f130ad69464fe7aff2f589b2ec75"/><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_buttons-set1.gif" hash="2c641e927bc83156b7004ea37920513c"/><file name="bkg_checkout.gif" hash="11258fe49feff5513c9608f2ea486776"/><file name="bkg_collapse-gm.gif" hash="37418f23e65006dcfde07ce9b249e057"/><file name="bkg_collapse.gif" hash="2333c68e38163ed4656da82b9bcf362b"/><file name="bkg_divider1.gif" hash="260ebae91ffb1b7c663906b29a069925"/><file name="bkg_form-search.gif" hash="2ca36eb80ea705e063409153f3821f78"/><file name="bkg_grand-total.gif" hash="10f1c3d82d78170706fa3e9c4baa7e04"/><file name="bkg_grid.gif" hash="a6f64fedbac51fb1b86184cd488cc4e6"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_login-box.gif" hash="5538675d7f1c35d96a2b8013948f42a6"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="bkg_nav0.jpg" hash="f9ac3f31e293cf075471d2d3fe07353a"/><file name="bkg_nav1.gif" hash="f4e26840c8cca0e74aba5b810341c5c0"/><file name="bkg_nav2.gif" hash="a64c8f5165b239e432d26a62ae5f79b6"/><file name="bkg_opc-title-off.gif" hash="f69b40b5331ab3760f54d038daf287eb"/><file name="bkg_pipe1.gif" hash="7852290f6a443000ead96b8cec5cd7c7"/><file name="bkg_pipe2.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="bkg_pipe3.gif" hash="11bfac1e590f0c77fb12f37d7f05cd3c"/><file name="bkg_product-view.gif" hash="7078a7f2827156d5ae0a1cb59da3c418"/><file name="bkg_product_collateral.gif" hash="1d4d6b22e5108aefae52709d3934f397"/><file name="bkg_rating.gif" hash="0a8777c815350ddf1e316a537ad0c335"/><file name="bkg_sp-methods.gif" hash="17d68b5449adaa87dafc62ae0afa1b9a"/><file name="bkg_tfoot.gif" hash="da2970eac0a22c850b19ee3680475d51"/><file name="bkg_th-v.gif" hash="b0d17555dfc6060941e0c067718189df"/><file name="bkg_th.gif" hash="f249911b08f2822fc0b561b7f98575d2"/><file name="bkg_toolbar.gif" hash="fb7ed019476eaa1643af922b59ede4fb"/><file name="btn_checkout.gif" hash="d2060501e14e86c29e28137130e5726e"/><file name="btn_edit.gif" hash="df3565eb4e4d0dc578201df60de54b47"/><file name="btn_gm-close.gif" hash="346e26eece27449a2f224aef76ae372e"/><file name="btn_google_checkout.gif" hash="843d75249ce05b5d87ca5419f37b1c3b"/><file name="btn_paypal_checkout.gif" hash="6edd61270b7b5632eafad10557129114"/><file name="btn_place_order.gif" hash="d35219f86ae2c983ee1a31557e37b612"/><file name="btn_previous.gif" hash="63473a1520a73bb0c9b47b685d17cd21"/><file name="btn_proceed_to_checkout.gif" hash="4daac687b514fecfd1068539500ac3d7"/><file name="btn_proceed_to_checkout_dis.gif" hash="9e152c01d5d88f690dc52cb62428f3b6"/><file name="btn_remove.gif" hash="6182e723aa2a253dc6cf334a3dfaaa84"/><file name="btn_remove2.gif" hash="234bddc4c5878c5ef16407a944824236"/><file name="btn_search.gif" hash="2d93b43c0a1c1182358677661e26a978"/><file name="btn_trash.gif" hash="bcb22f558a0eb32243a2a36645189e9f"/><file name="btn_window_close.gif" hash="c83f3cbbb2aedfc580dff78d5cfb63ed"/><file name="calendar.gif" hash="b1468e5239504974c689eea5d93f86d4"/><dir name="catalog"><dir name="product"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="cvv.gif" hash="83cdd38bf110b0f9c52fe84b56f45298"/><file name="cvv.jpg" hash="e27210d810bbab732935d9410936ef87"/><file name="fam_book_open.png" hash="0ba89b9fbe7e88d4c6896ed0a1f495aa"/><file name="free_shipping_callout.jpg" hash="cbf2e494ef7ca50acf8826321d739559"/><file name="grid-cal.gif" hash="b1468e5239504974c689eea5d93f86d4"/><file name="home_left_callout.jpg" hash="ee99a5586cf52e85c986d1275958a7da"/><file name="home_main_callout.jpg" hash="e6d1c119d5b24a5916fe394cb4b5cdc3"/><file name="i_arrow-top.gif" hash="3dbb0584e8eb1d96cc3d3c40c17d7aaf"/><file name="i_asc_arrow.gif" hash="40aa554212d6a1f60593c27d78d85fa3"/><file name="i_availability_only.gif" hash="bca1f00a50864171ad98317b778e869c"/><file name="i_availability_only_arrow.gif" hash="0cf32b72fefc94b89b74e4f3f02c2e93"/><file name="i_block-cart.gif" hash="cc19e21f9c89b70cc10354ff588ca8ab"/><file name="i_block-currency.gif" hash="643024bcae5ece554fdbbc041aeb297c"/><file name="i_block-list.gif" hash="fe8424127ecbe4b0d893bcf6f253dc1a"/><file name="i_block-poll.gif" hash="52d778dddbf48b8d04226bee9370a7ef"/><file name="i_block-related.gif" hash="4e277173b6372b1a90b0f19e0388ad54"/><file name="i_block-subscribe.gif" hash="9e5fee06a543742045118a95f2debcb8"/><file name="i_block-tags.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-viewed.gif" hash="67d1255c2c3e9ed1a5c845f8d4e4a3ba"/><file name="i_block-wishlist.gif" hash="8f8cda89ca20ba4a9b2f8c91f73fdff9"/><file name="i_desc_arrow.gif" hash="92fd194bfae4ce5ae3354e1e47d7ac7d"/><file name="i_discount.gif" hash="908d44da90de5e54185764d093bbdb77"/><file name="i_folder-table.gif" hash="bf006ddb591d8ac95d2e895bf2fdbc8d"/><file name="i_ma-info.gif" hash="91259557447ee80eb1110fe0c85cb3b5"/><file name="i_ma-reviews.gif" hash="859c97695ec396c0b284a0c3c7c416ad"/><file name="i_ma-tags.gif" hash="1e83e3b0b677c92b3aa8a252268f7b86"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="i_page1.gif" hash="704f7d4eccbdf9cabbad7770f18856ff"/><file name="i_page2.gif" hash="57a04ca584e05e28dc94c7e68f0af62e"/><file name="i_pager-next.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="i_pager-prev.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="i_print.gif" hash="0aed138181495642e9ab29e55d194d40"/><file name="i_rss-big.png" hash="6cf70e7c52a3f3d7b833ccadb041a555"/><file name="i_rss.gif" hash="e5bbc388d818c142868b4a1df0b48793"/><file name="i_search_criteria.gif" hash="cf67b9cc5c311ae3f99e68cd29ae17be"/><file name="i_shipping.gif" hash="91a0d2cc2eb2391f90ec8a75c04b3183"/><file name="i_tag_add.gif" hash="a736baa992aa55b6fb71e8742a04dc82"/><file name="i_tier.gif" hash="c5189e25afeb7c1a8c4902a42832593e"/><file name="i_type_grid.gif" hash="a1e5d8ac36fb2891ea16e729b95c552c"/><file name="i_type_list.gif" hash="61333d383ec142b8d270abe77324aa5d"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="logo_email.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="logo_print.gif" hash="4073982b6c0263fe5f902566fd5c305b"/><file name="magnifier_handle.gif" hash="238fbdd7959f517db11c6f57ee4daaf4"/><file name="map_popup_arrow.gif" hash="6383b40a9e7bd3c95260bef4fbb1b163"/><dir name="media"><file name="404_callout1.jpg" hash="834e53a03e2921a2fd3c135c0c7189df"/><file name="404_callout2.jpg" hash="016984b4a1579df34147f9407098db73"/><file name="about_us_img.jpg" hash="726f36dd75b5a709a1a14acab1660188"/><file name="best_selling_img01.jpg" hash="5e7337a4061a636df8ee4bf979a092ac"/><file name="best_selling_img02.jpg" hash="b9a49c0964938ec72fb834cb166b9352"/><file name="best_selling_img03.jpg" hash="e3581487fb4589baecc553f2ce8d5247"/><file name="best_selling_img04.jpg" hash="7e59bf99f5f813e327595c52d3320174"/><file name="best_selling_img05.jpg" hash="e396892daec7ffcf7244082b3e596911"/><file name="best_selling_img06.jpg" hash="2702839637efbe0fd0a4bad41cd6a551"/><file name="cell_phone_landing_banner1.jpg" hash="b25562360fc470f1091ca7ea014a3290"/><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="electronics_cellphones.jpg" hash="8f6badbc32ce806c6109c788df6ef5e9"/><file name="electronics_digitalcameras.jpg" hash="953b8d7db6f0bdcd53b1d6b1386962b9"/><file name="electronics_laptops.jpg" hash="e050e92d72000e6bdc763a7b5888ec8a"/><file name="furniture_callout_spot.jpg" hash="28edc7d72486ab2362324995550d87af"/><file name="furnitures_bed_room.jpg" hash="b8616c5bffc23a92d2a1c97dae57b262"/><file name="furnitures_living_room.jpg" hash="2663737f3997cb1a49ce24d07dc8aefb"/><file name="head_electronics_cellphones.gif" hash="a69425966444ea597fb7c629114d5165"/><file name="head_electronics_digicamera.gif" hash="bde3cec3fc16b2d0ae57e7783eb00652"/><file name="head_electronics_laptops.gif" hash="b2c55387ffa92277315bdedeb4cb9b8f"/><file name="laptop_callout_mid1.jpg" hash="4ffb50bd3b7b32a78fd059b1571c202e"/><file name="laptop_callout_mid2.jpg" hash="662cf3881b06b090e9500496b19b03e4"/><file name="laptop_callout_mid3.jpg" hash="22aa71ecfe0aa9b6936a1eddb62d889e"/><file name="laptop_callout_spot.jpg" hash="2e469d1bd871355eaef6076487a973db"/><file name="shirts_landing_banner1.jpg" hash="4acc8620b009d835e5c25587671ea25d"/></dir><file name="np_cart_thumb.gif" hash="e9fdd943e0947e15f0638506f477e358"/><file name="np_more_img.gif" hash="ace357bfe3e81ffb62137cd5b25ae5e1"/><file name="np_product_main.gif" hash="d0cccda76de50efa025215ce85dacb1c"/><file name="np_thumb.gif" hash="e46270c89358ecc8341d1565c14644b8"/><file name="np_thumb2.gif" hash="8502866cdabc5c74aca7d7bd32a06a03"/><file name="opc-ajax-loader.gif" hash="e805ea7eca1f34c75ba0f93780d32d38"/><file name="pager_arrow_left.gif" hash="75973b020105dccbaf34e49d7852552d"/><file name="pager_arrow_right.gif" hash="ed4d6640624c2b6edeab4c212314bd6d"/><file name="ph_callout_left_rebel.jpg" hash="0ce8ad0026d8b8a83ed7acdf6209129b"/><file name="ph_callout_left_top.gif" hash="f17a036d75e5065eb76bafbb2c8ad7ff"/><file name="product_zoom_overlay_magnif.gif" hash="83834893e162221d6d9257fe67847370"/><file name="slider_bg.gif" hash="87bc1b46d87de4f6252c7216216627c3"/><file name="slider_btn_zoom_in.gif" hash="ef0fc67f77f30827ee67f4e744b60781"/><file name="slider_btn_zoom_out.gif" hash="68b3d1c28dc5aec4f6b64d70a6996b6f"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/><file name="window_overlay.png" hash="9ec9aea4c2159e0b1e73bda29821a39f"/><dir name="xmlconnect"><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml b/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml
deleted file mode 100644
index 31ad16d..0000000
--- a/var/package/Interface_Frontend_Rwd_Default-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Frontend_Rwd_Default</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This is a RWD themes base</summary>
-    <description>This is a RWD themes base</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:41</time>
-    <contents><target name="magedesign"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="etc"><file name="theme.xml" hash="9d42933c3a4f2b1c291d5b5bbf11d6dd"/><file name="widget.xml" hash="00f1e461d9062e53090b4a894354b80a"/></dir><dir name="layout"><file name="bundle.xml" hash="aa8e8659b158139fbcb9eb1d548a519e"/><file name="catalog.xml" hash="ffb44336e278a04a6c175f07bc562fe7"/><file name="catalog_msrp.xml" hash="0d5a348db930eed42bc35d4ccf9908c1"/><file name="catalogsearch.xml" hash="4dde9f7a881e3cea3ec129bef1b13ee5"/><file name="checkout.xml" hash="20916639cb2d9994c091895da15a0b0f"/><file name="cms.xml" hash="2a6ec2cd93843f7f75061973934af241"/><file name="configurableswatches.xml" hash="9f029376440a19b8099a5b6e6665e984"/><file name="contacts.xml" hash="dfd97d1b8395cc271125a357e6811727"/><file name="customer.xml" hash="beaeb5e3415f50a80d9f91c758accefa"/><file name="directory.xml" hash="7b3ced90cf254b76500d5f8a363b28fc"/><file name="downloadable.xml" hash="6fb6aec95bd307fc8d848cdef16a87ea"/><file name="newsletter.xml" hash="99458a6f3e73b33348de623f83f44581"/><file name="oauth.xml" hash="705c8cc50c26f7e4285bb7416ab1f051"/><file name="page.xml" hash="187dd31efe8ba00dbae87c0522bc9676"/><file name="paypal.xml" hash="0ff834afd3728b32196e721ade5256aa"/><file name="persistent.xml" hash="5f744e61a14e2a072beff3857567d45f"/><file name="review.xml" hash="578157e3a9ef9539b06349fde10ddcbc"/><file name="rss.xml" hash="362997d9980766b785e50417795fcfde"/><file name="sales.xml" hash="8c19fa843eca0ddc45fc20e4678adec3"/><file name="wishlist.xml" hash="44d782a89f00808a097b43531e546c75"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="385a4bdbbb17021d7c8c725c5ca16dbb"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="view"><dir name="type"><dir name="bundle"><file name="availability.phtml" hash="cd7b4f76fe9ccb4862fcfe9fdf735bce"/><dir name="option"><file name="select.phtml" hash="fd5bdffd5c80730d26c432773fd929c9"/></dir></dir><file name="bundle.phtml" hash="390f520b82259a27539742c060d70cb8"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b9f0008d961f945d3102de4ebff06746"/></dir><dir name="invoice"><file name="default.phtml" hash="50c01c93a68ac239d23ac746ef8eecc6"/></dir><dir name="order"><file name="default.phtml" hash="6bae6cb6699a7e67fbcc0be01a9e3958"/></dir><dir name="shipment"><file name="default.phtml" hash="12efaca5f48e8e6216af313a93a0c836"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><file name="renderer.phtml" hash="01de9221542d4576b428002af5450038"/></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="5b2f1638d0d2a79ea51b34328bb376e5"/></dir><dir name="catalog"><dir name="layer"><file name="filter.phtml" hash="a9800445835d95e47b4667562c5504c9"/><file name="state.phtml" hash="68b812651343d8efe2f52396ae4b8bff"/><file name="view.phtml" hash="43ef898fd0184a34e8153eb45337bcf5"/></dir><dir name="msrp"><file name="popup.phtml" hash="dbeb5ac9707c288e9657d3082547890b"/></dir><dir name="navigation"><file name="left.phtml" hash="6575fb3943bd8962da3faa5f16d3eb55"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="51d60c165c9f6f9eec45e2c929a46665"/><file name="sidebar.phtml" hash="0be3217397d6d11966530589a98a5021"/></dir><dir name="list"><file name="related.phtml" hash="689fd2ed824260f8ce0e26c9923323dd"/><file name="toolbar.phtml" hash="ab66060531cfb82eb8e362c90cc83791"/><file name="upsell.phtml" hash="4b200ec4f7ff016917709dfddb751e31"/></dir><file name="list.phtml" hash="1a1d32406dd64a50691dc1e38b8e6398"/><file name="price.phtml" hash="c5e841d59f7f6bbf84f9c879f1ebed27"/><dir name="view"><file name="addto.phtml" hash="8117d1b5d647bf4b3fc8dd84f3dbc6ca"/><file name="addtocart.phtml" hash="63d5573173bbc198b29057b86a60fe54"/><file name="media.phtml" hash="5fb346c580f635b927a5412ae2556b6b"/><file name="sharing.phtml" hash="b9a62aeaeb1f1345c894d035bc5c98d8"/><dir name="type"><dir name="availability"><file name="default.phtml" hash="7fed915ce32b155a045301ee867c283e"/><file name="grouped.phtml" hash="9c467e68c5d5787181b9b54f71715b2b"/></dir><file name="default.phtml" hash="60d57df7bd2c9e0175a067c21c40c1ec"/><file name="grouped.phtml" hash="6740aff8dc4282a212c98d18da65a29c"/><dir name="options"><file name="configurable.phtml" hash="82d4bd6957faafaed86d3c2ea0610a04"/></dir></dir></dir><file name="view.phtml" hash="febb0fe90db741820576d0be0c4b701f"/><dir name="widget"><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="0048f859bd6db690859e81c704553455"/><file name="new_images_list.phtml" hash="6a3c1362ad5f86062f30aca148442a01"/><file name="new_names_list.phtml" hash="c1555ea48bcdf69eacf6d3d41ed52530"/></dir><dir name="content"><file name="new_grid.phtml" hash="e9fd476dbb4621d76c1918ad12caff6f"/><file name="new_list.phtml" hash="f4bb956b74a3ae4b8de53f4ddec18eb0"/></dir></dir></dir></dir></dir><dir name="cataloginventory"><dir name="stockqty"><file name="composite.phtml" hash="77b673795f6d199055461d07deeb6c73"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5f3f10ad173037b8aaaa8104d9c48a1b"/></dir><file name="form.mini.phtml" hash="5d203d602572292ab563b724026b2d3e"/><file name="result.phtml" hash="7c6e68ae4bf4edf13b90d7bba68b1208"/></dir><dir name="centinel"><dir name="authentication"><file name="start.phtml" hash="d80d808774fac08fef28c647bb76414e"/></dir></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="f2591f5cadb027ea4e5085946c8f9f80"/><file name="crosssell.phtml" hash="68afc918f0414b31b5f88df4cc6e3e92"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="a7f1e2c2d26c9b1ddb2e0269235ce499"/></dir><file name="default.phtml" hash="6ff4fd36c9a72e589ea0c92e9556301d"/></dir><dir name="minicart"><file name="default.phtml" hash="fee4b446fa9077b4dc17af56899d6383"/><file name="items.phtml" hash="e639d64e913ad9b8d3b1a56165574d3f"/></dir><file name="minicart.phtml" hash="b55c9a51a9eb6057a41d4e4c2b48e910"/><dir name="render"><file name="default.phtml" hash="9850aac16db5fc6263c25b07443bdafa"/><file name="simple.phtml" hash="bc76fc52fec4bc1b24c311cad53dc2b2"/></dir><file name="shipping.phtml" hash="2f462cead90bb493a2ce874e4d5a8747"/><dir name="sidebar"><file name="default.phtml" hash="3adc91979d26188830db7bc0b3731742"/></dir><file name="sidebar.phtml" hash="9ffb85ddaa41e91c9233ec5c82c7ae82"/></dir><file name="cart.phtml" hash="9a943d16f3d981366e5d613e88af7d34"/><dir name="multishipping"><file name="addresses.phtml" hash="bda46e6cb1800933a114258b47a5a0da"/><file name="billing.phtml" hash="884d9b8dd0879897e6d43c50440039c3"/><dir name="item"><file name="default.phtml" hash="d7beeb4d8edc0fec58e226f5ce525c6d"/></dir><dir name="overview"><file name="item.phtml" hash="0597f23f2cf6e05371e40ee5c7e2315d"/></dir><file name="overview.phtml" hash="e2c461b9e67959e849135b5d079c0537"/></dir><dir name="onepage"><file name="payment.phtml" hash="61cf9454d8f6169c9f3d4bdc6b10a8c2"/><file name="progress.phtml" hash="955bc23d4addd0efe3e7feac8d8feb5d"/><dir name="review"><file name="info.phtml" hash="34c7f8cf5827594b16c11e6ee3411513"/><file name="item.phtml" hash="c8e48375afa925eb2321e3aff1b0bf4c"/></dir><file name="shipping.phtml" hash="0ce8393c48e2bd2503b004e0a29e04fe"/></dir><file name="onepage.phtml" hash="af546fa00f2884b9fc6335bf1c0cba60"/></dir><dir name="configurableswatches"><dir name="catalog"><dir name="layer"><dir name="filter"><file name="swatches.phtml" hash="f9eee1bdd31e706a560d074efcd5313c"/></dir><dir name="state"><file name="swatch.phtml" hash="9d3f9998bc24cbe06b99046c8cc2a5f3"/></dir></dir><dir name="media"><file name="js.phtml" hash="57e9acda00f28629670ba5e84ea9cabb"/></dir><dir name="product"><dir name="list"><dir name="price"><file name="js.phtml" hash="b57be935901c4285b6f57f2077adf2eb"/></dir><file name="swatches.phtml" hash="d71db2c1ecc49b7bd1f5c3cb91692bac"/></dir><dir name="view"><dir name="type"><dir name="configurable"><file name="swatch-js.phtml" hash="7502a7498d8fc0d11e3aaae2f64f4c60"/></dir><dir name="options"><dir name="configurable"><file name="swatches.phtml" hash="75198b3138a8c825572830d13f42c443"/></dir></dir></dir></dir></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="7368ea4443c1bc85a880ba2fe84d9a0c"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="3a5ee9d2564cff6c85b9a8d81650ed12"/></dir><file name="dashboard.phtml" hash="f9bf153b12b881cd3aff3f874776e006"/><file name="navigation.phtml" hash="f573f85c06b8da6cd04fe30043a26986"/></dir><dir name="address"><file name="edit.phtml" hash="9ec6de2e18779d3f83469b2c08a9ba22"/></dir><dir name="form"><file name="address.phtml" hash="29ca055fce63adb7e7b781d9c5b44d37"/><file name="changepassword.phtml" hash="85e3a3f61d387ad99a724c49b50cb77b"/><file name="confirmation.phtml" hash="f7e3c2f26a601d85744676cd36310640"/><file name="edit.phtml" hash="aa5035754de40c1da9e6481a04fa686e"/><file name="forgotpassword.phtml" hash="19b6dcb57c9401398335ded1c669f7f0"/><file name="mini.login.phtml" hash="bfd6855770d271913c4c5b4b30cdbd56"/><file name="resetforgottenpassword.phtml" hash="0180eb6f13153ea9b9a4399a1687c68a"/></dir></dir><dir name="directory"><file name="currency.phtml" hash="a827c080db81adc467b091cbfd7001ba"/></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="type.phtml" hash="ac98a769be2e41a26702f9245d9d3c06"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="99baf0b573a57793538763745961d3e2"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="39b625a969337c7b42092ca989d3a6ce"/></dir></dir></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="9f13aedbb1a5a22ecc9ed803915eeafc"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="cd99c9d650bf7b3aa755b337cbd104db"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="1d056b77b1aa8edabe1d5cc39810910f"/></dir><dir name="order"><file name="downloadable.phtml" hash="70fb86f91a456322d7e39626ab2ab475"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="b996432e3f9ee66b75ba7f881a3ee7ac"/></dir></dir></dir></dir></dir><dir name="email"><dir name="catalog"><dir name="product"><file name="list.phtml" hash="e9151bd0765f84a45ddc640d1f0c5184"/><file name="new.phtml" hash="257a76796d136ec5d6a60407ad36978e"/></dir></dir><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="d28d47025ff2c145a6b974f002d9a231"/></dir><dir name="invoice"><file name="items.phtml" hash="f190f4c7af76fae8a78a329bf81de99e"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="invoice"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="order"><file name="default.phtml" hash="82d4fe9be011e52561450f65405dbf05"/></dir><dir name="shipment"><file name="default.phtml" hash="2719db4c14bbc1b2d608ee305a5ea133"/></dir></dir><file name="items.phtml" hash="2c838581f36f73ae6b637c081345bf34"/><dir name="shipment"><file name="items.phtml" hash="aad8aa56e8cbcd61f55c7d20d96e1c38"/><file name="track.phtml" hash="f4f2933f0b10a997e0448c00c30a3a6e"/></dir><dir name="totals"><file name="wrapper.phtml" hash="8c6c83bbe4597b477690a26eb302b1dc"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="01a800642590e4309af5a625b92c8798"/><file name="stock.phtml" hash="a9dfc2adb4cebcba4e49e4c64927d135"/></dir></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4181b6514038da8aded97015a970514f"/></dir><dir name="oauth"><dir name="authorize"><dir name="form"><file name="login-simple.phtml" hash="8151e5955a9d7abc37c6dea81169c272"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="5ec6b024c9566631ece9ce301757665b"/><file name="2columns-left.phtml" hash="3b4af8953d95de0d6bb065e98194ad5d"/><file name="2columns-right.phtml" hash="744f7542ceb13f537f2a5f9d21773142"/><file name="3columns.phtml" hash="97ae6d8ff601f9209017045a0042222b"/><file name="empty.phtml" hash="1af42c9aa138f5c963935eebcd1366fb"/><dir name="html"><file name="footer.phtml" hash="ac1eec00d1d9b5c0afe25b3368a6c9a7"/><file name="header.phtml" hash="ed448619d831b6305102888437f61961"/><file name="pager.phtml" hash="f8f400b9c0f28d4c74e2e0dbff1ea317"/><dir name="topmenu"><file name="renderer.phtml" hash="9faff6909c510d25b5f07aad435a715f"/></dir><file name="topmenu.phtml" hash="11a10215d1c7a30add262314285d3f8e"/></dir><file name="popup.phtml" hash="10f4360428b634fdeb2373268f0fa55a"/><file name="print.phtml" hash="a027a5fadfb452e75383342a9ca480d8"/><dir name="template"><file name="links.phtml" hash="54b4b7f1f7d3222a4d5df99282eddcd3"/></dir></dir><dir name="payment"><dir name="form"><file name="cc.phtml" hash="51dec65c95c89e69dd63bc5cc1898bb3"/><file name="ccsave.phtml" hash="3fa1af18be1f7968452b8bbdcb313b93"/></dir><dir name="info"><file name="default.phtml" hash="c0092cc9835da90892f58cb948a39e16"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="ae960a6fca0d31b9a68323c4b8e9da5f"/><dir name="express"><dir name="minicart"><file name="shortcut.phtml" hash="63c44eb36ddd6612a6eec4e6a9db47bc"/></dir><dir name="product"><file name="shortcut.phtml" hash="26b1caeb5c5f8dc2d37c06faa109a5b0"/></dir><dir name="review"><file name="address.phtml" hash="d1072f15dbab96e2c93950af5f1bef3a"/><file name="details.phtml" hash="cbd47ec4da46b1571a8f6f0ccbd19e75"/><dir name="shipping"><file name="method.phtml" hash="bd95f49f1b5367fee037f14f2af3b2e9"/></dir></dir><file name="review.phtml" hash="a3a5e9bcd232fc007a91a9f8e9f5ca5b"/></dir><dir name="partner"><file name="us_logo.phtml" hash="ba4e761f47080206c675082e6f514a2f"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="5695e84eb9dbd0511ea3715359f3cc38"/><file name="login.phtml" hash="23c302cccd47f395654a5746ed0f814d"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="72ea1858f6b6208b23725ebaddce91ff"/><file name="register.phtml" hash="e4b53536f0d2b7a61da4c6ea365f83c4"/></dir></dir><dir name="header"><file name="links.phtml" hash="7aaff67c92dae241de0bacc3417c23ba"/></dir><file name="remember_me.phtml" hash="c8f47428cc00f2806375a1136452ecad"/><file name="remember_me_tooltip.phtml" hash="8d280b3ef7a16f026e0bc7b29caca0f0"/></dir><dir name="rating"><file name="detailed.phtml" hash="3d2c39a5084f2b666bd8d6ea6560979d"/></dir><dir name="reports"><file name="product_viewed.phtml" hash="b4a4a62b93e19a093d0d01c06da0d6f7"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="7936d68ecb10a62a58b5fc5eee05132c"/><file name="compared_images_list.phtml" hash="5245694348fc74ee15a4505d446e11b7"/><file name="compared_names_list.phtml" hash="e6f2df68ea562b19b77de78c71bcafa6"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fcaf2c0999c4cb451a102b9af1f2b53a"/><file name="compared_list.phtml" hash="5ca659200e2a9e9b0de1564953b1a1b6"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="dc2e9b85e5f868d25bf6a32a45e105ce"/><file name="viewed_images_list.phtml" hash="44f93a1f2f8e0ac0ca4b4ea952d40c13"/><file name="viewed_names_list.phtml" hash="7f2cf572ac3b52e1638dd86ad18da88b"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="97b3189ef278cf2c4cd0155a614c9d8f"/><file name="viewed_list.phtml" hash="533d700a14b98d50e0e0ccd2ec9b2d13"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="view.phtml" hash="865b92d13fbffbd9fb3f6310ab58bdf7"/></dir><file name="form.phtml" hash="e8597f08333bc80f80ee7a7ed9626bd7"/><dir name="product"><dir name="view"><file name="list.phtml" hash="83c0ce228661a67de4ec7aaf96444d00"/></dir></dir><file name="view.phtml" hash="4217282c57ac3500a8d72bd028f343c0"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="0cc1dcc5c3bd87e0d7d732462586b008"/></dir><file name="agreements.phtml" hash="8377b6c1e9762b7b5043cd9a9638ea74"/></dir><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="d36c09b0c7dca4a92165796ad3fb2ee3"/></dir></dir><file name="items.phtml" hash="bdef8dbc88a3ee59541f61c01d80cf10"/></dir><file name="history.phtml" hash="031d84ed8ece9bc780aeb6dba97ef037"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="c800c5c9c1ca76d6e36e8703deb2a370"/></dir></dir><file name="items.phtml" hash="391ef549dec7247c0a30a1762133fe0d"/></dir><dir name="items"><dir name="renderer"><file name="default.phtml" hash="607386a20e19e5e4f3d227287eb6981b"/></dir></dir><file name="items.phtml" hash="04bec14b9ddccde555e95e2f8c1e8472"/><file name="recent.phtml" hash="2f33fdf671d8254bf122642365973e0f"/><dir name="shipment"><file name="items.phtml" hash="cb4cacfdd182b2dd4239e9e2caf4185a"/></dir></dir><dir name="recurring"><file name="grid.phtml" hash="48b8868e8e5fc11d72610bf5c3827c76"/><dir name="profile"><file name="view.phtml" hash="0d9092c3dd42a1fa5aa139992b9a58cb"/></dir></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="4d1db3053ea6e8232aaa45f14627fa08"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="ddda414b087a42b80412f1382a3249d9"/></dir><dir name="wishlist"><dir name="button"><file name="update.phtml" hash="717f14026c791d69ff37759b19e49c73"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="aec2495e407f50759911c0014e5e7f41"/><file name="info.phtml" hash="59dcab344169fed593b2bdbb9c0c6b3e"/><file name="price.phtml" hash="7c9c32c6584fb68a9826c249e987b62c"/><file name="quantity.phtml" hash="44aaab6cb59b9348df315d36a6ec9637"/></dir><file name="list.phtml" hash="9bbbb395f3dcb41d53c4ce300118715e"/></dir><file name="shared.phtml" hash="840e2ef47cc948131a71e29230759df7"/><file name="sidebar.phtml" hash="4a8d26e059ffe2f70ccefe3e4c4c0c64"/><file name="view.phtml" hash="576f56d55c297b1f56b61cc471a094f4"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="css"><file name="madisonisland-ie8.css" hash="95cb9c107091e9aa93e37e6ceac3b136"/><file name="madisonisland.css" hash="66e3dcea3cf2b034cb363780b584a071"/><file name="scaffold-forms.css" hash="cb597486f48e3a96acad3778eae91d20"/><file name="styles-ie8.css" hash="219b3af9795b072430d31928b985fa91"/><file name="styles.css" hash="f63fa8788b086198fb89164128630f40"/></dir><dir name="images"><file name="ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="bg_x.png" hash="c321c67f6929326129426c9e83207ea3"/><file name="demo-logo.png" hash="c6f4b110e5379547e71d367479f0f945"/><file name="demo_logo.png" hash="7694461c41abb69ca60c086c69e312cc"/><file name="icon_sprite.png" hash="e15f0103ef5ebe3baf48960bb9ccfaab"/><file name="icon_sprite@2x.png" hash="2e9c31d760a33d9f27951210f8311341"/><file name="logo.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_email.gif" hash="9024e782b5ef7fb76e935a47c39f53c6"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><dir name="media"><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="homepage_banner_1.jpg" hash="267b2827f3db118d99f7a623ee02ad8f"/><file name="homepage_banner_1@2x.jpg" hash="3baa6702111d6f5f5dd40d96f148fc60"/><file name="homepage_banner_2.jpg" hash="67f70cfb1690b5de6e185769fb55cd28"/><file name="homepage_callout_1.jpg" hash="4b8451e4e99e87b6c60a015f659d32b6"/><file name="homepage_callout_1@2x.jpg" hash="fb5e215f6cb623abf6f0365b5de1541d"/><file name="homepage_callout_2.jpg" hash="057ab6200f6ea05d4a6793969c5edac3"/><file name="homepage_callout_2@2x.jpg" hash="e923c6323d22235876fe61a9c5588c85"/><file name="homepage_callout_3.jpg" hash="b2cf1e73e87b3330df17425044d22f52"/><file name="homepage_callout_3@2x.jpg" hash="8b98dee63a61608b09c26bd60acea65e"/></dir><file name="opc-ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="social_icons.png" hash="a6d0bdaea0ca0f507bd36628a6ad31a2"/><file name="social_icons@2x.png" hash="531cc696a7b949dbc8121809c1bb4d46"/></dir><dir name="js"><file name="app.js" hash="de11809cde5667fe0efbb34889297cba"/><dir name="configurableswatches"><file name="configurable-swatch-prices.js" hash="69fb27c7bd77969e55a4842240892a13"/><file name="product-media.js" hash="14bcc410b70b000042434f750b2bf209"/><file name="swatches-list.js" hash="7be11df83b3f7bdd147b8938b299f905"/><file name="swatches-product.js" hash="50c047d9e0bf8d051aa6a041731248ec"/></dir><dir name="lib"><dir name="elevatezoom"><file name="jquery.elevateZoom-3.0.8.min.js" hash="a18ff8649464a0c999f5d063a081da61"/><file name="jquery.elevatezoom.js" hash="76494c5afa372e08d0a8a5f4ba7e58ed"/></dir><file name="enquire.js" hash="c11ca42a1f2bf189d004f9a4f42e3ca2"/><file name="fastclick.js" hash="7f1e1673fa395e43cbdc584c8798541b"/><file name="imagesloaded.js" hash="f70def9bddf45be549ec0575645b8038"/><file name="jquery.cycle2.min.js" hash="24f809434b3e494cc7b98c6c08404b33"/><file name="jquery.cycle2.swipe.min.js" hash="15747fbd45dd1adcaf8f04a2d8a71d68"/><file name="matchMedia.addListener.js" hash="6f47448212550bd3157c4265e3ebf085"/><file name="matchMedia.js" hash="89f369588d629240d6a8d4f8788490c8"/><file name="modernizr.custom.min.js" hash="e508acbc792b5761fe98dc892a1fd952"/><file name="selectivizr.js" hash="8e596ea5ffac3cf3eb53f75a15cdc7eb"/></dir><file name="minicart.js" hash="773d889227f7cb229ca4763df44e91cf"/><file name="msrp_rwd.js" hash="9360b9b788ddd45d46c5348e16624b94"/><file name="opcheckout_rwd.js" hash="166e1b25d0692833e241947f4d9f9c7e"/><file name="slideshow.js" hash="d95865e4fb72c8fc5aa2a09e6dbcd458"/></dir><dir name="scss"><file name="_core.scss" hash="8191f7bb4f132a9c0d1b823c7c285912"/><file name="_framework.scss" hash="9472094353a56c22a11b7704b0a38f6c"/><file name="_var.scss" hash="a0f35fb7e96b3cf79997afa3cae0f70b"/><file name="config.rb" hash="5f50b4dc5eefbab9e22abdfb80f4d689"/><dir name="content"><file name="_category.scss" hash="6dfe07f59c4c5f9005b716a57474bc88"/><file name="_home.scss" hash="4f72bbb962144c4c819418a469a4d273"/></dir><dir name="core"><file name="_common.scss" hash="101c56abd1bc1b1042ae8f8b1e4bdd5f"/><file name="_form.scss" hash="6d385bf6b997c595dd25a6d6340defcb"/><file name="_reset.scss" hash="e0457b30f892cfab4e9681713096a441"/><file name="_table.scss" hash="fc2d07038f3c159fd62ceca84f01f2f2"/></dir><file name="email-inline.scss" hash="6ce915b8334bc7aaa934cc4d1819685a"/><file name="email-non-inline.scss" hash="500aeb9f5a3662f1630f3d7d2002c092"/><dir name="function"><file name="_black.scss" hash="fefb3ce075b124fb155c7220f7b39d33"/><file name="_white.scss" hash="044a214db61206ec54be9305146c235c"/></dir><dir name="layout"><file name="_footer.scss" hash="4ddf8c6325300bbf8844d51ae4a5c4a3"/><file name="_global.scss" hash="4a023b134df7966469600212523a65fb"/><file name="_header-account.scss" hash="bf00cd96647d85aba09f00d283fdbdad"/><file name="_header-cart.scss" hash="3aadde0e39464bfdaf50155aabc48528"/><file name="_header-nav.scss" hash="2aaab0e5db6f416b57c3293adcb8cb91"/><file name="_header-search.scss" hash="079ecdcc3ebb7cc414946c0e78c19371"/><file name="_header.scss" hash="b7859a0931057ad1536db69b12241982"/></dir><file name="madisonisland-ie8.scss" hash="8b0cb6e8691a39a24fb33b7a3c82baf8"/><file name="madisonisland.scss" hash="b2a45438233a36258e66e6a5c8af6208"/><dir name="mixin"><file name="_breakpoint.scss" hash="cb02339d9740c3c6a8cde39183ed0166"/><file name="_clearfix.scss" hash="55e23e69145f99d1e38392b1a9420698"/><file name="_if-resolution.scss" hash="9d49ea0dac1bc376c581ba724fa0218b"/><file name="_image-replacement.scss" hash="f99ce5066b956b247bf8fdb7628c4c72"/><file name="_loading-overlay.scss" hash="a3a33484d034229193568e03384f12e7"/><file name="_menu.scss" hash="2330eab00fde007f3c826bf86b0e04b4"/><file name="_not-selectable.scss" hash="7e27705f1e57d8077e7edb5a39fdee6e"/><file name="_toggle-content.scss" hash="91e198e313fda382c9c2e9fb12bb342e"/><file name="_triangle.scss" hash="6df09b47978dcb46faabe8a789bcf412"/><file name="_typography.scss" hash="0634899cf1572349341ad02e68f3e5af"/></dir><dir name="module"><file name="_account-orders.scss" hash="1566481ee469c96ba9947e366912cbb3"/><file name="_account-reviews.scss" hash="a207a4b2e3f953f316dba7e97a4a87c9"/><file name="_billing-agreements.scss" hash="f9984020bb88042d857d6b4a165b7e8e"/><file name="_captcha.scss" hash="6a478cb360bb39aa978ce8b0dbfd8a2c"/><file name="_catalog-compare.scss" hash="1a72cc87d13992643ab826bf9e028929"/><file name="_catalog-msrp.scss" hash="d2c03f98dc9b2a31dbbedc3a56968619"/><file name="_catalog-product.scss" hash="217ee56f122c4ac9cf37320cbc0b31a1"/><file name="_checkout-cart-minicart.scss" hash="159fef349f60e392aecb7ab5f112a508"/><file name="_checkout-cart.scss" hash="d8d24dfb4dc5538b764b2a0b6e25a9e2"/><file name="_checkout-multi-address.scss" hash="b3d7777c347a55f00568c1b8d8d3470a"/><file name="_checkout-onepage.scss" hash="d532ce0af5ec92002ea3bca4df010911"/><file name="_checkout-success.scss" hash="8a27a309ed45f117b9a3f28121455dc7"/><file name="_cms.scss" hash="2d008923d1c787e8c9201428411ede0b"/><file name="_configurableswatches.scss" hash="42ff6cf4d1fe159a17c5ba6cdc82e3f6"/><file name="_contacts.scss" hash="67e9b5079eb38a1313df5abaf8dcbe8a"/><file name="_cookies.scss" hash="b6ef04bd507c26c5b8c277c398788579"/><file name="_customer.scss" hash="1c7dfda996e88a5f6517225738da3283"/><file name="_paypal.scss" hash="3c9550307fdfa293977b21f437d4c0a7"/><file name="_popular-terms.scss" hash="b3ec891b1706fb9bc914f1f0f9b36b19"/><file name="_pricing_conditions.scss" hash="36887033cc7ebadce1872a9d2c9e3ed2"/><file name="_product-list.scss" hash="8ba0f2f9b9c9e41509af955e5858cf41"/><file name="_recurring-profiles.scss" hash="1c06e6561e57aacd8c6f5c4342290964"/><file name="_review.scss" hash="28275bb7f69b44011618f0e534c6b60f"/><file name="_search.scss" hash="bf3eb603fbd3b8bff5b5ceb135ea4642"/><file name="_slideshow.scss" hash="7ec125b75db0a049d507e833bea8edb7"/><file name="_tags.scss" hash="712ac8bd4f7a99d144fb2af7e17bd5d8"/><file name="_widget.scss" hash="e41baab99ea2020e6ff006778f3de9b4"/><file name="_wishlist.scss" hash="72efb048a2242ca332f973404dc51a76"/></dir><dir name="override"><file name="_plugin.scss" hash="ec60b0b35e840eb6347f21a95f16b719"/></dir><file name="scaffold-forms.scss" hash="983e1df0846a9a75048825abb8405304"/><file name="styles-ie8.scss" hash="4d20f2d2b4317945b5350c91c91efddc"/><file name="styles.scss" hash="3ad39f7c860c02e9b0d7cc95cd0e8863"/><dir name="vendor"><file name="_normalize.scss" hash="d9edffd350bd218571fd141a9c658d29"/></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Frontend_Rwd_Default-1.9.4.2.xml b/var/package/Interface_Frontend_Rwd_Default-1.9.4.2.xml
new file mode 100644
index 0000000..41e84cd
--- /dev/null
+++ b/var/package/Interface_Frontend_Rwd_Default-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Frontend_Rwd_Default</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This is a RWD themes base</summary>
+    <description>This is a RWD themes base</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:00</time>
+    <contents><target name="magedesign"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="etc"><file name="theme.xml" hash="9d42933c3a4f2b1c291d5b5bbf11d6dd"/><file name="widget.xml" hash="00f1e461d9062e53090b4a894354b80a"/></dir><dir name="layout"><file name="bundle.xml" hash="aa8e8659b158139fbcb9eb1d548a519e"/><file name="catalog.xml" hash="ffb44336e278a04a6c175f07bc562fe7"/><file name="catalog_msrp.xml" hash="0d5a348db930eed42bc35d4ccf9908c1"/><file name="catalogsearch.xml" hash="4dde9f7a881e3cea3ec129bef1b13ee5"/><file name="checkout.xml" hash="20916639cb2d9994c091895da15a0b0f"/><file name="cms.xml" hash="2a6ec2cd93843f7f75061973934af241"/><file name="configurableswatches.xml" hash="9f029376440a19b8099a5b6e6665e984"/><file name="contacts.xml" hash="dfd97d1b8395cc271125a357e6811727"/><file name="customer.xml" hash="beaeb5e3415f50a80d9f91c758accefa"/><file name="directory.xml" hash="7b3ced90cf254b76500d5f8a363b28fc"/><file name="downloadable.xml" hash="6fb6aec95bd307fc8d848cdef16a87ea"/><file name="newsletter.xml" hash="99458a6f3e73b33348de623f83f44581"/><file name="oauth.xml" hash="705c8cc50c26f7e4285bb7416ab1f051"/><file name="page.xml" hash="187dd31efe8ba00dbae87c0522bc9676"/><file name="paypal.xml" hash="0ff834afd3728b32196e721ade5256aa"/><file name="persistent.xml" hash="5f744e61a14e2a072beff3857567d45f"/><file name="review.xml" hash="578157e3a9ef9539b06349fde10ddcbc"/><file name="rss.xml" hash="362997d9980766b785e50417795fcfde"/><file name="sales.xml" hash="8c19fa843eca0ddc45fc20e4678adec3"/><file name="wishlist.xml" hash="44d782a89f00808a097b43531e546c75"/></dir><dir name="template"><dir name="authorizenet"><dir name="directpost"><file name="form.phtml" hash="385a4bdbbb17021d7c8c725c5ca16dbb"/></dir></dir><dir name="bundle"><dir name="catalog"><dir name="product"><dir name="view"><dir name="type"><dir name="bundle"><file name="availability.phtml" hash="cd7b4f76fe9ccb4862fcfe9fdf735bce"/><dir name="option"><file name="select.phtml" hash="fd5bdffd5c80730d26c432773fd929c9"/></dir></dir><file name="bundle.phtml" hash="390f520b82259a27539742c060d70cb8"/></dir></dir></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b9f0008d961f945d3102de4ebff06746"/></dir><dir name="invoice"><file name="default.phtml" hash="50c01c93a68ac239d23ac746ef8eecc6"/></dir><dir name="order"><file name="default.phtml" hash="6bae6cb6699a7e67fbcc0be01a9e3958"/></dir><dir name="shipment"><file name="default.phtml" hash="12efaca5f48e8e6216af313a93a0c836"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><file name="renderer.phtml" hash="01de9221542d4576b428002af5450038"/></dir></dir></dir></dir><dir name="captcha"><file name="zend.phtml" hash="5b2f1638d0d2a79ea51b34328bb376e5"/></dir><dir name="catalog"><dir name="layer"><file name="filter.phtml" hash="a9800445835d95e47b4667562c5504c9"/><file name="state.phtml" hash="68b812651343d8efe2f52396ae4b8bff"/><file name="view.phtml" hash="43ef898fd0184a34e8153eb45337bcf5"/></dir><dir name="msrp"><file name="popup.phtml" hash="dbeb5ac9707c288e9657d3082547890b"/></dir><dir name="navigation"><file name="left.phtml" hash="6575fb3943bd8962da3faa5f16d3eb55"/></dir><dir name="product"><dir name="compare"><file name="list.phtml" hash="51d60c165c9f6f9eec45e2c929a46665"/><file name="sidebar.phtml" hash="0be3217397d6d11966530589a98a5021"/></dir><dir name="list"><file name="related.phtml" hash="689fd2ed824260f8ce0e26c9923323dd"/><file name="toolbar.phtml" hash="ab66060531cfb82eb8e362c90cc83791"/><file name="upsell.phtml" hash="4b200ec4f7ff016917709dfddb751e31"/></dir><file name="list.phtml" hash="1a1d32406dd64a50691dc1e38b8e6398"/><file name="price.phtml" hash="c5e841d59f7f6bbf84f9c879f1ebed27"/><dir name="view"><file name="addto.phtml" hash="8117d1b5d647bf4b3fc8dd84f3dbc6ca"/><file name="addtocart.phtml" hash="63d5573173bbc198b29057b86a60fe54"/><file name="media.phtml" hash="5fb346c580f635b927a5412ae2556b6b"/><file name="sharing.phtml" hash="b9a62aeaeb1f1345c894d035bc5c98d8"/><dir name="type"><dir name="availability"><file name="default.phtml" hash="7fed915ce32b155a045301ee867c283e"/><file name="grouped.phtml" hash="9c467e68c5d5787181b9b54f71715b2b"/></dir><file name="default.phtml" hash="60d57df7bd2c9e0175a067c21c40c1ec"/><file name="grouped.phtml" hash="6740aff8dc4282a212c98d18da65a29c"/><dir name="options"><file name="configurable.phtml" hash="82d4bd6957faafaed86d3c2ea0610a04"/></dir></dir></dir><file name="view.phtml" hash="febb0fe90db741820576d0be0c4b701f"/><dir name="widget"><dir name="new"><dir name="column"><file name="new_default_list.phtml" hash="0048f859bd6db690859e81c704553455"/><file name="new_images_list.phtml" hash="6a3c1362ad5f86062f30aca148442a01"/><file name="new_names_list.phtml" hash="c1555ea48bcdf69eacf6d3d41ed52530"/></dir><dir name="content"><file name="new_grid.phtml" hash="e9fd476dbb4621d76c1918ad12caff6f"/><file name="new_list.phtml" hash="f4bb956b74a3ae4b8de53f4ddec18eb0"/></dir></dir></dir></dir></dir><dir name="cataloginventory"><dir name="stockqty"><file name="composite.phtml" hash="77b673795f6d199055461d07deeb6c73"/></dir></dir><dir name="catalogsearch"><dir name="advanced"><file name="form.phtml" hash="5f3f10ad173037b8aaaa8104d9c48a1b"/></dir><file name="form.mini.phtml" hash="5d203d602572292ab563b724026b2d3e"/><file name="result.phtml" hash="7c6e68ae4bf4edf13b90d7bba68b1208"/></dir><dir name="centinel"><dir name="authentication"><file name="start.phtml" hash="d80d808774fac08fef28c647bb76414e"/></dir></dir><dir name="checkout"><dir name="cart"><file name="coupon.phtml" hash="f2591f5cadb027ea4e5085946c8f9f80"/><file name="crosssell.phtml" hash="68afc918f0414b31b5f88df4cc6e3e92"/><dir name="item"><dir name="configure"><file name="updatecart.phtml" hash="a7f1e2c2d26c9b1ddb2e0269235ce499"/></dir><file name="default.phtml" hash="6ff4fd36c9a72e589ea0c92e9556301d"/></dir><dir name="minicart"><file name="default.phtml" hash="fee4b446fa9077b4dc17af56899d6383"/><file name="items.phtml" hash="e639d64e913ad9b8d3b1a56165574d3f"/></dir><file name="minicart.phtml" hash="b55c9a51a9eb6057a41d4e4c2b48e910"/><dir name="render"><file name="default.phtml" hash="9850aac16db5fc6263c25b07443bdafa"/><file name="simple.phtml" hash="bc76fc52fec4bc1b24c311cad53dc2b2"/></dir><file name="shipping.phtml" hash="2f462cead90bb493a2ce874e4d5a8747"/><dir name="sidebar"><file name="default.phtml" hash="3adc91979d26188830db7bc0b3731742"/></dir><file name="sidebar.phtml" hash="9ffb85ddaa41e91c9233ec5c82c7ae82"/></dir><file name="cart.phtml" hash="9a943d16f3d981366e5d613e88af7d34"/><dir name="multishipping"><file name="addresses.phtml" hash="bda46e6cb1800933a114258b47a5a0da"/><file name="billing.phtml" hash="884d9b8dd0879897e6d43c50440039c3"/><dir name="item"><file name="default.phtml" hash="d7beeb4d8edc0fec58e226f5ce525c6d"/></dir><dir name="overview"><file name="item.phtml" hash="0597f23f2cf6e05371e40ee5c7e2315d"/></dir><file name="overview.phtml" hash="e2c461b9e67959e849135b5d079c0537"/></dir><dir name="onepage"><file name="payment.phtml" hash="61cf9454d8f6169c9f3d4bdc6b10a8c2"/><file name="progress.phtml" hash="955bc23d4addd0efe3e7feac8d8feb5d"/><dir name="review"><file name="info.phtml" hash="34c7f8cf5827594b16c11e6ee3411513"/><file name="item.phtml" hash="c8e48375afa925eb2321e3aff1b0bf4c"/></dir><file name="shipping.phtml" hash="0ce8393c48e2bd2503b004e0a29e04fe"/></dir><file name="onepage.phtml" hash="af546fa00f2884b9fc6335bf1c0cba60"/></dir><dir name="configurableswatches"><dir name="catalog"><dir name="layer"><dir name="filter"><file name="swatches.phtml" hash="f9eee1bdd31e706a560d074efcd5313c"/></dir><dir name="state"><file name="swatch.phtml" hash="9d3f9998bc24cbe06b99046c8cc2a5f3"/></dir></dir><dir name="media"><file name="js.phtml" hash="57e9acda00f28629670ba5e84ea9cabb"/></dir><dir name="product"><dir name="list"><dir name="price"><file name="js.phtml" hash="b57be935901c4285b6f57f2077adf2eb"/></dir><file name="swatches.phtml" hash="d71db2c1ecc49b7bd1f5c3cb91692bac"/></dir><dir name="view"><dir name="type"><dir name="configurable"><file name="swatch-js.phtml" hash="7502a7498d8fc0d11e3aaae2f64f4c60"/></dir><dir name="options"><dir name="configurable"><file name="swatches.phtml" hash="75198b3138a8c825572830d13f42c443"/></dir></dir></dir></dir></dir></dir></dir><dir name="contacts"><file name="form.phtml" hash="7368ea4443c1bc85a880ba2fe84d9a0c"/></dir><dir name="customer"><dir name="account"><dir name="dashboard"><file name="address.phtml" hash="3a5ee9d2564cff6c85b9a8d81650ed12"/></dir><file name="dashboard.phtml" hash="f9bf153b12b881cd3aff3f874776e006"/><file name="navigation.phtml" hash="f573f85c06b8da6cd04fe30043a26986"/></dir><dir name="address"><file name="edit.phtml" hash="9ec6de2e18779d3f83469b2c08a9ba22"/></dir><dir name="form"><file name="address.phtml" hash="29ca055fce63adb7e7b781d9c5b44d37"/><file name="changepassword.phtml" hash="85e3a3f61d387ad99a724c49b50cb77b"/><file name="confirmation.phtml" hash="f7e3c2f26a601d85744676cd36310640"/><file name="edit.phtml" hash="aa5035754de40c1da9e6481a04fa686e"/><file name="forgotpassword.phtml" hash="19b6dcb57c9401398335ded1c669f7f0"/><file name="mini.login.phtml" hash="bfd6855770d271913c4c5b4b30cdbd56"/><file name="resetforgottenpassword.phtml" hash="0180eb6f13153ea9b9a4399a1687c68a"/></dir></dir><dir name="directory"><file name="currency.phtml" hash="a827c080db81adc467b091cbfd7001ba"/></dir><dir name="downloadable"><dir name="catalog"><dir name="product"><file name="type.phtml" hash="ac98a769be2e41a26702f9245d9d3c06"/></dir></dir><dir name="checkout"><dir name="cart"><dir name="item"><file name="default.phtml" hash="99baf0b573a57793538763745961d3e2"/></dir></dir><dir name="onepage"><dir name="review"><file name="item.phtml" hash="39b625a969337c7b42092ca989d3a6ce"/></dir></dir></dir><dir name="customer"><dir name="products"><file name="list.phtml" hash="9f13aedbb1a5a22ecc9ed803915eeafc"/></dir></dir><dir name="email"><dir name="order"><dir name="items"><dir name="creditmemo"><file name="downloadable.phtml" hash="cd99c9d650bf7b3aa755b337cbd104db"/></dir><dir name="invoice"><file name="downloadable.phtml" hash="1d056b77b1aa8edabe1d5cc39810910f"/></dir><dir name="order"><file name="downloadable.phtml" hash="70fb86f91a456322d7e39626ab2ab475"/></dir></dir></dir></dir><dir name="sales"><dir name="order"><dir name="items"><dir name="renderer"><file name="downloadable.phtml" hash="b996432e3f9ee66b75ba7f881a3ee7ac"/></dir></dir></dir></dir></dir><dir name="email"><dir name="catalog"><dir name="product"><file name="list.phtml" hash="e9151bd0765f84a45ddc640d1f0c5184"/><file name="new.phtml" hash="257a76796d136ec5d6a60407ad36978e"/></dir></dir><dir name="order"><dir name="creditmemo"><file name="items.phtml" hash="d28d47025ff2c145a6b974f002d9a231"/></dir><dir name="invoice"><file name="items.phtml" hash="f190f4c7af76fae8a78a329bf81de99e"/></dir><dir name="items"><dir name="creditmemo"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="invoice"><file name="default.phtml" hash="b28b7a86e492f691763c7e5d842e78f3"/></dir><dir name="order"><file name="default.phtml" hash="82d4fe9be011e52561450f65405dbf05"/></dir><dir name="shipment"><file name="default.phtml" hash="2719db4c14bbc1b2d608ee305a5ea133"/></dir></dir><file name="items.phtml" hash="2c838581f36f73ae6b637c081345bf34"/><dir name="shipment"><file name="items.phtml" hash="aad8aa56e8cbcd61f55c7d20d96e1c38"/><file name="track.phtml" hash="f4f2933f0b10a997e0448c00c30a3a6e"/></dir><dir name="totals"><file name="wrapper.phtml" hash="8c6c83bbe4597b477690a26eb302b1dc"/></dir></dir><dir name="productalert"><file name="price.phtml" hash="01a800642590e4309af5a625b92c8798"/><file name="stock.phtml" hash="a9dfc2adb4cebcba4e49e4c64927d135"/></dir></dir><dir name="newsletter"><file name="subscribe.phtml" hash="4181b6514038da8aded97015a970514f"/></dir><dir name="oauth"><dir name="authorize"><dir name="form"><file name="login-simple.phtml" hash="8151e5955a9d7abc37c6dea81169c272"/></dir></dir></dir><dir name="page"><file name="1column.phtml" hash="5ec6b024c9566631ece9ce301757665b"/><file name="2columns-left.phtml" hash="3b4af8953d95de0d6bb065e98194ad5d"/><file name="2columns-right.phtml" hash="744f7542ceb13f537f2a5f9d21773142"/><file name="3columns.phtml" hash="97ae6d8ff601f9209017045a0042222b"/><file name="empty.phtml" hash="1af42c9aa138f5c963935eebcd1366fb"/><dir name="html"><file name="footer.phtml" hash="ac1eec00d1d9b5c0afe25b3368a6c9a7"/><file name="header.phtml" hash="ed448619d831b6305102888437f61961"/><file name="pager.phtml" hash="f8f400b9c0f28d4c74e2e0dbff1ea317"/><dir name="topmenu"><file name="renderer.phtml" hash="9faff6909c510d25b5f07aad435a715f"/></dir><file name="topmenu.phtml" hash="11a10215d1c7a30add262314285d3f8e"/></dir><file name="popup.phtml" hash="10f4360428b634fdeb2373268f0fa55a"/><file name="print.phtml" hash="a027a5fadfb452e75383342a9ca480d8"/><dir name="template"><file name="links.phtml" hash="54b4b7f1f7d3222a4d5df99282eddcd3"/></dir></dir><dir name="payment"><dir name="form"><file name="cc.phtml" hash="51dec65c95c89e69dd63bc5cc1898bb3"/><file name="ccsave.phtml" hash="3fa1af18be1f7968452b8bbdcb313b93"/></dir><dir name="info"><file name="default.phtml" hash="c0092cc9835da90892f58cb948a39e16"/></dir></dir><dir name="paypal"><file name="bml.phtml" hash="ae960a6fca0d31b9a68323c4b8e9da5f"/><dir name="express"><dir name="minicart"><file name="shortcut.phtml" hash="63c44eb36ddd6612a6eec4e6a9db47bc"/></dir><dir name="product"><file name="shortcut.phtml" hash="26b1caeb5c5f8dc2d37c06faa109a5b0"/></dir><dir name="review"><file name="address.phtml" hash="d1072f15dbab96e2c93950af5f1bef3a"/><file name="details.phtml" hash="cbd47ec4da46b1571a8f6f0ccbd19e75"/><dir name="shipping"><file name="method.phtml" hash="bd95f49f1b5367fee037f14f2af3b2e9"/></dir></dir><file name="review.phtml" hash="a3a5e9bcd232fc007a91a9f8e9f5ca5b"/></dir><dir name="partner"><file name="us_logo.phtml" hash="ba4e761f47080206c675082e6f514a2f"/></dir></dir><dir name="persistent"><dir name="checkout"><dir name="onepage"><file name="billing.phtml" hash="5695e84eb9dbd0511ea3715359f3cc38"/><file name="login.phtml" hash="23c302cccd47f395654a5746ed0f814d"/></dir></dir><dir name="customer"><dir name="form"><file name="login.phtml" hash="72ea1858f6b6208b23725ebaddce91ff"/><file name="register.phtml" hash="e4b53536f0d2b7a61da4c6ea365f83c4"/></dir></dir><dir name="header"><file name="links.phtml" hash="7aaff67c92dae241de0bacc3417c23ba"/></dir><file name="remember_me.phtml" hash="c8f47428cc00f2806375a1136452ecad"/><file name="remember_me_tooltip.phtml" hash="8d280b3ef7a16f026e0bc7b29caca0f0"/></dir><dir name="rating"><file name="detailed.phtml" hash="3d2c39a5084f2b666bd8d6ea6560979d"/></dir><dir name="reports"><file name="product_viewed.phtml" hash="b4a4a62b93e19a093d0d01c06da0d6f7"/><dir name="widget"><dir name="compared"><dir name="column"><file name="compared_default_list.phtml" hash="7936d68ecb10a62a58b5fc5eee05132c"/><file name="compared_images_list.phtml" hash="5245694348fc74ee15a4505d446e11b7"/><file name="compared_names_list.phtml" hash="e6f2df68ea562b19b77de78c71bcafa6"/></dir><dir name="content"><file name="compared_grid.phtml" hash="fcaf2c0999c4cb451a102b9af1f2b53a"/><file name="compared_list.phtml" hash="5ca659200e2a9e9b0de1564953b1a1b6"/></dir></dir><dir name="viewed"><dir name="column"><file name="viewed_default_list.phtml" hash="dc2e9b85e5f868d25bf6a32a45e105ce"/><file name="viewed_images_list.phtml" hash="44f93a1f2f8e0ac0ca4b4ea952d40c13"/><file name="viewed_names_list.phtml" hash="7f2cf572ac3b52e1638dd86ad18da88b"/></dir><dir name="content"><file name="viewed_grid.phtml" hash="97b3189ef278cf2c4cd0155a614c9d8f"/><file name="viewed_list.phtml" hash="533d700a14b98d50e0e0ccd2ec9b2d13"/></dir></dir></dir></dir><dir name="review"><dir name="customer"><file name="view.phtml" hash="865b92d13fbffbd9fb3f6310ab58bdf7"/></dir><file name="form.phtml" hash="e8597f08333bc80f80ee7a7ed9626bd7"/><dir name="product"><dir name="view"><file name="list.phtml" hash="83c0ce228661a67de4ec7aaf96444d00"/></dir></dir><file name="view.phtml" hash="4217282c57ac3500a8d72bd028f343c0"/></dir><dir name="sales"><dir name="billing"><dir name="agreement"><file name="view.phtml" hash="0cc1dcc5c3bd87e0d7d732462586b008"/></dir><file name="agreements.phtml" hash="8377b6c1e9762b7b5043cd9a9638ea74"/></dir><dir name="order"><dir name="creditmemo"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="d36c09b0c7dca4a92165796ad3fb2ee3"/></dir></dir><file name="items.phtml" hash="bdef8dbc88a3ee59541f61c01d80cf10"/></dir><file name="history.phtml" hash="031d84ed8ece9bc780aeb6dba97ef037"/><dir name="invoice"><dir name="items"><dir name="renderer"><file name="default.phtml" hash="c800c5c9c1ca76d6e36e8703deb2a370"/></dir></dir><file name="items.phtml" hash="391ef549dec7247c0a30a1762133fe0d"/></dir><dir name="items"><dir name="renderer"><file name="default.phtml" hash="607386a20e19e5e4f3d227287eb6981b"/></dir></dir><file name="items.phtml" hash="04bec14b9ddccde555e95e2f8c1e8472"/><file name="recent.phtml" hash="2f33fdf671d8254bf122642365973e0f"/><dir name="shipment"><file name="items.phtml" hash="cb4cacfdd182b2dd4239e9e2caf4185a"/></dir></dir><dir name="recurring"><file name="grid.phtml" hash="48b8868e8e5fc11d72610bf5c3827c76"/><dir name="profile"><file name="view.phtml" hash="0d9092c3dd42a1fa5aa139992b9a58cb"/></dir></dir><dir name="widget"><dir name="guest"><file name="form.phtml" hash="4d1db3053ea6e8232aaa45f14627fa08"/></dir></dir></dir><dir name="sendfriend"><file name="send.phtml" hash="ddda414b087a42b80412f1382a3249d9"/></dir><dir name="wishlist"><dir name="button"><file name="update.phtml" hash="717f14026c791d69ff37759b19e49c73"/></dir><dir name="item"><dir name="column"><file name="cart.phtml" hash="aec2495e407f50759911c0014e5e7f41"/><file name="info.phtml" hash="59dcab344169fed593b2bdbb9c0c6b3e"/><file name="price.phtml" hash="7c9c32c6584fb68a9826c249e987b62c"/><file name="quantity.phtml" hash="44aaab6cb59b9348df315d36a6ec9637"/></dir><file name="list.phtml" hash="9bbbb395f3dcb41d53c4ce300118715e"/></dir><file name="shared.phtml" hash="840e2ef47cc948131a71e29230759df7"/><file name="sidebar.phtml" hash="4a8d26e059ffe2f70ccefe3e4c4c0c64"/><file name="view.phtml" hash="576f56d55c297b1f56b61cc471a094f4"/></dir></dir></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="rwd"><dir name="default"><dir name="css"><file name="madisonisland-ie8.css" hash="95cb9c107091e9aa93e37e6ceac3b136"/><file name="madisonisland.css" hash="66e3dcea3cf2b034cb363780b584a071"/><file name="scaffold-forms.css" hash="cb597486f48e3a96acad3778eae91d20"/><file name="styles-ie8.css" hash="219b3af9795b072430d31928b985fa91"/><file name="styles.css" hash="f63fa8788b086198fb89164128630f40"/></dir><dir name="images"><file name="ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="bg_x.png" hash="c321c67f6929326129426c9e83207ea3"/><file name="demo-logo.png" hash="c6f4b110e5379547e71d367479f0f945"/><file name="demo_logo.png" hash="7694461c41abb69ca60c086c69e312cc"/><file name="icon_sprite.png" hash="e15f0103ef5ebe3baf48960bb9ccfaab"/><file name="icon_sprite@2x.png" hash="2e9c31d760a33d9f27951210f8311341"/><file name="logo.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><file name="logo_email.gif" hash="9024e782b5ef7fb76e935a47c39f53c6"/><file name="logo_print.gif" hash="b5c6c6f40ba031f613d0f2aaa7f3c087"/><dir name="media"><file name="col_left_callout.jpg" hash="5f762006021e046f9bd536f37ea7c463"/><file name="col_right_callout.jpg" hash="dae22f37a542da272a35195ec286ec25"/><file name="homepage_banner_1.jpg" hash="267b2827f3db118d99f7a623ee02ad8f"/><file name="homepage_banner_1@2x.jpg" hash="3baa6702111d6f5f5dd40d96f148fc60"/><file name="homepage_banner_2.jpg" hash="67f70cfb1690b5de6e185769fb55cd28"/><file name="homepage_callout_1.jpg" hash="4b8451e4e99e87b6c60a015f659d32b6"/><file name="homepage_callout_1@2x.jpg" hash="fb5e215f6cb623abf6f0365b5de1541d"/><file name="homepage_callout_2.jpg" hash="057ab6200f6ea05d4a6793969c5edac3"/><file name="homepage_callout_2@2x.jpg" hash="e923c6323d22235876fe61a9c5588c85"/><file name="homepage_callout_3.jpg" hash="b2cf1e73e87b3330df17425044d22f52"/><file name="homepage_callout_3@2x.jpg" hash="8b98dee63a61608b09c26bd60acea65e"/></dir><file name="opc-ajax-loader.gif" hash="f48ee069890b16455c3ddcacee9b5f75"/><file name="social_icons.png" hash="a6d0bdaea0ca0f507bd36628a6ad31a2"/><file name="social_icons@2x.png" hash="531cc696a7b949dbc8121809c1bb4d46"/></dir><dir name="js"><file name="app.js" hash="de11809cde5667fe0efbb34889297cba"/><dir name="configurableswatches"><file name="configurable-swatch-prices.js" hash="69fb27c7bd77969e55a4842240892a13"/><file name="product-media.js" hash="14bcc410b70b000042434f750b2bf209"/><file name="swatches-list.js" hash="7be11df83b3f7bdd147b8938b299f905"/><file name="swatches-product.js" hash="50c047d9e0bf8d051aa6a041731248ec"/></dir><dir name="lib"><dir name="elevatezoom"><file name="jquery.elevateZoom-3.0.8.min.js" hash="a18ff8649464a0c999f5d063a081da61"/><file name="jquery.elevatezoom.js" hash="76494c5afa372e08d0a8a5f4ba7e58ed"/></dir><file name="enquire.js" hash="c11ca42a1f2bf189d004f9a4f42e3ca2"/><file name="fastclick.js" hash="7f1e1673fa395e43cbdc584c8798541b"/><file name="imagesloaded.js" hash="f70def9bddf45be549ec0575645b8038"/><file name="jquery.cycle2.min.js" hash="24f809434b3e494cc7b98c6c08404b33"/><file name="jquery.cycle2.swipe.min.js" hash="15747fbd45dd1adcaf8f04a2d8a71d68"/><file name="matchMedia.addListener.js" hash="6f47448212550bd3157c4265e3ebf085"/><file name="matchMedia.js" hash="89f369588d629240d6a8d4f8788490c8"/><file name="modernizr.custom.min.js" hash="e508acbc792b5761fe98dc892a1fd952"/><file name="selectivizr.js" hash="8e596ea5ffac3cf3eb53f75a15cdc7eb"/></dir><file name="minicart.js" hash="773d889227f7cb229ca4763df44e91cf"/><file name="msrp_rwd.js" hash="9360b9b788ddd45d46c5348e16624b94"/><file name="opcheckout_rwd.js" hash="166e1b25d0692833e241947f4d9f9c7e"/><file name="slideshow.js" hash="d95865e4fb72c8fc5aa2a09e6dbcd458"/></dir><dir name="scss"><file name="_core.scss" hash="8191f7bb4f132a9c0d1b823c7c285912"/><file name="_framework.scss" hash="9472094353a56c22a11b7704b0a38f6c"/><file name="_var.scss" hash="a0f35fb7e96b3cf79997afa3cae0f70b"/><file name="config.rb" hash="5f50b4dc5eefbab9e22abdfb80f4d689"/><dir name="content"><file name="_category.scss" hash="6dfe07f59c4c5f9005b716a57474bc88"/><file name="_home.scss" hash="4f72bbb962144c4c819418a469a4d273"/></dir><dir name="core"><file name="_common.scss" hash="101c56abd1bc1b1042ae8f8b1e4bdd5f"/><file name="_form.scss" hash="6d385bf6b997c595dd25a6d6340defcb"/><file name="_reset.scss" hash="e0457b30f892cfab4e9681713096a441"/><file name="_table.scss" hash="fc2d07038f3c159fd62ceca84f01f2f2"/></dir><file name="email-inline.scss" hash="6ce915b8334bc7aaa934cc4d1819685a"/><file name="email-non-inline.scss" hash="500aeb9f5a3662f1630f3d7d2002c092"/><dir name="function"><file name="_black.scss" hash="fefb3ce075b124fb155c7220f7b39d33"/><file name="_white.scss" hash="044a214db61206ec54be9305146c235c"/></dir><dir name="layout"><file name="_footer.scss" hash="4ddf8c6325300bbf8844d51ae4a5c4a3"/><file name="_global.scss" hash="4a023b134df7966469600212523a65fb"/><file name="_header-account.scss" hash="bf00cd96647d85aba09f00d283fdbdad"/><file name="_header-cart.scss" hash="3aadde0e39464bfdaf50155aabc48528"/><file name="_header-nav.scss" hash="2aaab0e5db6f416b57c3293adcb8cb91"/><file name="_header-search.scss" hash="079ecdcc3ebb7cc414946c0e78c19371"/><file name="_header.scss" hash="b7859a0931057ad1536db69b12241982"/></dir><file name="madisonisland-ie8.scss" hash="8b0cb6e8691a39a24fb33b7a3c82baf8"/><file name="madisonisland.scss" hash="b2a45438233a36258e66e6a5c8af6208"/><dir name="mixin"><file name="_breakpoint.scss" hash="cb02339d9740c3c6a8cde39183ed0166"/><file name="_clearfix.scss" hash="55e23e69145f99d1e38392b1a9420698"/><file name="_if-resolution.scss" hash="9d49ea0dac1bc376c581ba724fa0218b"/><file name="_image-replacement.scss" hash="f99ce5066b956b247bf8fdb7628c4c72"/><file name="_loading-overlay.scss" hash="a3a33484d034229193568e03384f12e7"/><file name="_menu.scss" hash="2330eab00fde007f3c826bf86b0e04b4"/><file name="_not-selectable.scss" hash="7e27705f1e57d8077e7edb5a39fdee6e"/><file name="_toggle-content.scss" hash="91e198e313fda382c9c2e9fb12bb342e"/><file name="_triangle.scss" hash="6df09b47978dcb46faabe8a789bcf412"/><file name="_typography.scss" hash="0634899cf1572349341ad02e68f3e5af"/></dir><dir name="module"><file name="_account-orders.scss" hash="1566481ee469c96ba9947e366912cbb3"/><file name="_account-reviews.scss" hash="a207a4b2e3f953f316dba7e97a4a87c9"/><file name="_billing-agreements.scss" hash="f9984020bb88042d857d6b4a165b7e8e"/><file name="_captcha.scss" hash="6a478cb360bb39aa978ce8b0dbfd8a2c"/><file name="_catalog-compare.scss" hash="1a72cc87d13992643ab826bf9e028929"/><file name="_catalog-msrp.scss" hash="d2c03f98dc9b2a31dbbedc3a56968619"/><file name="_catalog-product.scss" hash="217ee56f122c4ac9cf37320cbc0b31a1"/><file name="_checkout-cart-minicart.scss" hash="159fef349f60e392aecb7ab5f112a508"/><file name="_checkout-cart.scss" hash="d8d24dfb4dc5538b764b2a0b6e25a9e2"/><file name="_checkout-multi-address.scss" hash="b3d7777c347a55f00568c1b8d8d3470a"/><file name="_checkout-onepage.scss" hash="d532ce0af5ec92002ea3bca4df010911"/><file name="_checkout-success.scss" hash="8a27a309ed45f117b9a3f28121455dc7"/><file name="_cms.scss" hash="2d008923d1c787e8c9201428411ede0b"/><file name="_configurableswatches.scss" hash="42ff6cf4d1fe159a17c5ba6cdc82e3f6"/><file name="_contacts.scss" hash="67e9b5079eb38a1313df5abaf8dcbe8a"/><file name="_cookies.scss" hash="b6ef04bd507c26c5b8c277c398788579"/><file name="_customer.scss" hash="1c7dfda996e88a5f6517225738da3283"/><file name="_paypal.scss" hash="3c9550307fdfa293977b21f437d4c0a7"/><file name="_popular-terms.scss" hash="b3ec891b1706fb9bc914f1f0f9b36b19"/><file name="_pricing_conditions.scss" hash="36887033cc7ebadce1872a9d2c9e3ed2"/><file name="_product-list.scss" hash="8ba0f2f9b9c9e41509af955e5858cf41"/><file name="_recurring-profiles.scss" hash="1c06e6561e57aacd8c6f5c4342290964"/><file name="_review.scss" hash="28275bb7f69b44011618f0e534c6b60f"/><file name="_search.scss" hash="bf3eb603fbd3b8bff5b5ceb135ea4642"/><file name="_slideshow.scss" hash="7ec125b75db0a049d507e833bea8edb7"/><file name="_tags.scss" hash="712ac8bd4f7a99d144fb2af7e17bd5d8"/><file name="_widget.scss" hash="e41baab99ea2020e6ff006778f3de9b4"/><file name="_wishlist.scss" hash="72efb048a2242ca332f973404dc51a76"/></dir><dir name="override"><file name="_plugin.scss" hash="ec60b0b35e840eb6347f21a95f16b719"/></dir><file name="scaffold-forms.scss" hash="983e1df0846a9a75048825abb8405304"/><file name="styles-ie8.scss" hash="4d20f2d2b4317945b5350c91c91efddc"/><file name="styles.scss" hash="3ad39f7c860c02e9b0d7cc95cd0e8863"/><dir name="vendor"><file name="_normalize.scss" hash="d9edffd350bd218571fd141a9c658d29"/></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Interface_Install_Default-1.9.4.1.xml b/var/package/Interface_Install_Default-1.9.4.1.xml
deleted file mode 100644
index 1a25d29..0000000
--- a/var/package/Interface_Install_Default-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Interface_Install_Default</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Default interface for Install</summary>
-    <description>Default interface for Install</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:41</time>
-    <contents><target name="magedesign"><dir name="install"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="main.xml" hash="1e4690304e35af0f0a4c0cf9ef3f871b"/></dir><dir name="template"><dir name="install"><file name="begin.phtml" hash="23e3039f3bd2f10952b25fca26c56d83"/><file name="config.phtml" hash="35b2debe9ab7dbb8fcd5ccf6ccf38a91"/><file name="create_admin.phtml" hash="f64acc16592d95dade30ffe810d56e5c"/><dir name="db"><file name="main.phtml" hash="814787c7d6882395bf8d44305bf678ce"/><file name="mysql4.phtml" hash="73a36d4eb1fe1fb571bfdbd108ee6223"/></dir><file name="download.phtml" hash="65f06ef8c58668dfe5b83ba4a5904df1"/><file name="end.phtml" hash="0fe6c358345f60570aa20c3a1cbff04a"/><file name="locale.phtml" hash="837b860853ca7e11e28273acd7b6be69"/><file name="state.phtml" hash="2964d0ec1dd7fe1e06e245ed70b0668f"/></dir><file name="page.phtml" hash="87adbd0e0ea8c046e66e4a88bace376c"/></dir></dir></dir></dir></target><target name="mageskin"><dir name="install"><dir name="default"><dir name="default"><dir name="css"><file name="boxes.css" hash="390ba9f8f8ae5deb254622b05f3a60cf"/><file name="clears.css" hash="5b5cefde368a471bc2ee25aee6752617"/><file name="ie7minus.css" hash="bf2d04f3e9e03a8dfb1424225694a350"/><file name="iestyles.css" hash="c22edc91efe49e87714c280cfb9eee52"/><file name="reset.css" hash="4c7ab20bcae42337b30ca4b5e4c9feb0"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Interface_Install_Default-1.9.4.2.xml b/var/package/Interface_Install_Default-1.9.4.2.xml
new file mode 100644
index 0000000..24cf53f
--- /dev/null
+++ b/var/package/Interface_Install_Default-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Interface_Install_Default</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Default interface for Install</summary>
+    <description>Default interface for Install</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="magedesign"><dir name="install"><dir name="default"><dir name="default"><dir name="etc"><file name="theme.xml" hash="6597b08917673ad27d51f73ea020523b"/></dir><dir name="layout"><file name="main.xml" hash="1e4690304e35af0f0a4c0cf9ef3f871b"/></dir><dir name="template"><dir name="install"><file name="begin.phtml" hash="23e3039f3bd2f10952b25fca26c56d83"/><file name="config.phtml" hash="35b2debe9ab7dbb8fcd5ccf6ccf38a91"/><file name="create_admin.phtml" hash="f64acc16592d95dade30ffe810d56e5c"/><dir name="db"><file name="main.phtml" hash="814787c7d6882395bf8d44305bf678ce"/><file name="mysql4.phtml" hash="73a36d4eb1fe1fb571bfdbd108ee6223"/></dir><file name="download.phtml" hash="65f06ef8c58668dfe5b83ba4a5904df1"/><file name="end.phtml" hash="0fe6c358345f60570aa20c3a1cbff04a"/><file name="locale.phtml" hash="837b860853ca7e11e28273acd7b6be69"/><file name="state.phtml" hash="2964d0ec1dd7fe1e06e245ed70b0668f"/></dir><file name="page.phtml" hash="87adbd0e0ea8c046e66e4a88bace376c"/></dir></dir></dir></dir></target><target name="mageskin"><dir name="install"><dir name="default"><dir name="default"><dir name="css"><file name="boxes.css" hash="390ba9f8f8ae5deb254622b05f3a60cf"/><file name="clears.css" hash="5b5cefde368a471bc2ee25aee6752617"/><file name="ie7minus.css" hash="bf2d04f3e9e03a8dfb1424225694a350"/><file name="iestyles.css" hash="c22edc91efe49e87714c280cfb9eee52"/><file name="reset.css" hash="4c7ab20bcae42337b30ca4b5e4c9feb0"/></dir><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="i_notice.gif" hash="ebd56dc80b8346e10e93628bc0e6c372"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Cm-1.9.4.1.xml b/var/package/Lib_Cm-1.9.4.1.xml
deleted file mode 100644
index a409487..0000000
--- a/var/package/Lib_Cm-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Cm</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Redis adapter for Zend_Cache</summary>
-    <description>Redis adapter for Zend_Cache</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="magelib"><dir name="Cm"><dir name="Cache"><dir name="Backend"><file name="Redis.php" hash="1c137eef42b9c034fa0b6d5258092c00"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_Cm-1.9.4.2.xml b/var/package/Lib_Cm-1.9.4.2.xml
new file mode 100644
index 0000000..0b1a8e9
--- /dev/null
+++ b/var/package/Lib_Cm-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Cm</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Redis adapter for Zend_Cache</summary>
+    <description>Redis adapter for Zend_Cache</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Colin Mollenhour</name><user>core</user><email>colin@mollenhour.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="magelib"><dir name="Cm"><dir name="Cache"><dir name="Backend"><file name="Redis.php" hash="1c137eef42b9c034fa0b6d5258092c00"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Credis-1.9.4.1.xml b/var/package/Lib_Credis-1.9.4.1.xml
deleted file mode 100644
index ecf29c4..0000000
--- a/var/package/Lib_Credis-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Credis</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Credis Library</summary>
-    <description>Credis Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="magelib"><dir name="Credis"><file name="Client.php" hash="1fde64fdcd768d51758ec437d5952861"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Credis-1.9.4.2.xml b/var/package/Lib_Credis-1.9.4.2.xml
new file mode 100644
index 0000000..b2a3cf7
--- /dev/null
+++ b/var/package/Lib_Credis-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Credis</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Credis Library</summary>
+    <description>Credis Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="magelib"><dir name="Credis"><file name="Client.php" hash="1fde64fdcd768d51758ec437d5952861"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Google_Checkout-1.9.4.1.xml b/var/package/Lib_Google_Checkout-1.9.4.1.xml
deleted file mode 100644
index 4877d6f..0000000
--- a/var/package/Lib_Google_Checkout-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Google_Checkout</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>Apache License</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Google Checkout Library</summary>
-    <description>Google Checkout Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Google_Checkout-1.9.4.2.xml b/var/package/Lib_Google_Checkout-1.9.4.2.xml
new file mode 100644
index 0000000..bed4dc7
--- /dev/null
+++ b/var/package/Lib_Google_Checkout-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Google_Checkout</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>Apache License</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Google Checkout Library</summary>
+    <description>Google Checkout Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_IDNA2-1.9.4.1.xml b/var/package/Lib_IDNA2-1.9.4.1.xml
deleted file mode 100644
index fb8c756..0000000
--- a/var/package/Lib_IDNA2-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_IDNA2</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/lgpl-3.0.en.html">GNU Lesser General Public License</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="magelib"><dir name="Net"><file name="IDNA2.php" hash="def073c649f1033d8a75189f6a99cf9d"/><dir name="IDNA2"><dir name="Exception"><file name="Nameprep.php" hash="06c4217024082f0f3b6c5a7e61ac7130"/></dir><file name="Exception.php" hash="72f605f2f6d9d56e07bb6bcec099d03a"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_IDNA2-1.9.4.2.xml b/var/package/Lib_IDNA2-1.9.4.2.xml
new file mode 100644
index 0000000..41df2dc
--- /dev/null
+++ b/var/package/Lib_IDNA2-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_IDNA2</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/lgpl-3.0.en.html">GNU Lesser General Public License</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="magelib"><dir name="Net"><file name="IDNA2.php" hash="def073c649f1033d8a75189f6a99cf9d"/><dir name="IDNA2"><dir name="Exception"><file name="Nameprep.php" hash="06c4217024082f0f3b6c5a7e61ac7130"/></dir><file name="Exception.php" hash="72f605f2f6d9d56e07bb6bcec099d03a"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Calendar-1.51.1.18.xml b/var/package/Lib_Js_Calendar-1.51.1.18.xml
deleted file mode 100644
index 7ae61bc..0000000
--- a/var/package/Lib_Js_Calendar-1.51.1.18.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Calendar</name>
-    <version>1.51.1.18</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Javascript Calendar for Magento</summary>
-    <description>Javascript Calendar for Magento</description>
-    <notes>1.51.1.18</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="calendar"><file name="calendar-blue.css" hash="b8bb29e3c1573d0d2917cd3112b5052d"/><file name="calendar-blue2.css" hash="654dfacebcdd70c75ccaf2b4aee2d059"/><file name="calendar-brown.css" hash="f326a6a84037e549a9cd71a92346f210"/><file name="calendar-green.css" hash="b44e2c25ff56efaa6e37d84df202e5d5"/><file name="calendar-setup.js" hash="0c21b9e48ecfad87b4c4885cfb1aca8d"/><file name="calendar-system.css" hash="9b446e2ee0e9e4420fce20922405cec7"/><file name="calendar-tas.css" hash="fa3baa9367504954ef03c1f05d44f1a6"/><file name="calendar-win2k-1.css" hash="e3c61212e6abc28844005381d8fe9690"/><file name="calendar-win2k-2.css" hash="332d8bc7dab6acd575dba49a15b62947"/><file name="calendar-win2k-cold-1.css" hash="b0810ce949e6c954c54053c52b21e74a"/><file name="calendar-win2k-cold-2.css" hash="3487ec4e054141057673d794ce6d1032"/><file name="calendar.js" hash="97705cd3aa011e9671c4441643cc704a"/><file name="img.gif" hash="c1e5255bd358fcd5a0779a0cc310a2fe"/><file name="menuarrow.gif" hash="b5a91d7a2755198b2eb729541ad3288c"/><file name="menuarrow2.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><dir name="skins"><dir name="aqua"><file name="active-bg.gif" hash="f8fb9f2b7428c94b41320aa1bc9cf601"/><file name="dark-bg.gif" hash="949f6a11667cbdfbb96f8986464ba81b"/><file name="hover-bg.gif" hash="803ac4dbc56c05739f515d6ac6a66163"/><file name="menuarrow.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><file name="normal-bg.gif" hash="851134e42206fd3b173a3db654981bb6"/><file name="rowhover-bg.gif" hash="c097de7289bcf68723e89c248b9a2749"/><file name="status-bg.gif" hash="123882ca533030f07ee55c3818fc46b9"/><file name="theme.css" hash="ec69465f70d45213258fe1f89c52eceb"/><file name="title-bg.gif" hash="8d652fc5b683706fcbbf1103131c6ac2"/><file name="today-bg.gif" hash="9befc7d912cad22ddf2ec3fc21188bfd"/></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Calendar-1.51.1.19.xml b/var/package/Lib_Js_Calendar-1.51.1.19.xml
new file mode 100644
index 0000000..3be2fa4
--- /dev/null
+++ b/var/package/Lib_Js_Calendar-1.51.1.19.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Calendar</name>
+    <version>1.51.1.19</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Javascript Calendar for Magento</summary>
+    <description>Javascript Calendar for Magento</description>
+    <notes>1.51.1.19</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="calendar"><file name="calendar-blue.css" hash="b8bb29e3c1573d0d2917cd3112b5052d"/><file name="calendar-blue2.css" hash="654dfacebcdd70c75ccaf2b4aee2d059"/><file name="calendar-brown.css" hash="f326a6a84037e549a9cd71a92346f210"/><file name="calendar-green.css" hash="b44e2c25ff56efaa6e37d84df202e5d5"/><file name="calendar-setup.js" hash="0c21b9e48ecfad87b4c4885cfb1aca8d"/><file name="calendar-system.css" hash="9b446e2ee0e9e4420fce20922405cec7"/><file name="calendar-tas.css" hash="fa3baa9367504954ef03c1f05d44f1a6"/><file name="calendar-win2k-1.css" hash="e3c61212e6abc28844005381d8fe9690"/><file name="calendar-win2k-2.css" hash="332d8bc7dab6acd575dba49a15b62947"/><file name="calendar-win2k-cold-1.css" hash="b0810ce949e6c954c54053c52b21e74a"/><file name="calendar-win2k-cold-2.css" hash="3487ec4e054141057673d794ce6d1032"/><file name="calendar.js" hash="97705cd3aa011e9671c4441643cc704a"/><file name="img.gif" hash="c1e5255bd358fcd5a0779a0cc310a2fe"/><file name="menuarrow.gif" hash="b5a91d7a2755198b2eb729541ad3288c"/><file name="menuarrow2.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><dir name="skins"><dir name="aqua"><file name="active-bg.gif" hash="f8fb9f2b7428c94b41320aa1bc9cf601"/><file name="dark-bg.gif" hash="949f6a11667cbdfbb96f8986464ba81b"/><file name="hover-bg.gif" hash="803ac4dbc56c05739f515d6ac6a66163"/><file name="menuarrow.gif" hash="1f8c673c8f76832febaeeac88a5f4353"/><file name="normal-bg.gif" hash="851134e42206fd3b173a3db654981bb6"/><file name="rowhover-bg.gif" hash="c097de7289bcf68723e89c248b9a2749"/><file name="status-bg.gif" hash="123882ca533030f07ee55c3818fc46b9"/><file name="theme.css" hash="ec69465f70d45213258fe1f89c52eceb"/><file name="title-bg.gif" hash="8d652fc5b683706fcbbf1103131c6ac2"/><file name="today-bg.gif" hash="9befc7d912cad22ddf2ec3fc21188bfd"/></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Ext-1.9.4.1.xml b/var/package/Lib_Js_Ext-1.9.4.1.xml
deleted file mode 100644
index aedf9d5..0000000
--- a/var/package/Lib_Js_Ext-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Ext</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Extjs Javascript Libraries for Magento</summary>
-    <description>Extjs Javascript Libraries for Magento</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="extjs"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="8fefe8397b484ac4855de7232d00fc5d"/><file name="box.css" hash="e042e86fe72ac68849bb2c927d1b94be"/><file name="button.css" hash="0baa72e592fb9cfddb48491ce74040c2"/><file name="combo.css" hash="5f3457b94b882c6037da7b62b10fd50b"/><file name="core.css" hash="49c87f77493ccaa4867c4c4b54e2f297"/><file name="date-picker.css" hash="cb973d925a5fe95e3a8a23393b9db283"/><file name="dd.css" hash="67c5b243c56a99eb1bdbd4d57fea7ce1"/><file name="debug.css" hash="e22d97cc54ad2f42b4f06daa921da622"/><file name="editor.css" hash="ab513287f9e04386f48980e399d4a0b1"/><file name="ext-all.css" hash="e5acad04d0e7877b829bac608437522c"/><file name="form.css" hash="22877998588bc093dcf9375b8707079c"/><file name="grid.css" hash="79cefd1763bb64802f99177f233bd676"/><file name="layout.css" hash="2ba12ec3ceff9989de97e02296c94281"/><file name="menu.css" hash="13b8de4d5f155bb5d526318431b8317f"/><file name="panel.css" hash="fb6624b2dfc4ef99e08bc11eac723e20"/><file name="qtips.css" hash="67b76bbd4ad59a7341ed74a07c8e2524"/><file name="reset-min.css" hash="9c797c4b3949999b27f0e4108132cb57"/><file name="resizable.css" hash="2271ebacebaa1e429d42ba09da460647"/><file name="tabs.css" hash="d19d0773d75a9e2fe2032b1c35a22161"/><file name="toolbar.css" hash="ff85187d3b869bf3b98a72db95fca184"/><file name="tree.css" hash="d8a55f993187bc822efc5beb03722369"/><file name="ytheme-aero.css" hash="e555e0439f7fc0a43de37784e3df23c6"/><file name="ytheme-gray.css" hash="9d08035f3b052a9c604b0116f9a6c0be"/><file name="ytheme-vista.css" hash="8b13f7980b254be7e7c54abc0d8dcc3f"/></dir><file name="ext-tree-checkbox.js" hash="b9d12cc79c28a69f86390a0c52f4b9c7"/><file name="ext-tree.js" hash="cbf1e494c6a179530e7defa99b15d67e"/><file name="fix-defer-before.js" hash="90cb0013791fb2ad864a09e821d58186"/><file name="fix-defer.js" hash="0c809c43ba95bfaa7eca20f073103b51"/><dir name="resources"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="4cc973c87f79ea230f372cea597963ba"/><file name="box.css" hash="3809db7ee254d629d52dba0aad472d35"/><file name="button.css" hash="d3f29c8497579832fe5d7aafff7c3544"/><file name="combo.css" hash="483a1a701ca9c7db718e0e767f3d4585"/><file name="core.css" hash="6e82710d5206b6b7c0f70399cf649449"/><file name="date-picker.css" hash="fa68b668561d477e702318fb5d59636c"/><file name="dd.css" hash="f0e5f55969aeda8f65a01033613181c5"/><file name="debug.css" hash="6ef466c0c857e0c405cac7b8911f0824"/><file name="editor.css" hash="2fdb75e85a247c362285d4f079c0a12f"/><file name="ext-all.css" hash="c5e12af950c3ea3a243d0b9ca0dc4dba"/><file name="form.css" hash="38bd5bd602a83075325696af2c447e65"/><file name="grid.css" hash="c6d110f89542c04e4cbf98de73e97e9b"/><file name="layout.css" hash="89251906d248b3756f0ed354491651a6"/><file name="menu.css" hash="88eb8b3754612496ccf9d386694a39e0"/><file name="panel.css" hash="deaf7ccb5526687fadd67c093da9e604"/><file name="qtips.css" hash="2a6e683a7b23cbdf52177d7141d17435"/><file name="reset-min.css" hash="8fddbb1b7930f2817f2d5d215be98d5f"/><file name="resizable.css" hash="a50b8d1ea8e9dfbdd101a43bc63857c3"/><file name="tabs.css" hash="323d6f11f1550a43a02a617e39242ed5"/><file name="toolbar.css" hash="d09eb7507f57178967d217caeaa8b046"/><file name="tree.css" hash="b0104f954fbe1f04ebf49acffcec74ef"/><file name="ytheme-aero.css" hash="c25b48ba1b913f2ea094065fa916e9da"/><file name="ytheme-galdaka.css" hash="8b1917749205e64bdbcecc893e188b09"/><file name="ytheme-gray.css" hash="c45ba874b89038c9c8d9a79a1c591f26"/><file name="ytheme-magento.css" hash="94c3fc72743ad6d1fe7d8e74d713750e"/><file name="ytheme-vista.css" hash="2092ef97154cf5f6b33893bf5e178e21"/></dir><dir name="images"><dir name="default"><dir name="basic-dialog"><file name="btn-arrow.gif" hash="9e2365ef98c6096f6b5f411ab618bb4e"/><file name="btn-sprite.gif" hash="73a8327c23c12ed9ec42ac8f52b072e0"/><file name="close.gif" hash="2d54069e9355f295dd27027f7f779eb9"/><file name="collapse.gif" hash="63b2687a2dc81537765a7d22f9e480da"/><file name="e-handle.gif" hash="f9357e6c1dfbd00da007cf6705e08225"/><file name="expand.gif" hash="740af52fb7de6ca9fd888184e86a5308"/><file name="hd-sprite.gif" hash="6a54ae98bef53397d52282201852c204"/><file name="progress.gif" hash="baff9a083b93588fa7ff3548844a9e1a"/><file name="progress2.gif" hash="339036f9eb530c1b180c77f9a109ef3e"/><file name="s-handle.gif" hash="36b90844c0b35da23da21aac599957d4"/><file name="se-handle.gif" hash="668b22581100befcf947e806599dc0ce"/></dir><dir name="box"><file name="corners-blue.gif" hash="86fd4c5664e0971bfc11959e8442604c"/><file name="corners.gif" hash="d2d1bc2085b369ce35ffd20c0121676e"/><file name="l-blue.gif" hash="ced9ffbf66ea39e77083a591f8257267"/><file name="l.gif" hash="c4d9dbbdc59ae06b5e9e72a6a865c981"/><file name="r-blue.gif" hash="82dbb522a80e3246f6297719371a9494"/><file name="r.gif" hash="bf1e1d4a45f951ae656968a8c834f04a"/><file name="tb-blue.gif" hash="7c4b19eb682afdc1bde0640d2321fb25"/><file name="tb.gif" hash="dd3f63afe7ba90983ba73dad1c66bf2f"/></dir><dir name="dd"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-no.gif" hash="ae536c37391ba78143b5c8283cec8d13"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/></dir><dir name="editor"><file name="tb-sprite.gif" hash="8908365d736426795ce46de7e328b508"/></dir><dir name="form"><file name="clear-trigger.gif" hash="97b3e5e9edf27b50d63d48098c2f1eae"/><file name="date-trigger.gif" hash="9245675ed8931df277184b419cf4cdad"/><file name="error-tip-corners.gif" hash="364474276178c7b48b6270056b42b808"/><file name="exclamation.gif" hash="40491021e901fa801dbbc09b6c59d73e"/><file name="search-trigger.gif" hash="559ef372cf27a38678d84e8c0b7237fc"/><file name="text-bg.gif" hash="d5ba54c1f417e6a72cbce8b909078727"/><file name="trigger-tpl.gif" hash="d7be20f0dc38f4f46cd318fe32cf3ce3"/><file name="trigger.gif" hash="45019efdf75528242c5a68742821dc57"/></dir><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><dir name="grid"><file name="Thumbs.db" hash="c3affff39ba36b80da43a08c34a61391"/><file name="arrow-left-white.gif" hash="b04e859bdcbd21ad1f06b8bfa7881df8"/><file name="arrow-right-white.gif" hash="714eb00f8134dde3a65c83f3f71ad2c4"/><file name="col-move-bottom.gif" hash="9c38bcb5cee1dc9b4ce64ad9ab1386f8"/><file name="col-move-top.gif" hash="c4584202d5172464050f675d396d1c6f"/><file name="dirty.gif" hash="decca3b96e2c37cf6eb04ddb0d9f669b"/><file name="done.gif" hash="365266930a93451414fe51ffc524a196"/><file name="drop-no.gif" hash="b53ca86d60fbcc7a45c8917299218bfd"/><file name="drop-yes.gif" hash="af96f4c3b32a470db2f38abb521b5c97"/><file name="footer-bg.gif" hash="65ed63e44c6149f1127ad3b4be4e0108"/><file name="grid-blue-hd.gif" hash="dd35d5c1202c440c2d1a945b335984d3"/><file name="grid-blue-split.gif" hash="0494ba49974ff2bc1bf81e1d82dfee18"/><file name="grid-hrow.gif" hash="55972a5063d80f35fb6b95a79bb0018a"/><file name="grid-loading.gif" hash="9ac6f737eb9b15272f12b00bfeb3c3c6"/><file name="grid-split.gif" hash="3ef419d4b9421d8e94f673a6238dc4c0"/><file name="grid-vista-hd.gif" hash="675f403e8a9cb5ab4bed725da9fe2023"/><file name="grid3-hd-btn.gif" hash="e3e77072c16a6b27556236961f29c552"/><file name="grid3-hrow-over.gif" hash="a92d8f6c106943995720f2884634670e"/><file name="grid3-hrow.gif" hash="4c58074bb961c8f184522355f1b0eb90"/><file name="grid3-special-col-bg.gif" hash="c9df03a1c107360128da89fa47066405"/><file name="grid3-special-col-sel-bg.gif" hash="a94039f89dec164896ceff1fbdf6dbc5"/><file name="hd-pop.gif" hash="e5f27a2f68cc2d13b11cf41c46d298dc"/><file name="hmenu-asc.gif" hash="048e0bc30f7c39d473dad5dabcbe03f2"/><file name="hmenu-desc.gif" hash="f0a987b34b003b25a7c82624d41f018a"/><file name="hmenu-lock.gif" hash="bcef18e25342c69c37c44dab87086065"/><file name="hmenu-lock.png" hash="2a3b0b441834f443c1086930939efdae"/><file name="hmenu-unlock.gif" hash="8cc8205dafa587ef02d8a86903ae8074"/><file name="hmenu-unlock.png" hash="c1f61df70b98c5498ea81e7e7b9effbb"/><file name="invalid_line.gif" hash="04a88e97b56e8a8ece4a66d49cc78828"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="mso-hd.gif" hash="37fba9c02f0eefe57f655890eef1c4a1"/><file name="nowait.gif" hash="23c91166dbb16ba8655363321bf5a400"/><file name="page-first-disabled.gif" hash="8d3185028c541cbcce67b5909c04824e"/><file name="page-first.gif" hash="16ec00fa770d860b768cf5034ddfca96"/><file name="page-last-disabled.gif" hash="1d123237ceeb5109a1b9274f0cf19d73"/><file name="page-last.gif" hash="ef524dd0b8dfe4eefecffaa1c0bb8edd"/><file name="page-next-disabled.gif" hash="0f4b8681772c91921fa93ede9c755ea0"/><file name="page-next.gif" hash="f6f9d2209dfc99912ffc9848d97646db"/><file name="page-prev-disabled.gif" hash="eefcbed15c8d37a89618b08f7b224297"/><file name="page-prev.gif" hash="80daad880483eed682b22ec70514ecc4"/><file name="pick-button.gif" hash="b431fdf306f1e2f033d0a431996de93f"/><file name="refresh.gif" hash="8dae08d3581dcd9a04ca73877eab4b53"/><file name="row-check-sprite.gif" hash="2d0aa7e501c3e6f97a97faf75e35d3c3"/><file name="row-expand-sprite.gif" hash="be81199d9d4fa69bef47a8f036a5a7d8"/><file name="row-over.gif" hash="f639094bd0560aefabc86e51a825f23d"/><file name="row-sel.gif" hash="ca87d6b950386edd5e17c985769d9101"/><file name="sort_asc.gif" hash="cc186187e31b0c39abbb7d2394916292"/><file name="sort_desc.gif" hash="fcfe91243fac2e5f24d05bb44f78ded4"/><file name="wait.gif" hash="b0cd5a5dc070c705ebf8814a909802c3"/></dir><dir name="layout"><file name="collapse.gif" hash="dfcec0803d488a783916c750fd83a897"/><file name="expand.gif" hash="c9c9b0ea5311c3dc016c69dc234912bc"/><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><file name="ns-collapse.gif" hash="efa9fbd7a1f3f0f1f22360391e16126f"/><file name="ns-expand.gif" hash="da1f9d40c091d3b6dc7a8dee4fc02ac6"/><file name="panel-close.gif" hash="b185da1837344529bfb684a96d8371b5"/><file name="panel-title-bg.gif" hash="b66384c309a397963389a76b07e9ecd4"/><file name="panel-title-light-bg.gif" hash="688d3a263442db125da170e5d3aebf70"/><file name="stick.gif" hash="be9e67ae0b61b01cfd15928ca7a3da51"/><file name="stuck.gif" hash="745e0cacb51250ea0216efc4a1cb50cb"/><file name="tab-close-on.gif" hash="0ae2c978e85391a69f0dce8da18d8b23"/><file name="tab-close.gif" hash="f92107cc6b4cb78af084648a628e01d2"/></dir><dir name="menu"><file name="checked.gif" hash="692bc97badf50c05495f6109143b4b11"/><file name="group-checked.gif" hash="f7973443d91e5e074013f1b07ee79479"/><file name="menu-parent.gif" hash="d303ad7e3ced891736e80f77e1d4e51d"/><file name="menu.gif" hash="5d34732294bbe06a862961dd02bcc962"/><file name="unchecked.gif" hash="9b90ed7c9e8f0892ce09f3b35b19db53"/></dir><dir name="panel"><file name="corners-sprite.gif" hash="06daef2335218cdfd900ce8bf7a68738"/><file name="left-right.gif" hash="49344fefef7c6f866f910b9067f0990f"/><file name="tool-sprite-tpl.gif" hash="e0449768cd5dce80b18fac904818ab33"/><file name="tool-sprites.gif" hash="31ccd74ac8dab4b5669887310a2341df"/><file name="top-bottom.gif" hash="d9a86e8466a31bd1cb87aae2cf55faf2"/><file name="white-corners-sprite.gif" hash="de8b3036676d19b9635f319a8a4aad36"/><file name="white-left-right.gif" hash="77a6389c6737ad507ca5330ad8816524"/><file name="white-top-bottom.gif" hash="f865d7237bff3c45fd4a8c448f97d236"/></dir><dir name="qtip"><file name="bg.gif" hash="49c0a530cc16357bb39d51c13065a88f"/><file name="close.gif" hash="0379d036250096cae2e42b427b3df2e7"/><file name="tip-sprite.gif" hash="11637a20b1f3f2331bf0627146c2f433"/></dir><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/><file name="shadow-c.png" hash="3abbfce345687daada53445adf6fddc7"/><file name="shadow-lr.png" hash="986270d8ab4330fa7499dc33ed135598"/><file name="shadow.png" hash="860bf4f690d2ea2aba7b11500925da62"/><dir name="shared"><file name="calendar.gif" hash="81296cff1f97f5365524f2b9dcf626da"/><file name="glass-bg.gif" hash="bc2cd5c5ac9b3874d956c892d23f2119"/><file name="left-btn.gif" hash="6bf30c6cf0b5d70436c3e463b5532b35"/><file name="right-btn.gif" hash="e7ad3a7f4814791cecf1b90e77e9e139"/><file name="warning.gif" hash="448dc934a7f0dd6092b51f88a1e47b2d"/></dir><dir name="sizer"><file name="e-handle-dark.gif" hash="b86289f41d7ad1a7401dd2b2a9b3c3d8"/><file name="e-handle.gif" hash="510edc95ebaa36306916c50ca10596f7"/><file name="ne-handle-dark.gif" hash="115f71b851c7f0b5f354caa7b8dfff15"/><file name="ne-handle.gif" hash="8e268b962dc909d275997b572ff17a72"/><file name="nw-handle-dark.gif" hash="4a361e6920b2e34a39fd425a515c83b9"/><file name="nw-handle.gif" hash="1120600505249c38c3d1cc2ab120cd13"/><file name="s-handle-dark.gif" hash="4a6bf15d308a4ae580dd03cbd431a95c"/><file name="s-handle.gif" hash="5e3338cb09e9df7f52383d6b1423fc86"/><file name="se-handle-dark.gif" hash="f3d8d8aac23e3e9633072e2366cda847"/><file name="se-handle.gif" hash="71edc3f63f79f447d2c81ee09e1fbbc3"/><file name="square.gif" hash="4431ea1954bfd2a9cea0931f07fc7ffa"/><file name="sw-handle-dark.gif" hash="44b2400d873cf8a23d84424827cde44d"/><file name="sw-handle.gif" hash="c3e0befc4208a51180344765fd7deeda"/></dir><dir name="tabs"><file name="tab-btm-inactive-left-bg.gif" hash="4f141a6abf25d3c9409b6c381333c138"/><file name="tab-btm-inactive-right-bg.gif" hash="eb2423d3b9dd072976ce955ab0c683d6"/><file name="tab-btm-left-bg.gif" hash="a36eb9382ed8b858eff2c5d4e5d7011a"/><file name="tab-btm-right-bg.gif" hash="9e4245776f0f7b6b6c7ddbf40a43103a"/><file name="tab-sprite.gif" hash="6a7d481bf5b74acfbfa0b01a35bd6620"/></dir><dir name="toolbar"><file name="btn-arrow-light.gif" hash="fa49b39a0fd88ef26264da44a2b4edea"/><file name="btn-arrow.gif" hash="12bda29a4c8016cfa047e852c4353f59"/><file name="btn-over-bg.gif" hash="faddf9b24cefa721326ba3f87f3ef31f"/><file name="gray-bg.gif" hash="cf2d9408f320e696e607d8472afa7ff0"/><file name="tb-bg.gif" hash="5309337fd7a22cab9d9467fd9eaa0a0c"/><file name="tb-btn-sprite.gif" hash="3aed28dd646d22e215c8a6a3e983322f"/></dir><dir name="tree"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-between.gif" hash="edb544a0de58547d4a39c526e06e3c82"/><file name="drop-no.gif" hash="67f83ea04a2eb1c50614a96faf625f25"/><file name="drop-over.gif" hash="d6b303cfa3de8784057d9d7e66cdaa86"/><file name="drop-under.gif" hash="55e5dbc9451cfa91423832260b0753aa"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/><file name="elbow-end-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-end-minus.gif" hash="a469f6a4394d797c2efeffc70409f6db"/><file name="elbow-end-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-end-plus.gif" hash="ec1482391363612d9e5f8c7087fddaba"/><file name="elbow-end.gif" hash="345551384aa325189ba28a1c20f3405e"/><file name="elbow-line.gif" hash="90e478158df476dc989a60daaafc87e6"/><file name="elbow-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-minus.gif" hash="71bb1bd44b1274c60d30dba1de472ed7"/><file name="elbow-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-plus.gif" hash="945572d06a74b5f952251a86c595f2da"/><file name="elbow.gif" hash="27679f3b1222ba95d9925885d7d82d02"/><file name="folder-open.gif" hash="c569141d6ae7c61d838ed8af26aa9380"/><file name="folder.gif" hash="b7209740bb4a825a06beb8698d92c2b1"/><file name="leaf.gif" hash="23757d6e353f343e3c7edfe28428f198"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/></dir><dir name="window"><file name="corners-sprite.gif" hash="b485d6e69678822a0fb77cc312487874"/><file name="left-right.gif" hash="3fe626d6ca2f71d36fc62c32cb1cc52a"/><file name="top-bottom.gif" hash="8a227016c401438e602c2f770a611d5b"/></dir></dir><dir name="magento"><dir name="basic-dialog"><file name="collapse-on.gif" hash="b60dfdc0d00cfb30a8a622e0c22eed84"/><file name="collapse.gif" hash="8525b9d2e93d31e0b071b1f9bf9550e5"/><file name="expand-on.gif" hash="0dfb4ac6d626cdcaa931c14dbb45848e"/><file name="expand.gif" hash="0eb5c03da8b8415e0568784c959e536a"/><file name="hd-sprite.gif" hash="035bf2296afd70af7020cf06b60bf3f6"/><file name="ns-collapse-on.gif" hash="88ed8b7578c803f68d9f1eb171454e00"/><file name="ns-collapse.gif" hash="44b91376c040f91672aaa98c1fcc062b"/><file name="ns-expand-on.gif" hash="587c2ce90066280e5e6cd731bb9d346c"/><file name="ns-expand.gif" hash="57b479b168f8a54200bd1770b5591630"/><file name="panel_close.gif" hash="686c6dfcf341de25487ab4d8ea5954ce"/><file name="pop_close.gif" hash="dd3605531f9959901eff6f089f084bdc"/><file name="pop_collapse.gif" hash="2b8007242ae1c9ae9f26c60a878a63f7"/></dir><dir name="grid"><file name="grid-body-bg.gif" hash="b5fe585c01f57b2171a2b723abcc4a38"/><file name="grid-split.gif" hash="32e210451e8dc4295b53cf7ca13bb4a6"/></dir><dir name="layout"><file name="checkered-bg.gif" hash="f0a0cd29a6120377c289fd39e2ee7e80"/><file name="icon-catalog.gif" hash="435ff2300ddefb9f8a4bad8ee806fb1a"/><file name="icon-category.gif" hash="ce2a146851bb5ec1e41670b68183b56a"/><file name="icon-my-tasks.gif" hash="0ecb888b160701845e25a7140d038af0"/><file name="icon-product.gif" hash="a0707878c5221052209e5ae6a4de0bd2"/></dir><file name="loading_bg.gif" hash="e202ef7e03d0ef3e9beac7480dae65bf"/><dir name="tabs"><file name="tab-sprite.gif" hash="049fb2f4186b6dc9de747ad96456b1ab"/></dir><dir name="toolbar"><file name="btn-arrow.gif" hash="938cffb6de5cc8b1febfd1851fd983c2"/><file name="header_bg.gif" hash="3696842a32740fa159484cabc3340d13"/><file name="toolbar-bg.gif" hash="8d1b465c2a75963407b536d9081f649f"/></dir><dir name="tree"><file name="elbow-end-minus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-minus.gif" hash="3dbdb88a9297fe5631e832f046b0350b"/><file name="elbow-end-plus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-plus.gif" hash="5470e5712a9742ba666c26cb429baaeb"/><file name="elbow-end.gif" hash="63fe879440e2784e0cc0d316ce017745"/><file name="elbow-line.gif" hash="b316a39455304e20e01dbc437f57fd32"/><file name="elbow-minus-nl.gif" hash="0e3129bff70475c8f7f297e0e59d1608"/><file name="elbow-minus.gif" hash="e7b18ff6800e65c6e171bbb2a911762e"/><file name="elbow-plus-nl.gif" hash="78a8f737941fa658f1e770258a3791cd"/><file name="elbow-plus.gif" hash="b02cb264df55aef2105b1b245d075e56"/><file name="elbow.gif" hash="b6bd0e0237e3cd413fa2dac27701c724"/><file name="folder-open.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="folder.gif" hash="03eb26c42137ac792609822862ef4d0f"/><file name="leaf.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="s.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/></dir></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Ext-1.9.4.2.xml b/var/package/Lib_Js_Ext-1.9.4.2.xml
new file mode 100644
index 0000000..8750e1e
--- /dev/null
+++ b/var/package/Lib_Js_Ext-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Ext</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Extjs Javascript Libraries for Magento</summary>
+    <description>Extjs Javascript Libraries for Magento</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="extjs"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="8fefe8397b484ac4855de7232d00fc5d"/><file name="box.css" hash="e042e86fe72ac68849bb2c927d1b94be"/><file name="button.css" hash="0baa72e592fb9cfddb48491ce74040c2"/><file name="combo.css" hash="5f3457b94b882c6037da7b62b10fd50b"/><file name="core.css" hash="49c87f77493ccaa4867c4c4b54e2f297"/><file name="date-picker.css" hash="cb973d925a5fe95e3a8a23393b9db283"/><file name="dd.css" hash="67c5b243c56a99eb1bdbd4d57fea7ce1"/><file name="debug.css" hash="e22d97cc54ad2f42b4f06daa921da622"/><file name="editor.css" hash="ab513287f9e04386f48980e399d4a0b1"/><file name="ext-all.css" hash="e5acad04d0e7877b829bac608437522c"/><file name="form.css" hash="22877998588bc093dcf9375b8707079c"/><file name="grid.css" hash="79cefd1763bb64802f99177f233bd676"/><file name="layout.css" hash="2ba12ec3ceff9989de97e02296c94281"/><file name="menu.css" hash="13b8de4d5f155bb5d526318431b8317f"/><file name="panel.css" hash="fb6624b2dfc4ef99e08bc11eac723e20"/><file name="qtips.css" hash="67b76bbd4ad59a7341ed74a07c8e2524"/><file name="reset-min.css" hash="9c797c4b3949999b27f0e4108132cb57"/><file name="resizable.css" hash="2271ebacebaa1e429d42ba09da460647"/><file name="tabs.css" hash="d19d0773d75a9e2fe2032b1c35a22161"/><file name="toolbar.css" hash="ff85187d3b869bf3b98a72db95fca184"/><file name="tree.css" hash="d8a55f993187bc822efc5beb03722369"/><file name="ytheme-aero.css" hash="e555e0439f7fc0a43de37784e3df23c6"/><file name="ytheme-gray.css" hash="9d08035f3b052a9c604b0116f9a6c0be"/><file name="ytheme-vista.css" hash="8b13f7980b254be7e7c54abc0d8dcc3f"/></dir><file name="ext-tree-checkbox.js" hash="b9d12cc79c28a69f86390a0c52f4b9c7"/><file name="ext-tree.js" hash="cbf1e494c6a179530e7defa99b15d67e"/><file name="fix-defer-before.js" hash="90cb0013791fb2ad864a09e821d58186"/><file name="fix-defer.js" hash="0c809c43ba95bfaa7eca20f073103b51"/><dir name="resources"><dir name="css"><file name="README.txt" hash="66440774774ca4995ad5137ac9ae48e0"/><file name="basic-dialog.css" hash="4cc973c87f79ea230f372cea597963ba"/><file name="box.css" hash="3809db7ee254d629d52dba0aad472d35"/><file name="button.css" hash="d3f29c8497579832fe5d7aafff7c3544"/><file name="combo.css" hash="483a1a701ca9c7db718e0e767f3d4585"/><file name="core.css" hash="6e82710d5206b6b7c0f70399cf649449"/><file name="date-picker.css" hash="fa68b668561d477e702318fb5d59636c"/><file name="dd.css" hash="f0e5f55969aeda8f65a01033613181c5"/><file name="debug.css" hash="6ef466c0c857e0c405cac7b8911f0824"/><file name="editor.css" hash="2fdb75e85a247c362285d4f079c0a12f"/><file name="ext-all.css" hash="c5e12af950c3ea3a243d0b9ca0dc4dba"/><file name="form.css" hash="38bd5bd602a83075325696af2c447e65"/><file name="grid.css" hash="c6d110f89542c04e4cbf98de73e97e9b"/><file name="layout.css" hash="89251906d248b3756f0ed354491651a6"/><file name="menu.css" hash="88eb8b3754612496ccf9d386694a39e0"/><file name="panel.css" hash="deaf7ccb5526687fadd67c093da9e604"/><file name="qtips.css" hash="2a6e683a7b23cbdf52177d7141d17435"/><file name="reset-min.css" hash="8fddbb1b7930f2817f2d5d215be98d5f"/><file name="resizable.css" hash="a50b8d1ea8e9dfbdd101a43bc63857c3"/><file name="tabs.css" hash="323d6f11f1550a43a02a617e39242ed5"/><file name="toolbar.css" hash="d09eb7507f57178967d217caeaa8b046"/><file name="tree.css" hash="b0104f954fbe1f04ebf49acffcec74ef"/><file name="ytheme-aero.css" hash="c25b48ba1b913f2ea094065fa916e9da"/><file name="ytheme-galdaka.css" hash="8b1917749205e64bdbcecc893e188b09"/><file name="ytheme-gray.css" hash="c45ba874b89038c9c8d9a79a1c591f26"/><file name="ytheme-magento.css" hash="94c3fc72743ad6d1fe7d8e74d713750e"/><file name="ytheme-vista.css" hash="2092ef97154cf5f6b33893bf5e178e21"/></dir><dir name="images"><dir name="default"><dir name="basic-dialog"><file name="btn-arrow.gif" hash="9e2365ef98c6096f6b5f411ab618bb4e"/><file name="btn-sprite.gif" hash="73a8327c23c12ed9ec42ac8f52b072e0"/><file name="close.gif" hash="2d54069e9355f295dd27027f7f779eb9"/><file name="collapse.gif" hash="63b2687a2dc81537765a7d22f9e480da"/><file name="e-handle.gif" hash="f9357e6c1dfbd00da007cf6705e08225"/><file name="expand.gif" hash="740af52fb7de6ca9fd888184e86a5308"/><file name="hd-sprite.gif" hash="6a54ae98bef53397d52282201852c204"/><file name="progress.gif" hash="baff9a083b93588fa7ff3548844a9e1a"/><file name="progress2.gif" hash="339036f9eb530c1b180c77f9a109ef3e"/><file name="s-handle.gif" hash="36b90844c0b35da23da21aac599957d4"/><file name="se-handle.gif" hash="668b22581100befcf947e806599dc0ce"/></dir><dir name="box"><file name="corners-blue.gif" hash="86fd4c5664e0971bfc11959e8442604c"/><file name="corners.gif" hash="d2d1bc2085b369ce35ffd20c0121676e"/><file name="l-blue.gif" hash="ced9ffbf66ea39e77083a591f8257267"/><file name="l.gif" hash="c4d9dbbdc59ae06b5e9e72a6a865c981"/><file name="r-blue.gif" hash="82dbb522a80e3246f6297719371a9494"/><file name="r.gif" hash="bf1e1d4a45f951ae656968a8c834f04a"/><file name="tb-blue.gif" hash="7c4b19eb682afdc1bde0640d2321fb25"/><file name="tb.gif" hash="dd3f63afe7ba90983ba73dad1c66bf2f"/></dir><dir name="dd"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-no.gif" hash="ae536c37391ba78143b5c8283cec8d13"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/></dir><dir name="editor"><file name="tb-sprite.gif" hash="8908365d736426795ce46de7e328b508"/></dir><dir name="form"><file name="clear-trigger.gif" hash="97b3e5e9edf27b50d63d48098c2f1eae"/><file name="date-trigger.gif" hash="9245675ed8931df277184b419cf4cdad"/><file name="error-tip-corners.gif" hash="364474276178c7b48b6270056b42b808"/><file name="exclamation.gif" hash="40491021e901fa801dbbc09b6c59d73e"/><file name="search-trigger.gif" hash="559ef372cf27a38678d84e8c0b7237fc"/><file name="text-bg.gif" hash="d5ba54c1f417e6a72cbce8b909078727"/><file name="trigger-tpl.gif" hash="d7be20f0dc38f4f46cd318fe32cf3ce3"/><file name="trigger.gif" hash="45019efdf75528242c5a68742821dc57"/></dir><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><dir name="grid"><file name="Thumbs.db" hash="c3affff39ba36b80da43a08c34a61391"/><file name="arrow-left-white.gif" hash="b04e859bdcbd21ad1f06b8bfa7881df8"/><file name="arrow-right-white.gif" hash="714eb00f8134dde3a65c83f3f71ad2c4"/><file name="col-move-bottom.gif" hash="9c38bcb5cee1dc9b4ce64ad9ab1386f8"/><file name="col-move-top.gif" hash="c4584202d5172464050f675d396d1c6f"/><file name="dirty.gif" hash="decca3b96e2c37cf6eb04ddb0d9f669b"/><file name="done.gif" hash="365266930a93451414fe51ffc524a196"/><file name="drop-no.gif" hash="b53ca86d60fbcc7a45c8917299218bfd"/><file name="drop-yes.gif" hash="af96f4c3b32a470db2f38abb521b5c97"/><file name="footer-bg.gif" hash="65ed63e44c6149f1127ad3b4be4e0108"/><file name="grid-blue-hd.gif" hash="dd35d5c1202c440c2d1a945b335984d3"/><file name="grid-blue-split.gif" hash="0494ba49974ff2bc1bf81e1d82dfee18"/><file name="grid-hrow.gif" hash="55972a5063d80f35fb6b95a79bb0018a"/><file name="grid-loading.gif" hash="9ac6f737eb9b15272f12b00bfeb3c3c6"/><file name="grid-split.gif" hash="3ef419d4b9421d8e94f673a6238dc4c0"/><file name="grid-vista-hd.gif" hash="675f403e8a9cb5ab4bed725da9fe2023"/><file name="grid3-hd-btn.gif" hash="e3e77072c16a6b27556236961f29c552"/><file name="grid3-hrow-over.gif" hash="a92d8f6c106943995720f2884634670e"/><file name="grid3-hrow.gif" hash="4c58074bb961c8f184522355f1b0eb90"/><file name="grid3-special-col-bg.gif" hash="c9df03a1c107360128da89fa47066405"/><file name="grid3-special-col-sel-bg.gif" hash="a94039f89dec164896ceff1fbdf6dbc5"/><file name="hd-pop.gif" hash="e5f27a2f68cc2d13b11cf41c46d298dc"/><file name="hmenu-asc.gif" hash="048e0bc30f7c39d473dad5dabcbe03f2"/><file name="hmenu-desc.gif" hash="f0a987b34b003b25a7c82624d41f018a"/><file name="hmenu-lock.gif" hash="bcef18e25342c69c37c44dab87086065"/><file name="hmenu-lock.png" hash="2a3b0b441834f443c1086930939efdae"/><file name="hmenu-unlock.gif" hash="8cc8205dafa587ef02d8a86903ae8074"/><file name="hmenu-unlock.png" hash="c1f61df70b98c5498ea81e7e7b9effbb"/><file name="invalid_line.gif" hash="04a88e97b56e8a8ece4a66d49cc78828"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="mso-hd.gif" hash="37fba9c02f0eefe57f655890eef1c4a1"/><file name="nowait.gif" hash="23c91166dbb16ba8655363321bf5a400"/><file name="page-first-disabled.gif" hash="8d3185028c541cbcce67b5909c04824e"/><file name="page-first.gif" hash="16ec00fa770d860b768cf5034ddfca96"/><file name="page-last-disabled.gif" hash="1d123237ceeb5109a1b9274f0cf19d73"/><file name="page-last.gif" hash="ef524dd0b8dfe4eefecffaa1c0bb8edd"/><file name="page-next-disabled.gif" hash="0f4b8681772c91921fa93ede9c755ea0"/><file name="page-next.gif" hash="f6f9d2209dfc99912ffc9848d97646db"/><file name="page-prev-disabled.gif" hash="eefcbed15c8d37a89618b08f7b224297"/><file name="page-prev.gif" hash="80daad880483eed682b22ec70514ecc4"/><file name="pick-button.gif" hash="b431fdf306f1e2f033d0a431996de93f"/><file name="refresh.gif" hash="8dae08d3581dcd9a04ca73877eab4b53"/><file name="row-check-sprite.gif" hash="2d0aa7e501c3e6f97a97faf75e35d3c3"/><file name="row-expand-sprite.gif" hash="be81199d9d4fa69bef47a8f036a5a7d8"/><file name="row-over.gif" hash="f639094bd0560aefabc86e51a825f23d"/><file name="row-sel.gif" hash="ca87d6b950386edd5e17c985769d9101"/><file name="sort_asc.gif" hash="cc186187e31b0c39abbb7d2394916292"/><file name="sort_desc.gif" hash="fcfe91243fac2e5f24d05bb44f78ded4"/><file name="wait.gif" hash="b0cd5a5dc070c705ebf8814a909802c3"/></dir><dir name="layout"><file name="collapse.gif" hash="dfcec0803d488a783916c750fd83a897"/><file name="expand.gif" hash="c9c9b0ea5311c3dc016c69dc234912bc"/><file name="gradient-bg.gif" hash="e117fca9d088e4cd5bbbcec7b99a8408"/><file name="ns-collapse.gif" hash="efa9fbd7a1f3f0f1f22360391e16126f"/><file name="ns-expand.gif" hash="da1f9d40c091d3b6dc7a8dee4fc02ac6"/><file name="panel-close.gif" hash="b185da1837344529bfb684a96d8371b5"/><file name="panel-title-bg.gif" hash="b66384c309a397963389a76b07e9ecd4"/><file name="panel-title-light-bg.gif" hash="688d3a263442db125da170e5d3aebf70"/><file name="stick.gif" hash="be9e67ae0b61b01cfd15928ca7a3da51"/><file name="stuck.gif" hash="745e0cacb51250ea0216efc4a1cb50cb"/><file name="tab-close-on.gif" hash="0ae2c978e85391a69f0dce8da18d8b23"/><file name="tab-close.gif" hash="f92107cc6b4cb78af084648a628e01d2"/></dir><dir name="menu"><file name="checked.gif" hash="692bc97badf50c05495f6109143b4b11"/><file name="group-checked.gif" hash="f7973443d91e5e074013f1b07ee79479"/><file name="menu-parent.gif" hash="d303ad7e3ced891736e80f77e1d4e51d"/><file name="menu.gif" hash="5d34732294bbe06a862961dd02bcc962"/><file name="unchecked.gif" hash="9b90ed7c9e8f0892ce09f3b35b19db53"/></dir><dir name="panel"><file name="corners-sprite.gif" hash="06daef2335218cdfd900ce8bf7a68738"/><file name="left-right.gif" hash="49344fefef7c6f866f910b9067f0990f"/><file name="tool-sprite-tpl.gif" hash="e0449768cd5dce80b18fac904818ab33"/><file name="tool-sprites.gif" hash="31ccd74ac8dab4b5669887310a2341df"/><file name="top-bottom.gif" hash="d9a86e8466a31bd1cb87aae2cf55faf2"/><file name="white-corners-sprite.gif" hash="de8b3036676d19b9635f319a8a4aad36"/><file name="white-left-right.gif" hash="77a6389c6737ad507ca5330ad8816524"/><file name="white-top-bottom.gif" hash="f865d7237bff3c45fd4a8c448f97d236"/></dir><dir name="qtip"><file name="bg.gif" hash="49c0a530cc16357bb39d51c13065a88f"/><file name="close.gif" hash="0379d036250096cae2e42b427b3df2e7"/><file name="tip-sprite.gif" hash="11637a20b1f3f2331bf0627146c2f433"/></dir><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/><file name="shadow-c.png" hash="3abbfce345687daada53445adf6fddc7"/><file name="shadow-lr.png" hash="986270d8ab4330fa7499dc33ed135598"/><file name="shadow.png" hash="860bf4f690d2ea2aba7b11500925da62"/><dir name="shared"><file name="calendar.gif" hash="81296cff1f97f5365524f2b9dcf626da"/><file name="glass-bg.gif" hash="bc2cd5c5ac9b3874d956c892d23f2119"/><file name="left-btn.gif" hash="6bf30c6cf0b5d70436c3e463b5532b35"/><file name="right-btn.gif" hash="e7ad3a7f4814791cecf1b90e77e9e139"/><file name="warning.gif" hash="448dc934a7f0dd6092b51f88a1e47b2d"/></dir><dir name="sizer"><file name="e-handle-dark.gif" hash="b86289f41d7ad1a7401dd2b2a9b3c3d8"/><file name="e-handle.gif" hash="510edc95ebaa36306916c50ca10596f7"/><file name="ne-handle-dark.gif" hash="115f71b851c7f0b5f354caa7b8dfff15"/><file name="ne-handle.gif" hash="8e268b962dc909d275997b572ff17a72"/><file name="nw-handle-dark.gif" hash="4a361e6920b2e34a39fd425a515c83b9"/><file name="nw-handle.gif" hash="1120600505249c38c3d1cc2ab120cd13"/><file name="s-handle-dark.gif" hash="4a6bf15d308a4ae580dd03cbd431a95c"/><file name="s-handle.gif" hash="5e3338cb09e9df7f52383d6b1423fc86"/><file name="se-handle-dark.gif" hash="f3d8d8aac23e3e9633072e2366cda847"/><file name="se-handle.gif" hash="71edc3f63f79f447d2c81ee09e1fbbc3"/><file name="square.gif" hash="4431ea1954bfd2a9cea0931f07fc7ffa"/><file name="sw-handle-dark.gif" hash="44b2400d873cf8a23d84424827cde44d"/><file name="sw-handle.gif" hash="c3e0befc4208a51180344765fd7deeda"/></dir><dir name="tabs"><file name="tab-btm-inactive-left-bg.gif" hash="4f141a6abf25d3c9409b6c381333c138"/><file name="tab-btm-inactive-right-bg.gif" hash="eb2423d3b9dd072976ce955ab0c683d6"/><file name="tab-btm-left-bg.gif" hash="a36eb9382ed8b858eff2c5d4e5d7011a"/><file name="tab-btm-right-bg.gif" hash="9e4245776f0f7b6b6c7ddbf40a43103a"/><file name="tab-sprite.gif" hash="6a7d481bf5b74acfbfa0b01a35bd6620"/></dir><dir name="toolbar"><file name="btn-arrow-light.gif" hash="fa49b39a0fd88ef26264da44a2b4edea"/><file name="btn-arrow.gif" hash="12bda29a4c8016cfa047e852c4353f59"/><file name="btn-over-bg.gif" hash="faddf9b24cefa721326ba3f87f3ef31f"/><file name="gray-bg.gif" hash="cf2d9408f320e696e607d8472afa7ff0"/><file name="tb-bg.gif" hash="5309337fd7a22cab9d9467fd9eaa0a0c"/><file name="tb-btn-sprite.gif" hash="3aed28dd646d22e215c8a6a3e983322f"/></dir><dir name="tree"><file name="drop-add.gif" hash="95eb34ac70a1a3c95ef39ab826a89491"/><file name="drop-between.gif" hash="edb544a0de58547d4a39c526e06e3c82"/><file name="drop-no.gif" hash="67f83ea04a2eb1c50614a96faf625f25"/><file name="drop-over.gif" hash="d6b303cfa3de8784057d9d7e66cdaa86"/><file name="drop-under.gif" hash="55e5dbc9451cfa91423832260b0753aa"/><file name="drop-yes.gif" hash="f3216326c00890259e84f1726dd1043f"/><file name="elbow-end-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-end-minus.gif" hash="a469f6a4394d797c2efeffc70409f6db"/><file name="elbow-end-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-end-plus.gif" hash="ec1482391363612d9e5f8c7087fddaba"/><file name="elbow-end.gif" hash="345551384aa325189ba28a1c20f3405e"/><file name="elbow-line.gif" hash="90e478158df476dc989a60daaafc87e6"/><file name="elbow-minus-nl.gif" hash="5e5bffba157eceee7989db95b919e4d5"/><file name="elbow-minus.gif" hash="71bb1bd44b1274c60d30dba1de472ed7"/><file name="elbow-plus-nl.gif" hash="f0f50c0dd3ee6dd4b11c1f245b36eb01"/><file name="elbow-plus.gif" hash="945572d06a74b5f952251a86c595f2da"/><file name="elbow.gif" hash="27679f3b1222ba95d9925885d7d82d02"/><file name="folder-open.gif" hash="c569141d6ae7c61d838ed8af26aa9380"/><file name="folder.gif" hash="b7209740bb4a825a06beb8698d92c2b1"/><file name="leaf.gif" hash="23757d6e353f343e3c7edfe28428f198"/><file name="loading.gif" hash="00ef871b291bc03a497d608a5bd8ec99"/><file name="s.gif" hash="fc94fb0c3ed8a8f909dbc7630a0987ff"/></dir><dir name="window"><file name="corners-sprite.gif" hash="b485d6e69678822a0fb77cc312487874"/><file name="left-right.gif" hash="3fe626d6ca2f71d36fc62c32cb1cc52a"/><file name="top-bottom.gif" hash="8a227016c401438e602c2f770a611d5b"/></dir></dir><dir name="magento"><dir name="basic-dialog"><file name="collapse-on.gif" hash="b60dfdc0d00cfb30a8a622e0c22eed84"/><file name="collapse.gif" hash="8525b9d2e93d31e0b071b1f9bf9550e5"/><file name="expand-on.gif" hash="0dfb4ac6d626cdcaa931c14dbb45848e"/><file name="expand.gif" hash="0eb5c03da8b8415e0568784c959e536a"/><file name="hd-sprite.gif" hash="035bf2296afd70af7020cf06b60bf3f6"/><file name="ns-collapse-on.gif" hash="88ed8b7578c803f68d9f1eb171454e00"/><file name="ns-collapse.gif" hash="44b91376c040f91672aaa98c1fcc062b"/><file name="ns-expand-on.gif" hash="587c2ce90066280e5e6cd731bb9d346c"/><file name="ns-expand.gif" hash="57b479b168f8a54200bd1770b5591630"/><file name="panel_close.gif" hash="686c6dfcf341de25487ab4d8ea5954ce"/><file name="pop_close.gif" hash="dd3605531f9959901eff6f089f084bdc"/><file name="pop_collapse.gif" hash="2b8007242ae1c9ae9f26c60a878a63f7"/></dir><dir name="grid"><file name="grid-body-bg.gif" hash="b5fe585c01f57b2171a2b723abcc4a38"/><file name="grid-split.gif" hash="32e210451e8dc4295b53cf7ca13bb4a6"/></dir><dir name="layout"><file name="checkered-bg.gif" hash="f0a0cd29a6120377c289fd39e2ee7e80"/><file name="icon-catalog.gif" hash="435ff2300ddefb9f8a4bad8ee806fb1a"/><file name="icon-category.gif" hash="ce2a146851bb5ec1e41670b68183b56a"/><file name="icon-my-tasks.gif" hash="0ecb888b160701845e25a7140d038af0"/><file name="icon-product.gif" hash="a0707878c5221052209e5ae6a4de0bd2"/></dir><file name="loading_bg.gif" hash="e202ef7e03d0ef3e9beac7480dae65bf"/><dir name="tabs"><file name="tab-sprite.gif" hash="049fb2f4186b6dc9de747ad96456b1ab"/></dir><dir name="toolbar"><file name="btn-arrow.gif" hash="938cffb6de5cc8b1febfd1851fd983c2"/><file name="header_bg.gif" hash="3696842a32740fa159484cabc3340d13"/><file name="toolbar-bg.gif" hash="8d1b465c2a75963407b536d9081f649f"/></dir><dir name="tree"><file name="elbow-end-minus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-minus.gif" hash="3dbdb88a9297fe5631e832f046b0350b"/><file name="elbow-end-plus-nl.gif" hash="6dc08c43109cc6a365bd0270f05e2f1c"/><file name="elbow-end-plus.gif" hash="5470e5712a9742ba666c26cb429baaeb"/><file name="elbow-end.gif" hash="63fe879440e2784e0cc0d316ce017745"/><file name="elbow-line.gif" hash="b316a39455304e20e01dbc437f57fd32"/><file name="elbow-minus-nl.gif" hash="0e3129bff70475c8f7f297e0e59d1608"/><file name="elbow-minus.gif" hash="e7b18ff6800e65c6e171bbb2a911762e"/><file name="elbow-plus-nl.gif" hash="78a8f737941fa658f1e770258a3791cd"/><file name="elbow-plus.gif" hash="b02cb264df55aef2105b1b245d075e56"/><file name="elbow.gif" hash="b6bd0e0237e3cd413fa2dac27701c724"/><file name="folder-open.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="folder.gif" hash="03eb26c42137ac792609822862ef4d0f"/><file name="leaf.gif" hash="e3cd196406d4857dc0c926807f16c409"/><file name="s.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/></dir></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Mage-1.9.4.1.xml b/var/package/Lib_Js_Mage-1.9.4.1.xml
deleted file mode 100644
index 1b7877a..0000000
--- a/var/package/Lib_Js_Mage-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Mage</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Javascript Libraries for Magento</summary>
-    <description>Javascript Libraries for Magento</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="lib"><file name="FABridge.js" hash="64244d8d58abd42bd71f0ee3309767ad"/><file name="boxover.js" hash="a5ade77452e8d5066cb84dcac3d34ed5"/><file name="ccard.js" hash="d3e849be0977d53de4af933b40293ff6"/><file name="dropdown.js" hash="d74331fd65500cd64785163be3a434e6"/><file name="ds-sleight.js" hash="85af457d444865d1587bfe4875bd4fc6"/><file name="flex.js" hash="f9d88fdfef8a3bed86df58ed37cab345"/><dir name="jquery"><file name="jquery-1.10.2.js" hash="91515770ce8c55de23b306444d8ea998"/><file name="jquery-1.10.2.min.js" hash="841dc30647f93349b7d8ef61deebe411"/><file name="jquery-1.10.2.min.map" hash="6c3ccfc221d36777d383b6e04d0b8af9"/><file name="jquery-1.12.1.js" hash="62f69d29b6f01c8d477a547cedd922f2"/><file name="jquery-1.12.1.min.js" hash="1d244cb043be8157f0050ce9e45c9ef2"/><file name="jquery-1.12.1.min.map" hash="7761e30c5da1bf6d7cebc61bf612cd0e"/><file name="noconflict.js" hash="eafadf93ad691e381b31c79222507a83"/></dir><dir name="uploader"><file name="flow.min.js" hash="a82a557db407b53d5909fa4e1833a596"/><file name="fusty-flow-factory.js" hash="b3f49be0f28be74e8b8bb76496c52bc3"/><file name="fusty-flow.js" hash="302f440908837093fd4e9b6e76ec01e0"/></dir></dir><dir name="mage"><dir name="adminhtml"><file name="accordion.js" hash="3aa37f15fffadff036e88674fcbba336"/><file name="backup.js" hash="a5d9b6f5613c1407d6e4a7a7951ace80"/><file name="browser.js" hash="4d317c43a354cf614c155536e0ce6186"/><file name="events.js" hash="6cf24a04511896958fafb2f51f9f2ead"/><file name="flexuploader.js" hash="db54e1f8de2e441716b7ea3e1c8f3e55"/><file name="form.js" hash="be6975ed85d5ccedf447bd620a52ce36"/><file name="giftmessage.js" hash="68687e12c1e297b6b1e370102ad213ef"/><dir name="giftoptions"><file name="tooltip.js" hash="ed97a2001cbe2e09720d1a96883dcb61"/></dir><file name="grid.js" hash="b01c7305db7f6eba4236a836b5e0004c"/><file name="hash.js" hash="02bc7053edc147185e4e8de7f935ab12"/><file name="image.js" hash="79bbb61c8ed6ebfe8b576358d8db0104"/><file name="loader.js" hash="66f7a49300e1ee0b00afb53b1f7a22bb"/><file name="magento-all.js" hash="21ba6e3e754f0a45440178ce81dd2604"/><dir name="product"><dir name="composite"><file name="configure.js" hash="310f5314b8dc7faa0be8e35e80cff7f4"/></dir></dir><file name="product.js" hash="38ffa4aa21de646b4f1acfc657a4cc68"/><file name="rules.js" hash="9cb6236e99586a32a4797ddd5ff14d40"/><dir name="sales"><file name="packaging.js" hash="4039a5cb08d716e88af502617111eacc"/></dir><file name="sales.js" hash="36e169d95a25c454f989ac10a0759153"/><file name="scrollbar.js" hash="111c61f0618cd2c5fab7a2bff60b27e7"/><file name="tabs.js" hash="c5b880d653923fe89a7c890cc48073e9"/><file name="tools.js" hash="9fdc751d2cdd5f299d44f0bbd72ae3ff"/><dir name="uploader"><file name="instance.js" hash="2a248014ba11ad618c407150c802bae9"/></dir><file name="uploader.js" hash="072d5070944ee0f95687ce3838ab61f9"/><file name="variables.js" hash="d6941a240dd440594cb8ca4f944840ba"/><dir name="wysiwyg"><dir name="tiny_mce"><dir name="plugins"><dir name="magentovariable"><file name="editor_plugin.js" hash="eea3b1037886236f0f307e80fb162409"/><dir name="img"><file name="icon.gif" hash="682b29a0e734f952cb2edabede6a25d1"/></dir></dir><dir name="magentowidget"><file name="editor_plugin.js" hash="ce29610466ae0718054f9e3defaf5acb"/><dir name="img"><file name="icon.gif" hash="532c141286373f098f1f4362e001c7f8"/></dir></dir></dir><file name="setup.js" hash="d1325c4d9a5695cd5ad17594225fed5a"/><dir name="themes"><dir name="advanced"><dir name="skins"><dir name="default"><file name="content.css" hash="f573fb8565f8da1b9a2a29dd887ddbc5"/><file name="dialog.css" hash="2aa257d84ac0fd6b8809eee27a7f4193"/></dir></dir></dir></dir></dir><file name="widget.js" hash="b3a489bd327120724dae7c177c45fd69"/></dir></dir><file name="captcha.js" hash="997a04b22dc43ec11d7268417d206b51"/><file name="centinel.js" hash="d075a88fa4ba8495692a63f535f4cbba"/><file name="cookies.js" hash="b6bd01414e9cd58410aa11c0415a3884"/><file name="directpost.js" hash="588b9fcae7ad1f7288245c2a2ad2bbbb"/><file name="translate.js" hash="dce2b661d6b0675c7474a431f0f5185f"/><file name="translate_inline.css" hash="1df877f84ffcfff5529f8b5b02b0768f"/><file name="translate_inline.js" hash="1b6ab25d6dd80ed93e4dafd44b3bf2b7"/></dir><dir name="varien"><file name="accordion.js" hash="6823368dbc5179d26de71e30191f4edc"/><file name="configurable.js" hash="00da2ece9e4fc6337d9fc89d62e109c6"/><file name="form.js" hash="b4842ad91d7717ab5d40012b4e5fcf14"/><file name="iehover-fix.js" hash="33e74ae53e94f614f23dbdd65a3066e2"/><file name="js.js" hash="365504893b4d855adb8be98e1dac09e8"/><file name="menu.js" hash="7b74f8382494b73951d667d11826ccda"/><file name="payment.js" hash="57714c8b509a5279293cb609a4ee72b6"/><file name="product.js" hash="b42952fdef14b8f0ef6ae786ffbf19c1"/><file name="product_options.js" hash="5ce9e7c61822c56a8148e3b94d527fc7"/><file name="telephone.js" hash="927282682aed203d711b14766d5ddafd"/><file name="weee.js" hash="fb7dffa37b206729b224ea5508395a86"/></dir><file name="blank.html" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="index.php" hash="80ad8e3ab73bcb13af1e8490f9d1637b"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><dir name="flash"><file name="AC_RunActiveContent.js" hash="3e038cea960c1b650442b85cea237053"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Mage-1.9.4.2.xml b/var/package/Lib_Js_Mage-1.9.4.2.xml
new file mode 100644
index 0000000..e0531dd
--- /dev/null
+++ b/var/package/Lib_Js_Mage-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Mage</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Javascript Libraries for Magento</summary>
+    <description>Javascript Libraries for Magento</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="lib"><file name="FABridge.js" hash="64244d8d58abd42bd71f0ee3309767ad"/><file name="boxover.js" hash="a5ade77452e8d5066cb84dcac3d34ed5"/><file name="ccard.js" hash="d3e849be0977d53de4af933b40293ff6"/><file name="dropdown.js" hash="d74331fd65500cd64785163be3a434e6"/><file name="ds-sleight.js" hash="85af457d444865d1587bfe4875bd4fc6"/><file name="flex.js" hash="f9d88fdfef8a3bed86df58ed37cab345"/><dir name="jquery"><file name="jquery-1.10.2.js" hash="91515770ce8c55de23b306444d8ea998"/><file name="jquery-1.10.2.min.js" hash="841dc30647f93349b7d8ef61deebe411"/><file name="jquery-1.10.2.min.map" hash="6c3ccfc221d36777d383b6e04d0b8af9"/><file name="jquery-1.12.1.js" hash="62f69d29b6f01c8d477a547cedd922f2"/><file name="jquery-1.12.1.min.js" hash="1d244cb043be8157f0050ce9e45c9ef2"/><file name="jquery-1.12.1.min.map" hash="7761e30c5da1bf6d7cebc61bf612cd0e"/><file name="noconflict.js" hash="eafadf93ad691e381b31c79222507a83"/></dir><dir name="uploader"><file name="flow.min.js" hash="a82a557db407b53d5909fa4e1833a596"/><file name="fusty-flow-factory.js" hash="b3f49be0f28be74e8b8bb76496c52bc3"/><file name="fusty-flow.js" hash="302f440908837093fd4e9b6e76ec01e0"/></dir></dir><dir name="mage"><dir name="adminhtml"><file name="accordion.js" hash="3aa37f15fffadff036e88674fcbba336"/><file name="backup.js" hash="a5d9b6f5613c1407d6e4a7a7951ace80"/><file name="browser.js" hash="4d317c43a354cf614c155536e0ce6186"/><file name="events.js" hash="6cf24a04511896958fafb2f51f9f2ead"/><file name="flexuploader.js" hash="db54e1f8de2e441716b7ea3e1c8f3e55"/><file name="form.js" hash="be6975ed85d5ccedf447bd620a52ce36"/><file name="giftmessage.js" hash="68687e12c1e297b6b1e370102ad213ef"/><dir name="giftoptions"><file name="tooltip.js" hash="ed97a2001cbe2e09720d1a96883dcb61"/></dir><file name="grid.js" hash="b01c7305db7f6eba4236a836b5e0004c"/><file name="hash.js" hash="02bc7053edc147185e4e8de7f935ab12"/><file name="image.js" hash="79bbb61c8ed6ebfe8b576358d8db0104"/><file name="loader.js" hash="66f7a49300e1ee0b00afb53b1f7a22bb"/><file name="magento-all.js" hash="21ba6e3e754f0a45440178ce81dd2604"/><dir name="product"><dir name="composite"><file name="configure.js" hash="310f5314b8dc7faa0be8e35e80cff7f4"/></dir></dir><file name="product.js" hash="38ffa4aa21de646b4f1acfc657a4cc68"/><file name="rules.js" hash="9cb6236e99586a32a4797ddd5ff14d40"/><dir name="sales"><file name="packaging.js" hash="4039a5cb08d716e88af502617111eacc"/></dir><file name="sales.js" hash="36e169d95a25c454f989ac10a0759153"/><file name="scrollbar.js" hash="111c61f0618cd2c5fab7a2bff60b27e7"/><file name="tabs.js" hash="c5b880d653923fe89a7c890cc48073e9"/><file name="tools.js" hash="9fdc751d2cdd5f299d44f0bbd72ae3ff"/><dir name="uploader"><file name="instance.js" hash="2a248014ba11ad618c407150c802bae9"/></dir><file name="uploader.js" hash="072d5070944ee0f95687ce3838ab61f9"/><file name="variables.js" hash="d6941a240dd440594cb8ca4f944840ba"/><dir name="wysiwyg"><dir name="tiny_mce"><dir name="plugins"><dir name="magentovariable"><file name="editor_plugin.js" hash="eea3b1037886236f0f307e80fb162409"/><dir name="img"><file name="icon.gif" hash="682b29a0e734f952cb2edabede6a25d1"/></dir></dir><dir name="magentowidget"><file name="editor_plugin.js" hash="ce29610466ae0718054f9e3defaf5acb"/><dir name="img"><file name="icon.gif" hash="532c141286373f098f1f4362e001c7f8"/></dir></dir></dir><file name="setup.js" hash="15d66288ec215c48ef7e5df216378d3a"/><dir name="themes"><dir name="advanced"><dir name="skins"><dir name="default"><file name="content.css" hash="f573fb8565f8da1b9a2a29dd887ddbc5"/><file name="dialog.css" hash="2aa257d84ac0fd6b8809eee27a7f4193"/></dir></dir></dir></dir></dir><file name="widget.js" hash="b3a489bd327120724dae7c177c45fd69"/></dir></dir><file name="captcha.js" hash="997a04b22dc43ec11d7268417d206b51"/><file name="centinel.js" hash="d075a88fa4ba8495692a63f535f4cbba"/><file name="cookies.js" hash="b6bd01414e9cd58410aa11c0415a3884"/><file name="directpost.js" hash="588b9fcae7ad1f7288245c2a2ad2bbbb"/><file name="translate.js" hash="dce2b661d6b0675c7474a431f0f5185f"/><file name="translate_inline.css" hash="1df877f84ffcfff5529f8b5b02b0768f"/><file name="translate_inline.js" hash="1b6ab25d6dd80ed93e4dafd44b3bf2b7"/></dir><dir name="varien"><file name="accordion.js" hash="6823368dbc5179d26de71e30191f4edc"/><file name="configurable.js" hash="00da2ece9e4fc6337d9fc89d62e109c6"/><file name="form.js" hash="b4842ad91d7717ab5d40012b4e5fcf14"/><file name="iehover-fix.js" hash="33e74ae53e94f614f23dbdd65a3066e2"/><file name="js.js" hash="b732ca3b2071dc4263534964532ad984"/><file name="menu.js" hash="7b74f8382494b73951d667d11826ccda"/><file name="payment.js" hash="57714c8b509a5279293cb609a4ee72b6"/><file name="product.js" hash="b42952fdef14b8f0ef6ae786ffbf19c1"/><file name="product_options.js" hash="5ce9e7c61822c56a8148e3b94d527fc7"/><file name="telephone.js" hash="927282682aed203d711b14766d5ddafd"/><file name="weee.js" hash="fb7dffa37b206729b224ea5508395a86"/></dir><file name="blank.html" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="index.php" hash="80ad8e3ab73bcb13af1e8490f9d1637b"/><file name="spacer.gif" hash="df3e567d6f16d040326c7a0ea29a4f41"/><dir name="flash"><file name="AC_RunActiveContent.js" hash="3e038cea960c1b650442b85cea237053"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_Prototype-1.9.4.1.xml b/var/package/Lib_Js_Prototype-1.9.4.1.xml
deleted file mode 100644
index 6237dc0..0000000
--- a/var/package/Lib_Js_Prototype-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_Prototype</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Prototype and Scriptaculous Javascript Libraries for Magento</summary>
-    <description>Prototype and Scriptaculous Javascript Libraries for Magento</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="prototype"><file name="debug.js" hash="d5990eabf728ade1f34496737455c8ff"/><file name="effects.js" hash="91e1b7d8c6043dff4eadbe054a90e3a7"/><file name="extended_debug.js" hash="cc706bc76bb1c5a2610fc296cd85e053"/><file name="prototype.js" hash="3b4b13dad33b475e11feb26fd3468ecc"/><file name="tooltip.js" hash="8509b04b1594b7e6382d7cfdf4ee1236"/><file name="tooltip_manager.js" hash="6b9759cbad296fda3c18d7669d6b5af0"/><file name="validation.js" hash="a841158a1143694d447cc78e1099b3c8"/><file name="window.js" hash="1ad7aab8deee02a99403dba716492e97"/><file name="window_effects.js" hash="3c0b47a0f3cd41753a3992d01c118c3d"/><file name="window_ext.js" hash="d5163111a6dc50d05cc3f98360855336"/><file name="window_readme.txt" hash="97306d2a8c4be2ec65f66d2ec233289c"/><dir name="windows"><file name="MIT-LICENSE" hash="a839f717f1675b571481268a4e4a4ee2"/><file name="README" hash="75b8b2e714cbcb48337540a451655967"/><dir name="themes"><dir name="alert"><file name="bottom.gif" hash="e859e3bc00c4f10360fa81a659aa673f"/><file name="bottom_left.gif" hash="53585b1a0351d599e76a85ccc26f7980"/><file name="bottom_right.gif" hash="8170abe3fec71fd17612869a2f036cd6"/><file name="left.gif" hash="4f235c4e6afb0d386d220638c49e4545"/><file name="overlay.png" hash="f4ddcee6f819975bc9c5643b570de6dc"/><file name="progress.gif" hash="86b1ac6d1c485d54efa3a53643e91ceb"/><file name="right.gif" hash="838ade41815529e7a63f99c93b3a01f7"/><file name="top.gif" hash="8702ca9b81c19f6220ce81c4ea215878"/><file name="top_left.gif" hash="a8c097bcb67bddf640c2bd9161b79476"/><file name="top_right.gif" hash="05ef4e1a417a5a2c81fc816406a4842a"/></dir><file name="alert.css" hash="27df86baae5a6fa2e3556bdf1b85ccc6"/><file name="alert_lite.css" hash="fbeaff8f185cd3b302f1a8db5efa0110"/><dir name="alphacube"><file name="bottom-left-c.gif" hash="434cdfc5298f33efb108264cf3370e1c"/><file name="bottom-middle.gif" hash="3f882dd32d57a29a785f448bbba5ed26"/><file name="bottom-right-c.gif" hash="4c37ad7b94fc901a1cfaf54a1742d5fd"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="1bb1207b43425d214d4dc0da108f5449"/><file name="frame-right.gif" hash="8b9c36079881aa15c27a137666c56a38"/><file name="left-top.gif" hash="1ea936a090b4dfe8160fcb3a90ddb145"/><file name="right-top.gif" hash="e1b641feab640cb4207fa52160715e32"/><file name="top-middle.gif" hash="7f94c1018d023832c7c9e1fa468a9555"/></dir><file name="alphacube.css" hash="27c968911eaef53df158c55083ef0c84"/><file name="behavior.htc" hash="5588dff36ad5595f8353730e853044e5"/><dir name="darkX"><file name="button-close-focused.png" hash="5090b529a86a79679e0a26ccb0e1b0c6"/><file name="button-maximize-focused.png" hash="0f84bfcc9626d2cb1826291268b29f20"/><file name="button-minimize-focused.png" hash="630cd8cdd7124d412c6253e5c7cfc32a"/><file name="frame-bottom-left-focused.png" hash="8a34a3be2f349315dfd287ec15148332"/><file name="frame-bottom-mid-focused.png" hash="f1dbacdb64a19e00a485d426126f26db"/><file name="frame-bottom-right-focused.png" hash="17acb7874856dc68c3c017238d42054a"/><file name="frame-left-focused.png" hash="f30ab13888b2e48d0637991164a8f748"/><file name="frame-right-focused.png" hash="1115115c62507971b2f5eed3c2c5c2d0"/><file name="titlebar-left-focused.png" hash="491130dedbdbb3b2682f37424347b14c"/><file name="titlebar-mid-focused.png" hash="ae46975fc8a5e5a9f73f810d0c88809a"/><file name="titlebar-right-focused.png" hash="9560eb10dee94985f3ebe935833e2ae4"/></dir><file name="darkX.css" hash="16a964cfe57a2c979ad3d97831673b79"/><file name="debug.css" hash="63ee9aa7b7d80e0bb5e311407746ccd3"/><dir name="default"><file name="bottom_left.gif" hash="fb99ffa815a8648f95f42698fe5dfaa1"/><file name="bottom_mid.gif" hash="49b9ca7025562ea7f070a9111282364b"/><file name="bottom_right.gif" hash="e46768f632765cd86c5fe5d0166dcf2c"/><file name="bottom_right_resize.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="center_left.gif" hash="bd567580b4ee16a7a2734057cfbbe219"/><file name="center_right.gif" hash="eef184d5d89d1710313581a2ccf408e8"/><file name="clear.gif" hash="7af1206eeb0e7834a75e69d70676060d"/><file name="close.gif" hash="8a08f243c37a8e25a88d4ac135b2f07d"/><file name="inspect.gif" hash="aa2a0961067aad5c54b8634919af863b"/><file name="maximize.gif" hash="e73cd71c4979ebeadeb9e27d40a9e8fb"/><file name="minimize.gif" hash="2d2f4b1bd0506f342425f80ab76c49a3"/><file name="overlay.png" hash="536d40e87cda0c7ae7b11f1721aa52d0"/><file name="resize.gif" hash="320f534b5d444b39701e0b679529e779"/><file name="sizer.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="top_left.gif" hash="9c5e5920bfc189a45cc618099af93aa8"/><file name="top_mid.gif" hash="a12ff2b944025ad2d127d033dae5e9e1"/><file name="top_right.gif" hash="0cf1ec5b93f8ac8fcce0e2f72cf7f45e"/></dir><file name="default.css" hash="16014098f441d12d06c088135e2fde28"/><dir name="iefix"><file name="blank.gif" hash="56398e76be6355ad5999b262208a17c9"/><file name="iepngfix.css" hash="da3154c9a817850376f73a7976bfcb13"/><file name="iepngfix.htc" hash="b50c4e352a64254c5ceb6c63bcd0b176"/></dir><dir name="lighting"><file name="background_buttons.gif" hash="e66e67aaaf08a7b24f3cd1ba22584b42"/><file name="bottom-left-blue.png" hash="7c9e91d421945141315fc105d464a99f"/><file name="bottom-left-darkblue.png" hash="e88c2380acf403ee28597c6045988cc6"/><file name="bottom-left-green.png" hash="ee25ce8a12229b009fbfd91f7ba51e26"/><file name="bottom-left-grey.png" hash="5fdb3eae397ac7279aa5a7fdaad3dcc2"/><file name="bottom-middle-blue.png" hash="e93cc9d31d88f45c047a98a66be04354"/><file name="bottom-middle-darkblue.png" hash="763c88c424e0900e675042d3f0958bd4"/><file name="bottom-middle-green.png" hash="77e0a22afd2c55a83b5c7fa98a12ef25"/><file name="bottom-middle-grey.png" hash="3a2ebdeff74e2ff63c4471575568dd01"/><file name="bottom-right-blue.png" hash="0bc11a61047e8716451a283ebff897e5"/><file name="bottom-right-darkblue.png" hash="88e33ea702a304ae237edd57bc8447d6"/><file name="bottom-right-green.png" hash="7bce162df013eba43a659ae6e780ae4b"/><file name="bottom-right-grey.png" hash="86eb476492d911aac5688c9747fe7a1d"/><file name="button-close-blue.png" hash="42ae1a35caf8a9a275d6e748c27769fb"/><file name="button-close-darkblue.png" hash="50dbcd898dc519c1e6ac0d3a478978cd"/><file name="button-close-green.png" hash="b4273572fa91cba909a0a3e15b994d19"/><file name="button-close-grey.png" hash="124964b634ba67f2bb6dd08cf8cafd5a"/><file name="button-maximize-blue.png" hash="85b79237d85b09c205e09166dd8f4af0"/><file name="button-maximize-darkblue.png" hash="108d10619214e3365820aa4ab008aed5"/><file name="button-maximize-green.png" hash="90f5527705e4fd81997564e81c6ac2a3"/><file name="button-maximize-grey.png" hash="c46a8c014bd14be167f4c6a2f2dd52ed"/><file name="button-minimize-blue.png" hash="1fd738b99877a4dfa5656491cc3d8e6b"/><file name="button-minimize-darkblue.png" hash="b6d9da1cdf51ab54682fa75a6df2c40d"/><file name="button-minimize-green.png" hash="9e7d26298a0a49ffee3fbab6ea838e01"/><file name="button-minimize-grey.png" hash="0432701c2425cb3a5143d8a04bda0d87"/><file name="left-blue.png" hash="0a6acf0a863c04845a93b681769527cd"/><file name="left-darkblue.png" hash="44cdce8a75de4425d7eb7763092cc38d"/><file name="left-green.png" hash="d83116c49d62dc46bff0b7b4200b4ecf"/><file name="left-grey.png" hash="f3486d3293ae98b5edb8889c4b4082ef"/><file name="pngbehavior.htc" hash="b94c44e30423fd18a8b82bda5a139db3"/><file name="right-blue.png" hash="2c9b6b80d4a6b190b8e38a1c101e828c"/><file name="right-darkblue.png" hash="9b3267c5d36bb3f4588167cc3e78e569"/><file name="right-green.png" hash="4436968c2adbe6ed7c475c225631bc7c"/><file name="right-grey.png" hash="36b3de47bcbbd6b53e2f6e06843ee6e8"/><file name="spinner.gif" hash="c7b3cbb3ec8249a7121b722cdd76b870"/><file name="top-left-blue.png" hash="a5cb9eaa82f67df223d6784a52b26f1f"/><file name="top-left-darkblue.png" hash="e4a3af23d2cae7909331eb1995963c82"/><file name="top-left-green.png" hash="eb4cb604177c342998023d3dcd3aa5b0"/><file name="top-left-grey.png" hash="9f6f39abc4ae9539a0f54567a4a5d4f8"/><file name="top-middle-blue.png" hash="6d01df8637385bbe592b8df369294c8d"/><file name="top-middle-darkblue.png" hash="2c91ea6462e72a29cd07300d4102b88a"/><file name="top-middle-green.png" hash="e0f56311091bfb370fc6783fc7e71068"/><file name="top-middle-grey.png" hash="8c02881b730d602589fe9ed4bcaeb689"/><file name="top-right-blue.png" hash="4afefb06dc63c864211724a6348f25ad"/><file name="top-right-darkblue.png" hash="d8a9031987f648f170af67023179618d"/><file name="top-right-green.png" hash="b38813f9200440051273bdd622f5e545"/><file name="top-right-grey.png" hash="d7f7332ddf8686fb9810e4170767bf52"/></dir><file name="lighting.css" hash="d13de730c8ee7ef04167d361bdf8eebd"/><file name="mac_os_x.css" hash="65204ef34c1eeff0be29c53b0614076a"/><file name="mac_os_x_dialog.css" hash="0b7cd9d6a9e8f940f50bc4a080f54b1b"/><dir name="nuncio"><file name="bottom_left.png" hash="d9be5c7b432a342c6da5ef9b10148267"/><file name="bottom_mid.png" hash="facee2e7ee7c572a8f412750b0ce5387"/><file name="bottom_right.png" hash="6f3c124a066a11ff225897112de8e9d7"/><file name="center_left.png" hash="a11bee83f99addccc0d5eff3d2e82b8f"/><file name="center_right.png" hash="bf6b023ad1751d5f60f9820eea72ac28"/><file name="close.png" hash="46744062a7b54416c8767f8e0ccf1c41"/><file name="minimize.png" hash="bc911a3e90fc0640e0899856759a5e01"/><file name="overlay.png" hash="5ccd88855e923eb8a1bd9da1dec9d7fe"/><file name="top_left.png" hash="d3105aacc2c69954df11af953875a12e"/><file name="top_mid.png" hash="cb679a8c77e9b7485b5f0eca547eb103"/><file name="top_right.png" hash="e65d6fc6bf53891c487e414db16f1038"/></dir><file name="nuncio.css" hash="e30e31b94d96b0b27c80ad6d943d7010"/><dir name="spread"><file name="bottom-left-c.gif" hash="84641d08576f68a11f717103365dfb83"/><file name="bottom-middle.gif" hash="20ab265c67355c5b72cdcdc8739af555"/><file name="bottom-right-c.gif" hash="cb27b72623e997badc599e76024a6e44"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="63dc99b0c4ba0518688f7eca1f1628ca"/><file name="frame-right.gif" hash="a03585eec830f37898c7041d557dafc5"/><file name="left-top.gif" hash="7c78b8b59976d19191acf940cbfc04fb"/><file name="right-top.gif" hash="597530287fe1dc491278f855749f7e01"/><file name="top-middle.gif" hash="fa6fd6b90945c47f8d1718d9139d0a75"/><file name=".gif" hash="9dd39829e7cfdd06f3317a931bdc177e"/></dir><file name="spread.css" hash="a804413d7f1f9550c134477f6f9219ee"/></dir></dir></dir><dir name="scriptaculous"><file name="builder.js" hash="1174f6fc34ca5d54ba10b0c719386e7c"/><file name="controls.js" hash="8c414e1787c0ac9f10b16b252361c8b2"/><file name="dragdrop.js" hash="046759400db7a6096376e50110104edd"/><file name="effects.js" hash="d795089f95a22306cca9b337c439c65a"/><file name="scriptaculous.js" hash="d59eba4e0b14b672208b0862ae1c2196"/><file name="slider.js" hash="6043f96a71d2685fecd02e2ab99e84d9"/><file name="sound.js" hash="0f0fab23fa2cb1bc7717fd2bdf45402e"/><file name="unittest.js" hash="99969698b22272f77bdf4c64586862b3"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_Prototype-1.9.4.2.xml b/var/package/Lib_Js_Prototype-1.9.4.2.xml
new file mode 100644
index 0000000..596e303
--- /dev/null
+++ b/var/package/Lib_Js_Prototype-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_Prototype</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Prototype and Scriptaculous Javascript Libraries for Magento</summary>
+    <description>Prototype and Scriptaculous Javascript Libraries for Magento</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="prototype"><file name="debug.js" hash="d5990eabf728ade1f34496737455c8ff"/><file name="effects.js" hash="91e1b7d8c6043dff4eadbe054a90e3a7"/><file name="extended_debug.js" hash="cc706bc76bb1c5a2610fc296cd85e053"/><file name="prototype.js" hash="3b4b13dad33b475e11feb26fd3468ecc"/><file name="tooltip.js" hash="8509b04b1594b7e6382d7cfdf4ee1236"/><file name="tooltip_manager.js" hash="6b9759cbad296fda3c18d7669d6b5af0"/><file name="validation.js" hash="a841158a1143694d447cc78e1099b3c8"/><file name="window.js" hash="1ad7aab8deee02a99403dba716492e97"/><file name="window_effects.js" hash="3c0b47a0f3cd41753a3992d01c118c3d"/><file name="window_ext.js" hash="d5163111a6dc50d05cc3f98360855336"/><file name="window_readme.txt" hash="97306d2a8c4be2ec65f66d2ec233289c"/><dir name="windows"><file name="MIT-LICENSE" hash="a839f717f1675b571481268a4e4a4ee2"/><file name="README" hash="75b8b2e714cbcb48337540a451655967"/><dir name="themes"><dir name="alert"><file name="bottom.gif" hash="e859e3bc00c4f10360fa81a659aa673f"/><file name="bottom_left.gif" hash="53585b1a0351d599e76a85ccc26f7980"/><file name="bottom_right.gif" hash="8170abe3fec71fd17612869a2f036cd6"/><file name="left.gif" hash="4f235c4e6afb0d386d220638c49e4545"/><file name="overlay.png" hash="f4ddcee6f819975bc9c5643b570de6dc"/><file name="progress.gif" hash="86b1ac6d1c485d54efa3a53643e91ceb"/><file name="right.gif" hash="838ade41815529e7a63f99c93b3a01f7"/><file name="top.gif" hash="8702ca9b81c19f6220ce81c4ea215878"/><file name="top_left.gif" hash="a8c097bcb67bddf640c2bd9161b79476"/><file name="top_right.gif" hash="05ef4e1a417a5a2c81fc816406a4842a"/></dir><file name="alert.css" hash="27df86baae5a6fa2e3556bdf1b85ccc6"/><file name="alert_lite.css" hash="fbeaff8f185cd3b302f1a8db5efa0110"/><dir name="alphacube"><file name="bottom-left-c.gif" hash="434cdfc5298f33efb108264cf3370e1c"/><file name="bottom-middle.gif" hash="3f882dd32d57a29a785f448bbba5ed26"/><file name="bottom-right-c.gif" hash="4c37ad7b94fc901a1cfaf54a1742d5fd"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="1bb1207b43425d214d4dc0da108f5449"/><file name="frame-right.gif" hash="8b9c36079881aa15c27a137666c56a38"/><file name="left-top.gif" hash="1ea936a090b4dfe8160fcb3a90ddb145"/><file name="right-top.gif" hash="e1b641feab640cb4207fa52160715e32"/><file name="top-middle.gif" hash="7f94c1018d023832c7c9e1fa468a9555"/></dir><file name="alphacube.css" hash="27c968911eaef53df158c55083ef0c84"/><file name="behavior.htc" hash="5588dff36ad5595f8353730e853044e5"/><dir name="darkX"><file name="button-close-focused.png" hash="5090b529a86a79679e0a26ccb0e1b0c6"/><file name="button-maximize-focused.png" hash="0f84bfcc9626d2cb1826291268b29f20"/><file name="button-minimize-focused.png" hash="630cd8cdd7124d412c6253e5c7cfc32a"/><file name="frame-bottom-left-focused.png" hash="8a34a3be2f349315dfd287ec15148332"/><file name="frame-bottom-mid-focused.png" hash="f1dbacdb64a19e00a485d426126f26db"/><file name="frame-bottom-right-focused.png" hash="17acb7874856dc68c3c017238d42054a"/><file name="frame-left-focused.png" hash="f30ab13888b2e48d0637991164a8f748"/><file name="frame-right-focused.png" hash="1115115c62507971b2f5eed3c2c5c2d0"/><file name="titlebar-left-focused.png" hash="491130dedbdbb3b2682f37424347b14c"/><file name="titlebar-mid-focused.png" hash="ae46975fc8a5e5a9f73f810d0c88809a"/><file name="titlebar-right-focused.png" hash="9560eb10dee94985f3ebe935833e2ae4"/></dir><file name="darkX.css" hash="16a964cfe57a2c979ad3d97831673b79"/><file name="debug.css" hash="63ee9aa7b7d80e0bb5e311407746ccd3"/><dir name="default"><file name="bottom_left.gif" hash="fb99ffa815a8648f95f42698fe5dfaa1"/><file name="bottom_mid.gif" hash="49b9ca7025562ea7f070a9111282364b"/><file name="bottom_right.gif" hash="e46768f632765cd86c5fe5d0166dcf2c"/><file name="bottom_right_resize.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="center_left.gif" hash="bd567580b4ee16a7a2734057cfbbe219"/><file name="center_right.gif" hash="eef184d5d89d1710313581a2ccf408e8"/><file name="clear.gif" hash="7af1206eeb0e7834a75e69d70676060d"/><file name="close.gif" hash="8a08f243c37a8e25a88d4ac135b2f07d"/><file name="inspect.gif" hash="aa2a0961067aad5c54b8634919af863b"/><file name="maximize.gif" hash="e73cd71c4979ebeadeb9e27d40a9e8fb"/><file name="minimize.gif" hash="2d2f4b1bd0506f342425f80ab76c49a3"/><file name="overlay.png" hash="536d40e87cda0c7ae7b11f1721aa52d0"/><file name="resize.gif" hash="320f534b5d444b39701e0b679529e779"/><file name="sizer.gif" hash="1b35a4ec3b734dfe37e31ba87bcc7d99"/><file name="top_left.gif" hash="9c5e5920bfc189a45cc618099af93aa8"/><file name="top_mid.gif" hash="a12ff2b944025ad2d127d033dae5e9e1"/><file name="top_right.gif" hash="0cf1ec5b93f8ac8fcce0e2f72cf7f45e"/></dir><file name="default.css" hash="16014098f441d12d06c088135e2fde28"/><dir name="iefix"><file name="blank.gif" hash="56398e76be6355ad5999b262208a17c9"/><file name="iepngfix.css" hash="da3154c9a817850376f73a7976bfcb13"/><file name="iepngfix.htc" hash="b50c4e352a64254c5ceb6c63bcd0b176"/></dir><dir name="lighting"><file name="background_buttons.gif" hash="e66e67aaaf08a7b24f3cd1ba22584b42"/><file name="bottom-left-blue.png" hash="7c9e91d421945141315fc105d464a99f"/><file name="bottom-left-darkblue.png" hash="e88c2380acf403ee28597c6045988cc6"/><file name="bottom-left-green.png" hash="ee25ce8a12229b009fbfd91f7ba51e26"/><file name="bottom-left-grey.png" hash="5fdb3eae397ac7279aa5a7fdaad3dcc2"/><file name="bottom-middle-blue.png" hash="e93cc9d31d88f45c047a98a66be04354"/><file name="bottom-middle-darkblue.png" hash="763c88c424e0900e675042d3f0958bd4"/><file name="bottom-middle-green.png" hash="77e0a22afd2c55a83b5c7fa98a12ef25"/><file name="bottom-middle-grey.png" hash="3a2ebdeff74e2ff63c4471575568dd01"/><file name="bottom-right-blue.png" hash="0bc11a61047e8716451a283ebff897e5"/><file name="bottom-right-darkblue.png" hash="88e33ea702a304ae237edd57bc8447d6"/><file name="bottom-right-green.png" hash="7bce162df013eba43a659ae6e780ae4b"/><file name="bottom-right-grey.png" hash="86eb476492d911aac5688c9747fe7a1d"/><file name="button-close-blue.png" hash="42ae1a35caf8a9a275d6e748c27769fb"/><file name="button-close-darkblue.png" hash="50dbcd898dc519c1e6ac0d3a478978cd"/><file name="button-close-green.png" hash="b4273572fa91cba909a0a3e15b994d19"/><file name="button-close-grey.png" hash="124964b634ba67f2bb6dd08cf8cafd5a"/><file name="button-maximize-blue.png" hash="85b79237d85b09c205e09166dd8f4af0"/><file name="button-maximize-darkblue.png" hash="108d10619214e3365820aa4ab008aed5"/><file name="button-maximize-green.png" hash="90f5527705e4fd81997564e81c6ac2a3"/><file name="button-maximize-grey.png" hash="c46a8c014bd14be167f4c6a2f2dd52ed"/><file name="button-minimize-blue.png" hash="1fd738b99877a4dfa5656491cc3d8e6b"/><file name="button-minimize-darkblue.png" hash="b6d9da1cdf51ab54682fa75a6df2c40d"/><file name="button-minimize-green.png" hash="9e7d26298a0a49ffee3fbab6ea838e01"/><file name="button-minimize-grey.png" hash="0432701c2425cb3a5143d8a04bda0d87"/><file name="left-blue.png" hash="0a6acf0a863c04845a93b681769527cd"/><file name="left-darkblue.png" hash="44cdce8a75de4425d7eb7763092cc38d"/><file name="left-green.png" hash="d83116c49d62dc46bff0b7b4200b4ecf"/><file name="left-grey.png" hash="f3486d3293ae98b5edb8889c4b4082ef"/><file name="pngbehavior.htc" hash="b94c44e30423fd18a8b82bda5a139db3"/><file name="right-blue.png" hash="2c9b6b80d4a6b190b8e38a1c101e828c"/><file name="right-darkblue.png" hash="9b3267c5d36bb3f4588167cc3e78e569"/><file name="right-green.png" hash="4436968c2adbe6ed7c475c225631bc7c"/><file name="right-grey.png" hash="36b3de47bcbbd6b53e2f6e06843ee6e8"/><file name="spinner.gif" hash="c7b3cbb3ec8249a7121b722cdd76b870"/><file name="top-left-blue.png" hash="a5cb9eaa82f67df223d6784a52b26f1f"/><file name="top-left-darkblue.png" hash="e4a3af23d2cae7909331eb1995963c82"/><file name="top-left-green.png" hash="eb4cb604177c342998023d3dcd3aa5b0"/><file name="top-left-grey.png" hash="9f6f39abc4ae9539a0f54567a4a5d4f8"/><file name="top-middle-blue.png" hash="6d01df8637385bbe592b8df369294c8d"/><file name="top-middle-darkblue.png" hash="2c91ea6462e72a29cd07300d4102b88a"/><file name="top-middle-green.png" hash="e0f56311091bfb370fc6783fc7e71068"/><file name="top-middle-grey.png" hash="8c02881b730d602589fe9ed4bcaeb689"/><file name="top-right-blue.png" hash="4afefb06dc63c864211724a6348f25ad"/><file name="top-right-darkblue.png" hash="d8a9031987f648f170af67023179618d"/><file name="top-right-green.png" hash="b38813f9200440051273bdd622f5e545"/><file name="top-right-grey.png" hash="d7f7332ddf8686fb9810e4170767bf52"/></dir><file name="lighting.css" hash="d13de730c8ee7ef04167d361bdf8eebd"/><file name="mac_os_x.css" hash="65204ef34c1eeff0be29c53b0614076a"/><file name="mac_os_x_dialog.css" hash="0b7cd9d6a9e8f940f50bc4a080f54b1b"/><dir name="nuncio"><file name="bottom_left.png" hash="d9be5c7b432a342c6da5ef9b10148267"/><file name="bottom_mid.png" hash="facee2e7ee7c572a8f412750b0ce5387"/><file name="bottom_right.png" hash="6f3c124a066a11ff225897112de8e9d7"/><file name="center_left.png" hash="a11bee83f99addccc0d5eff3d2e82b8f"/><file name="center_right.png" hash="bf6b023ad1751d5f60f9820eea72ac28"/><file name="close.png" hash="46744062a7b54416c8767f8e0ccf1c41"/><file name="minimize.png" hash="bc911a3e90fc0640e0899856759a5e01"/><file name="overlay.png" hash="5ccd88855e923eb8a1bd9da1dec9d7fe"/><file name="top_left.png" hash="d3105aacc2c69954df11af953875a12e"/><file name="top_mid.png" hash="cb679a8c77e9b7485b5f0eca547eb103"/><file name="top_right.png" hash="e65d6fc6bf53891c487e414db16f1038"/></dir><file name="nuncio.css" hash="e30e31b94d96b0b27c80ad6d943d7010"/><dir name="spread"><file name="bottom-left-c.gif" hash="84641d08576f68a11f717103365dfb83"/><file name="bottom-middle.gif" hash="20ab265c67355c5b72cdcdc8739af555"/><file name="bottom-right-c.gif" hash="cb27b72623e997badc599e76024a6e44"/><file name="button-close-focus.gif" hash="99c44a6df2733b58083af7a4d9522116"/><file name="button-max-focus.gif" hash="408cd33fa89269b8395bf10afe69d456"/><file name="button-min-focus.gif" hash="ae06210658bad8bcc88dea377c4dc908"/><file name="frame-left.gif" hash="63dc99b0c4ba0518688f7eca1f1628ca"/><file name="frame-right.gif" hash="a03585eec830f37898c7041d557dafc5"/><file name="left-top.gif" hash="7c78b8b59976d19191acf940cbfc04fb"/><file name="right-top.gif" hash="597530287fe1dc491278f855749f7e01"/><file name="top-middle.gif" hash="fa6fd6b90945c47f8d1718d9139d0a75"/><file name=".gif" hash="9dd39829e7cfdd06f3317a931bdc177e"/></dir><file name="spread.css" hash="a804413d7f1f9550c134477f6f9219ee"/></dir></dir></dir><dir name="scriptaculous"><file name="builder.js" hash="1174f6fc34ca5d54ba10b0c719386e7c"/><file name="controls.js" hash="8c414e1787c0ac9f10b16b252361c8b2"/><file name="dragdrop.js" hash="046759400db7a6096376e50110104edd"/><file name="effects.js" hash="d795089f95a22306cca9b337c439c65a"/><file name="scriptaculous.js" hash="d59eba4e0b14b672208b0862ae1c2196"/><file name="slider.js" hash="6043f96a71d2685fecd02e2ab99e84d9"/><file name="sound.js" hash="0f0fab23fa2cb1bc7717fd2bdf45402e"/><file name="unittest.js" hash="99969698b22272f77bdf4c64586862b3"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Js_TinyMCE-3.5.11.17.xml b/var/package/Lib_Js_TinyMCE-3.5.11.17.xml
deleted file mode 100644
index 57e52ee..0000000
--- a/var/package/Lib_Js_TinyMCE-3.5.11.17.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Js_TinyMCE</name>
-    <version>3.5.11.17</version>
-    <stability>stable</stability>
-    <license>Mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>TinyMCE Javascript Libraries for Magento</summary>
-    <description>TinyMCE Javascript Libraries for Magento</description>
-    <notes>3.5.11.17</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:42</time>
-    <contents><target name="mageweb"><dir name="js"><dir name="tiny_mce"><dir name="classes"><file name="AddOnManager.js" hash="394e98bc019eb5c08c657fe4f8a48546"/><file name="ControlManager.js" hash="26cedc474b183b1a9905cdb3d10254dc"/><file name="Editor.Events.js" hash="07af3e1a08aead0078eb0cd6b030b864"/><file name="Editor.js" hash="e921b224172fbe2bd134eaab1974f2e8"/><file name="EditorCommands.js" hash="18b0d752aafddca09cf59fa7cc4d45c2"/><file name="EditorManager.js" hash="68b7a4a6252ab8b326fa5c8ee52d8016"/><file name="EnterKey.js" hash="ecc48ccb75c80dca2bd6bd7023fc906e"/><file name="ForceBlocks.js" hash="186ad2042e7b9416d2c4f9ec5f519893"/><file name="Formatter.js" hash="413f6c83f256d864a01e05718fbe7ce6"/><file name="LegacyInput.js" hash="a14c5e4099e2e4cbc6339eb54d3ec8f9"/><file name="Popup.js" hash="b6775a0e19bd839625b4dfb6b92a9688"/><file name="UndoManager.js" hash="276955286b65fba55ee60833ca2d6671"/><file name="WindowManager.js" hash="794c3d88226e8b62eac09eeeef283c3b"/><dir name="adapter"><dir name="jquery"><file name="adapter.js" hash="a5eea8e2826d7b0929291aa7a927ec29"/><file name="jquery.tinymce.js" hash="f2f319f369a84757b8976c2d66872933"/></dir><dir name="prototype"><file name="adapter.js" hash="37d84615944f028635f68d05b889c5c2"/></dir></dir><dir name="dom"><file name="DOMUtils.js" hash="bb9a7c2b19ad2433c85984cb8511e085"/><file name="Element.js" hash="1208e71eb2bc8e578b5a9cb4ec3b1365"/><file name="EventUtils.js" hash="652351eaf41de2659cfc7e380b694c02"/><file name="Range.js" hash="05c8ac178fa799217f60ebb650b41e0f"/><file name="RangeUtils.js" hash="9948e6204548089899b1e325370355f1"/><file name="ScriptLoader.js" hash="742ce02734095db354ad54ab8399a0ee"/><file name="Selection.js" hash="3332b2293dfc2a93fdb6a67ce5329642"/><file name="Serializer.js" hash="8762f4920ed6d4a57203bfbb8bc8490c"/><file name="Sizzle.js" hash="7930b22f632c7b0240237df1393e5023"/><file name="TreeWalker.js" hash="55425ece6675a529525bad45c6acbd94"/><file name="TridentSelection.js" hash="1fd402d1bb8144fa8549031b5f061733"/></dir><dir name="firebug"><file name="FIREBUG.LICENSE" hash="3b402ea96cec202bac23ea7144653cfa"/><file name="firebug-lite.js" hash="1c9c10926be94a61564ad0541a50624f"/></dir><dir name="html"><file name="DomParser.js" hash="25a47241e40445f2870bc94ce6a10b3c"/><file name="Entities.js" hash="7292e9f893096fb66d3232920be3c3d9"/><file name="Node.js" hash="ea0a5b87b71760018a753eb41a4e0f48"/><file name="SaxParser.js" hash="6dbb27c6762a5f27a9e6e844391393f4"/><file name="Schema.js" hash="e4d6e60fbca99911660f272717b9c08b"/><file name="Serializer.js" hash="ab74a79798a6f20f4267e3f1da17f2da"/><file name="Styles.js" hash="72317437bb3c7f0a05302658ea19dfce"/><file name="Writer.js" hash="3a2e8b824b749c19c5f27f8c830f95a5"/></dir><file name="tinymce.js" hash="546ec1f2bbfbf1ee04b4a33dcc05bc52"/><dir name="ui"><file name="Button.js" hash="82e9cd9d322a714652b0bc8e40e7e503"/><file name="ColorSplitButton.js" hash="06760a696b922b56a482f5889407714e"/><file name="Container.js" hash="7929a5d6aef46380197061e49e4f9dfb"/><file name="Control.js" hash="460a997aaad3b1b24f684bfdbefd3d9c"/><file name="DropMenu.js" hash="3359b973c857ca38105eeb276119b99f"/><file name="KeyboardNavigation.js" hash="f446fdfbadd728e8b009dc4adfc0b0d2"/><file name="ListBox.js" hash="2cd7287ec70ac87cb3903ecf0a2ccfdc"/><file name="Menu.js" hash="02762fee614d37aaea7eaf14f07dece1"/><file name="MenuButton.js" hash="fb0251eb52a5b3779d76ed2c2f8ec77e"/><file name="MenuItem.js" hash="55d400a161aa44d9dd5334d6f58ed956"/><file name="NativeListBox.js" hash="964785fd8a23be00b6db650f96e9ebf7"/><file name="Separator.js" hash="d4c5d779114617360ea78a2c0d523c81"/><file name="SplitButton.js" hash="e78e53578280cce9d97f936a82eca6de"/><file name="Toolbar.js" hash="b742f894f63122c4ee635fa59958167d"/><file name="ToolbarGroup.js" hash="db7b059b984e114ea22b1dc558d3d1f2"/></dir><dir name="util"><file name="Cookie.js" hash="14bc612b28c3c75549138a1699d5c238"/><file name="Dispatcher.js" hash="bf9bd51bbabca1823634833b3b16097c"/><file name="JSON.js" hash="b9b5964dbcd4cff962264dd72d8e4df5"/><file name="JSONP.js" hash="0a39d9e1b8427ab8b6dbdd00177c8c48"/><file name="JSONRequest.js" hash="dd12f1ac5c78ec4ba7459fb825ff9e5e"/><file name="Quirks.js" hash="927b518cc3aa663a41921590d0d3b4ac"/><file name="URI.js" hash="7069a8a2dfa4b0315719778b8c744139"/><file name="VK.js" hash="78114029ce46d5a4a441b01c44f23b4f"/><file name="XHR.js" hash="b00450d636335e7be50d46d2c31cc5a0"/></dir><dir name="xml"><file name="Parser.js" hash="c6d6862014ef2ab23a5a16adaee1af6d"/></dir></dir><file name="jquery.tinymce.js" hash="751418d46d453e7c6b1a7fbd4e60fefa"/><dir name="langs"><file name="en.js" hash="eff36a9433bccea2f3243b1465fe6fe3"/></dir><file name="license.txt" hash="b238d032089de4c340f6e0119210ce3a"/><dir name="plugins"><dir name="advhr"><dir name="css"><file name="advhr.css" hash="15df80b2137bcc04d5455ffa3a51e0c5"/></dir><file name="editor_plugin.js" hash="d0a03059205455e5c19cf3a845a0ebde"/><file name="editor_plugin_src.js" hash="a7fda2e674f15a33baf53cea2e23ec66"/><dir name="js"><file name="rule.js" hash="ef46d7c850c8bcc869ea84ed7ac00c49"/></dir><dir name="langs"><file name="en_dlg.js" hash="af62ab3f1b7a27190f8e001c8aefdfa6"/></dir><file name="rule.htm" hash="492ebbdc24d46061e928d911873d5fc8"/></dir><dir name="advimage"><dir name="css"><file name="advimage.css" hash="1ccd374d5f1e89cc16e1649558a9bb33"/></dir><file name="editor_plugin.js" hash="8af1f904909820d132bc0cbeb6469130"/><file name="editor_plugin_src.js" hash="958a409150fba5532d27e862d52015e9"/><file name="image.htm" hash="0d204c8f7651c3080ab542fb36957881"/><dir name="img"><file name="sample.gif" hash="b9c7057c46716340e8967340ad11766e"/></dir><dir name="js"><file name="image.js" hash="d071360a06b4f8590b4b18a7eca039aa"/></dir><dir name="langs"><file name="en_dlg.js" hash="6f80f834e2209e6a95957403bb4842f0"/></dir></dir><dir name="advlink"><dir name="css"><file name="advlink.css" hash="aaf226732a7b4ae80ee680700f488a1e"/></dir><file name="editor_plugin.js" hash="5e440c6bcb7fd94e7fd597f8a183e16f"/><file name="editor_plugin_src.js" hash="4104cd66aea546becf5d8fca66cf7951"/><dir name="js"><file name="advlink.js" hash="80dd2f99418025b6f9fd757adfdb1a71"/></dir><dir name="langs"><file name="en_dlg.js" hash="8da3a95d6886837c0bca18670f57ae1c"/></dir><file name="link.htm" hash="206ef7aba261ac4bc14e7c6fdbdcc8c5"/></dir><dir name="advlist"><file name="editor_plugin.js" hash="5f1c8625c04a6b0f4567c1c8d5e28ff9"/><file name="editor_plugin_src.js" hash="d451908bf1e060ecd49356787f33fc7c"/></dir><dir name="autolink"><file name="editor_plugin.js" hash="5091233229ffe517f075b787c5f388a6"/><file name="editor_plugin_src.js" hash="f03a8ec9ad17bd53f897a525e3cc30f7"/></dir><dir name="autoresize"><file name="editor_plugin.js" hash="adf5cbe96119e3ed9ab4a86ba26405e7"/><file name="editor_plugin_src.js" hash="4d1cdbe307f73b4d36d1bf9b3bc2d0a9"/></dir><dir name="autosave"><file name="editor_plugin.js" hash="ae4c2aba85a22da66e3655f55d1c89fd"/><file name="editor_plugin_src.js" hash="6177147324865c00736c242b8ccb2de6"/><dir name="langs"><file name="en.js" hash="a33b0322c949a6d74bde7fa164396984"/></dir></dir><dir name="bbcode"><file name="editor_plugin.js" hash="31748a6cc57a13da54a0243c3301f3e6"/><file name="editor_plugin_src.js" hash="842450703b915245adb53df7d478ea5a"/></dir><dir name="contextmenu"><file name="editor_plugin.js" hash="5a0fc9ce2ba71bf2b6f54eb94838619f"/><file name="editor_plugin_src.js" hash="b923e4315f2d98703bbe9699465f84f0"/></dir><dir name="directionality"><file name="editor_plugin.js" hash="e2d925fe1e778dbcade06d55164fc276"/><file name="editor_plugin_src.js" hash="14b7a5b69fdc4f235b654436e4fe3081"/></dir><dir name="emotions"><file name="editor_plugin.js" hash="98cba02e33fc108024f3e993be0b0b62"/><file name="editor_plugin_src.js" hash="4cbc6e9b083a810ab0d3768af8f8f864"/><file name="emotions.htm" hash="9378bfd04b56a828318f7798f5696f67"/><dir name="img"><file name="smiley-cool.gif" hash="e26e97a318f82ec144b0818e5a8f8edb"/><file name="smiley-cry.gif" hash="e72bf995ceca9230273ed9909c5db9c8"/><file name="smiley-embarassed.gif" hash="d59171236e6b0b96091eeda1f7b57ce3"/><file name="smiley-foot-in-mouth.gif" hash="c12d9db6a14ad0b52f66f1e2cf2a38e7"/><file name="smiley-frown.gif" hash="59930208822fe755f651a67ef4b70530"/><file name="smiley-innocent.gif" hash="ec0477c8a206ff250782e40f9bae4b4c"/><file name="smiley-kiss.gif" hash="4ae8945f3960751b5d294f18242e144d"/><file name="smiley-laughing.gif" hash="c37f405db4e13cbebf24e745534687bf"/><file name="smiley-money-mouth.gif" hash="11c14bd1496afd0e21df115d25b68e96"/><file name="smiley-sealed.gif" hash="bb828cb46b377d1589927a02f8fd1762"/><file name="smiley-smile.gif" hash="2968a664098d9580079c66d628dad1a8"/><file name="smiley-surprised.gif" hash="2e136ebd637bf3e6c9fc6bdc20cbe73e"/><file name="smiley-tongue-out.gif" hash="5ec3bb4781c8e43a51d3a1a948b98fc0"/><file name="smiley-undecided.gif" hash="3c0c011d16b1a2331385ed97e160a42a"/><file name="smiley-wink.gif" hash="897275ac7d07032b4d93fb83a0d2a41b"/><file name="smiley-yell.gif" hash="19bb8ebfe3c2f5ef3ffb9aa4a027900d"/></dir><dir name="js"><file name="emotions.js" hash="85efe828d29037950412fec963b6f950"/></dir><dir name="langs"><file name="en_dlg.js" hash="62c052504a77e4f4cec6d90ece0d76c4"/></dir></dir><dir name="example"><file name="dialog.htm" hash="e6170a190a4d44ea5e6af089d2728d7e"/><file name="editor_plugin.js" hash="e0a175dca3d5e437657ccd5d548ff409"/><file name="editor_plugin_src.js" hash="b98bec73743c249187e0fa8f8311e3a3"/><dir name="img"><file name="example.gif" hash="6036655a01df362267183a8b23fead10"/></dir><dir name="js"><file name="dialog.js" hash="83245e76c97e24d466cf5df2308f9bf4"/></dir><dir name="langs"><file name="en.js" hash="78c88182b5fb900fc956845f75885b3a"/><file name="en_dlg.js" hash="7aec7a3b9d4642fbf7bb3ef1ed8a7570"/></dir></dir><dir name="example_dependency"><file name="editor_plugin.js" hash="405d190ae03384a9acb00533568b2cfd"/><file name="editor_plugin_src.js" hash="473878118b45efe326d335f992ff9943"/></dir><dir name="fullpage"><dir name="css"><file name="fullpage.css" hash="2ac64c98369f8b4f7cbf6fa70e25bfca"/></dir><file name="editor_plugin.js" hash="5dfbe0a82c87eb0fb65b11dcd39406d0"/><file name="editor_plugin_src.js" hash="636afe66f3de447eb92611bdcfb7f2b3"/><file name="fullpage.htm" hash="8c58825b698712e7297f95da51a9c03c"/><dir name="js"><file name="fullpage.js" hash="a7913b6b1a1ae634a509c3db9faf381a"/></dir><dir name="langs"><file name="en_dlg.js" hash="963f370d56f19c2f94de09b10a306187"/></dir></dir><dir name="fullscreen"><file name="editor_plugin.js" hash="15134339e36472281b8a1626233f747d"/><file name="editor_plugin_src.js" hash="a28a8a8bf569d6ee5e6dccbc988490ce"/><file name="fullscreen.htm" hash="b6d76297c2f679b9110ec7119d091900"/></dir><dir name="iespell"><file name="editor_plugin.js" hash="22526393cacb6447a0e3bfff2fb47773"/><file name="editor_plugin_src.js" hash="311e13bcc85c06da43decc37dc1b4f83"/></dir><dir name="inlinepopups"><file name="editor_plugin.js" hash="db32751b98f40ca6eee24efc848d6cbb"/><file name="editor_plugin_src.js" hash="d1c1de414c13fef3593ffd14503d37c0"/><dir name="skins"><dir name="clearlooks2"><dir name="img"><file name="alert.gif" hash="568d4cf84413656fb72fe39d1dd60f8d"/><file name="button.gif" hash="19f864cb81177840dcd534df4d537ea3"/><file name="buttons.gif" hash="1743ac9f7f2267a6edafefc536a2265d"/><file name="confirm.gif" hash="1bc337a20c319e531cda6ced531827d0"/><file name="corners.gif" hash="55298b5baaecb7e06a251db9f0a4b14c"/><file name="horizontal.gif" hash="0365e75dd4a9ad61dc98dcb641207c21"/><file name="vertical.gif" hash="0261136fac58ce77bdbd96aa0194947e"/></dir><file name="window.css" hash="f715affab9da63bc26f8c6362a989395"/></dir></dir><file name="template.htm" hash="3d7e3ae05511a9f64c5da924b9e971ba"/></dir><dir name="insertdatetime"><file name="editor_plugin.js" hash="d99072498466cdb2f53ed7c02da85982"/><file name="editor_plugin_src.js" hash="32a2afa1cd3ff8c9b966f8724ba3e0b3"/></dir><dir name="layer"><file name="editor_plugin.js" hash="4e5fc1b467c19d79dcf6246ba3a63cd8"/><file name="editor_plugin_src.js" hash="3754eb57b08539e459509caa74acecc6"/></dir><dir name="legacyoutput"><file name="editor_plugin.js" hash="b732a86187723cd9cc32853d67730061"/><file name="editor_plugin_src.js" hash="8a0a69cbe8d447d722aaef7d4ed7dcc1"/></dir><dir name="lists"><file name="editor_plugin.js" hash="46ba57884d8fe05d92cd9d98d3bb00af"/><file name="editor_plugin_src.js" hash="04e1f245c19d6dc9454dae57faec9b6f"/></dir><dir name="media"><dir name="css"><file name="media.css" hash="f211293a697a2c83da00effd67f535a2"/></dir><file name="editor_plugin.js" hash="5ad7db86c5008f98ec135595db4a4973"/><file name="editor_plugin_src.js" hash="1d03ec1ec36745041db26132b07b0491"/><dir name="img"><file name="flash.gif" hash="6c69b02015d09280332ff8b07e4ea2f3"/><file name="quicktime.gif" hash="9a6a9fdead205b125c07ea37e71ed4f1"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="baa643b587565755157618032dc93e3c"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/><file name="media.js" hash="4f35c0283a30f3556e023e76c34368b2"/></dir><dir name="langs"><file name="en_dlg.js" hash="9523fc123c577642000fd409bd862c3f"/></dir><file name="media.htm" hash="be58b1edf9a4a4dbf3a1993e3d897e1a"/><file name="moxieplayer.swf" hash="9217cea72c76c361fa5033526712284e"/><file name=".htaccess" hash="9f2e3ee0d6e50d80819eb8c0300a0913"/></dir><dir name="nonbreaking"><file name="editor_plugin.js" hash="232f23a586f10bd8ddabf38d767113d4"/><file name="editor_plugin_src.js" hash="fefbda5243d10652038ccf40801b8893"/></dir><dir name="noneditable"><file name="editor_plugin.js" hash="b332a5f8767506024a0f50aa4204b1fe"/><file name="editor_plugin_src.js" hash="273d35e2221889e75f33fd545f77d44e"/></dir><dir name="pagebreak"><dir name="css"><file name="content.css" hash="d9664762a610f2b5f7b10b5781f3299a"/></dir><file name="editor_plugin.js" hash="8be3376740c886fa2842d2f4eb282bbc"/><file name="editor_plugin_src.js" hash="c2d432a5914f0095a859ff443700a5e9"/><dir name="img"><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/></dir></dir><dir name="paste"><file name="editor_plugin.js" hash="1b68c59eb95a28ccc2aff2cfb85a8829"/><file name="editor_plugin_src.js" hash="40eef37ac300b571da5383bc0bddf73f"/><dir name="js"><file name="pastetext.js" hash="d6e4b39f19b89118b34b0d21491494b7"/><file name="pasteword.js" hash="112504d12e971e4d32f17a59c5616c36"/></dir><dir name="langs"><file name="en_dlg.js" hash="6ea2189562f65287be8e5e3185c405b7"/></dir><file name="pastetext.htm" hash="8f217769e59a5dd67843c7c17c842f41"/><file name="pasteword.htm" hash="8b9459b98f9a70ed684832326bf1cdf6"/></dir><dir name="preview"><file name="editor_plugin.js" hash="925216b63aabd5adc67d642ca2d04b4a"/><file name="editor_plugin_src.js" hash="6f9c3234dfdc0f62b713e8771f4ca5dc"/><file name="example.html" hash="9b9290408ae10fa29ec29db60682be91"/><dir name="jscripts"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/></dir><file name="preview.html" hash="bb02414f4cdd28c4a66e7fb5ed820f2d"/></dir><dir name="print"><file name="editor_plugin.js" hash="53eb1da78f727ee8337671fb86354c17"/><file name="editor_plugin_src.js" hash="f11547aa114df69b35df319003105e11"/></dir><dir name="save"><file name="editor_plugin.js" hash="307a0743c68c4e4aff005f13027f296f"/><file name="editor_plugin_src.js" hash="4dcbdaab64f06550a2db2b650f99d411"/></dir><dir name="searchreplace"><dir name="css"><file name="searchreplace.css" hash="ad0addca1bd5727432f39ec9b7fdac1e"/></dir><file name="editor_plugin.js" hash="ed4f1fa6e12844b533c86258647a298f"/><file name="editor_plugin_src.js" hash="7292198991a0fda1b9c7b28c921c6521"/><dir name="js"><file name="searchreplace.js" hash="0eeedb83f5bf1240348e1c6e77be2c47"/></dir><dir name="langs"><file name="en_dlg.js" hash="fbd47078679d87b541479000589ef4c9"/></dir><file name="searchreplace.htm" hash="4d01ee3be4045a600778fca1e11cee61"/></dir><dir name="spellchecker"><dir name="css"><file name="content.css" hash="ac0c7dbbbe44022d29d63b7b05123e3d"/></dir><file name="editor_plugin.js" hash="629a571ee7686ace6ee7ad1181be916b"/><file name="editor_plugin_src.js" hash="bae03899e91abca8b4b77c8ea886b561"/><dir name="img"><file name="wline.gif" hash="c136c9f8e00718a98947a21d8adbcc56"/></dir></dir><dir name="style"><dir name="css"><file name="props.css" hash="c2d2adc78609ea65760dae2dab058395"/></dir><file name="editor_plugin.js" hash="f9bcd692d63dfef1fe5c586d27ecd91b"/><file name="editor_plugin_src.js" hash="2ec50d9d37ce1e732380a746fabceefc"/><dir name="js"><file name="props.js" hash="f3614bf040f29057162e423822b89e11"/></dir><dir name="langs"><file name="en_dlg.js" hash="62a82106cfd480a6da4442b4763a2f2d"/></dir><file name="props.htm" hash="32f3f16194be9170386419c9dcc5b99a"/><file name="readme.txt" hash="ced5c8e014184a33da5507dbcd96b91f"/></dir><dir name="tabfocus"><file name="editor_plugin.js" hash="d3e5ef7a1a203516af0d8fdf94952fd2"/><file name="editor_plugin_src.js" hash="12889ccf8caf1d466859ba949f52fbca"/></dir><dir name="table"><file name="cell.htm" hash="f427b778a4924154a5e2317ddfd0f567"/><dir name="css"><file name="cell.css" hash="56394e6cdb267d97e23a07a98820e84b"/><file name="row.css" hash="81a75523c1e83be93e524c8bb901a089"/><file name="table.css" hash="f5e651f5a32284f1c4e0faa1d7cd5ff4"/></dir><file name="editor_plugin.js" hash="c12f0891c5bf0a7a6dd43ef0bd44dd82"/><file name="editor_plugin_src.js" hash="8228b4ab83fe4dfe2e377850dc2cf97e"/><dir name="js"><file name="cell.js" hash="8b0d4a7fe48c2f92c8b9b79dbb12cca1"/><file name="merge_cells.js" hash="3650484c93d6c9a197d03a5c3c3d2e80"/><file name="row.js" hash="d1cf0ab3d974f0b528e467d4b5c5c89f"/><file name="table.js" hash="f894721e5f5a6c2efa1a232c4b4a85b6"/></dir><dir name="langs"><file name="en_dlg.js" hash="ee3484503050cdae74d2cafa7d2e9999"/></dir><file name="merge_cells.htm" hash="f939ddd56826c0ec3c9e6e9a478346bf"/><file name="row.htm" hash="7ad9e68624759b28be626ac4b53c8907"/><file name="table.htm" hash="88fb36057ec1cb1681fed2dcb0b44693"/></dir><dir name="template"><file name="blank.htm" hash="9553e76581d74579d23bea5c7ea8a807"/><dir name="css"><file name="template.css" hash="5b2c159120cbef004c9b0804c292820b"/></dir><file name="editor_plugin.js" hash="70cb20c4e287110ae8aeed999893c532"/><file name="editor_plugin_src.js" hash="336af7b2ec3e0f7c83a7d05bf16cd018"/><dir name="js"><file name="template.js" hash="75abfd82a90ae648fb18c5517dfd925b"/></dir><dir name="langs"><file name="en_dlg.js" hash="1ce03c0fcf0f1aa74c132459abe30f39"/></dir><file name="template.htm" hash="b55e174e239e5c4b3a52d6ad60eb991d"/></dir><dir name="visualblocks"><dir name="css"><file name="visualblocks.css" hash="1fe4f62cc93864784b9b2d6b11b050b7"/></dir><file name="editor_plugin.js" hash="592e70a44aeb7c974eb9c5ff05c107a7"/><file name="editor_plugin_src.js" hash="6d1a4ea64bfedf8797260792e33f4c17"/></dir><dir name="visualchars"><file name="editor_plugin.js" hash="e494d07c71e24040a407b20017ca63e3"/><file name="editor_plugin_src.js" hash="f285c8f2ffac745325e86687b8cf0fb5"/></dir><dir name="wordcount"><file name="editor_plugin.js" hash="fb71ed139697b519f0054179d28ec782"/><file name="editor_plugin_src.js" hash="a034fddb393e4b6e7d25fc3761bea529"/></dir><dir name="xhtmlxtras"><file name="abbr.htm" hash="e514d143e00e4b121cab8fe8dfae48d2"/><file name="acronym.htm" hash="ec632b3d4b6afb189c055afa234e6291"/><file name="attributes.htm" hash="cf540b962f752babf53faa7a47bde108"/><file name="cite.htm" hash="1468438313b9cb1de0e53e50d75c92fa"/><dir name="css"><file name="attributes.css" hash="abc1b941c6eef8e1ea76915984e8a03e"/><file name="popup.css" hash="ed53e7b6ab799f6a249c3d403047dcfc"/></dir><file name="del.htm" hash="81bbcce0d19d78698fad760ee90b6948"/><file name="editor_plugin.js" hash="c9f91af5f1b8a1ba7a1e4ccf53fc7790"/><file name="editor_plugin_src.js" hash="b8b8236893ef2347a46cb131fc1a8c69"/><file name="ins.htm" hash="47e7db25678cee383fe6532ebb9e3fcb"/><dir name="js"><file name="abbr.js" hash="d91ae7d986336de4ecb977d19dcfab19"/><file name="acronym.js" hash="0a19f79bdc9222d3273712fe37a8051c"/><file name="attributes.js" hash="e75f23fae888b9febb57a29f2eb5a86c"/><file name="cite.js" hash="ba39487ce6a625538b838c21502bbaa7"/><file name="del.js" hash="be96fef888076d27384dd3546e8b6b6f"/><file name="element_common.js" hash="b817f5e2d514147d72765c92c1f60f3d"/><file name="ins.js" hash="6148dd4151e58dcda9112933908b97b1"/></dir><dir name="langs"><file name="en_dlg.js" hash="45db1586e7debc385f63092a13a9f43c"/></dir></dir></dir><dir name="themes"><dir name="advanced"><file name="about.htm" hash="ff135857e9b930d4d4658f92077e051c"/><file name="anchor.htm" hash="79d46a2b007b5cb08a3920e922a5da7f"/><file name="charmap.htm" hash="be712e4cf08670a1212e9eed2f452693"/><file name="color_picker.htm" hash="8db4d59dec910525149039f006a2bb9e"/><file name="editor_template.js" hash="a2b3085f0ab3c323dd28187b739139ec"/><file name="editor_template_src.js" hash="1fa308a86046cee68c5227ca58013bba"/><file name="image.htm" hash="2cb986c0cad7efd0592a4d8c35e41f0a"/><dir name="img"><file name="colorpicker.jpg" hash="9bcc36292defe94bca5a013a1736c7d7"/><file name="flash.gif" hash="33adee48d32bbbba3e6412cc54ecf335"/><file name="icons.gif" hash="75ad72872bc6280c32609e12fc3b610a"/><file name="iframe.gif" hash="a1af02e9ba370f64297087b46e80591e"/><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="quicktime.gif" hash="61da1ff8729ca5016344c4e8eb173369"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="1ce7d48784981aac9d4375cf2effdc4d"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="video.gif" hash="f85c56813ea016a75e496bba50d66ab4"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="about.js" hash="606c16492a17240ebded6e9fce75a555"/><file name="anchor.js" hash="da6a28397899bec3570216b2d2106684"/><file name="charmap.js" hash="02f40a38033ef8a0abeac870e5f4eda8"/><file name="color_picker.js" hash="cfc0f59a846661e748cae1c0adca77dc"/><file name="image.js" hash="75df8142a91f0245367e4121a2da7065"/><file name="link.js" hash="71949506dce04e923bbbc2ecc8ab5f1f"/><file name="source_editor.js" hash="4cbdfdf929a0949070f4d7ab4818b0f2"/></dir><dir name="langs"><file name="en.js" hash="58c814313230f1dec07fe45ad5f304e5"/><file name="en_dlg.js" hash="3a2c8aed5b7579ae45be6bd2b34ef06b"/></dir><file name="link.htm" hash="65c56f5a6d714fdbdc47c68ec9422976"/><file name="shortcuts.htm" hash="2bae05c8667b54b9ec019b529e743327"/><dir name="skins"><dir name="default"><file name="content.css" hash="1779499935490440d7a2423157756bc5"/><file name="dialog.css" hash="ab94126c11ff9c79445cc4ad537b2823"/><dir name="img"><file name="buttons.png" hash="33b2f2e08cc3ade5254fec64c4183558"/><file name="items.gif" hash="d201498a710fc8aac6e117820b9814b7"/><file name="menu_arrow.gif" hash="e21752451a9d80e276fef7b602bdbdba"/><file name="menu_check.gif" hash="c7d003885737f94768eecae49dcbca63"/><file name="progress.gif" hash="50c5e3e79b276c92df6cc52caeb464f0"/><file name="tabs.gif" hash="6473bbcd0a011e9fcdd9f777ef437410"/></dir><file name="ui.css" hash="823d750bb9c2bde55084d322f44b17c1"/></dir><dir name="highcontrast"><file name="content.css" hash="8294a1222d0ab5fa7520879cc9073e85"/><file name="dialog.css" hash="f6e95a7450471eb7473f8dbc3e6b6581"/><file name="ui.css" hash="1bdbee2f94594ca00c65b4d6a930bbf6"/></dir><dir name="o2k7"><file name="content.css" hash="c696812903368f41cd65616574c81484"/><file name="dialog.css" hash="661f54aa4a283b67c0acd25f91f2f213"/><dir name="img"><file name="button_bg.png" hash="36fd9fbd748860f515df259443367163"/><file name="button_bg_black.png" hash="9645f90b37102a3618a52be18b74b02b"/><file name="button_bg_silver.png" hash="15fbf2b4a20dbaa86205af6764f4fee4"/></dir><file name="ui.css" hash="a108668128c143e61bc44990dff89fe6"/><file name="ui_black.css" hash="ba8d82d9bff6e2854b29b1f97ead05fe"/><file name="ui_silver.css" hash="b42c7d51247d02ddca437a1661e748e5"/></dir></dir><file name="source_editor.htm" hash="42f3a13b55ffcf7c2d3ab768012abfcc"/></dir><dir name="simple"><file name="editor_template.js" hash="3ac3fd3129ee9605052b8470f8d58538"/><file name="editor_template_src.js" hash="409e0cce50eb6c62463d6dd9c6120859"/><dir name="img"><file name="icons.gif" hash="273dad62be4d114c5d52210b50a5838f"/></dir><dir name="langs"><file name="en.js" hash="50dce0602a45ba9fac56f12f76a63ec3"/></dir><dir name="skins"><dir name="default"><file name="content.css" hash="0f70f3ca9624e252d1c41ea064fc65e7"/><file name="ui.css" hash="c46c68283c617bb61dada1cd2494dd9f"/></dir><dir name="o2k7"><file name="content.css" hash="eb7a087c67578b6e3b5e0987caa4ba64"/><dir name="img"><file name="button_bg.png" hash="405ca3d63b48667ef485553192507f59"/></dir><file name="ui.css" hash="f0ec0273462e01b81e1dfd292f64451e"/></dir></dir></dir></dir><file name="tiny_mce.js" hash="199630688fff7a8bb0a549cd80187cbd"/><file name="tiny_mce_dev.js" hash="3a3819b032736635cc608076a02b3dbe"/><file name="tiny_mce_jquery.js" hash="87ee7a1967b86d56f5cdb1ba985ef4ce"/><file name="tiny_mce_jquery_src.js" hash="212727559aacdd03ea9ae6f5c6ede65a"/><file name="tiny_mce_popup.js" hash="5a318277fedf491a0301e177a9ef10b3"/><file name="tiny_mce_prototype.js" hash="0c65808fab93d86cf8552976f691b9c8"/><file name="tiny_mce_prototype_src.js" hash="3629c32a57bcf63cb52f455f18709223"/><file name="tiny_mce_src.js" hash="98575c8e6816a36f73145c2d97b0846a"/><dir name="utils"><file name="editable_selects.js" hash="e760eb21f60892a1ef2298da7df313e5"/><file name="form_utils.js" hash="579b2803ffca7953c50f53dcbef5df7e"/><file name="mctabs.js" hash="51b9bfe349fe76204ac5b65254bbef6f"/><file name="validate.js" hash="bfbaf5dc8058ff772afe2d87f4e82fbf"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Js_TinyMCE-3.5.11.18.xml b/var/package/Lib_Js_TinyMCE-3.5.11.18.xml
new file mode 100644
index 0000000..c1aaf80
--- /dev/null
+++ b/var/package/Lib_Js_TinyMCE-3.5.11.18.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Js_TinyMCE</name>
+    <version>3.5.11.18</version>
+    <stability>stable</stability>
+    <license>Mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>TinyMCE Javascript Libraries for Magento</summary>
+    <description>TinyMCE Javascript Libraries for Magento</description>
+    <notes>3.5.11.18</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:01</time>
+    <contents><target name="mageweb"><dir name="js"><dir name="tiny_mce"><dir name="classes"><file name="AddOnManager.js" hash="394e98bc019eb5c08c657fe4f8a48546"/><file name="ControlManager.js" hash="26cedc474b183b1a9905cdb3d10254dc"/><file name="Editor.Events.js" hash="07af3e1a08aead0078eb0cd6b030b864"/><file name="Editor.js" hash="e921b224172fbe2bd134eaab1974f2e8"/><file name="EditorCommands.js" hash="18b0d752aafddca09cf59fa7cc4d45c2"/><file name="EditorManager.js" hash="68b7a4a6252ab8b326fa5c8ee52d8016"/><file name="EnterKey.js" hash="ecc48ccb75c80dca2bd6bd7023fc906e"/><file name="ForceBlocks.js" hash="186ad2042e7b9416d2c4f9ec5f519893"/><file name="Formatter.js" hash="413f6c83f256d864a01e05718fbe7ce6"/><file name="LegacyInput.js" hash="a14c5e4099e2e4cbc6339eb54d3ec8f9"/><file name="Popup.js" hash="b6775a0e19bd839625b4dfb6b92a9688"/><file name="UndoManager.js" hash="276955286b65fba55ee60833ca2d6671"/><file name="WindowManager.js" hash="794c3d88226e8b62eac09eeeef283c3b"/><dir name="adapter"><dir name="jquery"><file name="adapter.js" hash="a5eea8e2826d7b0929291aa7a927ec29"/><file name="jquery.tinymce.js" hash="f2f319f369a84757b8976c2d66872933"/></dir><dir name="prototype"><file name="adapter.js" hash="37d84615944f028635f68d05b889c5c2"/></dir></dir><dir name="dom"><file name="DOMUtils.js" hash="bb9a7c2b19ad2433c85984cb8511e085"/><file name="Element.js" hash="1208e71eb2bc8e578b5a9cb4ec3b1365"/><file name="EventUtils.js" hash="652351eaf41de2659cfc7e380b694c02"/><file name="Range.js" hash="05c8ac178fa799217f60ebb650b41e0f"/><file name="RangeUtils.js" hash="9948e6204548089899b1e325370355f1"/><file name="ScriptLoader.js" hash="742ce02734095db354ad54ab8399a0ee"/><file name="Selection.js" hash="3332b2293dfc2a93fdb6a67ce5329642"/><file name="Serializer.js" hash="8762f4920ed6d4a57203bfbb8bc8490c"/><file name="Sizzle.js" hash="7930b22f632c7b0240237df1393e5023"/><file name="TreeWalker.js" hash="55425ece6675a529525bad45c6acbd94"/><file name="TridentSelection.js" hash="1fd402d1bb8144fa8549031b5f061733"/></dir><dir name="firebug"><file name="FIREBUG.LICENSE" hash="3b402ea96cec202bac23ea7144653cfa"/><file name="firebug-lite.js" hash="1c9c10926be94a61564ad0541a50624f"/></dir><dir name="html"><file name="DomParser.js" hash="25a47241e40445f2870bc94ce6a10b3c"/><file name="Entities.js" hash="7292e9f893096fb66d3232920be3c3d9"/><file name="Node.js" hash="ea0a5b87b71760018a753eb41a4e0f48"/><file name="SaxParser.js" hash="6dbb27c6762a5f27a9e6e844391393f4"/><file name="Schema.js" hash="e4d6e60fbca99911660f272717b9c08b"/><file name="Serializer.js" hash="ab74a79798a6f20f4267e3f1da17f2da"/><file name="Styles.js" hash="72317437bb3c7f0a05302658ea19dfce"/><file name="Writer.js" hash="3a2e8b824b749c19c5f27f8c830f95a5"/></dir><file name="tinymce.js" hash="546ec1f2bbfbf1ee04b4a33dcc05bc52"/><dir name="ui"><file name="Button.js" hash="82e9cd9d322a714652b0bc8e40e7e503"/><file name="ColorSplitButton.js" hash="06760a696b922b56a482f5889407714e"/><file name="Container.js" hash="7929a5d6aef46380197061e49e4f9dfb"/><file name="Control.js" hash="460a997aaad3b1b24f684bfdbefd3d9c"/><file name="DropMenu.js" hash="3359b973c857ca38105eeb276119b99f"/><file name="KeyboardNavigation.js" hash="f446fdfbadd728e8b009dc4adfc0b0d2"/><file name="ListBox.js" hash="2cd7287ec70ac87cb3903ecf0a2ccfdc"/><file name="Menu.js" hash="02762fee614d37aaea7eaf14f07dece1"/><file name="MenuButton.js" hash="fb0251eb52a5b3779d76ed2c2f8ec77e"/><file name="MenuItem.js" hash="55d400a161aa44d9dd5334d6f58ed956"/><file name="NativeListBox.js" hash="964785fd8a23be00b6db650f96e9ebf7"/><file name="Separator.js" hash="d4c5d779114617360ea78a2c0d523c81"/><file name="SplitButton.js" hash="e78e53578280cce9d97f936a82eca6de"/><file name="Toolbar.js" hash="b742f894f63122c4ee635fa59958167d"/><file name="ToolbarGroup.js" hash="db7b059b984e114ea22b1dc558d3d1f2"/></dir><dir name="util"><file name="Cookie.js" hash="14bc612b28c3c75549138a1699d5c238"/><file name="Dispatcher.js" hash="bf9bd51bbabca1823634833b3b16097c"/><file name="JSON.js" hash="b9b5964dbcd4cff962264dd72d8e4df5"/><file name="JSONP.js" hash="0a39d9e1b8427ab8b6dbdd00177c8c48"/><file name="JSONRequest.js" hash="dd12f1ac5c78ec4ba7459fb825ff9e5e"/><file name="Quirks.js" hash="927b518cc3aa663a41921590d0d3b4ac"/><file name="URI.js" hash="7069a8a2dfa4b0315719778b8c744139"/><file name="VK.js" hash="78114029ce46d5a4a441b01c44f23b4f"/><file name="XHR.js" hash="b00450d636335e7be50d46d2c31cc5a0"/></dir><dir name="xml"><file name="Parser.js" hash="c6d6862014ef2ab23a5a16adaee1af6d"/></dir></dir><file name="jquery.tinymce.js" hash="751418d46d453e7c6b1a7fbd4e60fefa"/><dir name="langs"><file name="en.js" hash="eff36a9433bccea2f3243b1465fe6fe3"/></dir><file name="license.txt" hash="b238d032089de4c340f6e0119210ce3a"/><dir name="plugins"><dir name="advhr"><dir name="css"><file name="advhr.css" hash="15df80b2137bcc04d5455ffa3a51e0c5"/></dir><file name="editor_plugin.js" hash="d0a03059205455e5c19cf3a845a0ebde"/><file name="editor_plugin_src.js" hash="a7fda2e674f15a33baf53cea2e23ec66"/><dir name="js"><file name="rule.js" hash="ef46d7c850c8bcc869ea84ed7ac00c49"/></dir><dir name="langs"><file name="en_dlg.js" hash="af62ab3f1b7a27190f8e001c8aefdfa6"/></dir><file name="rule.htm" hash="492ebbdc24d46061e928d911873d5fc8"/></dir><dir name="advimage"><dir name="css"><file name="advimage.css" hash="1ccd374d5f1e89cc16e1649558a9bb33"/></dir><file name="editor_plugin.js" hash="8af1f904909820d132bc0cbeb6469130"/><file name="editor_plugin_src.js" hash="958a409150fba5532d27e862d52015e9"/><file name="image.htm" hash="0d204c8f7651c3080ab542fb36957881"/><dir name="img"><file name="sample.gif" hash="b9c7057c46716340e8967340ad11766e"/></dir><dir name="js"><file name="image.js" hash="d071360a06b4f8590b4b18a7eca039aa"/></dir><dir name="langs"><file name="en_dlg.js" hash="6f80f834e2209e6a95957403bb4842f0"/></dir></dir><dir name="advlink"><dir name="css"><file name="advlink.css" hash="aaf226732a7b4ae80ee680700f488a1e"/></dir><file name="editor_plugin.js" hash="5e440c6bcb7fd94e7fd597f8a183e16f"/><file name="editor_plugin_src.js" hash="4104cd66aea546becf5d8fca66cf7951"/><dir name="js"><file name="advlink.js" hash="80dd2f99418025b6f9fd757adfdb1a71"/></dir><dir name="langs"><file name="en_dlg.js" hash="8da3a95d6886837c0bca18670f57ae1c"/></dir><file name="link.htm" hash="206ef7aba261ac4bc14e7c6fdbdcc8c5"/></dir><dir name="advlist"><file name="editor_plugin.js" hash="5f1c8625c04a6b0f4567c1c8d5e28ff9"/><file name="editor_plugin_src.js" hash="d451908bf1e060ecd49356787f33fc7c"/></dir><dir name="autolink"><file name="editor_plugin.js" hash="5091233229ffe517f075b787c5f388a6"/><file name="editor_plugin_src.js" hash="f03a8ec9ad17bd53f897a525e3cc30f7"/></dir><dir name="autoresize"><file name="editor_plugin.js" hash="adf5cbe96119e3ed9ab4a86ba26405e7"/><file name="editor_plugin_src.js" hash="4d1cdbe307f73b4d36d1bf9b3bc2d0a9"/></dir><dir name="autosave"><file name="editor_plugin.js" hash="ae4c2aba85a22da66e3655f55d1c89fd"/><file name="editor_plugin_src.js" hash="6177147324865c00736c242b8ccb2de6"/><dir name="langs"><file name="en.js" hash="a33b0322c949a6d74bde7fa164396984"/></dir></dir><dir name="bbcode"><file name="editor_plugin.js" hash="31748a6cc57a13da54a0243c3301f3e6"/><file name="editor_plugin_src.js" hash="842450703b915245adb53df7d478ea5a"/></dir><dir name="contextmenu"><file name="editor_plugin.js" hash="5a0fc9ce2ba71bf2b6f54eb94838619f"/><file name="editor_plugin_src.js" hash="b923e4315f2d98703bbe9699465f84f0"/></dir><dir name="directionality"><file name="editor_plugin.js" hash="e2d925fe1e778dbcade06d55164fc276"/><file name="editor_plugin_src.js" hash="14b7a5b69fdc4f235b654436e4fe3081"/></dir><dir name="emotions"><file name="editor_plugin.js" hash="98cba02e33fc108024f3e993be0b0b62"/><file name="editor_plugin_src.js" hash="4cbc6e9b083a810ab0d3768af8f8f864"/><file name="emotions.htm" hash="9378bfd04b56a828318f7798f5696f67"/><dir name="img"><file name="smiley-cool.gif" hash="e26e97a318f82ec144b0818e5a8f8edb"/><file name="smiley-cry.gif" hash="e72bf995ceca9230273ed9909c5db9c8"/><file name="smiley-embarassed.gif" hash="d59171236e6b0b96091eeda1f7b57ce3"/><file name="smiley-foot-in-mouth.gif" hash="c12d9db6a14ad0b52f66f1e2cf2a38e7"/><file name="smiley-frown.gif" hash="59930208822fe755f651a67ef4b70530"/><file name="smiley-innocent.gif" hash="ec0477c8a206ff250782e40f9bae4b4c"/><file name="smiley-kiss.gif" hash="4ae8945f3960751b5d294f18242e144d"/><file name="smiley-laughing.gif" hash="c37f405db4e13cbebf24e745534687bf"/><file name="smiley-money-mouth.gif" hash="11c14bd1496afd0e21df115d25b68e96"/><file name="smiley-sealed.gif" hash="bb828cb46b377d1589927a02f8fd1762"/><file name="smiley-smile.gif" hash="2968a664098d9580079c66d628dad1a8"/><file name="smiley-surprised.gif" hash="2e136ebd637bf3e6c9fc6bdc20cbe73e"/><file name="smiley-tongue-out.gif" hash="5ec3bb4781c8e43a51d3a1a948b98fc0"/><file name="smiley-undecided.gif" hash="3c0c011d16b1a2331385ed97e160a42a"/><file name="smiley-wink.gif" hash="897275ac7d07032b4d93fb83a0d2a41b"/><file name="smiley-yell.gif" hash="19bb8ebfe3c2f5ef3ffb9aa4a027900d"/></dir><dir name="js"><file name="emotions.js" hash="85efe828d29037950412fec963b6f950"/></dir><dir name="langs"><file name="en_dlg.js" hash="62c052504a77e4f4cec6d90ece0d76c4"/></dir></dir><dir name="example"><file name="dialog.htm" hash="e6170a190a4d44ea5e6af089d2728d7e"/><file name="editor_plugin.js" hash="e0a175dca3d5e437657ccd5d548ff409"/><file name="editor_plugin_src.js" hash="b98bec73743c249187e0fa8f8311e3a3"/><dir name="img"><file name="example.gif" hash="6036655a01df362267183a8b23fead10"/></dir><dir name="js"><file name="dialog.js" hash="83245e76c97e24d466cf5df2308f9bf4"/></dir><dir name="langs"><file name="en.js" hash="78c88182b5fb900fc956845f75885b3a"/><file name="en_dlg.js" hash="7aec7a3b9d4642fbf7bb3ef1ed8a7570"/></dir></dir><dir name="example_dependency"><file name="editor_plugin.js" hash="405d190ae03384a9acb00533568b2cfd"/><file name="editor_plugin_src.js" hash="473878118b45efe326d335f992ff9943"/></dir><dir name="fullpage"><dir name="css"><file name="fullpage.css" hash="2ac64c98369f8b4f7cbf6fa70e25bfca"/></dir><file name="editor_plugin.js" hash="5dfbe0a82c87eb0fb65b11dcd39406d0"/><file name="editor_plugin_src.js" hash="636afe66f3de447eb92611bdcfb7f2b3"/><file name="fullpage.htm" hash="8c58825b698712e7297f95da51a9c03c"/><dir name="js"><file name="fullpage.js" hash="a7913b6b1a1ae634a509c3db9faf381a"/></dir><dir name="langs"><file name="en_dlg.js" hash="963f370d56f19c2f94de09b10a306187"/></dir></dir><dir name="fullscreen"><file name="editor_plugin.js" hash="15134339e36472281b8a1626233f747d"/><file name="editor_plugin_src.js" hash="a28a8a8bf569d6ee5e6dccbc988490ce"/><file name="fullscreen.htm" hash="b6d76297c2f679b9110ec7119d091900"/></dir><dir name="iespell"><file name="editor_plugin.js" hash="22526393cacb6447a0e3bfff2fb47773"/><file name="editor_plugin_src.js" hash="311e13bcc85c06da43decc37dc1b4f83"/></dir><dir name="inlinepopups"><file name="editor_plugin.js" hash="db32751b98f40ca6eee24efc848d6cbb"/><file name="editor_plugin_src.js" hash="d1c1de414c13fef3593ffd14503d37c0"/><dir name="skins"><dir name="clearlooks2"><dir name="img"><file name="alert.gif" hash="568d4cf84413656fb72fe39d1dd60f8d"/><file name="button.gif" hash="19f864cb81177840dcd534df4d537ea3"/><file name="buttons.gif" hash="1743ac9f7f2267a6edafefc536a2265d"/><file name="confirm.gif" hash="1bc337a20c319e531cda6ced531827d0"/><file name="corners.gif" hash="55298b5baaecb7e06a251db9f0a4b14c"/><file name="horizontal.gif" hash="0365e75dd4a9ad61dc98dcb641207c21"/><file name="vertical.gif" hash="0261136fac58ce77bdbd96aa0194947e"/></dir><file name="window.css" hash="f715affab9da63bc26f8c6362a989395"/></dir></dir><file name="template.htm" hash="3d7e3ae05511a9f64c5da924b9e971ba"/></dir><dir name="insertdatetime"><file name="editor_plugin.js" hash="d99072498466cdb2f53ed7c02da85982"/><file name="editor_plugin_src.js" hash="32a2afa1cd3ff8c9b966f8724ba3e0b3"/></dir><dir name="layer"><file name="editor_plugin.js" hash="4e5fc1b467c19d79dcf6246ba3a63cd8"/><file name="editor_plugin_src.js" hash="3754eb57b08539e459509caa74acecc6"/></dir><dir name="legacyoutput"><file name="editor_plugin.js" hash="b732a86187723cd9cc32853d67730061"/><file name="editor_plugin_src.js" hash="8a0a69cbe8d447d722aaef7d4ed7dcc1"/></dir><dir name="lists"><file name="editor_plugin.js" hash="46ba57884d8fe05d92cd9d98d3bb00af"/><file name="editor_plugin_src.js" hash="04e1f245c19d6dc9454dae57faec9b6f"/></dir><dir name="media"><dir name="css"><file name="media.css" hash="f211293a697a2c83da00effd67f535a2"/></dir><file name="editor_plugin.js" hash="5ad7db86c5008f98ec135595db4a4973"/><file name="editor_plugin_src.js" hash="1d03ec1ec36745041db26132b07b0491"/><dir name="img"><file name="flash.gif" hash="6c69b02015d09280332ff8b07e4ea2f3"/><file name="quicktime.gif" hash="9a6a9fdead205b125c07ea37e71ed4f1"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="baa643b587565755157618032dc93e3c"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/><file name="media.js" hash="dbc6493c7c0d992665587e1a61b432ad"/></dir><dir name="langs"><file name="en_dlg.js" hash="9523fc123c577642000fd409bd862c3f"/></dir><file name="media.htm" hash="be58b1edf9a4a4dbf3a1993e3d897e1a"/><file name="moxieplayer.swf" hash="9217cea72c76c361fa5033526712284e"/><file name=".htaccess" hash="9f2e3ee0d6e50d80819eb8c0300a0913"/></dir><dir name="nonbreaking"><file name="editor_plugin.js" hash="232f23a586f10bd8ddabf38d767113d4"/><file name="editor_plugin_src.js" hash="fefbda5243d10652038ccf40801b8893"/></dir><dir name="noneditable"><file name="editor_plugin.js" hash="b332a5f8767506024a0f50aa4204b1fe"/><file name="editor_plugin_src.js" hash="273d35e2221889e75f33fd545f77d44e"/></dir><dir name="pagebreak"><dir name="css"><file name="content.css" hash="d9664762a610f2b5f7b10b5781f3299a"/></dir><file name="editor_plugin.js" hash="8be3376740c886fa2842d2f4eb282bbc"/><file name="editor_plugin_src.js" hash="c2d432a5914f0095a859ff443700a5e9"/><dir name="img"><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/></dir></dir><dir name="paste"><file name="editor_plugin.js" hash="1b68c59eb95a28ccc2aff2cfb85a8829"/><file name="editor_plugin_src.js" hash="40eef37ac300b571da5383bc0bddf73f"/><dir name="js"><file name="pastetext.js" hash="d6e4b39f19b89118b34b0d21491494b7"/><file name="pasteword.js" hash="112504d12e971e4d32f17a59c5616c36"/></dir><dir name="langs"><file name="en_dlg.js" hash="6ea2189562f65287be8e5e3185c405b7"/></dir><file name="pastetext.htm" hash="8f217769e59a5dd67843c7c17c842f41"/><file name="pasteword.htm" hash="8b9459b98f9a70ed684832326bf1cdf6"/></dir><dir name="preview"><file name="editor_plugin.js" hash="925216b63aabd5adc67d642ca2d04b4a"/><file name="editor_plugin_src.js" hash="6f9c3234dfdc0f62b713e8771f4ca5dc"/><file name="example.html" hash="9b9290408ae10fa29ec29db60682be91"/><dir name="jscripts"><file name="embed.js" hash="39ebc57f44e1cc683724e1c1ff761894"/></dir><file name="preview.html" hash="bb02414f4cdd28c4a66e7fb5ed820f2d"/></dir><dir name="print"><file name="editor_plugin.js" hash="53eb1da78f727ee8337671fb86354c17"/><file name="editor_plugin_src.js" hash="f11547aa114df69b35df319003105e11"/></dir><dir name="save"><file name="editor_plugin.js" hash="307a0743c68c4e4aff005f13027f296f"/><file name="editor_plugin_src.js" hash="4dcbdaab64f06550a2db2b650f99d411"/></dir><dir name="searchreplace"><dir name="css"><file name="searchreplace.css" hash="ad0addca1bd5727432f39ec9b7fdac1e"/></dir><file name="editor_plugin.js" hash="ed4f1fa6e12844b533c86258647a298f"/><file name="editor_plugin_src.js" hash="7292198991a0fda1b9c7b28c921c6521"/><dir name="js"><file name="searchreplace.js" hash="0eeedb83f5bf1240348e1c6e77be2c47"/></dir><dir name="langs"><file name="en_dlg.js" hash="fbd47078679d87b541479000589ef4c9"/></dir><file name="searchreplace.htm" hash="4d01ee3be4045a600778fca1e11cee61"/></dir><dir name="spellchecker"><dir name="css"><file name="content.css" hash="ac0c7dbbbe44022d29d63b7b05123e3d"/></dir><file name="editor_plugin.js" hash="629a571ee7686ace6ee7ad1181be916b"/><file name="editor_plugin_src.js" hash="bae03899e91abca8b4b77c8ea886b561"/><dir name="img"><file name="wline.gif" hash="c136c9f8e00718a98947a21d8adbcc56"/></dir></dir><dir name="style"><dir name="css"><file name="props.css" hash="c2d2adc78609ea65760dae2dab058395"/></dir><file name="editor_plugin.js" hash="f9bcd692d63dfef1fe5c586d27ecd91b"/><file name="editor_plugin_src.js" hash="2ec50d9d37ce1e732380a746fabceefc"/><dir name="js"><file name="props.js" hash="f3614bf040f29057162e423822b89e11"/></dir><dir name="langs"><file name="en_dlg.js" hash="62a82106cfd480a6da4442b4763a2f2d"/></dir><file name="props.htm" hash="32f3f16194be9170386419c9dcc5b99a"/><file name="readme.txt" hash="ced5c8e014184a33da5507dbcd96b91f"/></dir><dir name="tabfocus"><file name="editor_plugin.js" hash="d3e5ef7a1a203516af0d8fdf94952fd2"/><file name="editor_plugin_src.js" hash="12889ccf8caf1d466859ba949f52fbca"/></dir><dir name="table"><file name="cell.htm" hash="f427b778a4924154a5e2317ddfd0f567"/><dir name="css"><file name="cell.css" hash="56394e6cdb267d97e23a07a98820e84b"/><file name="row.css" hash="81a75523c1e83be93e524c8bb901a089"/><file name="table.css" hash="f5e651f5a32284f1c4e0faa1d7cd5ff4"/></dir><file name="editor_plugin.js" hash="c12f0891c5bf0a7a6dd43ef0bd44dd82"/><file name="editor_plugin_src.js" hash="8228b4ab83fe4dfe2e377850dc2cf97e"/><dir name="js"><file name="cell.js" hash="8b0d4a7fe48c2f92c8b9b79dbb12cca1"/><file name="merge_cells.js" hash="3650484c93d6c9a197d03a5c3c3d2e80"/><file name="row.js" hash="d1cf0ab3d974f0b528e467d4b5c5c89f"/><file name="table.js" hash="f894721e5f5a6c2efa1a232c4b4a85b6"/></dir><dir name="langs"><file name="en_dlg.js" hash="ee3484503050cdae74d2cafa7d2e9999"/></dir><file name="merge_cells.htm" hash="f939ddd56826c0ec3c9e6e9a478346bf"/><file name="row.htm" hash="7ad9e68624759b28be626ac4b53c8907"/><file name="table.htm" hash="88fb36057ec1cb1681fed2dcb0b44693"/></dir><dir name="template"><file name="blank.htm" hash="9553e76581d74579d23bea5c7ea8a807"/><dir name="css"><file name="template.css" hash="5b2c159120cbef004c9b0804c292820b"/></dir><file name="editor_plugin.js" hash="70cb20c4e287110ae8aeed999893c532"/><file name="editor_plugin_src.js" hash="336af7b2ec3e0f7c83a7d05bf16cd018"/><dir name="js"><file name="template.js" hash="75abfd82a90ae648fb18c5517dfd925b"/></dir><dir name="langs"><file name="en_dlg.js" hash="1ce03c0fcf0f1aa74c132459abe30f39"/></dir><file name="template.htm" hash="b55e174e239e5c4b3a52d6ad60eb991d"/></dir><dir name="visualblocks"><dir name="css"><file name="visualblocks.css" hash="1fe4f62cc93864784b9b2d6b11b050b7"/></dir><file name="editor_plugin.js" hash="592e70a44aeb7c974eb9c5ff05c107a7"/><file name="editor_plugin_src.js" hash="6d1a4ea64bfedf8797260792e33f4c17"/></dir><dir name="visualchars"><file name="editor_plugin.js" hash="e494d07c71e24040a407b20017ca63e3"/><file name="editor_plugin_src.js" hash="f285c8f2ffac745325e86687b8cf0fb5"/></dir><dir name="wordcount"><file name="editor_plugin.js" hash="fb71ed139697b519f0054179d28ec782"/><file name="editor_plugin_src.js" hash="a034fddb393e4b6e7d25fc3761bea529"/></dir><dir name="xhtmlxtras"><file name="abbr.htm" hash="e514d143e00e4b121cab8fe8dfae48d2"/><file name="acronym.htm" hash="ec632b3d4b6afb189c055afa234e6291"/><file name="attributes.htm" hash="cf540b962f752babf53faa7a47bde108"/><file name="cite.htm" hash="1468438313b9cb1de0e53e50d75c92fa"/><dir name="css"><file name="attributes.css" hash="abc1b941c6eef8e1ea76915984e8a03e"/><file name="popup.css" hash="ed53e7b6ab799f6a249c3d403047dcfc"/></dir><file name="del.htm" hash="81bbcce0d19d78698fad760ee90b6948"/><file name="editor_plugin.js" hash="c9f91af5f1b8a1ba7a1e4ccf53fc7790"/><file name="editor_plugin_src.js" hash="b8b8236893ef2347a46cb131fc1a8c69"/><file name="ins.htm" hash="47e7db25678cee383fe6532ebb9e3fcb"/><dir name="js"><file name="abbr.js" hash="d91ae7d986336de4ecb977d19dcfab19"/><file name="acronym.js" hash="0a19f79bdc9222d3273712fe37a8051c"/><file name="attributes.js" hash="e75f23fae888b9febb57a29f2eb5a86c"/><file name="cite.js" hash="ba39487ce6a625538b838c21502bbaa7"/><file name="del.js" hash="be96fef888076d27384dd3546e8b6b6f"/><file name="element_common.js" hash="b817f5e2d514147d72765c92c1f60f3d"/><file name="ins.js" hash="6148dd4151e58dcda9112933908b97b1"/></dir><dir name="langs"><file name="en_dlg.js" hash="45db1586e7debc385f63092a13a9f43c"/></dir></dir></dir><dir name="themes"><dir name="advanced"><file name="about.htm" hash="ff135857e9b930d4d4658f92077e051c"/><file name="anchor.htm" hash="79d46a2b007b5cb08a3920e922a5da7f"/><file name="charmap.htm" hash="be712e4cf08670a1212e9eed2f452693"/><file name="color_picker.htm" hash="8db4d59dec910525149039f006a2bb9e"/><file name="editor_template.js" hash="a2b3085f0ab3c323dd28187b739139ec"/><file name="editor_template_src.js" hash="1fa308a86046cee68c5227ca58013bba"/><file name="image.htm" hash="2cb986c0cad7efd0592a4d8c35e41f0a"/><dir name="img"><file name="colorpicker.jpg" hash="9bcc36292defe94bca5a013a1736c7d7"/><file name="flash.gif" hash="33adee48d32bbbba3e6412cc54ecf335"/><file name="icons.gif" hash="75ad72872bc6280c32609e12fc3b610a"/><file name="iframe.gif" hash="a1af02e9ba370f64297087b46e80591e"/><file name="pagebreak.gif" hash="48872075f721bf57a517e3275d61c0ba"/><file name="quicktime.gif" hash="61da1ff8729ca5016344c4e8eb173369"/><file name="realmedia.gif" hash="b9734ee16d790e67bea01046feba28b7"/><file name="shockwave.gif" hash="1ce7d48784981aac9d4375cf2effdc4d"/><file name="trans.gif" hash="12bf9e19374920de3146a64775f46a5e"/><file name="video.gif" hash="f85c56813ea016a75e496bba50d66ab4"/><file name="windowsmedia.gif" hash="c327cd167b3a7bc263d908b0d0154ead"/></dir><dir name="js"><file name="about.js" hash="606c16492a17240ebded6e9fce75a555"/><file name="anchor.js" hash="da6a28397899bec3570216b2d2106684"/><file name="charmap.js" hash="02f40a38033ef8a0abeac870e5f4eda8"/><file name="color_picker.js" hash="cfc0f59a846661e748cae1c0adca77dc"/><file name="image.js" hash="75df8142a91f0245367e4121a2da7065"/><file name="link.js" hash="71949506dce04e923bbbc2ecc8ab5f1f"/><file name="source_editor.js" hash="4cbdfdf929a0949070f4d7ab4818b0f2"/></dir><dir name="langs"><file name="en.js" hash="58c814313230f1dec07fe45ad5f304e5"/><file name="en_dlg.js" hash="3a2c8aed5b7579ae45be6bd2b34ef06b"/></dir><file name="link.htm" hash="65c56f5a6d714fdbdc47c68ec9422976"/><file name="shortcuts.htm" hash="2bae05c8667b54b9ec019b529e743327"/><dir name="skins"><dir name="default"><file name="content.css" hash="1779499935490440d7a2423157756bc5"/><file name="dialog.css" hash="ab94126c11ff9c79445cc4ad537b2823"/><dir name="img"><file name="buttons.png" hash="33b2f2e08cc3ade5254fec64c4183558"/><file name="items.gif" hash="d201498a710fc8aac6e117820b9814b7"/><file name="menu_arrow.gif" hash="e21752451a9d80e276fef7b602bdbdba"/><file name="menu_check.gif" hash="c7d003885737f94768eecae49dcbca63"/><file name="progress.gif" hash="50c5e3e79b276c92df6cc52caeb464f0"/><file name="tabs.gif" hash="6473bbcd0a011e9fcdd9f777ef437410"/></dir><file name="ui.css" hash="823d750bb9c2bde55084d322f44b17c1"/></dir><dir name="highcontrast"><file name="content.css" hash="8294a1222d0ab5fa7520879cc9073e85"/><file name="dialog.css" hash="f6e95a7450471eb7473f8dbc3e6b6581"/><file name="ui.css" hash="1bdbee2f94594ca00c65b4d6a930bbf6"/></dir><dir name="o2k7"><file name="content.css" hash="c696812903368f41cd65616574c81484"/><file name="dialog.css" hash="661f54aa4a283b67c0acd25f91f2f213"/><dir name="img"><file name="button_bg.png" hash="36fd9fbd748860f515df259443367163"/><file name="button_bg_black.png" hash="9645f90b37102a3618a52be18b74b02b"/><file name="button_bg_silver.png" hash="15fbf2b4a20dbaa86205af6764f4fee4"/></dir><file name="ui.css" hash="a108668128c143e61bc44990dff89fe6"/><file name="ui_black.css" hash="ba8d82d9bff6e2854b29b1f97ead05fe"/><file name="ui_silver.css" hash="b42c7d51247d02ddca437a1661e748e5"/></dir></dir><file name="source_editor.htm" hash="42f3a13b55ffcf7c2d3ab768012abfcc"/></dir><dir name="simple"><file name="editor_template.js" hash="3ac3fd3129ee9605052b8470f8d58538"/><file name="editor_template_src.js" hash="409e0cce50eb6c62463d6dd9c6120859"/><dir name="img"><file name="icons.gif" hash="273dad62be4d114c5d52210b50a5838f"/></dir><dir name="langs"><file name="en.js" hash="50dce0602a45ba9fac56f12f76a63ec3"/></dir><dir name="skins"><dir name="default"><file name="content.css" hash="0f70f3ca9624e252d1c41ea064fc65e7"/><file name="ui.css" hash="c46c68283c617bb61dada1cd2494dd9f"/></dir><dir name="o2k7"><file name="content.css" hash="eb7a087c67578b6e3b5e0987caa4ba64"/><dir name="img"><file name="button_bg.png" hash="405ca3d63b48667ef485553192507f59"/></dir><file name="ui.css" hash="f0ec0273462e01b81e1dfd292f64451e"/></dir></dir></dir></dir><file name="tiny_mce.js" hash="199630688fff7a8bb0a549cd80187cbd"/><file name="tiny_mce_dev.js" hash="3a3819b032736635cc608076a02b3dbe"/><file name="tiny_mce_jquery.js" hash="87ee7a1967b86d56f5cdb1ba985ef4ce"/><file name="tiny_mce_jquery_src.js" hash="212727559aacdd03ea9ae6f5c6ede65a"/><file name="tiny_mce_popup.js" hash="5a318277fedf491a0301e177a9ef10b3"/><file name="tiny_mce_prototype.js" hash="0c65808fab93d86cf8552976f691b9c8"/><file name="tiny_mce_prototype_src.js" hash="3629c32a57bcf63cb52f455f18709223"/><file name="tiny_mce_src.js" hash="98575c8e6816a36f73145c2d97b0846a"/><dir name="utils"><file name="editable_selects.js" hash="e760eb21f60892a1ef2298da7df313e5"/><file name="form_utils.js" hash="579b2803ffca7953c50f53dcbef5df7e"/><file name="mctabs.js" hash="51b9bfe349fe76204ac5b65254bbef6f"/><file name="validate.js" hash="bfbaf5dc8058ff772afe2d87f4e82fbf"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_LinLibertineFont-2.8.14.18.xml b/var/package/Lib_LinLibertineFont-2.8.14.18.xml
deleted file mode 100644
index 5453196..0000000
--- a/var/package/Lib_LinLibertineFont-2.8.14.18.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_LinLibertineFont</name>
-    <version>2.8.14.18</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/gpl.html">GPL</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Libertine Open Fonts Project fonts for PDF print-outs</summary>
-    <description>Libertine Open Fonts Project fonts for PDF print-outs</description>
-    <notes>2.8.14.18</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:43</time>
-    <contents><target name="magelib"><dir name="LinLibertineFont"><file name="Bugs" hash="9ecefd5b5d739618917f6ff1a496af4d"/><file name="ChangeLog.txt" hash="c4a43af51dc70f4acbd09eeda8a1f95d"/><file name="GPL.txt" hash="ae32e069c670f1247694f4313efcc977"/><file name="LICENCE.txt" hash="9752e08000ee88048cb953607250dd7b"/><file name="LinLibertineC_Re-2.8.0.ttf" hash="7c98097ee899568bc86c28a8eafd77a3"/><file name="LinLibertine_Bd-2.8.1.ttf" hash="81c9c61a6c91fc6ccb93f1e6ec6ed06a"/><file name="LinLibertine_It-2.8.2.ttf" hash="5d334990c5d59bd428ae684ce8490c5c"/><file name="LinLibertine_Re-4.4.1.ttf" hash="de5bccf92a5145f4532b126f9506c28d"/><file name="OFL.txt" hash="6237e6976dcefd3d9fc3f1264b3c3bb9"/><file name="Readme" hash="9bbff4f7c21eb0a037527720e4b8473d"/><file name="Readme-TEX.txt" hash="14cb95ee0acecf6c3ef563f1b906443b"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_LinLibertineFont-2.8.14.19.xml b/var/package/Lib_LinLibertineFont-2.8.14.19.xml
new file mode 100644
index 0000000..c06436d
--- /dev/null
+++ b/var/package/Lib_LinLibertineFont-2.8.14.19.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_LinLibertineFont</name>
+    <version>2.8.14.19</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/gpl.html">GPL</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Libertine Open Fonts Project fonts for PDF print-outs</summary>
+    <description>Libertine Open Fonts Project fonts for PDF print-outs</description>
+    <notes>2.8.14.19</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:02</time>
+    <contents><target name="magelib"><dir name="LinLibertineFont"><file name="Bugs" hash="9ecefd5b5d739618917f6ff1a496af4d"/><file name="ChangeLog.txt" hash="c4a43af51dc70f4acbd09eeda8a1f95d"/><file name="GPL.txt" hash="ae32e069c670f1247694f4313efcc977"/><file name="LICENCE.txt" hash="9752e08000ee88048cb953607250dd7b"/><file name="LinLibertineC_Re-2.8.0.ttf" hash="7c98097ee899568bc86c28a8eafd77a3"/><file name="LinLibertine_Bd-2.8.1.ttf" hash="81c9c61a6c91fc6ccb93f1e6ec6ed06a"/><file name="LinLibertine_It-2.8.2.ttf" hash="5d334990c5d59bd428ae684ce8490c5c"/><file name="LinLibertine_Re-4.4.1.ttf" hash="de5bccf92a5145f4532b126f9506c28d"/><file name="OFL.txt" hash="6237e6976dcefd3d9fc3f1264b3c3bb9"/><file name="Readme" hash="9bbff4f7c21eb0a037527720e4b8473d"/><file name="Readme-TEX.txt" hash="14cb95ee0acecf6c3ef563f1b906443b"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Mage-1.9.4.1.xml b/var/package/Lib_Mage-1.9.4.1.xml
deleted file mode 100644
index 37c6d9b..0000000
--- a/var/package/Lib_Mage-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Mage</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Mage Library</summary>
-    <description>Mage Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:43</time>
-    <contents><target name="magelib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="885d30e2585116c9c5c3b35c579eb8cc"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="a4aeeebc126d4120438e0d28a35e043e"/></dir><file name="Archive.php" hash="e2fc609c9a68b600ee3d004ea47e11a4"/><dir name="Autoload"><file name="Simple.php" hash="0c93e10e43467dc314329567e4f1017a"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="3ca2f9e886689a5a177b1926af96270b"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="54069ee402c8aff0674969c649080647"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Cache"><dir name="Backend"><file name="File.php" hash="6cb7c7a675a38a8572367d2057760c5b"/><file name="Redis.php" hash="cfbc64fae1141401527d564e50b19975"/></dir></dir><dir name="Connect"><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="9392eea3bf03eeededfdb77189a77ed1"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="aeb7f173a74e88b126f24a5c423d238d"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="3f9fa5724199094218b7a423fc2188f1"/><file name="Package_Header.php" hash="99644d4f466ac78c1443a340c8ae73ef"/><file name="Registry.php" hash="3380f750bb96583b8e15024fe215b6da"/><file name="Registry_Header.php" hash="0f6571d92254cb88f697cc87300a8153"/><file name="Remote.php" hash="058b14285950694cd3abf2e82991fa59"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="7377f6955be0ef8df32ceea23bd43a05"/><file name="Config.php" hash="4fbfe162550121cdcc11573f5c8a3eef"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="f1b095d29a7e1441006c6ac8e07e5687"/></dir><file name="Frontend.php" hash="d2f246e8f0e5ada260676a12b4e79188"/><file name="Ftp.php" hash="72efa691308535fead42e7220a0ec853"/><dir name="Loader"><file name="Ftp.php" hash="a835c7fe4b0d2069c74134f152b78847"/></dir><file name="Loader.php" hash="5c6b2b24c4d5bf2343a61101156878a3"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="8f8c4f28da356e4a5893ac0523673a85"/></dir><file name="Package.php" hash="fe4dc41cbd8468e99a0b45072eb1fd66"/><file name="Packager.php" hash="7888f316b4d504708bde21844c05818f"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Rest.php" hash="bf1dd62f5ffe4c908b74d34e8361da05"/><file name="Singleconfig.php" hash="ca24a1a23c2a0d5033d8679cf3b33b00"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="616706e0605b61a63ea209174ee8f68c"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="e524751d0497a6142c2aaf2b8d94d310"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="01b98ec808157fe1ee18bdad2912e545"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="9ecc29ecd17c7a58063053bb5b44c6f9"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="f8800d0e16431a6d51869b8109912d8e"/><file name="Ftp.php" hash="191e30aa3d5917e3df81388e0914c35d"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Mage-1.9.4.2.xml b/var/package/Lib_Mage-1.9.4.2.xml
new file mode 100644
index 0000000..02e643c
--- /dev/null
+++ b/var/package/Lib_Mage-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Mage</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Mage Library</summary>
+    <description>Mage Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:03</time>
+    <contents><target name="magelib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="885d30e2585116c9c5c3b35c579eb8cc"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="a4aeeebc126d4120438e0d28a35e043e"/></dir><file name="Archive.php" hash="e2fc609c9a68b600ee3d004ea47e11a4"/><dir name="Autoload"><file name="Simple.php" hash="0c93e10e43467dc314329567e4f1017a"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="3ca2f9e886689a5a177b1926af96270b"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="54069ee402c8aff0674969c649080647"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Cache"><dir name="Backend"><file name="File.php" hash="6cb7c7a675a38a8572367d2057760c5b"/><file name="Redis.php" hash="cfbc64fae1141401527d564e50b19975"/></dir></dir><dir name="Connect"><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="9392eea3bf03eeededfdb77189a77ed1"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="aeb7f173a74e88b126f24a5c423d238d"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="3f9fa5724199094218b7a423fc2188f1"/><file name="Package_Header.php" hash="99644d4f466ac78c1443a340c8ae73ef"/><file name="Registry.php" hash="3380f750bb96583b8e15024fe215b6da"/><file name="Registry_Header.php" hash="0f6571d92254cb88f697cc87300a8153"/><file name="Remote.php" hash="058b14285950694cd3abf2e82991fa59"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="7377f6955be0ef8df32ceea23bd43a05"/><file name="Config.php" hash="4fbfe162550121cdcc11573f5c8a3eef"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="f1b095d29a7e1441006c6ac8e07e5687"/></dir><file name="Frontend.php" hash="d2f246e8f0e5ada260676a12b4e79188"/><file name="Ftp.php" hash="72efa691308535fead42e7220a0ec853"/><dir name="Loader"><file name="Ftp.php" hash="a835c7fe4b0d2069c74134f152b78847"/></dir><file name="Loader.php" hash="5c6b2b24c4d5bf2343a61101156878a3"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="8f8c4f28da356e4a5893ac0523673a85"/></dir><file name="Package.php" hash="fe4dc41cbd8468e99a0b45072eb1fd66"/><file name="Packager.php" hash="7888f316b4d504708bde21844c05818f"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Rest.php" hash="bf1dd62f5ffe4c908b74d34e8361da05"/><file name="Singleconfig.php" hash="ca24a1a23c2a0d5033d8679cf3b33b00"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="616706e0605b61a63ea209174ee8f68c"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="e524751d0497a6142c2aaf2b8d94d310"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="01b98ec808157fe1ee18bdad2912e545"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="9ecc29ecd17c7a58063053bb5b44c6f9"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="f8800d0e16431a6d51869b8109912d8e"/><file name="Ftp.php" hash="191e30aa3d5917e3df81388e0914c35d"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Magento-1.9.4.1.xml b/var/package/Lib_Magento-1.9.4.1.xml
deleted file mode 100644
index a8952a1..0000000
--- a/var/package/Lib_Magento-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Magento</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:44</time>
-    <contents><target name="magelib"><dir name="Magento"><dir name="Autoload"><file name="ClassMap.php" hash="d7d379df650db4eb4fc37168151c947c"/><file name="IncludePath.php" hash="c7917ae3d56f3a4b49f9b2ec79a135c4"/><file name="Simple.php" hash="a63a70fd7e06f77e2827a518de094961"/></dir><file name="Crypt.php" hash="4ef70800c1fa7c02d201c1fccf55d1a8"/><dir name="Db"><dir name="Adapter"><dir name="Pdo"><file name="Mysql.php" hash="55046e3803f80607287ae1d73e8ae14e"/></dir></dir><dir name="Object"><file name="Interface.php" hash="d54abcd0881635c5ac599af581d854bd"/><file name="Table.php" hash="58e1917b843b5523671cff24b632f4aa"/><file name="Trigger.php" hash="76c9abc78a55542112d2f0b963d286f7"/><file name="View.php" hash="cdc398ea71b49718dc07ca4644675058"/></dir><file name="Object.php" hash="7a511bb00c4e496ba81e943bd2e09855"/><dir name="Sql"><file name="Select.php" hash="898d4b91dbce179d1ccac6c9b64bebb4"/><file name="Trigger.php" hash="80bbbd22a7564c622ef07e648cd3da7a"/></dir></dir><file name="Exception.php" hash="794834095fb24ea0f5577069f7d336e7"/><dir name="Profiler"><dir name="Output"><file name="Csvfile.php" hash="b4aea3fd851994613172d0b27f8f0d6c"/><file name="Firebug.php" hash="d1665ccdde2353e4fc35c7b0254f8161"/><file name="Html.php" hash="704b989bf1009b94b55be3cf8b5d40c8"/></dir><file name="OutputAbstract.php" hash="531e71bf6953ea65a449a8ba417c1500"/></dir><file name="Profiler.php" hash="7c94820b4c445ee99fd7ad1d61431cd6"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Magento-1.9.4.2.xml b/var/package/Lib_Magento-1.9.4.2.xml
new file mode 100644
index 0000000..05a0ca1
--- /dev/null
+++ b/var/package/Lib_Magento-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Magento</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="Magento"><dir name="Autoload"><file name="ClassMap.php" hash="d7d379df650db4eb4fc37168151c947c"/><file name="IncludePath.php" hash="c7917ae3d56f3a4b49f9b2ec79a135c4"/><file name="Simple.php" hash="a63a70fd7e06f77e2827a518de094961"/></dir><file name="Crypt.php" hash="4ef70800c1fa7c02d201c1fccf55d1a8"/><dir name="Db"><dir name="Adapter"><dir name="Pdo"><file name="Mysql.php" hash="55046e3803f80607287ae1d73e8ae14e"/></dir></dir><dir name="Object"><file name="Interface.php" hash="d54abcd0881635c5ac599af581d854bd"/><file name="Table.php" hash="58e1917b843b5523671cff24b632f4aa"/><file name="Trigger.php" hash="76c9abc78a55542112d2f0b963d286f7"/><file name="View.php" hash="cdc398ea71b49718dc07ca4644675058"/></dir><file name="Object.php" hash="7a511bb00c4e496ba81e943bd2e09855"/><dir name="Sql"><file name="Select.php" hash="898d4b91dbce179d1ccac6c9b64bebb4"/><file name="Trigger.php" hash="80bbbd22a7564c622ef07e648cd3da7a"/></dir></dir><file name="Exception.php" hash="794834095fb24ea0f5577069f7d336e7"/><dir name="Profiler"><dir name="Output"><file name="Csvfile.php" hash="b4aea3fd851994613172d0b27f8f0d6c"/><file name="Firebug.php" hash="d1665ccdde2353e4fc35c7b0254f8161"/><file name="Html.php" hash="704b989bf1009b94b55be3cf8b5d40c8"/></dir><file name="OutputAbstract.php" hash="531e71bf6953ea65a449a8ba417c1500"/></dir><file name="Profiler.php" hash="7c94820b4c445ee99fd7ad1d61431cd6"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Mcryptcompat-1.9.4.1.xml b/var/package/Lib_Mcryptcompat-1.9.4.1.xml
deleted file mode 100644
index 2f71d89..0000000
--- a/var/package/Lib_Mcryptcompat-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Mcryptcompat</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://www.opensource.org/licenses/mit-license.html">MIT</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Mcrypt Library</summary>
-    <description>PHP 7.1 removed the mcrypt extension. This provides a compatibility layer for legacy applications.</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Jim Wigginton</name><user>core</user><email>terrafrost@php.net</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:44</time>
-    <contents><target name="magelib"><dir name="mcryptcompat"><file name="mcrypt.php" hash="bf8efc3ef65399aba6c1f08e9b3adbe0"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Mcryptcompat-1.9.4.2.xml b/var/package/Lib_Mcryptcompat-1.9.4.2.xml
new file mode 100644
index 0000000..bc60d49
--- /dev/null
+++ b/var/package/Lib_Mcryptcompat-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Mcryptcompat</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://www.opensource.org/licenses/mit-license.html">MIT</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Mcrypt Library</summary>
+    <description>PHP 7.1 removed the mcrypt extension. This provides a compatibility layer for legacy applications.</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Jim Wigginton</name><user>core</user><email>terrafrost@php.net</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="mcryptcompat"><file name="mcrypt.php" hash="bf8efc3ef65399aba6c1f08e9b3adbe0"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Pelago-1.9.4.1.xml b/var/package/Lib_Pelago-1.9.4.1.xml
deleted file mode 100644
index 743fef2..0000000
--- a/var/package/Lib_Pelago-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Pelago</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Pelago Library</summary>
-    <description>Pelago Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:44</time>
-    <contents><target name="magelib"><dir name="Pelago"><file name="Emogrifier.php" hash="de3919d36c718834d9755dd1cb68df87"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Pelago-1.9.4.2.xml b/var/package/Lib_Pelago-1.9.4.2.xml
new file mode 100644
index 0000000..a0d979c
--- /dev/null
+++ b/var/package/Lib_Pelago-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Pelago</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Pelago Library</summary>
+    <description>Pelago Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="Pelago"><file name="Emogrifier.php" hash="de3919d36c718834d9755dd1cb68df87"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Phpseclib-1.9.4.1.xml b/var/package/Lib_Phpseclib-1.9.4.1.xml
deleted file mode 100644
index 35befb1..0000000
--- a/var/package/Lib_Phpseclib-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Phpseclib</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://www.gnu.org/licenses/lgpl.txt">LGPL v.3</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Phpseclib Library</summary>
-    <description>Phpseclib Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:44</time>
-    <contents><target name="magelib"><dir name="phpseclib"><dir name="Crypt"><file name="AES.php" hash="22d0024134a5291b96ba1e04ff5706cc"/><file name="Base.php" hash="30f53da6745acd05de335bbf8a81c171"/><file name="Blowfish.php" hash="af6bf1aa8864cba2be2cd01059504f8c"/><file name="DES.php" hash="dd4ec1b7a4b4a67d0b41fc45a3d9a060"/><file name="Hash.php" hash="eb18f40942a4431ef8704b7e3a8013fd"/><file name="RC2.php" hash="e26943cba9cf24f4231fc9fa52002eca"/><file name="RC4.php" hash="de8b1dcc1a3e0a18b4d0b27f9f56c063"/><file name="RSA.php" hash="450260568ddca20f50130fb54f3907a7"/><file name="Random.php" hash="93193a666526c63ba95629cd71504aef"/><file name="Rijndael.php" hash="e695ed56c5178ac7ee1f438e728f1f24"/><file name="TripleDES.php" hash="3c282665b77ed6a970f2f34ec0305953"/><file name="Twofish.php" hash="5eb765fe5f99cee6236198ef6b0ce273"/></dir><dir name="File"><file name="ANSI.php" hash="0bbcc6b7de2830e94d8653123441eabe"/><dir name="ASN1"><file name="Element.php" hash="c94013bbb82d49d0c467a5e48fc318bd"/></dir><file name="ASN1.php" hash="f08c586b9ae2d22439620659410e0d8f"/><file name="X509.php" hash="b1c6ed7a19714520d227eb9d951c0963"/></dir><dir name="Math"><file name="BigInteger.php" hash="ac5a5a2c4575e74393c3137cc76e0919"/></dir><dir name="Net"><file name="SCP.php" hash="6f04a3784d5b677391fac09b152d2c86"/><dir name="SFTP"><file name="Stream.php" hash="819f66e981bbd02ad8237413c8cb13a2"/></dir><file name="SFTP.php" hash="81b700bba41e7578744b87f0daf5da6d"/><file name="SSH1.php" hash="aa19523d08b5db590d8413795f7d9f41"/><file name="SSH2.php" hash="97b204231f064dd38b0751aaf7617e48"/></dir><dir name="PHP"><dir name="Compat"><dir name="Function"><file name="array_fill.php" hash="2c0a4268deed10ced9491155e2284a82"/><file name="bcpowmod.php" hash="37fc1de34085874a930eaa76888f0cb1"/><file name="str_split.php" hash="889ab2b0d90b0962ded2ee65f1bfbc37"/></dir></dir></dir><dir name="System"><dir name="SSH"><dir name="Agent"><file name="Identity.php" hash="0592ff991d07c93a2bcbb2dfcbd85e5b"/></dir><file name="Agent.php" hash="4d1554ca5700f3359c827a8cb9c9ca07"/></dir></dir><file name="bootstrap.php" hash="1fd3efc24ca047574642e5fe830e6194"/><file name="openssl.cnf" hash="b4409823562c617107907cd04d67c8fa"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Phpseclib-1.9.4.2.xml b/var/package/Lib_Phpseclib-1.9.4.2.xml
new file mode 100644
index 0000000..722af1a
--- /dev/null
+++ b/var/package/Lib_Phpseclib-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Phpseclib</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://www.gnu.org/licenses/lgpl.txt">LGPL v.3</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Phpseclib Library</summary>
+    <description>Phpseclib Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="phpseclib"><dir name="Crypt"><file name="AES.php" hash="22d0024134a5291b96ba1e04ff5706cc"/><file name="Base.php" hash="30f53da6745acd05de335bbf8a81c171"/><file name="Blowfish.php" hash="af6bf1aa8864cba2be2cd01059504f8c"/><file name="DES.php" hash="dd4ec1b7a4b4a67d0b41fc45a3d9a060"/><file name="Hash.php" hash="eb18f40942a4431ef8704b7e3a8013fd"/><file name="RC2.php" hash="e26943cba9cf24f4231fc9fa52002eca"/><file name="RC4.php" hash="de8b1dcc1a3e0a18b4d0b27f9f56c063"/><file name="RSA.php" hash="450260568ddca20f50130fb54f3907a7"/><file name="Random.php" hash="93193a666526c63ba95629cd71504aef"/><file name="Rijndael.php" hash="e695ed56c5178ac7ee1f438e728f1f24"/><file name="TripleDES.php" hash="3c282665b77ed6a970f2f34ec0305953"/><file name="Twofish.php" hash="5eb765fe5f99cee6236198ef6b0ce273"/></dir><dir name="File"><file name="ANSI.php" hash="0bbcc6b7de2830e94d8653123441eabe"/><dir name="ASN1"><file name="Element.php" hash="c94013bbb82d49d0c467a5e48fc318bd"/></dir><file name="ASN1.php" hash="f08c586b9ae2d22439620659410e0d8f"/><file name="X509.php" hash="b1c6ed7a19714520d227eb9d951c0963"/></dir><dir name="Math"><file name="BigInteger.php" hash="ac5a5a2c4575e74393c3137cc76e0919"/></dir><dir name="Net"><file name="SCP.php" hash="6f04a3784d5b677391fac09b152d2c86"/><dir name="SFTP"><file name="Stream.php" hash="819f66e981bbd02ad8237413c8cb13a2"/></dir><file name="SFTP.php" hash="81b700bba41e7578744b87f0daf5da6d"/><file name="SSH1.php" hash="aa19523d08b5db590d8413795f7d9f41"/><file name="SSH2.php" hash="97b204231f064dd38b0751aaf7617e48"/></dir><dir name="PHP"><dir name="Compat"><dir name="Function"><file name="array_fill.php" hash="3e4447472476fae11a7da92ed423312d"/><file name="bcpowmod.php" hash="2e8a52baa7152d7b68766fcb364775b2"/><file name="str_split.php" hash="a6a819d04367fbb16fcf774b7ba33a94"/></dir></dir></dir><dir name="System"><dir name="SSH"><dir name="Agent"><file name="Identity.php" hash="0592ff991d07c93a2bcbb2dfcbd85e5b"/></dir><file name="Agent.php" hash="4d1554ca5700f3359c827a8cb9c9ca07"/></dir></dir><file name="bootstrap.php" hash="1fd3efc24ca047574642e5fe830e6194"/><file name="openssl.cnf" hash="b4409823562c617107907cd04d67c8fa"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Unserialize-1.9.4.1.xml b/var/package/Lib_Unserialize-1.9.4.1.xml
deleted file mode 100644
index 15fc695..0000000
--- a/var/package/Lib_Unserialize-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Unserialize</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">Magento Core Edition</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Library</summary>
-    <description>Magento Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:45</time>
-    <contents><target name="magelib"><dir name="Unserialize"><file name="Parser.php" hash="2e8c12e6185b0479fbbc97c192e3506c"/><dir name="Reader"><file name="Arr.php" hash="28e3bbd54c4b71c6ff67ab4cc980e01e"/><file name="ArrKey.php" hash="69d3bd343bf5724e36f038c14983facf"/><file name="ArrValue.php" hash="3f7052850f22d567970d26405cac1aca"/><file name="Bool.php" hash="9eb2785c62cc29ae17aaccf563db303b"/><file name="Dbl.php" hash="f5140de1c3b69adeb94e245699b670e7"/><file name="Int.php" hash="fae6a1cc12c0f49e03862fefbfca9744"/><file name="Null.php" hash="01cbebcb0c7a8cc4959debf5f9197abe"/><file name="Str.php" hash="ad1fb0146566ac112708848f46ca997c"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_Unserialize-1.9.4.2.xml b/var/package/Lib_Unserialize-1.9.4.2.xml
new file mode 100644
index 0000000..49f5b04
--- /dev/null
+++ b/var/package/Lib_Unserialize-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Unserialize</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">Magento Core Edition</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Library</summary>
+    <description>Magento Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="Unserialize"><file name="Parser.php" hash="2e8c12e6185b0479fbbc97c192e3506c"/><dir name="Reader"><file name="Arr.php" hash="28e3bbd54c4b71c6ff67ab4cc980e01e"/><file name="ArrKey.php" hash="69d3bd343bf5724e36f038c14983facf"/><file name="ArrValue.php" hash="3f7052850f22d567970d26405cac1aca"/><file name="Bool.php" hash="9eb2785c62cc29ae17aaccf563db303b"/><file name="Dbl.php" hash="f5140de1c3b69adeb94e245699b670e7"/><file name="Int.php" hash="fae6a1cc12c0f49e03862fefbfca9744"/><file name="Null.php" hash="01cbebcb0c7a8cc4959debf5f9197abe"/><file name="Str.php" hash="ad1fb0146566ac112708848f46ca997c"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Lib_Varien-1.9.4.1.xml b/var/package/Lib_Varien-1.9.4.1.xml
deleted file mode 100644
index e59b462..0000000
--- a/var/package/Lib_Varien-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_Varien</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Varien Library</summary>
-    <description>Varien Library</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:45</time>
-    <contents><target name="magelib"><dir name="Varien"><file name="Autoload.php" hash="83df31b32908601ff8accdd77b3a6570"/><dir name="Cache"><dir name="Backend"><file name="Database.php" hash="4558bc9ea129984dff92225e5c906093"/><file name="Eaccelerator.php" hash="fdd6c0506169a715e59a7832d6713206"/><file name="Memcached.php" hash="d7352ab7c11f72bdda6d47734a20d2a4"/></dir><file name="Core.php" hash="8cbff322c428d6878a57733dee251db2"/></dir><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="aa07c8969ac7c8fca3d5884e3642bcb3"/><file name="Interface.php" hash="fc98355673ada6d3e0c83c274c19d11f"/></dir><file name="Action.php" hash="54f84922e0586b6c8d553b714553d483"/><dir name="Adapter"><file name="Abstract.php" hash="802883b133a2a24c49aee649a71f1825"/><dir name="Db"><file name="Table.php" hash="1c500fca0433926194d95b59be5da50a"/></dir><dir name="Http"><file name="Curl.php" hash="cb020fbec631754244c91b3b207ae2d9"/></dir><file name="Http.php" hash="b781730ed9e32ac995bff79b624cd986"/><file name="Interface.php" hash="376a5b2839eabbea5278147ce90abb4b"/><file name="Io.php" hash="4deae02038f64dbfc96d4954225d44d7"/><file name="Soap.php" hash="fe1eab70e9a8b079e14c49a770a64297"/><file name="Std.php" hash="6fc7283d42c4ac649e6cbef19c72f9a0"/><dir name="Zend"><file name="Cache.php" hash="382dc52125350b0f42d8f848add2e97a"/><file name="Db.php" hash="ee44aae9549aad006b398c72237b7bce"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="aa0e7b0922d141d7852f45c04acaf0d1"/><file name="Collection.php" hash="76c3b2d4d61ceb5c03c55374063d8c84"/><file name="Generic.php" hash="11d8b3f6a501ac3650aa5541376eea1b"/><file name="Interface.php" hash="38ffd9337b2463e7c65c80ed334f3af3"/></dir><file name="Exception.php" hash="16b20354f42fec8bdda1fd65f5e0ee18"/><dir name="Mapper"><file name="Abstract.php" hash="e895d317b69731452eae05e27fc63861"/><file name="Column.php" hash="ed7b17ba976591bd417b04103c032d99"/><file name="Interface.php" hash="32bf96e77d133ce506b84140cae8788e"/></dir><dir name="Parser"><file name="Abstract.php" hash="547315ff4562e1df05399927c12bd9d5"/><file name="Csv.php" hash="83c6df8fe7e94bb3b308714f1078b552"/><file name="Interface.php" hash="5b3ebb007ec8c128fb0291d266f0570f"/><file name="Serialize.php" hash="bb9ac58f4f49e66ec2a9fc15c8aea70b"/><dir name="Xml"><file name="Excel.php" hash="4421faf73c3dac535ea0f24bf4ca81c1"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="1623035ede75f21e0297236166a215e4"/><file name="Collection.php" hash="1f333c4138cf744e0bf7869f21e73b9e"/></dir><file name="Profile.php" hash="03bfbba826814962f3c42bfe3564e182"/><dir name="Validator"><file name="Abstract.php" hash="fb95584b2c52839d1ccd44d54e2eaa01"/><file name="Column.php" hash="2b636ba1a0a02ec4435fe53a61eefe0d"/><file name="Dryrun.php" hash="6c92bf4eea4b7dd52bd15ce538aad37f"/><file name="Interface.php" hash="bfca360c34a9c522b0e0ef82cf981dd3"/></dir></dir><file name="Convert.php" hash="1c68406f2e0c3a73f6d2387104b1a3dc"/><dir name="Crypt"><file name="Abstract.php" hash="011df9e3225b279c4b6560e8bb8e0428"/><file name="Mcrypt.php" hash="fc9ea287df54f9852e24bfed5d9d3ce5"/></dir><file name="Crypt.php" hash="bcb35e50d720bf63860d6efc63fbabdb"/><dir name="Data"><dir name="Collection"><file name="Db.php" hash="0368acf6151bede860ad5c55544063f7"/><file name="Filesystem.php" hash="0e6286ddcf1897a30a61e2b18cd09b8d"/></dir><file name="Collection.php" hash="2df83d72dada45878e2f6769805b2a96"/><dir name="Form"><file name="Abstract.php" hash="26cab9dd0a0d1206cd52e7ff18921611"/><dir name="Element"><file name="Abstract.php" hash="5ff02044990476d5b1e551ff26504567"/><file name="Button.php" hash="4fca414994ee5802820d2685bbd42f52"/><file name="Checkbox.php" hash="695e3a8cf4fcff4c9748c19a59e1912e"/><file name="Checkboxes.php" hash="af8b4f2a834ae33b1c88e55d5b0ebb00"/><file name="Collection.php" hash="77da6fbe771af0fd0ac21a1abad5375c"/><file name="Column.php" hash="1fc996bbd070e76884010bdbf3911e95"/><file name="Date.php" hash="0f048edb364a4bd244b53c975618aec6"/><file name="Datetime.php" hash="0a41fb17cbb707ecb73bbd18f263c399"/><file name="Editor.php" hash="4d1c28f25474e5939753f80c8832a054"/><file name="Fieldset.php" hash="3762ae485be0672cd360e22d3d6dabff"/><file name="File.php" hash="0fd2adca3bf64fb7bafd2f2ee6256657"/><file name="Gallery.php" hash="17de4da040848ee231feb958e6fd376d"/><file name="Hidden.php" hash="aafa27aef7c8627690c615c7a931d09d"/><file name="Image.php" hash="8b0818947fae070af5e15cba7c8ab88f"/><file name="Imagefile.php" hash="9cbaba642ad82387ffee20e897411126"/><file name="Label.php" hash="3fd825f28e4950915a41ba892d79fcba"/><file name="Link.php" hash="3dccac5b75d83a9be6baa3fcfbeec68d"/><file name="Multiline.php" hash="f7cc823504866ca65ac44e0104e491bd"/><file name="Multiselect.php" hash="26c9b48c08542b7ee72de706e492f138"/><file name="Note.php" hash="50063c006a00212caddedb38a87a056d"/><file name="Obscure.php" hash="a115890f5039f23a7adc9e16dfbe70cd"/><file name="Password.php" hash="0efb7743673f16499c03a5010a7b77e0"/><file name="Radio.php" hash="12c91f9d706aa95f9f5403afc8a64c23"/><file name="Radios.php" hash="3de26d652e0f38bc8bc87bc494d49566"/><dir name="Renderer"><file name="Interface.php" hash="37007cfe3e3c72ef25b11f0cf6ecca83"/></dir><file name="Reset.php" hash="13016bb7b85371cfcdd0971724960bd8"/><file name="Select.php" hash="7b6f4201e6f9d67d071e56304137a83a"/><file name="Submit.php" hash="8028d2ced5195be2e2ec48d6837437c8"/><file name="Text.php" hash="97fbb6865f668d3a728c97767bd132e9"/><file name="Textarea.php" hash="87c9ba8bad825a4b79686ae2598f6184"/><file name="Time.php" hash="7cc613f3ae502d6848890e08f03dcaec"/></dir><dir name="Filter"><file name="Date.php" hash="db74b10371cd790b816092c0396c9a93"/><file name="Datetime.php" hash="cc217bad27dd64f00321365807c7558f"/><file name="Escapehtml.php" hash="18170646fab195203459896e9e60ae48"/><file name="Interface.php" hash="59df343d05f57d3bf9ad7ddd0947a77f"/><file name="Striptags.php" hash="640c9f50c64dd95ee27cfe313f173e2f"/></dir></dir><file name="Form.php" hash="ab131826b74ed3a10d31d9f62b6b259c"/><dir name="Tree"><file name="Db.php" hash="ec1181ad3895fb284a96382128a20f61"/><file name="Dbp.php" hash="469b6348043d25fb898437856841cc79"/><dir name="Node"><file name="Collection.php" hash="894b62ae263c0134ffad85991ac3dee9"/></dir><file name="Node.php" hash="182d394ee942f1b43e74e09a3e03e38a"/></dir><file name="Tree.php" hash="55648442ae71e7178ed613c5a5f62148"/></dir><file name="Date.php" hash="e5633ee80d29f2c4d37a727539a3f4b2"/><dir name="Db"><dir name="Adapter"><file name="Interface.php" hash="45b43500799e07a4dee06c7fa0c5476c"/><file name="Mysqli.php" hash="60d034a0e9f7101f816b3c28399c56a8"/><dir name="Pdo"><file name="Mysql.php" hash="b751a77a9c214dd73ab0c1163ba72e02"/></dir></dir><dir name="Ddl"><file name="Table.php" hash="ee2db3d640dbc6894c24412c769268df"/></dir><file name="Exception.php" hash="0d4789e6f30f7a7ef4dfb4ccd0c170f4"/><file name="Helper.php" hash="5cf99fb372f50ba340d5aead53cd4208"/><file name="Select.php" hash="990f82d2e9c2f857a82bcd1767dd7684"/><dir name="Statement"><file name="Parameter.php" hash="5ad28b7d637943572958352ac94b4f9a"/><dir name="Pdo"><file name="Mysql.php" hash="d89336de4c80f6389564330efdd3de36"/></dir></dir><dir name="Tree"><file name="Exception.php" hash="1e0bb5144a0ddeb8e0fc9d131027b0d7"/><dir name="Node"><file name="Exception.php" hash="e25dc938220e7bf4a4ebb9a108b5d2cc"/></dir><file name="Node.php" hash="21620e7483feac19ff2586e8c95725ae"/><dir name="NodeSet"><file name="Exception.php" hash="1397d3b273ae824f13fa8427147a97a6"/></dir><file name="NodeSet.php" hash="96c7dc66089e12bdade0d2e857ff149d"/></dir><file name="Tree.php" hash="d755be61028aa1b24f9d8b1347f622ed"/></dir><file name="Debug.php" hash="d8189861656b0da46cb37c9b3766f5d3"/><dir name="Directory"><file name="Collection.php" hash="f7b5a07b0b4f2df3b36ea0cc0a5bcad6"/><file name="Factory.php" hash="c5d91520dcec96b71cb7ec98faa17057"/><file name="IFactory.php" hash="cfa6810941e34e3c3ef6eba359d66814"/><file name="a.txt" hash="026e450c46ac92ea375302955a4f42fb"/></dir><dir name="Event"><file name="Collection.php" hash="471c3c72741cb35d07ac91c9a85a498b"/><dir name="Observer"><file name="Collection.php" hash="bc756715513f1f6a7ae10ac799f345c7"/><file name="Cron.php" hash="2a9d3e29d0d6b1c24176dd0c32856555"/><file name="Regex.php" hash="63cfe9d637d0c0de8350e1080b49bfa4"/></dir><file name="Observer.php" hash="3c97ff427cfe0a08de3132ed21daaae6"/></dir><file name="Event.php" hash="91150d8313ab2fd9993013bcbacc72b3"/><file name="Exception.php" hash="aa0d83d218f712f916c03f7a79190389"/><dir name="File"><file name="Csv.php" hash="be3bfde4744a8b5d3fbf9ab542454c26"/><file name="CsvMulty.php" hash="f94c12c3aaf73780dcd31f967f7e466a"/><file name="Object.php" hash="b61957e11dee3356f2f115c6b52ca69a"/><dir name="Transfer"><dir name="Adapter"><file name="Http.php" hash="8daeb55bb020d8bcf28feee86d66a718"/></dir></dir><dir name="Uploader"><file name="Image.php" hash="422dac7a6347c032f83e14f1fc86e07b"/></dir><file name="Uploader.php" hash="ec947e50f553f9830a1ad4d2d7659085"/></dir><dir name="Filter"><dir name="Array"><file name="Grid.php" hash="65505e4fd2e926d4e85d991886831f7c"/></dir><file name="Array.php" hash="22eb10bd9b3677837298364270af7f84"/><file name="Email.php" hash="ae58e662d03948a1a3027fb0db032c75"/><file name="FormElementName.php" hash="20f765343435adeb2b5b25f0b297ae20"/><file name="Money.php" hash="5143d8a013808cd125789297bd393b4b"/><dir name="Object"><file name="Grid.php" hash="ffe87e23b82aa39bbed05c72ea349275"/></dir><file name="Object.php" hash="e8fa3670dd3c2abf1e2ea207da15ee3e"/><file name="Sprintf.php" hash="3651ab095c5a80fa66269078c7e088c7"/><dir name="Template"><file name="Simple.php" hash="f8d5fc519df002eec91320bf2c5d1b65"/><dir name="Tokenizer"><file name="Abstract.php" hash="b2ea9c4923890d7117a4f3a590bbe2b7"/><file name="Parameter.php" hash="38d46e28f4aeae6926f14e9b6e397c7a"/><file name="Variable.php" hash="d7c7081594072b2868361aae7865e83c"/></dir></dir><file name="Template.php" hash="7275f80bde808fe75c13150cf5245572"/></dir><dir name="Http"><dir name="Adapter"><file name="Curl.php" hash="930d5fe90e800319bcdfce8fe5b265f1"/></dir><file name="Client.php" hash="5e80a6051da1050e78742921a8d51dc1"/></dir><dir name="Image"><dir name="Adapter"><file name="Abstract.php" hash="98a297efcd312b3080f66ef7433be7cf"/><file name="Gd2.php" hash="129ec92e8529d535efef7ee3c8893d4c"/></dir><file name="Adapter.php" hash="85f0fbd720486910a30a23fdac001545"/></dir><file name="Image.php" hash="362c46214e9a5fecc72af8e948fe4f9b"/><dir name="Io"><file name="Abstract.php" hash="bb956b8f692477dd51d58d3945db6d85"/><file name="Exception.php" hash="b346d28ea3165f8026600124c7615564"/><file name="File.php" hash="48eaf08b241c41283d9520aa5d2a47fd"/><file name="Ftp.php" hash="c754d9a23a6d715f1b355d110208f128"/><file name="Interface.php" hash="a88c19f93828f4a2187ab5921c5a18e6"/><file name="Sftp.php" hash="55f977b370029afd3bee62e489d5d7d1"/></dir><dir name="Object"><file name="Cache.php" hash="7e9edfcc8fedea2059184ef237f28b37"/><file name="Mapper.php" hash="0ba64566287bda680391b996b38c19a2"/></dir><file name="Object.php" hash="a65322d769c9e40a53926f4ad5cd192d"/><dir name="Pear"><file name="Frontend.php" hash="253e0208f7b488167e825f22bdb8b1db"/><file name="Package.php" hash="351364f80d012550c0a78a73e99ede65"/><file name="Registry.php" hash="d9ab146f9555953d418023859a46ea78"/></dir><file name="Pear.php" hash="c4e8719324d78665db52674d2c898847"/><file name="Profiler.php" hash="88cd98aad2d9b3adec60f5e32fb159ea"/><dir name="Simplexml"><dir name="Config"><dir name="Cache"><file name="Abstract.php" hash="07de624696215a35278a490ad7ff98b8"/><file name="File.php" hash="4170f2792397ff9e6c179a8de4cb50bb"/></dir></dir><file name="Config.php" hash="7c49d3d0937856ec23a4b34e6b7995e1"/><file name="Element.php" hash="737cc893da6cd0ead13a4cee79de96a5"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF</name><channel>community</channel><min>1.12.10.17</min><max>1.12.10.17</max></package><extension><name>PDO</name><min/><max/></extension><extension><name>SPL</name><min/><max/></extension><extension><name>curl</name><min/><max/></extension><extension><name>SimpleXML</name><min/><max/></extension><extension><name>dom</name><min/><max/></extension><extension><name>gd</name><min/><max/></extension><extension><name>iconv</name><min/><max/></extension><extension><name>pdo_mysql</name><min/><max/></extension><extension><name>mcrypt</name><min/><max/></extension><extension><name>pcre</name><min/><max/></extension><extension><name>Reflection</name><min/><max/></extension><extension><name>session</name><min/><max/></extension></required></dependencies>
-</package>
diff --git a/var/package/Lib_Varien-1.9.4.2.xml b/var/package/Lib_Varien-1.9.4.2.xml
new file mode 100644
index 0000000..2ff8bcc
--- /dev/null
+++ b/var/package/Lib_Varien-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_Varien</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Varien Library</summary>
+    <description>Varien Library</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="Varien"><file name="Autoload.php" hash="83df31b32908601ff8accdd77b3a6570"/><dir name="Cache"><dir name="Backend"><file name="Database.php" hash="4558bc9ea129984dff92225e5c906093"/><file name="Eaccelerator.php" hash="fdd6c0506169a715e59a7832d6713206"/><file name="Memcached.php" hash="d7352ab7c11f72bdda6d47734a20d2a4"/></dir><file name="Core.php" hash="8cbff322c428d6878a57733dee251db2"/></dir><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="aa07c8969ac7c8fca3d5884e3642bcb3"/><file name="Interface.php" hash="fc98355673ada6d3e0c83c274c19d11f"/></dir><file name="Action.php" hash="54f84922e0586b6c8d553b714553d483"/><dir name="Adapter"><file name="Abstract.php" hash="802883b133a2a24c49aee649a71f1825"/><dir name="Db"><file name="Table.php" hash="1c500fca0433926194d95b59be5da50a"/></dir><dir name="Http"><file name="Curl.php" hash="cb020fbec631754244c91b3b207ae2d9"/></dir><file name="Http.php" hash="b781730ed9e32ac995bff79b624cd986"/><file name="Interface.php" hash="376a5b2839eabbea5278147ce90abb4b"/><file name="Io.php" hash="4deae02038f64dbfc96d4954225d44d7"/><file name="Soap.php" hash="fe1eab70e9a8b079e14c49a770a64297"/><file name="Std.php" hash="6fc7283d42c4ac649e6cbef19c72f9a0"/><dir name="Zend"><file name="Cache.php" hash="382dc52125350b0f42d8f848add2e97a"/><file name="Db.php" hash="ee44aae9549aad006b398c72237b7bce"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="aa0e7b0922d141d7852f45c04acaf0d1"/><file name="Collection.php" hash="76c3b2d4d61ceb5c03c55374063d8c84"/><file name="Generic.php" hash="11d8b3f6a501ac3650aa5541376eea1b"/><file name="Interface.php" hash="38ffd9337b2463e7c65c80ed334f3af3"/></dir><file name="Exception.php" hash="16b20354f42fec8bdda1fd65f5e0ee18"/><dir name="Mapper"><file name="Abstract.php" hash="e895d317b69731452eae05e27fc63861"/><file name="Column.php" hash="ed7b17ba976591bd417b04103c032d99"/><file name="Interface.php" hash="32bf96e77d133ce506b84140cae8788e"/></dir><dir name="Parser"><file name="Abstract.php" hash="547315ff4562e1df05399927c12bd9d5"/><file name="Csv.php" hash="83c6df8fe7e94bb3b308714f1078b552"/><file name="Interface.php" hash="5b3ebb007ec8c128fb0291d266f0570f"/><file name="Serialize.php" hash="bb9ac58f4f49e66ec2a9fc15c8aea70b"/><dir name="Xml"><file name="Excel.php" hash="4421faf73c3dac535ea0f24bf4ca81c1"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="1623035ede75f21e0297236166a215e4"/><file name="Collection.php" hash="1f333c4138cf744e0bf7869f21e73b9e"/></dir><file name="Profile.php" hash="03bfbba826814962f3c42bfe3564e182"/><dir name="Validator"><file name="Abstract.php" hash="fb95584b2c52839d1ccd44d54e2eaa01"/><file name="Column.php" hash="2b636ba1a0a02ec4435fe53a61eefe0d"/><file name="Dryrun.php" hash="6c92bf4eea4b7dd52bd15ce538aad37f"/><file name="Interface.php" hash="bfca360c34a9c522b0e0ef82cf981dd3"/></dir></dir><file name="Convert.php" hash="1c68406f2e0c3a73f6d2387104b1a3dc"/><dir name="Crypt"><file name="Abstract.php" hash="011df9e3225b279c4b6560e8bb8e0428"/><file name="Mcrypt.php" hash="fc9ea287df54f9852e24bfed5d9d3ce5"/></dir><file name="Crypt.php" hash="bcb35e50d720bf63860d6efc63fbabdb"/><dir name="Data"><dir name="Collection"><file name="Db.php" hash="0368acf6151bede860ad5c55544063f7"/><file name="Filesystem.php" hash="0e6286ddcf1897a30a61e2b18cd09b8d"/></dir><file name="Collection.php" hash="2df83d72dada45878e2f6769805b2a96"/><dir name="Form"><file name="Abstract.php" hash="26cab9dd0a0d1206cd52e7ff18921611"/><dir name="Element"><file name="Abstract.php" hash="5ff02044990476d5b1e551ff26504567"/><file name="Button.php" hash="4fca414994ee5802820d2685bbd42f52"/><file name="Checkbox.php" hash="695e3a8cf4fcff4c9748c19a59e1912e"/><file name="Checkboxes.php" hash="af8b4f2a834ae33b1c88e55d5b0ebb00"/><file name="Collection.php" hash="77da6fbe771af0fd0ac21a1abad5375c"/><file name="Column.php" hash="1fc996bbd070e76884010bdbf3911e95"/><file name="Date.php" hash="0f048edb364a4bd244b53c975618aec6"/><file name="Datetime.php" hash="0a41fb17cbb707ecb73bbd18f263c399"/><file name="Editor.php" hash="4d1c28f25474e5939753f80c8832a054"/><file name="Fieldset.php" hash="3762ae485be0672cd360e22d3d6dabff"/><file name="File.php" hash="0fd2adca3bf64fb7bafd2f2ee6256657"/><file name="Gallery.php" hash="17de4da040848ee231feb958e6fd376d"/><file name="Hidden.php" hash="aafa27aef7c8627690c615c7a931d09d"/><file name="Image.php" hash="8b0818947fae070af5e15cba7c8ab88f"/><file name="Imagefile.php" hash="9cbaba642ad82387ffee20e897411126"/><file name="Label.php" hash="3fd825f28e4950915a41ba892d79fcba"/><file name="Link.php" hash="3dccac5b75d83a9be6baa3fcfbeec68d"/><file name="Multiline.php" hash="f7cc823504866ca65ac44e0104e491bd"/><file name="Multiselect.php" hash="26c9b48c08542b7ee72de706e492f138"/><file name="Note.php" hash="50063c006a00212caddedb38a87a056d"/><file name="Obscure.php" hash="a115890f5039f23a7adc9e16dfbe70cd"/><file name="Password.php" hash="0efb7743673f16499c03a5010a7b77e0"/><file name="Radio.php" hash="12c91f9d706aa95f9f5403afc8a64c23"/><file name="Radios.php" hash="3de26d652e0f38bc8bc87bc494d49566"/><dir name="Renderer"><file name="Interface.php" hash="37007cfe3e3c72ef25b11f0cf6ecca83"/></dir><file name="Reset.php" hash="13016bb7b85371cfcdd0971724960bd8"/><file name="Select.php" hash="7b6f4201e6f9d67d071e56304137a83a"/><file name="Submit.php" hash="8028d2ced5195be2e2ec48d6837437c8"/><file name="Text.php" hash="97fbb6865f668d3a728c97767bd132e9"/><file name="Textarea.php" hash="87c9ba8bad825a4b79686ae2598f6184"/><file name="Time.php" hash="7cc613f3ae502d6848890e08f03dcaec"/></dir><dir name="Filter"><file name="Date.php" hash="db74b10371cd790b816092c0396c9a93"/><file name="Datetime.php" hash="cc217bad27dd64f00321365807c7558f"/><file name="Escapehtml.php" hash="18170646fab195203459896e9e60ae48"/><file name="Interface.php" hash="59df343d05f57d3bf9ad7ddd0947a77f"/><file name="Striptags.php" hash="640c9f50c64dd95ee27cfe313f173e2f"/></dir></dir><file name="Form.php" hash="ab131826b74ed3a10d31d9f62b6b259c"/><dir name="Tree"><file name="Db.php" hash="ec1181ad3895fb284a96382128a20f61"/><file name="Dbp.php" hash="469b6348043d25fb898437856841cc79"/><dir name="Node"><file name="Collection.php" hash="894b62ae263c0134ffad85991ac3dee9"/></dir><file name="Node.php" hash="182d394ee942f1b43e74e09a3e03e38a"/></dir><file name="Tree.php" hash="55648442ae71e7178ed613c5a5f62148"/></dir><file name="Date.php" hash="e5633ee80d29f2c4d37a727539a3f4b2"/><dir name="Db"><dir name="Adapter"><file name="Interface.php" hash="45b43500799e07a4dee06c7fa0c5476c"/><file name="Mysqli.php" hash="60d034a0e9f7101f816b3c28399c56a8"/><dir name="Pdo"><file name="Mysql.php" hash="b751a77a9c214dd73ab0c1163ba72e02"/></dir></dir><dir name="Ddl"><file name="Table.php" hash="ee2db3d640dbc6894c24412c769268df"/></dir><file name="Exception.php" hash="0d4789e6f30f7a7ef4dfb4ccd0c170f4"/><file name="Helper.php" hash="5cf99fb372f50ba340d5aead53cd4208"/><file name="Select.php" hash="990f82d2e9c2f857a82bcd1767dd7684"/><dir name="Statement"><file name="Parameter.php" hash="5ad28b7d637943572958352ac94b4f9a"/><dir name="Pdo"><file name="Mysql.php" hash="d89336de4c80f6389564330efdd3de36"/></dir></dir><dir name="Tree"><file name="Exception.php" hash="1e0bb5144a0ddeb8e0fc9d131027b0d7"/><dir name="Node"><file name="Exception.php" hash="e25dc938220e7bf4a4ebb9a108b5d2cc"/></dir><file name="Node.php" hash="21620e7483feac19ff2586e8c95725ae"/><dir name="NodeSet"><file name="Exception.php" hash="1397d3b273ae824f13fa8427147a97a6"/></dir><file name="NodeSet.php" hash="96c7dc66089e12bdade0d2e857ff149d"/></dir><file name="Tree.php" hash="d755be61028aa1b24f9d8b1347f622ed"/></dir><file name="Debug.php" hash="d8189861656b0da46cb37c9b3766f5d3"/><dir name="Directory"><file name="Collection.php" hash="f7b5a07b0b4f2df3b36ea0cc0a5bcad6"/><file name="Factory.php" hash="c5d91520dcec96b71cb7ec98faa17057"/><file name="IFactory.php" hash="cfa6810941e34e3c3ef6eba359d66814"/><file name="a.txt" hash="026e450c46ac92ea375302955a4f42fb"/></dir><dir name="Event"><file name="Collection.php" hash="471c3c72741cb35d07ac91c9a85a498b"/><dir name="Observer"><file name="Collection.php" hash="bc756715513f1f6a7ae10ac799f345c7"/><file name="Cron.php" hash="2a9d3e29d0d6b1c24176dd0c32856555"/><file name="Regex.php" hash="63cfe9d637d0c0de8350e1080b49bfa4"/></dir><file name="Observer.php" hash="3c97ff427cfe0a08de3132ed21daaae6"/></dir><file name="Event.php" hash="91150d8313ab2fd9993013bcbacc72b3"/><file name="Exception.php" hash="aa0d83d218f712f916c03f7a79190389"/><dir name="File"><file name="Csv.php" hash="be3bfde4744a8b5d3fbf9ab542454c26"/><file name="CsvMulty.php" hash="f94c12c3aaf73780dcd31f967f7e466a"/><file name="Object.php" hash="b61957e11dee3356f2f115c6b52ca69a"/><dir name="Transfer"><dir name="Adapter"><file name="Http.php" hash="8daeb55bb020d8bcf28feee86d66a718"/></dir></dir><dir name="Uploader"><file name="Image.php" hash="422dac7a6347c032f83e14f1fc86e07b"/></dir><file name="Uploader.php" hash="ec947e50f553f9830a1ad4d2d7659085"/></dir><dir name="Filter"><dir name="Array"><file name="Grid.php" hash="65505e4fd2e926d4e85d991886831f7c"/></dir><file name="Array.php" hash="22eb10bd9b3677837298364270af7f84"/><file name="Email.php" hash="ae58e662d03948a1a3027fb0db032c75"/><file name="FormElementName.php" hash="20f765343435adeb2b5b25f0b297ae20"/><file name="Money.php" hash="5143d8a013808cd125789297bd393b4b"/><dir name="Object"><file name="Grid.php" hash="ffe87e23b82aa39bbed05c72ea349275"/></dir><file name="Object.php" hash="e8fa3670dd3c2abf1e2ea207da15ee3e"/><file name="Sprintf.php" hash="3651ab095c5a80fa66269078c7e088c7"/><dir name="Template"><file name="Simple.php" hash="f8d5fc519df002eec91320bf2c5d1b65"/><dir name="Tokenizer"><file name="Abstract.php" hash="b2ea9c4923890d7117a4f3a590bbe2b7"/><file name="Parameter.php" hash="38d46e28f4aeae6926f14e9b6e397c7a"/><file name="Variable.php" hash="d7c7081594072b2868361aae7865e83c"/></dir></dir><file name="Template.php" hash="7275f80bde808fe75c13150cf5245572"/></dir><dir name="Http"><dir name="Adapter"><file name="Curl.php" hash="930d5fe90e800319bcdfce8fe5b265f1"/></dir><file name="Client.php" hash="5e80a6051da1050e78742921a8d51dc1"/></dir><dir name="Image"><dir name="Adapter"><file name="Abstract.php" hash="98a297efcd312b3080f66ef7433be7cf"/><file name="Gd2.php" hash="129ec92e8529d535efef7ee3c8893d4c"/></dir><file name="Adapter.php" hash="85f0fbd720486910a30a23fdac001545"/></dir><file name="Image.php" hash="362c46214e9a5fecc72af8e948fe4f9b"/><dir name="Io"><file name="Abstract.php" hash="bb956b8f692477dd51d58d3945db6d85"/><file name="Exception.php" hash="b346d28ea3165f8026600124c7615564"/><file name="File.php" hash="48eaf08b241c41283d9520aa5d2a47fd"/><file name="Ftp.php" hash="c754d9a23a6d715f1b355d110208f128"/><file name="Interface.php" hash="a88c19f93828f4a2187ab5921c5a18e6"/><file name="Sftp.php" hash="55f977b370029afd3bee62e489d5d7d1"/></dir><dir name="Object"><file name="Cache.php" hash="7e9edfcc8fedea2059184ef237f28b37"/><file name="Mapper.php" hash="0ba64566287bda680391b996b38c19a2"/></dir><file name="Object.php" hash="a65322d769c9e40a53926f4ad5cd192d"/><dir name="Pear"><file name="Frontend.php" hash="253e0208f7b488167e825f22bdb8b1db"/><file name="Package.php" hash="351364f80d012550c0a78a73e99ede65"/><file name="Registry.php" hash="d9ab146f9555953d418023859a46ea78"/></dir><file name="Pear.php" hash="c4e8719324d78665db52674d2c898847"/><file name="Profiler.php" hash="88cd98aad2d9b3adec60f5e32fb159ea"/><dir name="Simplexml"><dir name="Config"><dir name="Cache"><file name="Abstract.php" hash="07de624696215a35278a490ad7ff98b8"/><file name="File.php" hash="4170f2792397ff9e6c179a8de4cb50bb"/></dir></dir><file name="Config.php" hash="7c49d3d0937856ec23a4b34e6b7995e1"/><file name="Element.php" hash="737cc893da6cd0ead13a4cee79de96a5"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF</name><channel>community</channel><min>1.12.10.18</min><max>1.12.10.18</max></package><extension><name>PDO</name><min/><max/></extension><extension><name>SPL</name><min/><max/></extension><extension><name>curl</name><min/><max/></extension><extension><name>SimpleXML</name><min/><max/></extension><extension><name>dom</name><min/><max/></extension><extension><name>gd</name><min/><max/></extension><extension><name>iconv</name><min/><max/></extension><extension><name>pdo_mysql</name><min/><max/></extension><extension><name>mcrypt</name><min/><max/></extension><extension><name>pcre</name><min/><max/></extension><extension><name>Reflection</name><min/><max/></extension><extension><name>session</name><min/><max/></extension></required></dependencies>
+</package>
diff --git a/var/package/Lib_ZF-1.12.10.17.xml b/var/package/Lib_ZF-1.12.10.17.xml
deleted file mode 100644
index 8c29b90..0000000
--- a/var/package/Lib_ZF-1.12.10.17.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_ZF</name>
-    <version>1.12.10.17</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Zend Framework</summary>
-    <description>Zend Framework</description>
-    <notes>1.12.10.17</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:45</time>
-    <contents><target name="magelib"><dir name="Zend"><dir name="Acl"><dir name="Assert"><file name="Interface.php" hash="753f4c058211502ad047851c4550a121"/></dir><file name="Exception.php" hash="833945ed22a5631224398ec5d1a51736"/><dir name="Resource"><file name="Interface.php" hash="ec27f75c67a2ddb21ede3e8f5cf2188c"/></dir><file name="Resource.php" hash="1eac5e2cda19d6f595ce678ee9b27065"/><dir name="Role"><file name="Interface.php" hash="e61127c46f87a10799582eb5d58673ca"/><dir name="Registry"><file name="Exception.php" hash="1ab8aea40c56fb9754ea4d76cf022893"/></dir><file name="Registry.php" hash="b13b4d4f96691f26328aba33d2a725f6"/></dir><file name="Role.php" hash="4ffca60ba53123c02874b9f412a1d5a0"/></dir><file name="Acl.php" hash="9362ea321157987e2d667ce6ba6640c4"/><dir name="Amf"><dir name="Adobe"><file name="Auth.php" hash="5f1b8fa4bc0646bfc7e1a0248af99e4d"/><file name="DbInspector.php" hash="c945730a861cc8dfb79affc681d935cd"/><file name="Introspector.php" hash="1faa52d4a734963e2114f0244b4eb0fc"/></dir><dir name="Auth"><file name="Abstract.php" hash="eb1eebcde25e987e8cfd64b097a64438"/></dir><file name="Constants.php" hash="27f591080a8aa87a7603079496b03f31"/><file name="Exception.php" hash="c37e40e651b342f39763d2651a86e907"/><dir name="Parse"><dir name="Amf0"><file name="Deserializer.php" hash="91d9e217cf20c9012993d945e3f7e744"/><file name="Serializer.php" hash="fc6f4e7a3adcee15df87e6f5e918891d"/></dir><dir name="Amf3"><file name="Deserializer.php" hash="63f1c82ab2bf8029208347a5d6188cf9"/><file name="Serializer.php" hash="94893d06b63c1c7b89958790051a96b8"/></dir><file name="Deserializer.php" hash="6bf0ed466d51a8ed7d47842ae56b0c2e"/><file name="InputStream.php" hash="8825ad088d82c7b0e1eec7f1fc2a977f"/><file name="OutputStream.php" hash="f6954a735a7abc530b3d08c3a66a1610"/><dir name="Resource"><file name="MysqlResult.php" hash="f93006c3cf636f4426559266c7254301"/><file name="MysqliResult.php" hash="3ff39905a315dc50438612cdfd044003"/><file name="Stream.php" hash="9fac77c33d3b8a5932618b7140eb480e"/></dir><file name="Serializer.php" hash="89f6dade3493238bcebd57f7aec7c441"/><file name="TypeLoader.php" hash="2eb3de6c0c76a88c84e52d053db1b3c3"/></dir><dir name="Request"><file name="Http.php" hash="3ceb2e9419c58b42b8a91dfa518bdbe6"/></dir><file name="Request.php" hash="210fafeb570fabde64f45367aa2b818f"/><dir name="Response"><file name="Http.php" hash="9165da2b40ea937760d21e82d14fccfd"/></dir><file name="Response.php" hash="df120c6bdcd3624007e264387c3ea49d"/><dir name="Server"><file name="Exception.php" hash="b49d17bc0487b1f94e263edc3cd63b80"/></dir><file name="Server.php" hash="a382bc11323a9e000c8b903609842a60"/><dir name="Util"><file name="BinaryStream.php" hash="2be5bd9b9c7daf56a578bb98c79c4393"/></dir><dir name="Value"><file name="ByteArray.php" hash="3501ce99e15b597c7159a47a166585b3"/><file name="MessageBody.php" hash="8b61f8ee1c39105e5c19ee0c3df1eedf"/><file name="MessageHeader.php" hash="3719e3197128d0db242a664278740de3"/><dir name="Messaging"><file name="AbstractMessage.php" hash="3091614466f82c843414c7f780e2713f"/><file name="AcknowledgeMessage.php" hash="0102f33c15054d697d29ab872d587e75"/><file name="ArrayCollection.php" hash="5070cc263f4b56b4aa6a62110c563ae7"/><file name="AsyncMessage.php" hash="ad0d187dc1179ce2cad255fe5fbd00a6"/><file name="CommandMessage.php" hash="46b117af57383509740a975f1d35a801"/><file name="ErrorMessage.php" hash="cd980b1cc29739aa685d714e3645f5bd"/><file name="RemotingMessage.php" hash="acaa5c29b712d4d24168bb384d512bd8"/></dir><file name="TraitsInfo.php" hash="91da9ed050e8e44979a229eadf433bf4"/></dir></dir><dir name="Application"><dir name="Bootstrap"><file name="Bootstrap.php" hash="a54f574a13568e3b0d79f9792b58a77b"/><file name="BootstrapAbstract.php" hash="85403088f5775085724427f2db4e3f41"/><file name="Bootstrapper.php" hash="f6ffc93f65f911d74273c97480019ebc"/><file name="Exception.php" hash="592efcd13a2430fb8a8051c77af2bdbf"/><file name="ResourceBootstrapper.php" hash="b5697b89f0bee36d64f1323ae0e6fad7"/></dir><file name="Exception.php" hash="33b45075f371aa758ab73043d9bb345b"/><dir name="Module"><file name="Autoloader.php" hash="561bbbddfd1d5d66e9950b1c5435e822"/><file name="Bootstrap.php" hash="a982af99ca3f8583e7e06754c932bee6"/></dir><dir name="Resource"><file name="Cachemanager.php" hash="aed3b8889084e6b3b46b9e1ad2482309"/><file name="Db.php" hash="a5bc7745dd9416c3cee07ca45701672d"/><file name="Dojo.php" hash="ed17a22f02f2b4b52219cb1a8f5f283f"/><file name="Exception.php" hash="e7cc6162f923bea3163ab3c72a9144c2"/><file name="Frontcontroller.php" hash="4096de73ec4a62565475ade369fa2f10"/><file name="Layout.php" hash="cc29553ce7af25e5497433b38cb33d96"/><file name="Locale.php" hash="d9ddba5ce3e52cf74e06bcaa28e9f701"/><file name="Log.php" hash="6425ed565c8ffa8d6a2061b4bed90c77"/><file name="Mail.php" hash="43d891a5921b267f2298392f5de16f2e"/><file name="Modules.php" hash="de2fead30f02effe859de66503972e1a"/><file name="Multidb.php" hash="f958bb43354951af50a592a27c1de9c0"/><file name="Navigation.php" hash="fa7ac38efd17722bb2fd0181131af18d"/><file name="Resource.php" hash="fea870fdc0a7fe568ff6f7d1d10ab523"/><file name="ResourceAbstract.php" hash="5808f3f8a2c6a349aa21e4de678fef40"/><file name="Router.php" hash="54f15d496ef84d800897d8571523e5b5"/><file name="Session.php" hash="714544fe025fa8e5db47686b58fd410b"/><file name="Translate.php" hash="9b75da2a9e3f571a90f30f14bbe72582"/><file name="Useragent.php" hash="17a0a2deba744c0fd4091fb48958b782"/><file name="View.php" hash="18803d667bd908ccfc04edc3e39d209b"/></dir></dir><file name="Application.php" hash="a0c9ea8a48289b2bd9bafd2dfe76765c"/><dir name="Auth"><dir name="Adapter"><file name="DbTable.php" hash="c8b79405b8855b67ffd8d6f82e6a4045"/><file name="Digest.php" hash="bbc1edafb9a244774ca986a2790e5661"/><file name="Exception.php" hash="194d445ab6929d8c5a6faefe604c64a0"/><dir name="Http"><dir name="Resolver"><file name="Exception.php" hash="cf95d8463e66b8dcc7eb679aaa0127cb"/><file name="File.php" hash="56c75079c07a8f3081841dff74f4f8b5"/><file name="Interface.php" hash="136ff303d6f17f676641db12415a679e"/></dir></dir><file name="Http.php" hash="0cfb159e07de35d89ab6754c9e409b1e"/><file name="Interface.php" hash="9baba8292deab88415d58155627009ea"/><file name="Ldap.php" hash="5bec476c61237745110b07a6981f0ba7"/><file name="OpenId.php" hash="9b87324993b0882e8add83140b24799b"/></dir><file name="Exception.php" hash="0cbee6397372cb825d4d2330f1e01cbf"/><file name="Result.php" hash="011bad9ebfb3e12cde52dc199c1b9b0c"/><dir name="Storage"><file name="Exception.php" hash="7c0657994ccacd29c396728dd3e40ead"/><file name="Interface.php" hash="336438156ed6a7db4183fbb365ec24e0"/><file name="NonPersistent.php" hash="88366aa8fd16a4c565e7a6cf467c9d45"/><file name="Session.php" hash="128255a8d51a1d9fa137e137f17b773f"/></dir></dir><file name="Auth.php" hash="6ec79877089d5629bf32dc9cfca8a5ed"/><dir name="Barcode"><file name="Exception.php" hash="5cf74c43e0bb3bda36dab4cdcf435a7c"/><dir name="Object"><file name="Code128.php" hash="989d2bf6723d392c704a9d793a0870c6"/><file name="Code25.php" hash="945a62bd63cefd4bc548aca2175a798e"/><file name="Code25interleaved.php" hash="163795899dd207d6777ed489b3652783"/><file name="Code39.php" hash="6a9d919307643317d2670d0b5a0cfc75"/><file name="Ean13.php" hash="d073b0b3b0d548aa553128e61a8f739e"/><file name="Ean2.php" hash="244bfc6ef32a4d56629c045c929138f1"/><file name="Ean5.php" hash="198f60f22d8bb1d165bff02c5820a20b"/><file name="Ean8.php" hash="8cea912422779ab67e11d8a169063216"/><file name="Error.php" hash="20edaea0778ac6253009722af4bc1ba8"/><file name="Exception.php" hash="4222bc4babead0b78ff6cd53aa72e359"/><file name="Identcode.php" hash="8a1ac5c7c3b04d3e62aa8265c4e1c2f7"/><file name="Itf14.php" hash="9384e00165c9961a203d1f135a3eaa5d"/><file name="Leitcode.php" hash="3c805e7d37dfb51e8de1f35d16ed5da5"/><file name="ObjectAbstract.php" hash="017bd4e5560bfddab60971b889d9f0a0"/><file name="Planet.php" hash="e1c10362fbc9baa5aabede9041060d79"/><file name="Postnet.php" hash="5f6845e59e609f8991fa580bbdc5eefc"/><file name="Royalmail.php" hash="8cc2c93b813ed89f4b0f6cd60df29f77"/><file name="Upca.php" hash="1485da9e266c49e993a00f9d287b4019"/><file name="Upce.php" hash="7cbde278294ce55ff3cb0857f5c014c5"/></dir><dir name="Renderer"><file name="Exception.php" hash="8579d580dcc35ccd16c82590ff39c1b9"/><file name="Image.php" hash="dba737459af451c5c51bad867b77a0a6"/><file name="Pdf.php" hash="1e2d590fe769d9ebf74d901a34635aa7"/><file name="RendererAbstract.php" hash="359cbfacb66cc0fb5ae362845b3fbf58"/><file name="Svg.php" hash="93544d770411772a4dc2c995cced685e"/></dir></dir><file name="Barcode.php" hash="0586994cdf9871ebabd7aa8079566258"/><dir name="Cache"><dir name="Backend"><file name="Apc.php" hash="0770aacd96ff057d06978bcc7a22035e"/><file name="BlackHole.php" hash="f51e1f122876be7d7ba667e39c540901"/><file name="ExtendedInterface.php" hash="fb6c1f28d7049d8ebb5b367586a386b4"/><file name="File.php" hash="292986e780e4b420968b5dfa15267a01"/><file name="Interface.php" hash="9e9a235e4aa33de40ff9fbc97efa468d"/><file name="Libmemcached.php" hash="2f9d3d284be576c031ff2195afaabc20"/><file name="Memcached.php" hash="cbee447e2af7453a2a37ddee2206f971"/><file name="Sqlite.php" hash="8c2ffff28dbe7e5c27a2bfb6fa1a4759"/><file name="Static.php" hash="8b4e8ac2f3e416316d447266e1a6f8dd"/><file name="Test.php" hash="6bcaf9deb1e13215d9fada844fa0bb25"/><file name="TwoLevels.php" hash="1d48225fde0e61fc38401841b28740da"/><file name="WinCache.php" hash="57da7293a57294e3cc2878d872230aea"/><file name="Xcache.php" hash="364f350bb7e58a221a9dda26dfd940d3"/><file name="ZendPlatform.php" hash="dd2264172835c8ac2b1cd0eba670d1ee"/><dir name="ZendServer"><file name="Disk.php" hash="092b29cf8ea2e0391e156ca38a9c8dbd"/><file name="ShMem.php" hash="94d219bd689df1b0ce1f5fe48c0fda7e"/></dir><file name="ZendServer.php" hash="6397a63f6ceba054b9c4c774451109a6"/></dir><file name="Backend.php" hash="046904b4b5c7661bbdcb6c3ec7969af3"/><file name="Core.php" hash="26e9ed27936fe7c894f36a1241b6aa35"/><file name="Exception.php" hash="64896658ade26dbd6b15851aee788379"/><dir name="Frontend"><file name="Capture.php" hash="5e7254e902e587587a9f7c1749787690"/><file name="Class.php" hash="e0fba9da74e040fc5fcbfeede03147d2"/><file name="File.php" hash="291450665f2b240c3a1d0b8f81d9e505"/><file name="Function.php" hash="80926f9d0d94953c8534f381b3e9e92b"/><file name="Output.php" hash="b3902a3f0ddf1b4608b84f6172a317e6"/><file name="Page.php" hash="d447d1e18b8c9ccfe95f5cbd4f8ad0aa"/></dir><file name="Manager.php" hash="bba8e1dfc892616eccc5f033d3849aec"/></dir><file name="Cache.php" hash="dd6b3426e3682f832f5e73a5a5e7bbe4"/><dir name="Captcha"><file name="Adapter.php" hash="c80da3e14f86386865a1a11f386509f0"/><file name="Base.php" hash="f3f587f183c8dbb0f71b588a99f56728"/><file name="Dumb.php" hash="42cf7479a157ab4f6d92f4ea2edd402f"/><file name="Exception.php" hash="a1ea444d80d4629ae987f5120d7b6ab4"/><file name="Figlet.php" hash="9434c31c17fa4558d823f72863bda27e"/><file name="Image.php" hash="8f1bb1448407f673d986cc387846bf3f"/><file name="ReCaptcha.php" hash="7213da2f0082b6a209bf5659d5279036"/><file name="Word.php" hash="2b20aa38f1132306e259f4032ad1de6e"/></dir><dir name="Cloud"><file name="AbstractFactory.php" hash="0360f699d631c5eb6f1f5e117a2a6524"/><dir name="DocumentService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="3679fe7eef0b73516d98565b35e90366"/><dir name="SimpleDb"><file name="Query.php" hash="163f21a702cb5aa76d58682d29559bd2"/></dir><file name="SimpleDb.php" hash="78628ea1029ec6f267c83c302611b6e8"/><dir name="WindowsAzure"><file name="Query.php" hash="657934a415bd7d731906ebb3fa42187d"/></dir><file name="WindowsAzure.php" hash="9a48103bc6327e24a98f27307641c397"/></dir><file name="Adapter.php" hash="22799d67b8935e871e9fcb5403617a9d"/><file name="Document.php" hash="e76315e7e307aa99dae6d634b51c2ece"/><file name="DocumentSet.php" hash="53cabe8e2d6454beab6b476953fb9a58"/><file name="Exception.php" hash="e69eb63ef3ac0476422e553c0f9d0b7c"/><file name="Factory.php" hash="d11189e3ba364466584a8461e9bea29b"/><file name="Query.php" hash="dcf377f4d08e1adc178dcef42a7e21d4"/><file name="QueryAdapter.php" hash="b683d5360841a57b8b58f0ac937b4991"/></dir><file name="Exception.php" hash="baa1da441578d83ef668c947bc26993a"/><dir name="Infrastructure"><dir name="Adapter"><file name="AbstractAdapter.php" hash="1a0c85424e055522ed27fd848641adb9"/><file name="Ec2.php" hash="f702d42320cb2a843124faeff6308673"/><file name="Rackspace.php" hash="12ca011eaa260a98e5f0b021497d6d9f"/></dir><file name="Adapter.php" hash="8fd0db5ff41dd87d2730981cf6a651e6"/><file name="Exception.php" hash="dd74945bd044a9b569715d8b8f33d6c6"/><file name="Factory.php" hash="e35fedab839a9897bd494b4525c70d74"/><file name="Image.php" hash="d0b5a851095a8a6d00cc758e66de65d0"/><file name="ImageList.php" hash="330f4330efa43095c73963860719d8dc"/><file name="Instance.php" hash="aa600d04524311d6da4bfac324aae00f"/><file name="InstanceList.php" hash="9f5c27c450518e4090aa5200261e0804"/></dir><file name="OperationNotAvailableException.php" hash="cb15f6dfb2c6caf15bf3d3c7192a2859"/><dir name="QueueService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="6aafd9d7c44e76e68dd7b8ea83aea6fe"/><file name="Sqs.php" hash="03b431d971a7679aa43dba8d235fd9bb"/><file name="WindowsAzure.php" hash="b4762cebc1460850e73552d5a617ea6d"/><file name="ZendQueue.php" hash="d8aaa2f4ec3302693fcaee2833339bac"/></dir><file name="Adapter.php" hash="c950feca6fdab3f115ba62146e9c4061"/><file name="Exception.php" hash="0406a9d40baf106b1e7c7a52c58622ce"/><file name="Factory.php" hash="1489be14015fdbc7364317e2e6fdb4dc"/><file name="Message.php" hash="48907828e50d23674d1500834ac33d96"/><file name="MessageSet.php" hash="f4371e5f68036dbea532b7899c59679c"/></dir><dir name="StorageService"><dir name="Adapter"><file name="FileSystem.php" hash="c2066ccb70e97bfccf1dc6eca5beabed"/><file name="Rackspace.php" hash="d5b49d598b7a2ca875599df0c07d17e2"/><file name="S3.php" hash="36d663a296803282ec6ffbb4d1f6ecf7"/><file name="WindowsAzure.php" hash="1c266330be81f9034e491cdc5c0becee"/></dir><file name="Adapter.php" hash="4bf256cad4b27a0b4ccd0ea0d2e5df44"/><file name="Exception.php" hash="b1938d4a1d75a132c7896c9d1d49c316"/><file name="Factory.php" hash="e60551fd66495592c25f2143683c0eae"/></dir></dir><dir name="CodeGenerator"><file name="Abstract.php" hash="8bb5c3fb76b0953dad77b8aefd240552"/><file name="Exception.php" hash="2f35c31886c1506cbce95bd48ceb8302"/><dir name="Php"><file name="Abstract.php" hash="7ffc414197119b98d09c089d38b745cf"/><file name="Body.php" hash="4354cf77549e88c8ef742f74df428824"/><file name="Class.php" hash="e96e076b5e9a7a41b9dff5d65d65cbf8"/><dir name="Docblock"><dir name="Tag"><file name="License.php" hash="fa6989bdda9dcc8eed58dfcd5cd11d3e"/><file name="Param.php" hash="c5402463f594b0ada366547e2140c087"/><file name="Return.php" hash="d36a1b1dbd2383043b9703449212218e"/></dir><file name="Tag.php" hash="94c4d5bf7254f1122a9140578562cf4a"/></dir><file name="Docblock.php" hash="3630eee3a36264ed70bb414b1b6659d2"/><file name="Exception.php" hash="4d0d644d274ba0d93c86edabe96a937a"/><file name="File.php" hash="16190c6965142355870ea2d86065c2f3"/><dir name="Member"><file name="Abstract.php" hash="a07d1b1c01755725fd9c670b83e14c6e"/><file name="Container.php" hash="52c0f2936e0dd96e3efaca239e97a537"/></dir><file name="Method.php" hash="facb978030d8ed1148d3fd9b27647a5c"/><dir name="Parameter"><file name="DefaultValue.php" hash="402dc7efb5a973be4b3695d97df9d5e6"/></dir><file name="Parameter.php" hash="f963e92d375973d82c64e9aeeb99aa68"/><dir name="Property"><file name="DefaultValue.php" hash="23583ff2c6b01162f217d3f18e17f5bb"/></dir><file name="Property.php" hash="5d85c620c090d866edd2cc4af3bb0737"/></dir></dir><dir name="Config"><file name="Exception.php" hash="825b93db4d92fc10ff2334d0701ac39a"/><file name="Ini.php" hash="bc377745cc51608820d81f08bb5e622c"/><file name="Json.php" hash="191c7eb21cbb2042491e5548a59087a4"/><dir name="Writer"><file name="Array.php" hash="fa6b3a9d9f68cc5973db7309b93454eb"/><file name="FileAbstract.php" hash="14f344ccee37bac7224aa203e5be6bf5"/><file name="Ini.php" hash="c658c697e401b7fab66edac3e5ab5edf"/><file name="Json.php" hash="675cff174476aab6e44540ce20b9ef6f"/><file name="Xml.php" hash="0ff4954d3f6be816d2911cc236d588de"/><file name="Yaml.php" hash="0a6d7e361af7f4f5cff8a9eb81264318"/></dir><file name="Writer.php" hash="7bca990f32b4a7bf64b6d7bcd6a8b144"/><file name="Xml.php" hash="24d64c4d3269a55f1577d40717069b3f"/><file name="Yaml.php" hash="d559550b7de8c77f03a6d8c5ab1af715"/></dir><file name="Config.php" hash="0ec674c135a25bb65bf7f2f536496373"/><dir name="Console"><dir name="Getopt"><file name="Exception.php" hash="ba4d96e50ff729964f51d3ff320a695b"/></dir><file name="Getopt.php" hash="a8165d6a04ff959844c118bd1517d4af"/></dir><dir name="Controller"><dir name="Action"><file name="Exception.php" hash="5c5bfb99e09c49bfd42afc92cca046a3"/><dir name="Helper"><file name="Abstract.php" hash="2db15ec4775320a42a86fc96ded791f6"/><file name="ActionStack.php" hash="72d618b0c01345a39b86362d00b519e5"/><file name="AjaxContext.php" hash="d25cd19237deee404b1d78c3babc51e6"/><dir name="AutoComplete"><file name="Abstract.php" hash="8265a4c01db3fc5ef8359855b5bc7de7"/></dir><file name="AutoCompleteDojo.php" hash="bc727565a422d34c4ee642604bca989f"/><file name="AutoCompleteScriptaculous.php" hash="423035f705a0ead78f0b508915f9f11d"/><file name="Cache.php" hash="5e1ee2f20930ce3ce6c9ff95c7986fd5"/><file name="ContextSwitch.php" hash="bbde32302aea3a45df7525ee558ba61b"/><file name="FlashMessenger.php" hash="6f60de563b5b400d75b630f359ce09be"/><file name="Json.php" hash="46f702a70e0d5e4ecff66439b34502aa"/><file name="Redirector.php" hash="246b26f4b71cdab25a5992577986b119"/><file name="Url.php" hash="16c5a98afe9f6f14bee59bbb0ee58583"/><file name="ViewRenderer.php" hash="6eac5b3e0152d2c000145c6a4076456a"/></dir><dir name="HelperBroker"><file name="PriorityStack.php" hash="9919f1af00251ac5d7a362dba0a280c8"/></dir><file name="HelperBroker.php" hash="aa9cf211934ac5b4fc9e4220ad26d7ca"/><file name="Interface.php" hash="0cb0ece63ce5a245010b9c79927149fe"/></dir><file name="Action.php" hash="1eff5915284945de72327a06cb10c10a"/><dir name="Dispatcher"><file name="Abstract.php" hash="3a481b8b2beb61d223f1c90757339a6d"/><file name="Exception.php" hash="21e0c2b4a1f642448f391e0601bf8327"/><file name="Interface.php" hash="323c3bfe932dca40b3f0f18ebaa39bf4"/><file name="Standard.php" hash="ccbde33f1d7616c2c35ee556039b12a0"/></dir><file name="Exception.php" hash="75ef40958ca34b2ce0007a6a9bd11b62"/><file name="Front.php" hash="a0cd827d65e2d2cc1d51d96009d61032"/><dir name="Plugin"><file name="Abstract.php" hash="4f9c2a5fcb32f0f02d01559c2900e2ff"/><file name="ActionStack.php" hash="dc0f223ebf96304711e62b0ff066cbe6"/><file name="Broker.php" hash="4558d24e01418e1a7a4a45f8a0419b05"/><file name="ErrorHandler.php" hash="1b86cb0d967cb3a80091271532e5f29f"/><file name="PutHandler.php" hash="5b65c0f667538e81cd5152060b1fc50e"/></dir><dir name="Request"><file name="Abstract.php" hash="479150985f9f5b1ad60da1c627ba5422"/><file name="Apache404.php" hash="6e4073adcf927bc08c36267350259110"/><file name="Exception.php" hash="401a6bfe6ee4f2eef739d5622d457235"/><file name="Http.php" hash="4866762dc4e2d7f2f70ebcf3ec3f3174"/><file name="HttpTestCase.php" hash="fee8b0ea3da866bae3125716977e609a"/><file name="Simple.php" hash="4debb461f0bf9c865b3ef7e9a2f9eec1"/></dir><dir name="Response"><file name="Abstract.php" hash="41812ba5c1950b91ca6db21c36a65022"/><file name="Cli.php" hash="1be9de58bd3af4e70797422c5936b9f0"/><file name="Exception.php" hash="daf74bb0fb6ffed9c50a414b78947388"/><file name="Http.php" hash="1b97675e6f09aca759dd04cadc2ada31"/><file name="HttpTestCase.php" hash="b8e25dbcd9245fce7f9e985aedb53ab2"/></dir><dir name="Router"><file name="Abstract.php" hash="7c3976721fbba2c462793f6152a7952a"/><file name="Exception.php" hash="10f91dd02d28dfb9c5de84d778f5e451"/><file name="Interface.php" hash="3f0e4586ac18e02e172ff65e1228a197"/><file name="Rewrite.php" hash="333634b9f184476914d985f68d06b12a"/><dir name="Route"><file name="Abstract.php" hash="c0437b622e03a117783fc6d8c2a581da"/><file name="Chain.php" hash="eb747ff18f4f5549888a7964b8f16f2e"/><file name="Hostname.php" hash="b54e6b9f68ffa63f9c493f82606ab2ac"/><file name="Interface.php" hash="80dd1da3a1fe916fcf173891716985cc"/><file name="Module.php" hash="dca7ac356221ebd066c5b17a72557551"/><file name="Regex.php" hash="4bcd3642f6ee8d66b9ec9cf591cfa121"/><file name="Static.php" hash="2bc26cb37610470e8fbb0e9302e76175"/></dir><file name="Route.php" hash="9be953ae63b6074535656826c99f88dd"/></dir></dir><dir name="Crypt"><dir name="DiffieHellman"><file name="Exception.php" hash="27066062da23c7b0b5c8ea405d63424f"/></dir><file name="DiffieHellman.php" hash="b146591071090ba7dc2d120c8d7cfcb1"/><file name="Exception.php" hash="98d264f8b46a12e8e1fa644b37488636"/><dir name="Hmac"><file name="Exception.php" hash="3b8bf2fed9087ce573c7d9e461211d01"/></dir><file name="Hmac.php" hash="7beea2bae905ad98fc8212a5a2ba906c"/><dir name="Math"><dir name="BigInteger"><file name="Bcmath.php" hash="7ad0514366aa1cfbbacf9a841d17209d"/><file name="Exception.php" hash="c7047b1ec96c2c5bf9d2ec8fd516c232"/><file name="Gmp.php" hash="1e136ad9748ff4e120be567de7195084"/><file name="Interface.php" hash="a1a15aadc0d1232e19e3660778e25a4e"/></dir><file name="BigInteger.php" hash="5941fbc6fa7558f254212a5c704de46f"/><file name="Exception.php" hash="0a2a9e2cdf2619549bb1891d31565cb4"/></dir><file name="Math.php" hash="0e54c36e33bb980ba251c42719e72e48"/><dir name="Rsa"><file name="Exception.php" hash="9af79ec754f6202584671b395e9898cb"/><dir name="Key"><file name="Private.php" hash="6b8486eba224159d7c05dea23039ec8e"/><file name="Public.php" hash="8cd4ac9225b58e1a2990659f4a97a45d"/></dir><file name="Key.php" hash="a0c0daf511c3a74d1e754faeaace0f83"/></dir><file name="Rsa.php" hash="e46289dffb56184f7c15faa3b24a0a68"/></dir><file name="Crypt.php" hash="ae1d981cb224263c8625604621d0ffc9"/><dir name="Currency"><file name="CurrencyInterface.php" hash="c52c23140b8d66185e2792cb10c65b40"/><file name="Exception.php" hash="f04c4fcb9b9b4117ab0c91e688904a06"/></dir><file name="Currency.php" hash="e380eca83740d28bb55435c3489204cf"/><dir name="Date"><file name="Cities.php" hash="4698b47f264db687c97ea7fa5ccd717e"/><file name="DateObject.php" hash="05ef22746ef2b1925cce51d42a5670b9"/><file name="Exception.php" hash="b91a2d166cf91afa1325a07747bafe57"/></dir><file name="Date.php" hash="6d17472f661d6b599477f215dda67f82"/><dir name="Db"><dir name="Adapter"><file name="Abstract.php" hash="7d5a1b64e9f292c018fec8fca159311b"/><dir name="Db2"><file name="Exception.php" hash="b64143620db1d7e5cd7b90312aeaf7bf"/></dir><file name="Db2.php" hash="d27757593a5be92da47326b25af8b4a4"/><file name="Exception.php" hash="461a43822f24e3e79bf8a844541235a3"/><dir name="Mysqli"><file name="Exception.php" hash="71ae5837eee0e261ba7639dff878845c"/></dir><file name="Mysqli.php" hash="c997a7381205b413a03efba602f2debd"/><dir name="Oracle"><file name="Exception.php" hash="8a08377363d09d1711c31ed0e2b4f220"/></dir><file name="Oracle.php" hash="2c539f9ac5ce7e656f3432c9aa00daae"/><dir name="Pdo"><file name="Abstract.php" hash="1f71eaf0415b750ee0573a80374e61cb"/><dir name="Ibm"><file name="Db2.php" hash="b947c61e9abf1f277adb40dc1aaf6319"/><file name="Ids.php" hash="a2d4fcf42c7b9435515399862224d74c"/></dir><file name="Ibm.php" hash="1042d1f01417241dc09679e1edb3a248"/><file name="Mssql.php" hash="139b7b3957b4e2b347d220b9dc8e959d"/><file name="Mysql.php" hash="0ca1bc627085e101ce51e02328b16347"/><file name="Oci.php" hash="819a1b3d31d7f65ba3f9de49ceecdf30"/><file name="Pgsql.php" hash="1b7fde0593b3799e4afa1f74b63499d7"/><file name="Sqlite.php" hash="efb68039f3e1b9e34a81c3dc9d0e8f20"/></dir><dir name="Sqlsrv"><file name="Exception.php" hash="097530f562d1993a992d6f62aadea809"/></dir><file name="Sqlsrv.php" hash="0fb64191a2d9e688410094c736d5eda6"/></dir><file name="Exception.php" hash="aebb5d861915d6a2494c58fc343f2752"/><file name="Expr.php" hash="2dca05427df6b34d6da9fb872517f684"/><dir name="Profiler"><file name="Exception.php" hash="42d03d9fd63aada757d6dabacdb73cb0"/><file name="Firebug.php" hash="1f5b0198a97091bba6ec8a8f74f3cf1a"/><file name="Query.php" hash="fe0bfc38389c14cecc76d528e33bfe83"/></dir><file name="Profiler.php" hash="e7327368b94ae8e094c602e41f617609"/><dir name="Select"><file name="Exception.php" hash="f8b241a9791bc28c77ca8c14cf80ba84"/></dir><file name="Select.php" hash="0fb5975684da5ea68ed45e4437d759d6"/><dir name="Statement"><dir name="Db2"><file name="Exception.php" hash="05225962b3d3107841d87d0d6c4ca9de"/></dir><file name="Db2.php" hash="36c397903c5e07ebe5b82b5e76030c7a"/><file name="Exception.php" hash="d41110267373d38bb4af77e1785329ae"/><file name="Interface.php" hash="222f50673200f578767b1e0c43d5a6bd"/><dir name="Mysqli"><file name="Exception.php" hash="1932b0ae9232ab79ccacadd46a45f022"/></dir><file name="Mysqli.php" hash="64e3e41642115ec95cce487da79fe737"/><dir name="Oracle"><file name="Exception.php" hash="59588ef7feadf4b0a726d1e1410f10bd"/></dir><file name="Oracle.php" hash="3fd727a08bbb347495dd6a2fb044defb"/><dir name="Pdo"><file name="Ibm.php" hash="aadb46dbcc67223ab9e240c35301cb0d"/><file name="Oci.php" hash="75a7032f82e8e29f52a8994a847e9533"/></dir><file name="Pdo.php" hash="91da6eddeaa94a88bcea2c3c912480bb"/><dir name="Sqlsrv"><file name="Exception.php" hash="925701544428f06183ecbb6718047839"/></dir><file name="Sqlsrv.php" hash="4d49d2edc91902768b1685768ac0421c"/></dir><file name="Statement.php" hash="48578c5307d13998d3b9dc73486bb666"/><dir name="Table"><file name="Abstract.php" hash="d1f0eb94b3a83abab809a132edec8d70"/><file name="Definition.php" hash="056d17187e24f48f42059889802ade8d"/><file name="Exception.php" hash="4ad0192e2759ce865081bfd65fba1537"/><dir name="Row"><file name="Abstract.php" hash="79e1dca4c87a158d36b171b11ec721a5"/><file name="Exception.php" hash="3182c2febc7a67988a02a2f4e3262c7c"/></dir><file name="Row.php" hash="adb2429446ad01b98bf74a1c79802009"/><dir name="Rowset"><file name="Abstract.php" hash="6474578f17e077f0d176de3d41bd43fa"/><file name="Exception.php" hash="c5e373d4e4d06e728572b3ca8c5d7d40"/></dir><file name="Rowset.php" hash="0534466fa3f58d60e28761013df1035d"/><dir name="Select"><file name="Exception.php" hash="c87230b6b7401370de518e6ad7218203"/></dir><file name="Select.php" hash="4a86cf29c8e383613e79caa5ef51ca36"/></dir><file name="Table.php" hash="bddf2a8c1ee791ef8a75fd81362a95b9"/></dir><file name="Db.php" hash="944811d3042ae76f201ce5ccee064693"/><file name="Debug.php" hash="e91277596844e74a3189f72b260d743f"/><dir name="Dojo"><file name="BuildLayer.php" hash="59fd3f007b9ddfe836308735a4fad349"/><file name="Data.php" hash="584f49393cc79deedcd43f36ff7cf68e"/><file name="Exception.php" hash="ce849ec1ac41925ce396495a4c0b5e5f"/><dir name="Form"><dir name="Decorator"><file name="AccordionContainer.php" hash="5ccfa22f987078a553c8334a1751a78e"/><file name="AccordionPane.php" hash="bfb6959fc54968e6e631a7b812f795cc"/><file name="BorderContainer.php" hash="3630699c89e4d611d463952ab7b616af"/><file name="ContentPane.php" hash="f5e7d589fc667a74c537f1c4a1d2f1ee"/><file name="DijitContainer.php" hash="6e30cb3a91ee447e6d9ae587a5b08fdc"/><file name="DijitElement.php" hash="63a591c8ae6f23a5fac3c4c4799849b6"/><file name="DijitForm.php" hash="3107c8e3a51efd7cd960a4d140fd2552"/><file name="SplitContainer.php" hash="32118776073ace34a7a6e6b775f7a41d"/><file name="StackContainer.php" hash="511f80fb7e777c7420df3a33e5d36df3"/><file name="TabContainer.php" hash="bfba332a70e20ac8e4bc1f9a7b488ffe"/></dir><file name="DisplayGroup.php" hash="4fc35365159beb7532119735b43ac5ae"/><dir name="Element"><file name="Button.php" hash="3ed66e9ab5b21731a355a35cc0bdadc5"/><file name="CheckBox.php" hash="cdf55f6261658dc12c508397228c86d5"/><file name="ComboBox.php" hash="ad263405d78671cb38f39a42f4153306"/><file name="CurrencyTextBox.php" hash="8a0101a9a7fdc7504fe882222df91d8b"/><file name="DateTextBox.php" hash="b1a766b9190c2c124d34d59d8c742f04"/><file name="Dijit.php" hash="8389aeca66aecb8a39d9341f81ded916"/><file name="DijitMulti.php" hash="bd0fe55261b57bcd2c92ea196eceaf08"/><file name="Editor.php" hash="bb3636533a931bc1f9a5782ac4c66565"/><file name="FilteringSelect.php" hash="d330a4330b410089733f8c1eeb1839e2"/><file name="HorizontalSlider.php" hash="b23bd0da212335080121f31e318f743d"/><file name="NumberSpinner.php" hash="9ae185b60accc9edb7baed24b93ca540"/><file name="NumberTextBox.php" hash="cc340c040ab7c8eaa02bf401a9a91bc3"/><file name="PasswordTextBox.php" hash="48b304d5bbfb2417adf1724362e032b6"/><file name="RadioButton.php" hash="80e8b86eaf8258626084f54272a7a576"/><file name="SimpleTextarea.php" hash="69791b92fb7d656676266fe53592b6b0"/><file name="Slider.php" hash="21f9f99bb495bcf2997a022f6a43c276"/><file name="SubmitButton.php" hash="52c7e25fd90d33b9501150746b046e14"/><file name="TextBox.php" hash="874413d9bf8c39f9a7a73d7175842cf5"/><file name="Textarea.php" hash="1fab8c9619163b0fd1cdeaf4bf4113c7"/><file name="TimeTextBox.php" hash="6ab9be9f6555bdc14ba9a02fb18c3157"/><file name="ValidationTextBox.php" hash="dd456a154f47bc74e05834800490ad53"/><file name="VerticalSlider.php" hash="c99c979911b12b2907b9ce727d595f42"/></dir><file name="SubForm.php" hash="46b28da42e2447cdf7f23ce8635a6243"/></dir><file name="Form.php" hash="5dc7b152deef6e0fedf0c0caa73f7c68"/><dir name="View"><file name="Exception.php" hash="fed5a27397fd8fb08841c1db38364df7"/><dir name="Helper"><file name="AccordionContainer.php" hash="3b2eaa765a22ea9a2d3d2e507da446b8"/><file name="AccordionPane.php" hash="94b8d5edb317926ca8aee3539c33ce8a"/><file name="BorderContainer.php" hash="f8b3939b919a3f961c8da6196b2166be"/><file name="Button.php" hash="e1e816f2362a2f973acceadb1414de98"/><file name="CheckBox.php" hash="43f1a6ad27883f62cda4bc1b560c9f89"/><file name="ComboBox.php" hash="d2811e390eb44a4f3e953c241949db0e"/><file name="ContentPane.php" hash="041084c11934376f3f759154a1835abf"/><file name="CurrencyTextBox.php" hash="56f2046e985a0d1cd81ba0d045f91a7a"/><file name="CustomDijit.php" hash="34bfe4e1501f8dc1227adcc9b7e2b20b"/><file name="DateTextBox.php" hash="81bdffce0b2acb693a7c2cbd3941f156"/><file name="Dijit.php" hash="7a1eb3742998cbbabac1b2338a590566"/><file name="DijitContainer.php" hash="3091a920fbfb48215a59f73be1988eaa"/><dir name="Dojo"><file name="Container.php" hash="e40d8395af2e395a2e81d593e8f4602c"/></dir><file name="Dojo.php" hash="6303c9d4ede5b67cc828ead89c4016a6"/><file name="Editor.php" hash="f251624a2b798b53eea465d9938ac276"/><file name="FilteringSelect.php" hash="60bbdd84239febff9241199104b4cf1a"/><file name="Form.php" hash="105f502558eb241c81c39be0e5d85a72"/><file name="HorizontalSlider.php" hash="7b3c19156aee3db41dbaee18abe2ded7"/><file name="NumberSpinner.php" hash="cf27c892acfeb8ba60027bba29d8715a"/><file name="NumberTextBox.php" hash="9674fa01666c5622896d4513da69ce8d"/><file name="PasswordTextBox.php" hash="0ba727cff497c3b580bffaf04eecc75b"/><file name="RadioButton.php" hash="ddd9733fd29a47cf20f224115895d2cb"/><file name="SimpleTextarea.php" hash="8162db2b947a8b380099ee4266bd2edb"/><file name="Slider.php" hash="b09cd129a4885cb799978b234e8ef496"/><file name="SplitContainer.php" hash="8fa96d45ff63d2b0f24250856afea806"/><file name="StackContainer.php" hash="f3f24abf9640124f26274b9663eccd5d"/><file name="SubmitButton.php" hash="9083d4797eb4be0a879951a88be9a6f3"/><file name="TabContainer.php" hash="8b6865aa0b8015b220896d3487ec0966"/><file name="TextBox.php" hash="75b65da85221b840ff6f3bd4d38890e2"/><file name="Textarea.php" hash="58421d644f61edc039bdaf8b2d13af7d"/><file name="TimeTextBox.php" hash="7865f42c62fd06ead74987324d2310d0"/><file name="ValidationTextBox.php" hash="59bc7469004e22811c038791462d67a7"/><file name="VerticalSlider.php" hash="9c113d757c1b99048d09ba8949452034"/></dir></dir></dir><file name="Dojo.php" hash="3d5a5b6120bb16fbde6a24fc082bb2e7"/><dir name="Dom"><file name="Exception.php" hash="764e44b0e7b8346387c4b677e725d6bf"/><dir name="Query"><file name="Css2Xpath.php" hash="84d8020779e37ed005fa2ca53052731c"/><file name="Result.php" hash="2c8f3fdb6f945804d2a2b5881b5c0567"/></dir><file name="Query.php" hash="ac0c71f2c7a030485756a780c2ca5904"/></dir><dir name="EventManager"><file name="Event.php" hash="73a22bba4a1536ad0bedb311992ed841"/><file name="EventCollection.php" hash="6846535fe1c08a148593082878839b2b"/><file name="EventDescription.php" hash="6cb5b7a743c322cc486c09de9e2466c1"/><file name="EventManager.php" hash="775973335393a6aab98b63fd7e580f6f"/><file name="EventManagerAware.php" hash="616ae31ca46f1f0206e28851f408e777"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4651b42388b3cc0f6a8c77b8c92a988f"/></dir><file name="Exception.php" hash="a7a76fcb8615694bebfd1b7a6c63cc2e"/><dir name="Filter"><file name="FilterIterator.php" hash="479bdbab563e57ade8718744d6a9eaed"/></dir><file name="Filter.php" hash="a6705be98a15d9abb250329a18bc5f44"/><file name="FilterChain.php" hash="0bbe4e22e4bd7731c91b0d8849e24dd4"/><file name="GlobalEventManager.php" hash="2448f17e7235ad32e0986dccaaf6f21f"/><file name="ListenerAggregate.php" hash="e0bf702bb54b9ba2d54828a2d66d2954"/><file name="ResponseCollection.php" hash="14500f355513b35b17a7dd7e947f5301"/><file name="SharedEventCollection.php" hash="0504cdf3c7168fa6e6a1d164705617c7"/><file name="SharedEventCollectionAware.php" hash="c53dea67b8742191c78911a87cf4c1c5"/><file name="SharedEventManager.php" hash="973daf2597a36f485ec43ae91f53fbef"/><file name="StaticEventManager.php" hash="47bc3c834d44e64eab6ea0b0c0a83eba"/></dir><file name="Exception.php" hash="fdca55eece8acc76af7ec98eca620311"/><dir name="Feed"><file name="Abstract.php" hash="66b85329fd8524fc66b93c16397cc49d"/><file name="Atom.php" hash="24d80774c71e1932b8be5054793d4fd6"/><dir name="Builder"><file name="Entry.php" hash="4871eb1a5d2084552d48b346fb9424ae"/><file name="Exception.php" hash="f8d2074819dd7157b4de4428579958c9"/><dir name="Header"><file name="Itunes.php" hash="da87e20a7e6b587316644377c8cc3c55"/></dir><file name="Header.php" hash="7e1b1053ef90762e3b6d9933cab4964b"/><file name="Interface.php" hash="407dbfd89e522c6e033214974954ad9c"/></dir><file name="Builder.php" hash="9453c5958f2cc22bd37a1e8e8de22ff7"/><file name="Element.php" hash="04f6a067ec047936af106f5a3ee9f0ee"/><dir name="Entry"><file name="Abstract.php" hash="44340d16439984b02edd6f26d7a1885e"/><file name="Atom.php" hash="a2642776469712e0e2dfcc0912e98aa3"/><file name="Rss.php" hash="93e478df77e9c9c43c55334ce2165a8d"/></dir><file name="Exception.php" hash="3ce015184369dd3392923dba02ccb4ab"/><dir name="Pubsubhubbub"><file name="CallbackAbstract.php" hash="5fc3da695c59069c88f54206485038c9"/><file name="CallbackInterface.php" hash="3b8478bc6bac3d9309c0fe7ba6f89dd0"/><file name="Exception.php" hash="028e2d741379246df90e62b96393ffe9"/><file name="HttpResponse.php" hash="6a929e3ac877b89fd0b8664b9894f953"/><dir name="Model"><file name="ModelAbstract.php" hash="ce0a0b0b03f77348b066a947e4d4a087"/><file name="Subscription.php" hash="99c0b396f4e21b0fe2bc3c068220958e"/><file name="SubscriptionInterface.php" hash="63f95bde2e9254d0e3c31b905fea78bc"/></dir><file name="Publisher.php" hash="44d781a089ad5ac1ee949b74badad6ca"/><dir name="Subscriber"><file name="Callback.php" hash="c50e22f4bec18ed4365b7a7fd472db69"/></dir><file name="Subscriber.php" hash="3a06e76251527da315017fd545595ee2"/></dir><file name="Pubsubhubbub.php" hash="9187f4accebd9b1b23010e141485f2c8"/><dir name="Reader"><dir name="Collection"><file name="Author.php" hash="bd0aee1688a6905cfa60ad3df2876d42"/><file name="Category.php" hash="0ac74f5a4ea9492998e7f76e6e959283"/><file name="CollectionAbstract.php" hash="a0d023979ca9ca7c2fdf93e0acb36745"/></dir><file name="Collection.php" hash="6a92b8355578f92468d24f03c33f6e7b"/><dir name="Entry"><file name="Atom.php" hash="c4f9ba356c97d5ad4ad6a5a210fa5d31"/><file name="Rss.php" hash="01b9d9b750ec9c730bc3fa624629deeb"/></dir><file name="EntryAbstract.php" hash="b9e05d05ad657e24bca3947764bf4aba"/><file name="EntryInterface.php" hash="3e33c60c08158ac0398bb9f05ec2090b"/><dir name="Extension"><dir name="Atom"><file name="Entry.php" hash="6baacc2e3ddc23ad3cfa9e190fd54157"/><file name="Feed.php" hash="16e84c49d96b759d10b1fe86982cca2f"/></dir><dir name="Content"><file name="Entry.php" hash="4a01e7b785bc08518739d03825f8c7af"/></dir><dir name="CreativeCommons"><file name="Entry.php" hash="4c7cc6a5ddcb6971e2a7d30c701151b7"/><file name="Feed.php" hash="40b8c9f5146271c2fe7433f7daff07ac"/></dir><dir name="DublinCore"><file name="Entry.php" hash="3ff54fc3fe5df35c8ba4075ed42dabeb"/><file name="Feed.php" hash="56f06a3e2739c70c66da54e7608c9496"/></dir><file name="EntryAbstract.php" hash="fb62ce68f7a440fac11ec666e9e4bc22"/><file name="FeedAbstract.php" hash="c1283a62809662e762cd0a7875b0b913"/><dir name="Podcast"><file name="Entry.php" hash="738c47a9b19c44bedbce6a6e901ee173"/><file name="Feed.php" hash="23c593352bc891c6bbce22e98da18f6e"/></dir><dir name="Slash"><file name="Entry.php" hash="29d24797987342ea6a580a48af0accb5"/></dir><dir name="Syndication"><file name="Feed.php" hash="67ec064681ba8a77b4f6d44a35d4d8f7"/></dir><dir name="Thread"><file name="Entry.php" hash="202da1cb171c55d435b125cfb264d874"/></dir><dir name="WellFormedWeb"><file name="Entry.php" hash="88c3ee8f88632712522d206426a2927c"/></dir></dir><dir name="Feed"><dir name="Atom"><file name="Source.php" hash="71d4bceda67dd3a4acbc45bbee33853a"/></dir><file name="Atom.php" hash="042c93075ae2e933e5241750c101d3de"/><file name="Rss.php" hash="e354bd24fbf48a5bab9d518e3912bd93"/></dir><file name="FeedAbstract.php" hash="e577cfdd039f4025877f12d2d08dcce6"/><file name="FeedInterface.php" hash="7eaed63ef055848aa1b299bc98d8cc11"/><file name="FeedSet.php" hash="5ba5f156ac7607b73929dac85826c659"/></dir><file name="Reader.php" hash="d9bc6e5b898eb8be4fa72e313e89bccb"/><file name="Rss.php" hash="e14ca674ad56d9ce18df5d9728c770bc"/><dir name="Writer"><file name="Deleted.php" hash="35aad5db793b86ca638a81d052c6ae14"/><file name="Entry.php" hash="87c1a1d4b637d4918f5fabe8b56c1a9a"/><dir name="Exception"><file name="InvalidMethodException.php" hash="02419d36ca4d923b7ae46f8cf5e9808b"/></dir><dir name="Extension"><dir name="Atom"><dir name="Renderer"><file name="Feed.php" hash="e1c642e0775de8ace9639daff1a932aa"/></dir></dir><dir name="Content"><dir name="Renderer"><file name="Entry.php" hash="f86cd399902d04ab6652aa952c81916f"/></dir></dir><dir name="DublinCore"><dir name="Renderer"><file name="Entry.php" hash="6f79082f7b75e1d7b73930169ff6d5e0"/><file name="Feed.php" hash="8b6825b40579ce795e0018eac48a0fa6"/></dir></dir><dir name="ITunes"><file name="Entry.php" hash="e23d802f1cc74b432a3c5362be650c55"/><file name="Feed.php" hash="ffa388bb1b1c868a92978ee85f3c8d50"/><dir name="Renderer"><file name="Entry.php" hash="184f5e6f780c987cb55374c6b899dee2"/><file name="Feed.php" hash="c5df3307f99f2349024d3a31612d67a5"/></dir></dir><file name="RendererAbstract.php" hash="427c8bd29a3f0aec64f2034405b8fa89"/><file name="RendererInterface.php" hash="2cbb9d13b450a08098921fe99f5084bf"/><dir name="Slash"><dir name="Renderer"><file name="Entry.php" hash="95b4d946971ccd12e852d36125e241ad"/></dir></dir><dir name="Threading"><dir name="Renderer"><file name="Entry.php" hash="81fa4f73e25ce35482f8ea2d01ceac48"/></dir></dir><dir name="WellFormedWeb"><dir name="Renderer"><file name="Entry.php" hash="45c4795ca01add23d35af6ca1961a27b"/></dir></dir></dir><dir name="Feed"><file name="FeedAbstract.php" hash="65fa012f95547e0e63deb8715038c9c0"/></dir><file name="Feed.php" hash="699463ea19aa24d3cf48d9ddf37d63d4"/><dir name="Renderer"><dir name="Entry"><dir name="Atom"><file name="Deleted.php" hash="65126201b8fb20b29f945956c3c7aa14"/></dir><file name="Atom.php" hash="fd98f2be04963b4a660c49cd0bb9db5e"/><file name="Rss.php" hash="f0e70e6a183416e6c04a1aa58d91b128"/></dir><dir name="Feed"><dir name="Atom"><file name="AtomAbstract.php" hash="2762eb27cc4182026d7cb5d4a2d8e7d0"/><file name="Source.php" hash="b4432fc84152c9922c2a0318043431e2"/></dir><file name="Atom.php" hash="a4e0a7056233cc18c1abcbcf45895b3a"/><file name="Rss.php" hash="b01a32487ec79c8e29848e56d12f4fef"/></dir><file name="RendererAbstract.php" hash="e818b72ef7cccb7e411218194c4a90c2"/><file name="RendererInterface.php" hash="b9d0002ea9fd72117b6438231ca2db9e"/></dir><file name="Source.php" hash="3cce4bf24782f65948e0078eee3af8b8"/></dir><file name="Writer.php" hash="31915fe86b889b38f29cd365dfa2eef8"/></dir><file name="Feed.php" hash="90930372cd8489f1be5480df69e492a3"/><dir name="File"><file name="ClassFileLocator.php" hash="a763041253fb82e55d99e50078f9e791"/><file name="PhpClassFile.php" hash="95812fdfe2ea77215eaf98220970d2bc"/><dir name="Transfer"><dir name="Adapter"><file name="Abstract.php" hash="9f8caf0965ee20c3e394cc9abd39dc64"/><file name="Http.php" hash="98db3d564539a149becd025db2996089"/></dir><file name="Exception.php" hash="825fcee61f10cdfe37140f8053177a3f"/></dir><file name="Transfer.php" hash="3b238f59905a999aa851bd4e7b641d64"/></dir><dir name="Filter"><file name="Alnum.php" hash="4ca46f20de00a3ae2c141f1ceff56bad"/><file name="Alpha.php" hash="5b07ed4ed80ac52058355dc25eab7f17"/><file name="BaseName.php" hash="625ce144adaded5d1a792f2cdff08ddb"/><file name="Boolean.php" hash="8a4ccc8b5fe35cc6371f2a876c1687c4"/><file name="Callback.php" hash="877df95b6818f3919ff98ef2b792beab"/><dir name="Compress"><file name="Bz2.php" hash="85a13672065e12d52a4a53c7d57b5956"/><file name="CompressAbstract.php" hash="e31d6c9f72772def373f5f947ebb4857"/><file name="CompressInterface.php" hash="fea3425ce29a7262ac9aa37ca15e7ccd"/><file name="Gz.php" hash="e1a5c9d4301ba780b0fc2a2ab69b9cef"/><file name="Lzf.php" hash="238dbeb23d34fab2ce1fd53c5728c981"/><file name="Rar.php" hash="ee424491867ca2fce1556bdcf01e0a7f"/><file name="Tar.php" hash="e9fc01174f800ebf4e87294361714fe8"/><file name="Zip.php" hash="1adcddd63511b526c388dbbfb2693ca5"/></dir><file name="Compress.php" hash="17af88fb4588855a0fa2ad0c747e567c"/><file name="Decompress.php" hash="9900b029a91c9c1620903061b15d8b5d"/><file name="Decrypt.php" hash="ea36fb417859a47bc8090908f91c79b0"/><file name="Digits.php" hash="988e652d047ccb2b3f51368702b39932"/><file name="Dir.php" hash="ded6da050ac44e21c8729c4fd74559f0"/><dir name="Encrypt"><file name="Interface.php" hash="02481da5488767e23939a73b434d6728"/><file name="Mcrypt.php" hash="2320868b4e3235e934023f6339edb9ee"/><file name="Openssl.php" hash="37f02c9e5fd864557aca070ca8525e36"/></dir><file name="Encrypt.php" hash="41b1fa4536947b9ce5e4dcadb3bf80b7"/><file name="Exception.php" hash="ee7fa3aa3daed6b376e4fe3ff0533a65"/><dir name="File"><file name="Decrypt.php" hash="f82c770a201d0016ed0054874f39c90f"/><file name="Encrypt.php" hash="63c6232b0c216381bee8c18df751ab59"/><file name="LowerCase.php" hash="664f911dfcba8fb26ad86605eda4ad93"/><file name="Rename.php" hash="d854b8b98abd89db4d4b0eca30a2b496"/><file name="UpperCase.php" hash="9aad43cc07b024188734fe231ec7a80e"/></dir><file name="HtmlEntities.php" hash="6ce1c0425b0b5f48c21649c15ffe1d26"/><file name="Inflector.php" hash="b6b671c8956fe8c359af7739c56867a8"/><file name="Input.php" hash="fc8cc25c2f9da1b1da7b2839eb914c99"/><file name="Int.php" hash="41724f5b9f96f08b6b01281891bc3eab"/><file name="Interface.php" hash="0f810dcab23fc1f455c960af3f317a04"/><file name="LocalizedToNormalized.php" hash="6b98acca5dc278027620e0d5361a316e"/><file name="NormalizedToLocalized.php" hash="27f9795714f46c3d4a143330e77219ce"/><file name="Null.php" hash="fe5c2ff3f08d7ef9ffc140ad251dd6da"/><file name="PregReplace.php" hash="7b0c18825dcc9016d0cc2a0fea8fee53"/><file name="RealPath.php" hash="133f0776eaa042a0712e2d8e7db3ed7c"/><file name="StringToLower.php" hash="9a7352bfa73b4ac825bc2af9fef3c286"/><file name="StringToUpper.php" hash="ec2165f772585dcf346b589bbf9bc716"/><file name="StringTrim.php" hash="ca76b8743fd9ec88290ef11a24d48a03"/><file name="StripNewlines.php" hash="fe69c99129f9bd2b69ea16c0bbfc61c1"/><file name="StripTags.php" hash="78d7393075f2327644e873d4e9196082"/><dir name="Word"><file name="CamelCaseToDash.php" hash="3793e4ef36c6778b9e5df032dfc15b67"/><file name="CamelCaseToSeparator.php" hash="cd445e16f5d3ef145c4b0f35a10b1dcd"/><file name="CamelCaseToUnderscore.php" hash="932bcf0ead2bda7d9ba9544458fe2de8"/><file name="DashToCamelCase.php" hash="705245ae67e4a9eede0bb3c0bf0e6ac4"/><file name="DashToSeparator.php" hash="6edcb2382b8fc7acc8448679d6fb46b4"/><file name="DashToUnderscore.php" hash="1075b2edc67d246d7f300c336a00a745"/><dir name="Separator"><file name="Abstract.php" hash="7c13a127a26229fc8d5e0678e8efcb5f"/></dir><file name="SeparatorToCamelCase.php" hash="87f3c3a2ab24e2146db100710050d873"/><file name="SeparatorToDash.php" hash="d13f2d966ffd8cfb05114fbb9f3906b1"/><file name="SeparatorToSeparator.php" hash="3f70eae82b1616c098cd9aec7be41f9c"/><file name="UnderscoreToCamelCase.php" hash="5f19c37337b901edd5fe5080a8353116"/><file name="UnderscoreToDash.php" hash="2f25783e6e165b827fc113f046f30f44"/><file name="UnderscoreToSeparator.php" hash="b0e92b24b679b3dcbee459cd752a2478"/></dir></dir><file name="Filter.php" hash="383fca34ab08e0a803adb2c7766fad95"/><dir name="Form"><dir name="Decorator"><file name="Abstract.php" hash="8522e625655a35646b477ad4ff99dfe5"/><file name="Callback.php" hash="190782b871a222c75dfc8444b863da11"/><dir name="Captcha"><file name="ReCaptcha.php" hash="39b4156e05bfd86a8bc607c94f437e32"/><file name="Word.php" hash="880894024cfbed08b5f1078076512a25"/></dir><file name="Captcha.php" hash="1d07f76a5ba267e35b801bbfa6437b1f"/><file name="Description.php" hash="4c386b676076f9d5839eea503b633567"/><file name="DtDdWrapper.php" hash="124076232159f0fa26fc9fe67685830f"/><file name="Errors.php" hash="e10d634460b6dae52065a83cd5c3b3a2"/><file name="Exception.php" hash="7540f704e53237cd3a6715d1e480c3b9"/><file name="Fieldset.php" hash="6bd5c5b9ff8e9e489e5a7c560aff175a"/><file name="File.php" hash="c06f2200db61e4ebffa266d99260c726"/><file name="Form.php" hash="c0117ea6a352a32b780baae652d717b9"/><file name="FormElements.php" hash="8cb9c8f03fb877b45696b534c1b39b14"/><file name="FormErrors.php" hash="723036887204776c398e63c715b762fa"/><file name="HtmlTag.php" hash="2b90f769619b1e6624e14922dc2c32ec"/><file name="Image.php" hash="2a1a7dd1624ee71cfc13b7c96b4796e9"/><file name="Interface.php" hash="60d51f6f15d396b5a16519ba5eeec204"/><file name="Label.php" hash="277f64b41efc25890d78eba58db9b780"/><dir name="Marker"><dir name="File"><file name="Interface.php" hash="30667e6ff2ccced89c3b62cf0e13f931"/></dir></dir><file name="PrepareElements.php" hash="0ff6fb16d6c5a748c9c3d3e48037755d"/><file name="Tooltip.php" hash="bb7394628ade765908544c69c6790844"/><file name="ViewHelper.php" hash="c5cc8db2e0cec01b77be69fa2e1b9299"/><file name="ViewScript.php" hash="23ef6fc6fdac5fd8c9105738c5cd3ccf"/></dir><file name="DisplayGroup.php" hash="ee080ba86203eeb41ac17d38877651f5"/><dir name="Element"><file name="Button.php" hash="730df0b76e3957882f877197447d5f1d"/><file name="Captcha.php" hash="0752ad99fb0f43536c91367c70a494df"/><file name="Checkbox.php" hash="e39255d645c7c1b2ac042cc64c2e7cc9"/><file name="Exception.php" hash="c1a78bc6fbcad9d8544ef102ee578bd7"/><file name="File.php" hash="8a78cdb33c6d598fee1f22fe008e7479"/><file name="Hash.php" hash="98a63f7085dc662488f510b8341a450a"/><file name="Hidden.php" hash="4f1b7d49e10c937cbe9bc1f481a24e9e"/><file name="Image.php" hash="050990ff646853c7def62d5912a3a57e"/><file name="Multi.php" hash="546108cee3f938abc94159392b279638"/><file name="MultiCheckbox.php" hash="8da3e1c8f63673889aa82c8a477bc19e"/><file name="Multiselect.php" hash="70685894797a172bfbfeed0b3ca0c8c9"/><file name="Note.php" hash="db0386ab8c66da2df8c912e37b11110f"/><file name="Password.php" hash="4cee94cd5c56812e101f9cae256d79cf"/><file name="Radio.php" hash="088e0a26f8b959fd252edc7080cbe3c6"/><file name="Reset.php" hash="782f1aa0cbe1a792a0d05a51d58d8beb"/><file name="Select.php" hash="ee8919ec27665b02cc44cc0083609878"/><file name="Submit.php" hash="0a97601d86f82bd50d3ea6777937254c"/><file name="Text.php" hash="781ee2e638e37fc613ad760bbd2d30bb"/><file name="Textarea.php" hash="85a7119e8e0fa3377b0576b16aa05c51"/><file name="Xhtml.php" hash="4c20761fbbb7ca24ea9b49ac3cd41e58"/></dir><file name="Element.php" hash="f03fcc6dcd7b3e0da5a36046d36d727f"/><file name="Exception.php" hash="d33a48b9d1ec7e213210383b1f7bca68"/><file name="SubForm.php" hash="ba968be3402ccdf8b4185f4d53234120"/></dir><file name="Form.php" hash="4001592cf753a1170ba2cf1c178c17ce"/><dir name="Gdata"><dir name="Analytics"><file name="AccountEntry.php" hash="e12468f4c63d78e8edecbc473933aa4a"/><file name="AccountFeed.php" hash="a2f9b14dbdc470693a82907f57c4d258"/><file name="AccountQuery.php" hash="8f5b153ae38c2c0598dcdd0f4ca851a4"/><file name="DataEntry.php" hash="e45ec9042ba8356cdf29505e1e9e2d0b"/><file name="DataFeed.php" hash="5db9ffeb61cefb3659e9be8400ed20e8"/><file name="DataQuery.php" hash="f42425d8f43dada50bb8f128d8f975f6"/><dir name="Extension"><file name="Dimension.php" hash="38282ab7af5abb515f4aa658f820fc34"/><file name="Goal.php" hash="2c46c1d7db9b5f507a47e4bb121e2b4c"/><file name="Metric.php" hash="8560747659930f23b28cc94bd837440b"/><file name="Property.php" hash="d1ba271f052e44a1152eed24533824b0"/><file name="TableId.php" hash="60e5a4486c861d393b6f3183c2485267"/></dir></dir><file name="Analytics.php" hash="a97cd7d0faa0f65351e65f55c28fcc60"/><dir name="App"><file name="AuthException.php" hash="6f8d23065cd17d239b2cec093015ad8e"/><file name="BadMethodCallException.php" hash="86fe8ce683680f512145d94a22ab21d5"/><file name="Base.php" hash="109e590e151826d3347d1f2f58dcab56"/><file name="BaseMediaSource.php" hash="d1ec6648e8c89711225d42a07e4738d7"/><file name="CaptchaRequiredException.php" hash="7a3e3893b6f8a9c282d920acb9928e21"/><file name="Entry.php" hash="06786f3fe9e30b60c79888be9c70c067"/><file name="Exception.php" hash="82c41ada4e9863867adb2795fe7b1ca0"/><dir name="Extension"><file name="Author.php" hash="2df6f04ec34d35d1d79bbd189a9c53a8"/><file name="Category.php" hash="273bbd08b463d8394b8528294f2f43ef"/><file name="Content.php" hash="ba2ae463fc480db7c017c495c47f8380"/><file name="Contributor.php" hash="b06a5ee82e874422c7053e9bc4efa7a7"/><file name="Control.php" hash="2215659703162befaa49e7a18ad7abe1"/><file name="Draft.php" hash="45da888e1837d3002d099e483cc4e117"/><file name="Edited.php" hash="94503a1886214c959eb189dc1331a1e3"/><file name="Element.php" hash="1ff84c0f8b8e3e9be1edf28774125044"/><file name="Email.php" hash="f3733ecc80e481cd3e35b93df18a216d"/><file name="Generator.php" hash="aef1362208e44f2be51e4094089b4795"/><file name="Icon.php" hash="36d027f0cf96a2deb42b6c1aab0468ef"/><file name="Id.php" hash="9609dfb9218d0b8263086504e6b0d63c"/><file name="Link.php" hash="de21b9578b8592c5b3e3fcfb84419671"/><file name="Logo.php" hash="23c88a04e6897da7a7606733d5880094"/><file name="Name.php" hash="bcefb468fb70012b66b7322b1b9c618f"/><file name="Person.php" hash="5190427185a73d6cd253d4ad37d3130e"/><file name="Published.php" hash="f5b6d374545f8fea7382644413c786ee"/><file name="Rights.php" hash="add154a43b16eea075f70fef1dc0c614"/><file name="Source.php" hash="9b5c51a557d100b8d32f04c2e631d51e"/><file name="Subtitle.php" hash="87ccbc9582dabb57b4e5254c3cdb5419"/><file name="Summary.php" hash="308fcbd2860bac275a68bbaa455d75e5"/><file name="Text.php" hash="bcb0f1d994917499bb98c2045839cf78"/><file name="Title.php" hash="37736e9d970dbfb6508fe95c8b1d4c4a"/><file name="Updated.php" hash="3a00f1cac5e73b47fe960a4568d753a2"/><file name="Uri.php" hash="c8a0fd8b1e0ef4620dcb4f8d3bdf2f02"/></dir><file name="Extension.php" hash="e8d500cede8625e9a513241cb9340b8b"/><file name="Feed.php" hash="2a9b8a370e645cac248df5cec9752bf4"/><file name="FeedEntryParent.php" hash="03a2448db19430ce9d63af5a794c49ee"/><file name="FeedSourceParent.php" hash="ad513f8bba194a7c597d62332e1b748d"/><file name="HttpException.php" hash="e235854ac6db814217beb8e0f4432bda"/><file name="IOException.php" hash="4fe86dbdc8efd68b4f4e91eb720476fe"/><file name="InvalidArgumentException.php" hash="bb79aa3b093b89f2d1740e3de29c591b"/><file name="LoggingHttpClientAdapterSocket.php" hash="6c6fcbec1d914d2f0f1b4c9f9f9d6ded"/><file name="MediaEntry.php" hash="665829aa3a0b00efad9d39516ac20296"/><file name="MediaFileSource.php" hash="33e29faf6b09ad55399f8c4605de560b"/><file name="MediaSource.php" hash="956d976c017eb2969ec6980ba6a10227"/><file name="Util.php" hash="a978ace39e376ebb7a77168bb980e500"/><file name="VersionException.php" hash="46a96dcdf49d163f2b558f6af76770f8"/></dir><file name="App.php" hash="0611ada3705cf91a416144719aa34f4d"/><file name="AuthSub.php" hash="7d6c8fa90f00569465838f7485e6f8c9"/><dir name="Books"><file name="CollectionEntry.php" hash="e9400464091b197c1406c31904c89f46"/><file name="CollectionFeed.php" hash="50eb4262a08af25008fc23dc8ce38261"/><dir name="Extension"><file name="AnnotationLink.php" hash="229515a8187537875bec1df18a216e70"/><file name="BooksCategory.php" hash="94043b4e41582b92bd585a2f6ca55401"/><file name="BooksLink.php" hash="d4d4d737a079e5a06f9ec239156acc3b"/><file name="Embeddability.php" hash="02ea13af1b4c9e4bdf019cf85bd2e1e3"/><file name="InfoLink.php" hash="e901bc048235143eca51ac93750e148f"/><file name="PreviewLink.php" hash="96cc9f7155d4a8420b59dfab337df144"/><file name="Review.php" hash="8263c22752814fc5b8ed79f5b8fb0c64"/><file name="ThumbnailLink.php" hash="d39c8c46fdcd113b6e78b0a291e3fb7e"/><file name="Viewability.php" hash="00ab00c410d09d756c1f4eac2617dd85"/></dir><file name="VolumeEntry.php" hash="c792cd0a1600d1f82b359e4488ca96d6"/><file name="VolumeFeed.php" hash="df63b570832f03352f8fd9caf5dd0ad9"/><file name="VolumeQuery.php" hash="7c4eafbfe2dffe63d19da553d7116784"/></dir><file name="Books.php" hash="2b24e8b1f35eeb6c045c82aaea8ff279"/><dir name="Calendar"><file name="EventEntry.php" hash="3a8929e9b816b58b948bb27c5f5b7b11"/><file name="EventFeed.php" hash="cb77e63f75b7b00e3ad977160bf1df3b"/><file name="EventQuery.php" hash="c87b0d6fb40e7b41509bbf0c72c35563"/><dir name="Extension"><file name="AccessLevel.php" hash="0c08117546cfc5687e831e7c1c911386"/><file name="Color.php" hash="173b3b7765f71816d9474b4d662fa78b"/><file name="Hidden.php" hash="e013d7fa1de0281467fd342b68d82e47"/><file name="Link.php" hash="9024ffbc848c26dc7142791d334ed4c6"/><file name="QuickAdd.php" hash="b27ef7921a5f849c6d3670e80205a826"/><file name="Selected.php" hash="af19756358007c35c1e97b25d3c40f98"/><file name="SendEventNotifications.php" hash="ad25cf943facb4ca07b5eea08b29d6c0"/><file name="Timezone.php" hash="f42b5243c11888a5ba4075b0e9663d64"/><file name="WebContent.php" hash="b7097ddc1f180e4a85097a414b96bba9"/></dir><file name="ListEntry.php" hash="0579d1450de838b1b893f9720a7dacc1"/><file name="ListFeed.php" hash="e21a404f7d250f78fdac64f729d2b377"/></dir><file name="Calendar.php" hash="507e33fa6d185c57b0c2c351c0fbc060"/><file name="ClientLogin.php" hash="d5025122f58267716ea25d7546da7d62"/><dir name="Docs"><file name="DocumentListEntry.php" hash="08219506950f07c0cb16e1196dc4e09c"/><file name="DocumentListFeed.php" hash="dd7d591781ad9cf3293f73bc94e64e78"/><file name="Query.php" hash="e6c962a8f8cfe02d3ca0701b932dd5c9"/></dir><file name="Docs.php" hash="f29d7a621a95734e8b83a4afa5a6fe42"/><dir name="DublinCore"><dir name="Extension"><file name="Creator.php" hash="c56d34f65d24a0ad25e60a4e913fd54a"/><file name="Date.php" hash="54b46f21e08d7ca7d230c6b7e83e7210"/><file name="Description.php" hash="6f4bb927deae9cb5b501b37e4cbdeca7"/><file name="Format.php" hash="a2eb4fd88c1197f1b122adfcca64e4c5"/><file name="Identifier.php" hash="7900202e14b61bf0323069f736521521"/><file name="Language.php" hash="b47e4dafd3fcebd4d11b4ac0806cea70"/><file name="Publisher.php" hash="1660d7ee8e0fa26d24376ed8414849e3"/><file name="Rights.php" hash="1cddf53544c56ad8a29f012f1501501e"/><file name="Subject.php" hash="a287af1b176e22b3f7001e4a8d69129f"/><file name="Title.php" hash="77bbd2f9afb01b6337b03b12c19cd0ba"/></dir></dir><file name="DublinCore.php" hash="6fa896e35490d67182eb013b08ef6d75"/><file name="Entry.php" hash="b2f85f13672d64d288bbcf9824058488"/><dir name="Exif"><file name="Entry.php" hash="cba9027e69ca0d3431f5fa8e84519d22"/><dir name="Extension"><file name="Distance.php" hash="69d8d71b3c8f02fd85e22e72453f5e7c"/><file name="Exposure.php" hash="5b4f1e1c91ada58e661412e391c9167c"/><file name="FStop.php" hash="78c90acf5134d6a8cd7debc8dfff3942"/><file name="Flash.php" hash="bc1c363115d8ee05fc043ae829ca9398"/><file name="FocalLength.php" hash="ba8dba20995e7ad0dc5fbe056a13a431"/><file name="ImageUniqueId.php" hash="3007c391ed138e7db78cca05ad964cb5"/><file name="Iso.php" hash="9b7340beb6cd2f991d0b590da9929207"/><file name="Make.php" hash="b96528e1c95904dcf7a32b6d2b855c4a"/><file name="Model.php" hash="de354ebd3ac53b26c7ba7d07b7eaf74e"/><file name="Tags.php" hash="0b6dca99d61d601cd89ddfe6d9af5990"/><file name="Time.php" hash="880ab5825cab35d85036460d54b18148"/></dir><file name="Feed.php" hash="d102e026496f926fa8dbf0024e75ea22"/></dir><file name="Exif.php" hash="31c98117fa58af3fbc8a9504aed7f05d"/><dir name="Extension"><file name="AttendeeStatus.php" hash="dac3c0490bccbf09f924948ad44232cd"/><file name="AttendeeType.php" hash="3b42bd943b0536d5bde7e735fd8615d4"/><file name="Comments.php" hash="9afbcf4a4ce1d7dd52706e0e8928a8ee"/><file name="EntryLink.php" hash="5a280e630417eb616c257813c3ead727"/><file name="EventStatus.php" hash="61f988f2bfafa564543cabe4e7f86f29"/><file name="ExtendedProperty.php" hash="2d80f08e6e2e79da98134e959b58fbbd"/><file name="FeedLink.php" hash="679a6f5c9ebed486b6b41bac1522fba3"/><file name="OpenSearchItemsPerPage.php" hash="8430c39b6ce1bfb8deb8d2ff4070edf6"/><file name="OpenSearchStartIndex.php" hash="118645c4f8d38b135ebdd9792ba30234"/><file name="OpenSearchTotalResults.php" hash="8e7bbe094d00d023b1ac76184bbc871c"/><file name="OriginalEvent.php" hash="799806cbff3654b92028550a96d3f418"/><file name="Rating.php" hash="96f79437551070a76a0ffc8cf0ce3f93"/><file name="Recurrence.php" hash="da2e478f7368e9fae3e91aa4975769b9"/><file name="RecurrenceException.php" hash="1565fac963250d130a9a18d0e87a9462"/><file name="Reminder.php" hash="84525523e8827d09cda261f02f4c4214"/><file name="Transparency.php" hash="2c99f3896ceaa90632f565d3910eba43"/><file name="Visibility.php" hash="df49298225481498f3a082cc88092ed6"/><file name="When.php" hash="4a02d7db9ade6210d5d01fd401938732"/><file name="Where.php" hash="5d1d9557f1a8a24be5c6076464f35cda"/><file name="Who.php" hash="8d3c827558b62b6fbbdb1786bc6dc8f0"/></dir><file name="Extension.php" hash="3dbf28598313aea3fbcb6ae0a9218373"/><file name="Feed.php" hash="8ae61588a220ed9e612bd0d306ed7be9"/><dir name="Gapps"><file name="EmailListEntry.php" hash="beeaa4d8624538255fd4fa414bf2aa2b"/><file name="EmailListFeed.php" hash="dae8f9390c01ce354aacf7a03b56faa3"/><file name="EmailListQuery.php" hash="38e4255133125d1c3cd461769ff2bbf6"/><file name="EmailListRecipientEntry.php" hash="5042400a2ccf63b598d11098c08a02a8"/><file name="EmailListRecipientFeed.php" hash="e67f7530086c3c3de9bf49ce731ba816"/><file name="EmailListRecipientQuery.php" hash="6b48a9d58feb39241c63a1c448259894"/><file name="Error.php" hash="2739432a885e3aa64112124acf85666a"/><dir name="Extension"><file name="EmailList.php" hash="d83a001f6b79d69a55a534c352df4518"/><file name="Login.php" hash="068572b0a7d975d816564d334aa6cf07"/><file name="Name.php" hash="b895fe7b562ab015bc391c82be75d63e"/><file name="Nickname.php" hash="12ce7eb02489b501861272c13acec59d"/><file name="Property.php" hash="4517466631d6a91e771e3eba6c4d028e"/><file name="Quota.php" hash="18a9c44fdf6146c74b51d123c00bd7d4"/></dir><file name="GroupEntry.php" hash="5c36b2030c5394629693de197c909286"/><file name="GroupFeed.php" hash="13b68ebe7768fabe2f408b5a317bb088"/><file name="GroupQuery.php" hash="fc3f172f6fda1a3b50c6c8c2f3beebd6"/><file name="MemberEntry.php" hash="987fddd8e68938e62d4fb4c80a0b7586"/><file name="MemberFeed.php" hash="aaec820fc096293a6e6f4e5dc9a213a7"/><file name="MemberQuery.php" hash="1fe4b7f18ca161de836a9bf2b18cf123"/><file name="NicknameEntry.php" hash="f0fbcba505a6cac9d64328acf86c168a"/><file name="NicknameFeed.php" hash="80df6633ccad4aea2f1b0ff1fc56fedc"/><file name="NicknameQuery.php" hash="b3fc90f01854679f692ca2d34f1ef867"/><file name="OwnerEntry.php" hash="a66d48e8d46fddf2a9e3ea0330bcea45"/><file name="OwnerFeed.php" hash="98123454cb3cc6dc134d9ad827d297b2"/><file name="OwnerQuery.php" hash="5c829232390b828f06565012b2af3ce6"/><file name="Query.php" hash="a893bb0bebd43c558fac8f7b58477577"/><file name="ServiceException.php" hash="e62bc29c1a67ab44455ebc10fb033887"/><file name="UserEntry.php" hash="327e60ce8bad4fad8aa9d785902a0488"/><file name="UserFeed.php" hash="12a6e44ebb6b809f1ab17884c957d034"/><file name="UserQuery.php" hash="36d9b6e3c53812f1a0b3ba58b8348d1f"/></dir><file name="Gapps.php" hash="006b69cd2b4bb52efbc481cba3ded85d"/><dir name="Gbase"><file name="Entry.php" hash="d1c0594bd7f509ee8b71a0d4c6e93cef"/><dir name="Extension"><file name="BaseAttribute.php" hash="9860f259d07b1d7c48953ac145e91173"/></dir><file name="Feed.php" hash="a3a9a55b4dafc0c71da475d0b8ab4ed3"/><file name="ItemEntry.php" hash="4ad3d155cdb9fce8010cb9ff27d3ff54"/><file name="ItemFeed.php" hash="44ffbf3810fe7d602fa50a219f4d0c6b"/><file name="ItemQuery.php" hash="d85aa16b033dfc7478cbfa9cd38cbd69"/><file name="Query.php" hash="feaa71301ffc82297a5c768b267ff5b2"/><file name="SnippetEntry.php" hash="023249497ffc22f6fbad8645c50dc78d"/><file name="SnippetFeed.php" hash="5197182ca6edcf33fa8452f809597510"/><file name="SnippetQuery.php" hash="17365d8dc24d1da93b8b730c6fe6d864"/></dir><file name="Gbase.php" hash="78c17b83a499c8c31d31762990d83d3b"/><dir name="Geo"><file name="Entry.php" hash="bf5d39448208c58aba61ec64d6a79ad8"/><dir name="Extension"><file name="GeoRssWhere.php" hash="914e0e1155c117f5908f07dadc6ee889"/><file name="GmlPoint.php" hash="a5bf5b02bdec49c06e1aa44763bba1a8"/><file name="GmlPos.php" hash="8ef27447e497a39031e475372a8cb08a"/></dir><file name="Feed.php" hash="c2adb51ac77e046f74ac15f7bcfb53d3"/></dir><file name="Geo.php" hash="2a5a5a2dfa2462e061234e4946fbc8f4"/><dir name="Health"><dir name="Extension"><file name="Ccr.php" hash="5f6686a6c63958e949db8bf5deb92f2b"/></dir><file name="ProfileEntry.php" hash="a2c0dd3747b54680f62089aa25ca26c0"/><file name="ProfileFeed.php" hash="1a41a46d2871e28239c45f23f0b50868"/><file name="ProfileListEntry.php" hash="ee7b66b18af7f3d7406c10c82dbe903a"/><file name="ProfileListFeed.php" hash="1d15e991cf6dc94a83b52ec64aed7a2a"/><file name="Query.php" hash="6dd89b579a5aa4d35de32e74c0df5502"/></dir><file name="Health.php" hash="6b0a156697fe84a09efbde31eea3f497"/><file name="HttpAdapterStreamingProxy.php" hash="6b2964e32bf7c0e110b8ab25445ed53f"/><file name="HttpAdapterStreamingSocket.php" hash="b5b74e5c1cb8206da4b163666a81fed4"/><file name="HttpClient.php" hash="9cee0a291d6c4b11f7358628923f925f"/><dir name="Kind"><file name="EventEntry.php" hash="1f1204191536089911a984770ce0cb47"/></dir><dir name="Media"><file name="Entry.php" hash="9cc1bd304119ff7d428225d3107c3a34"/><dir name="Extension"><file name="MediaCategory.php" hash="8f9345afe735f43c0936d2741556db13"/><file name="MediaContent.php" hash="947b1ca390fa6021690d0a67f81c0c28"/><file name="MediaCopyright.php" hash="947dadff8c8d2708ccb7af6aaa5d928e"/><file name="MediaCredit.php" hash="6d2b9d4be6e3c896fc9c9f9a9581ce9d"/><file name="MediaDescription.php" hash="eeaf98530facd9f42d2e3c46661db3f3"/><file name="MediaGroup.php" hash="9e6dcb6e453393b23d7efb8dde3fb4b0"/><file name="MediaHash.php" hash="2f84bf6db86d3302709347222ad1eba4"/><file name="MediaKeywords.php" hash="6a1a4c5eee620173c5c1995a8bc0aa25"/><file name="MediaPlayer.php" hash="c7d51126d6604718daec1674785e90af"/><file name="MediaRating.php" hash="915d64d3fa690969aa6697c945ef7b28"/><file name="MediaRestriction.php" hash="8921f3bd9d80f7a530b826ab009668c4"/><file name="MediaText.php" hash="557defecdbd618e8917ed5fcd6ccddbf"/><file name="MediaThumbnail.php" hash="e5e272a715318c877fae805dc78e3fee"/><file name="MediaTitle.php" hash="4134d9c00494d89ba462ae9500d1e2bc"/></dir><file name="Feed.php" hash="f67c9bb85cbfbf098fb53ae50a026044"/></dir><file name="Media.php" hash="752e78b67dca41a50ffb85dee3b3e483"/><file name="MediaMimeStream.php" hash="de9b3dd42e0f9f62341fa075bb900c6c"/><file name="MimeBodyString.php" hash="ea742b4f32d34ddac64454b990d4ef37"/><file name="MimeFile.php" hash="0afbad3bc750c1cc5d3f93c54c3c5019"/><dir name="Photos"><file name="AlbumEntry.php" hash="1ab5e6bdc070df30938e912d52eada85"/><file name="AlbumFeed.php" hash="07c42ecd6819d25e428b94f31882c1a0"/><file name="AlbumQuery.php" hash="5da3a372fe52f8c076e9d97a35f823e1"/><file name="CommentEntry.php" hash="f7822566e08ea7b3f74c955abf89a41f"/><dir name="Extension"><file name="Access.php" hash="8d4c3dfe21dbb25632e87659070125d1"/><file name="AlbumId.php" hash="45b3059567bf5e49a6f8edf6b8a16937"/><file name="BytesUsed.php" hash="fd2a43339909b5c7402208dccbdf68c0"/><file name="Checksum.php" hash="5ca31e3430e2e9b747d91c94c000de8a"/><file name="Client.php" hash="2a3276f0666bc92c7d7155bcfbc74f42"/><file name="CommentCount.php" hash="48176e51ea9b1c3c0de6edcf24e25d19"/><file name="CommentingEnabled.php" hash="5b460e8f02be0079867d34af9ab54bce"/><file name="Height.php" hash="d913feb4798b7f3c8ba645bc6ecd1d59"/><file name="Id.php" hash="c5c6fcef6647a1523b99463cfb0a6ebe"/><file name="Location.php" hash="b2b10096aeca032d37e138b09f4ce18e"/><file name="MaxPhotosPerAlbum.php" hash="d1b61411c47e1eb91cb0b80be60998a0"/><file name="Name.php" hash="7e6637d23584ef1ebc3834940fc2ad52"/><file name="Nickname.php" hash="c4345329b15d815de6527d0f8e0277e6"/><file name="NumPhotos.php" hash="160edc7a3b4837435a36befe5378e01e"/><file name="NumPhotosRemaining.php" hash="a3b358f036c2fbefdf93830c92a027fd"/><file name="PhotoId.php" hash="ff997a353b24d944f439702d4ece0966"/><file name="Position.php" hash="cf9f8b0c29c98c1680b2675ebf47e6b2"/><file name="QuotaCurrent.php" hash="a57ff86ba83287a1f145f272ca463756"/><file name="QuotaLimit.php" hash="00c6e94954fbe136a09d4b7ca8f7128c"/><file name="Rotation.php" hash="513a2712c12e10fb61dde21976824b7e"/><file name="Size.php" hash="ab29ba1766a003c1b3ad22db180d18cc"/><file name="Thumbnail.php" hash="6a59c5bebc192e34992e8058ccfd11c1"/><file name="Timestamp.php" hash="b52abdc854529af5cb545691692375ec"/><file name="User.php" hash="3a21cef935fd5fb42f97e308b1997583"/><file name="Version.php" hash="9625bc1c6aefcf580c5fbe0d2f045b4e"/><file name="Weight.php" hash="a8bc3ed41e626323f92adf87410af458"/><file name="Width.php" hash="06f910c1bb1e4e747c38c26ed409522b"/></dir><file name="PhotoEntry.php" hash="ada12abf9bb991fa672ca9a05cb979a5"/><file name="PhotoFeed.php" hash="3b29ec6d750456cdd799bcbaa751e89b"/><file name="PhotoQuery.php" hash="93b28eba3750d181f44fe41181e45663"/><file name="TagEntry.php" hash="8c088bb0af6e8a14eced2775aa3a291c"/><file name="UserEntry.php" hash="15e59c396a645fc30f03cb42d2efc351"/><file name="UserFeed.php" hash="e1498967cc3f5d361c96a0bcde82437d"/><file name="UserQuery.php" hash="26f3ef6227851523817358a97544ebd6"/></dir><file name="Photos.php" hash="c46ff72fca949809ff42f17b0079c069"/><file name="Query.php" hash="100dee31d0a572c4d2e990a96f7e9a0e"/><dir name="Spreadsheets"><file name="CellEntry.php" hash="93cc5079095d6daa6c2147b62131a890"/><file name="CellFeed.php" hash="ca07b9478e1b6ecae9147bc2105c8bd7"/><file name="CellQuery.php" hash="bc7fbfd4e84481e19df568357bc22e37"/><file name="DocumentQuery.php" hash="fd2935ddca76445d1bea58c4f6799ebc"/><dir name="Extension"><file name="Cell.php" hash="917abed62f74a5101511f4449c805140"/><file name="ColCount.php" hash="dba4f0796d79fe80ff15d4dc9bebcd24"/><file name="Custom.php" hash="8f805dee81206d515ab43097cecedb1b"/><file name="RowCount.php" hash="be76b9f5b367cb349576283ab9765d34"/></dir><file name="ListEntry.php" hash="7b8c759afeb6cee40fc5ce231dcf6f2e"/><file name="ListFeed.php" hash="688c2cd0aab8cffabce85d835e4fe077"/><file name="ListQuery.php" hash="2bd4f1eb97b6b3c92c8d2f52fcdbbccf"/><file name="SpreadsheetEntry.php" hash="e43a1862baadf19907770d4a61a56626"/><file name="SpreadsheetFeed.php" hash="2cd1cf91c61a54ea236e1aaf73877009"/><file name="WorksheetEntry.php" hash="7091ab92f732197dbf7e45dcc9c87bf3"/><file name="WorksheetFeed.php" hash="3a4c334028cc35e76255507be1efe061"/></dir><file name="Spreadsheets.php" hash="5706fa18d101c716c73b5f1f6869f33b"/><dir name="YouTube"><file name="ActivityEntry.php" hash="19c73663008cbcbb141c35e8717521aa"/><file name="ActivityFeed.php" hash="5e45cff4ae0df9e35683067769a26386"/><file name="CommentEntry.php" hash="8f17768b645f4165b9601e59fab4045a"/><file name="CommentFeed.php" hash="a391a8ea8c0b27904e365eace8b03458"/><file name="ContactEntry.php" hash="440d8c1c0196e59dd80c6c52e30b2459"/><file name="ContactFeed.php" hash="ae3698b6ccf9d339f7a30b4a5789f698"/><dir name="Extension"><file name="AboutMe.php" hash="8011ef3b524bea9fff089882ea4ed0ab"/><file name="Age.php" hash="e2a9893b2e911b3db507465320cbcf63"/><file name="Books.php" hash="89b35f4bc0027463f91824b5cd2e47cb"/><file name="Company.php" hash="549c355f976cc892cebc6811fe2580a1"/><file name="Control.php" hash="578a083eabf62931b62d095600b80003"/><file name="CountHint.php" hash="666969cd9d5d77e06c9a115fae9de6b8"/><file name="Description.php" hash="8a7dbf10f59ccd573eb0c90cc5971cf6"/><file name="Duration.php" hash="24f2181f720fe6db1cb22503ffee459c"/><file name="FirstName.php" hash="d28dd3cd580a2fa7c6bfb829e8711166"/><file name="Gender.php" hash="260b84dc18e9c01eac563404d0fa5f5d"/><file name="Hobbies.php" hash="2dd89e1c8199ef743d771702ecc95c8f"/><file name="Hometown.php" hash="fda3ebb42524b3ab8d54467887da61f5"/><file name="LastName.php" hash="f19b93c1d745cafe6ecf20c7bc8d0c3d"/><file name="Link.php" hash="d93c9801f25b8c8cb13d87ff3b3b460e"/><file name="Location.php" hash="20909b4d155c9fd517081322b835f306"/><file name="MediaContent.php" hash="1b53bccaa9f1de51c19378fc8c442868"/><file name="MediaCredit.php" hash="4571da70916493177e72f0aebeaa78ac"/><file name="MediaGroup.php" hash="36cca7fb741bb294f4dcb4142733d100"/><file name="MediaRating.php" hash="099d0984cdb2c9110ca259311047d0de"/><file name="Movies.php" hash="464957a1f90eb56899ec503c4ede6ef9"/><file name="Music.php" hash="947c3294f34d0f35ab88c7f7a9c4f4b3"/><file name="NoEmbed.php" hash="1e6e4a5995de606554e7145a0df0b6d4"/><file name="Occupation.php" hash="b33c3053639572a312fec678395d7436"/><file name="PlaylistId.php" hash="af87bcfda7115ae9c55bf3c1f2986754"/><file name="PlaylistTitle.php" hash="79b89ae7bdce993a758fd1bf45188252"/><file name="Position.php" hash="d92a78e714b2f7afdfabd8d09f73ff1d"/><file name="Private.php" hash="93bd6eeaf228e882ccceda591813228f"/><file name="QueryString.php" hash="5e5c57c2e219ef2e5ca3184997d87ccd"/><file name="Racy.php" hash="ad019d20c5c40d12da9cfc9df9daeaec"/><file name="Recorded.php" hash="7af195c7f3f045946f13504cc38522a0"/><file name="Relationship.php" hash="b42aac9538b504662222635a29149436"/><file name="ReleaseDate.php" hash="beb4a4d9830ff40a06816a341de8dd15"/><file name="School.php" hash="51a1ff928489cc7cd3aacc7a7aaf08a3"/><file name="State.php" hash="04cd3d54d4050aafc5ce27e719d234e9"/><file name="Statistics.php" hash="73270160b45c7ec91914467ccda850ef"/><file name="Status.php" hash="aadcb325d6f3b51cae180406d4caf9a4"/><file name="Token.php" hash="8686b59bd2a0048283389bc01acf77bb"/><file name="Uploaded.php" hash="9ee6ea6660e515f1440d92b2ef4d97dd"/><file name="Username.php" hash="c3782552a9accafea073e8f0081e43f3"/><file name="VideoId.php" hash="30fdd4c5cd5b212a1e4c17cd28fbb12b"/></dir><file name="InboxEntry.php" hash="24eb593b56341f919f0bc0446b4b71f8"/><file name="InboxFeed.php" hash="69487f9424ad1686f1b00e2b1f73ad29"/><file name="MediaEntry.php" hash="924fd5fcbfec4c44e965812618c08b6e"/><file name="PlaylistListEntry.php" hash="367ad32e10ea7203408d99bcfae836a2"/><file name="PlaylistListFeed.php" hash="6a2db1a031b1f749231326b4bd57d9bd"/><file name="PlaylistVideoEntry.php" hash="5453811dc274201e95b9ca6450180669"/><file name="PlaylistVideoFeed.php" hash="54be8eb4c90f3a5a4b6ce1ce578f7e56"/><file name="SubscriptionEntry.php" hash="f602292610ce553fb7493cda0bc25cb0"/><file name="SubscriptionFeed.php" hash="576b63779940d7e3576a1c505bff284f"/><file name="UserProfileEntry.php" hash="4eafc0f86b477f85405429572ba1ba62"/><file name="VideoEntry.php" hash="1ef39076a4e9cd95f91bf8d69bf4f52c"/><file name="VideoFeed.php" hash="aa4889f83dab3ed5524583b48a7a5a22"/><file name="VideoQuery.php" hash="a2a973590b187f7314e994d824a6a288"/></dir><file name="YouTube.php" hash="a8dc12d5116ec45b159b59dacddbf946"/></dir><file name="Gdata.php" hash="f1583b57defcf04cb1b35c2875a95ea1"/><dir name="Http"><dir name="Client"><dir name="Adapter"><file name="Curl.php" hash="a4300f6a2b52d63e0edd1e81c4fe2dd5"/><file name="Exception.php" hash="edeae8782f6926386f145d8a873d23bb"/><file name="Interface.php" hash="588b60a6607675c8698be8b3fd2d4e22"/><file name="Proxy.php" hash="6892b7d0c9de3a441adb25d4fbbd22ec"/><file name="Socket.php" hash="6078a103596ba3a8b2544563d252d505"/><file name="Stream.php" hash="14a0106f768a6388688690a54a3eef27"/><file name="Test.php" hash="35e3087f1d6baa3b6fa2cda8228febf9"/></dir><file name="Exception.php" hash="a5f986ab6d87cb83bed91a1caf56ac00"/></dir><file name="Client.php" hash="26f6df4ccf15f65b213ebd0f5538978a"/><file name="Cookie.php" hash="a56a600d64c9bae67c66ae784de2fe58"/><file name="CookieJar.php" hash="7d93690c2caf40108c35a66b10e25586"/><file name="Exception.php" hash="b345b84b1e9b8a1ae2478ff04f37fc2f"/><dir name="Header"><dir name="Exception"><file name="InvalidArgumentException.php" hash="02d00d00a945c0595a648ea418fe3673"/><file name="RuntimeException.php" hash="8c166ae41ab4e516abda9289f19e973c"/></dir><file name="HeaderValue.php" hash="c0e08b696c63818f37faa68a0f733d32"/><file name="SetCookie.php" hash="5f5620b08a9a298bd60cab553cc4f213"/></dir><dir name="Response"><file name="Stream.php" hash="8a41b22b489629a6766dfb3cb96e0ed2"/></dir><file name="Response.php" hash="a34c934977d3bbc1da1a2153692a5743"/><dir name="UserAgent"><file name="AbstractDevice.php" hash="e52f1ad149795aad5075c4bc6cf977f3"/><file name="Bot.php" hash="e5679a2e30d3f1ef581d508446c1f482"/><file name="Checker.php" hash="0b6bb9cb341b75ca7bfb749cb2c871bd"/><file name="Console.php" hash="93650b34bd1238887e88c238291853c0"/><file name="Desktop.php" hash="9829ee285a2cdc4388326a07644d042c"/><file name="Device.php" hash="72533d95dea2a7fe6366bd2145b5b938"/><file name="Email.php" hash="f0a3fab08e59378c0189073237611af7"/><file name="Exception.php" hash="beb38f75f587ac56cbb7a843f59a84ae"/><dir name="Features"><dir name="Adapter"><file name="Browscap.php" hash="a88ccf8fa0b5aca789f32a08f83c98e7"/><file name="DeviceAtlas.php" hash="725061814353e65cc2d89e2a67a00673"/><file name="TeraWurfl.php" hash="1f91bc3ded39c5b108d8232d18cd17f4"/></dir><file name="Adapter.php" hash="a4dcf44cd31de8969f3e941f9a14d0a5"/><file name="Exception.php" hash="a8fba4a7bf9a1a58225ab313b5fa4dd3"/></dir><file name="Feed.php" hash="716918e5334ac352997eac35ca5956dc"/><file name="Mobile.php" hash="00d3e607c4ac5e298492bd3d7762c555"/><file name="Offline.php" hash="6c1ce88c65a43a63416928292c5f9f5c"/><file name="Probe.php" hash="b4df007dbdeb6ef7c49f599d728eed49"/><file name="Spam.php" hash="a4402ccfc92bdf4c49ed1a27bb1905eb"/><dir name="Storage"><file name="Exception.php" hash="ab40f3958bb905a85cfa5cf14af640d4"/><file name="NonPersistent.php" hash="9c8d459eb114f70df099bd397a542a1f"/><file name="Session.php" hash="6b94c84a472e0a767d42be7e26aec3c7"/></dir><file name="Storage.php" hash="ec42c71aae122ea711cbf87ef261c4e4"/><file name="Text.php" hash="711458780f3c17ad437f3d56b5109321"/><file name="Validator.php" hash="69d6afb8a82293c61a642c791f5a16db"/></dir><file name="UserAgent.php" hash="460734f564ed89053481a1204db01c79"/></dir><dir name="Json"><file name="Decoder.php" hash="be80f4b8fe57afd69752fc51c349dcc8"/><file name="Encoder.php" hash="0282ee4cb81e78771c8829398f64082f"/><file name="Exception.php" hash="949bff931d3430258aa0d8688d70df18"/><file name="Expr.php" hash="5985e830701d7f8d5daeb230ce56b1a3"/><dir name="Server"><file name="Cache.php" hash="149b4bcdb085ccd0d535903aa463a0a6"/><file name="Error.php" hash="f3bec127c343a8e14a7a9b1339ab28aa"/><file name="Exception.php" hash="1b0ac33c450ec1bee800421995576fa7"/><dir name="Request"><file name="Http.php" hash="832d82cb88edefb954c4d4d730d0a95c"/></dir><file name="Request.php" hash="35999aec48306723cd44da4c5a62fe35"/><dir name="Response"><file name="Http.php" hash="a5f156d547e04bd224295be634e864da"/></dir><file name="Response.php" hash="a3c115766d7a5e6e57cb4a27887cad2a"/><dir name="Smd"><file name="Service.php" hash="9aef500f4cef8c72886b6103820397e5"/></dir><file name="Smd.php" hash="c8dce4255950f809a22ee60febb2bc2c"/></dir><file name="Server.php" hash="90dcadb42953db253627a783aafa0b80"/></dir><file name="Json.php" hash="9c8bd17cde28999638cd2f05fe470cbb"/><dir name="Layout"><dir name="Controller"><dir name="Action"><dir name="Helper"><file name="Layout.php" hash="c049699d9228b85c2823d7bfdba7d8de"/></dir></dir><dir name="Plugin"><file name="Layout.php" hash="2af276e070314489ccdd514b841d86ad"/></dir></dir><file name="Exception.php" hash="a479f33598f2c4e1cb228883ae6f22ac"/></dir><file name="Layout.php" hash="6d7b1d2ad0c1bf5d5d1ea058ca5a24f7"/><dir name="Ldap"><file name="Attribute.php" hash="a334347a968defb0fda698c3c54f46d7"/><dir name="Collection"><dir name="Iterator"><file name="Default.php" hash="8f8a4876cf258d6b1f71582a805df017"/></dir></dir><file name="Collection.php" hash="ac57de545867cf7cd1df3d6c113263ca"/><dir name="Converter"><file name="Exception.php" hash="4e029f2da6d5c7df7644bfd2c434c6d0"/></dir><file name="Converter.php" hash="8e09bff7ca34d3051cee4a873f5b58a1"/><file name="Dn.php" hash="b5653205b12da006a91e498ca7fc7dc4"/><file name="Exception.php" hash="e12baa19246087c376b7d5cbf0ab7eca"/><dir name="Filter"><file name="Abstract.php" hash="efc802cd50bc28c4181e5bbab247e725"/><file name="And.php" hash="662ca1c25383de02b569c76bc62a058f"/><file name="Exception.php" hash="4f8ae5e40c68e60f00550dd5ccd7aa34"/><file name="Logical.php" hash="06aad3c5c574bae76adc46927ae21474"/><file name="Mask.php" hash="904d6707c87b202d9b66e1e3532fbd94"/><file name="Not.php" hash="028697704f21551b33dcb7c160369691"/><file name="Or.php" hash="8dec15db06446ad375c61c7f46912d7c"/><file name="String.php" hash="b1cc0c074d1822be6124f6c48e351a86"/></dir><file name="Filter.php" hash="c50df357d992c35c217ac7803ce314b2"/><dir name="Ldif"><file name="Encoder.php" hash="d1116ef8bfa81ce18fd5cbae52942227"/></dir><dir name="Node"><file name="Abstract.php" hash="e84bbf67046f975a1f5775aa0d49348d"/><file name="ChildrenIterator.php" hash="8b0c6775e5111e80938ccc9cb60aed0c"/><file name="Collection.php" hash="11098b8c84df455895877fad99f30a20"/><dir name="RootDse"><file name="ActiveDirectory.php" hash="c5f5e80b8dd2cb1e31ac3e03fc279024"/><file name="OpenLdap.php" hash="dcd6e7ebc3775e6a5cba8485bd78c8d6"/><file name="eDirectory.php" hash="f946fccdb3015b015d3cff00829a6ea6"/></dir><file name="RootDse.php" hash="c247acc47a79441717304abade296309"/><dir name="Schema"><file name="ActiveDirectory.php" hash="85bc7915ab42dae47c2d4fb8e3dba51c"/><dir name="AttributeType"><file name="ActiveDirectory.php" hash="04a142f499e0848e9ae43a64786328d4"/><file name="Interface.php" hash="ae4ab45b50efa4e032e32912d9c6a776"/><file name="OpenLdap.php" hash="a823f4b81c597a3820e4fe67e5454e70"/></dir><file name="Item.php" hash="fe670cbd69aa5863f9f66efadfcd3dd2"/><dir name="ObjectClass"><file name="ActiveDirectory.php" hash="e678fbe8c0e965cf7db01e829adff67f"/><file name="Interface.php" hash="166b71e4032d84ecfc88365d89b1de11"/><file name="OpenLdap.php" hash="428b8707dc060e1f9e7854005c51d58e"/></dir><file name="OpenLdap.php" hash="2e52c69ae03823a1d0f42e83aff2f316"/></dir><file name="Schema.php" hash="2745fb40a9578d326a48718ee91cc5fa"/></dir><file name="Node.php" hash="648c759b832b68b000e8bf08af0339ce"/></dir><file name="Ldap.php" hash="da470d2a2a451bc59b2ed1ecb118ec5d"/><dir name="Loader"><dir name="Autoloader"><file name="Interface.php" hash="5a8847bbf702beb3c5d03d9b6620291a"/><file name="Resource.php" hash="b9e4409e67051a21f4e2ae855c1bd691"/></dir><file name="Autoloader.php" hash="4882de8624fe2953294bb4a2a2a6f8f6"/><file name="AutoloaderFactory.php" hash="3ec199fa5c2dec860143b37f17b5ce65"/><file name="ClassMapAutoloader.php" hash="2acb3037511952ac7eb2bab70501dcd9"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4286045d7c3bad36fa3e101f0beadfaa"/></dir><file name="Exception.php" hash="81dbec797bf5464d3dd93886de055be3"/><dir name="PluginLoader"><file name="Exception.php" hash="fba867bd38d0dbb235f86cc6899d834e"/><file name="Interface.php" hash="60638720a3d503c41b6679d1a12c9e59"/></dir><file name="PluginLoader.php" hash="6be3d7edad844778eb79c52494f04eb8"/><file name="SplAutoloader.php" hash="b35315f66536a170485d6a91cc962a4f"/><file name="StandardAutoloader.php" hash="181406bd273d500ef771e5f24b0bd909"/></dir><file name="Loader.php" hash="817eebfff3c19cf057a8bd92f0c9c679"/><dir name="Log"><file name="Exception.php" hash="b163db6d6600897c6d7d9675f5b2082a"/><file name="FactoryInterface.php" hash="950fce8f1016b9149a3afa78cb5d6bdd"/><dir name="Filter"><file name="Abstract.php" hash="588c7a33b8cc18516fb09f45b6e4df27"/><file name="Interface.php" hash="8e207e5fde37a093bc429eca471abdb5"/><file name="Message.php" hash="42c00aa794507e263369816ebd6ecfb9"/><file name="Priority.php" hash="3bc818826edb7d8d47778c71534968ca"/><file name="Suppress.php" hash="6198f609922c91844696ad749f8f988b"/></dir><dir name="Formatter"><file name="Abstract.php" hash="f6b6a3a2f08104b92f02916dfae10819"/><file name="Firebug.php" hash="18bf525dd98a338a0068adc7223004aa"/><file name="Interface.php" hash="f304a62a7dc3774938c9a4c0386e312a"/><file name="Simple.php" hash="e99de8b500f61444ef4ffd6bd44f8b28"/><file name="Xml.php" hash="dc3361c1aeaa94dca0dac28920c7ea8d"/></dir><dir name="Writer"><file name="Abstract.php" hash="79ccb8a60f0146adc3d1019487a99a69"/><file name="Db.php" hash="e9dd86777ca1735ccec177c7e385316e"/><file name="Firebug.php" hash="6227fe3e164c36db1829e4afd5fdddd2"/><file name="Mail.php" hash="3f76aaf2c1bfa288b7f126efd127c306"/><file name="Mock.php" hash="be44a2526cd397f294cb3350334479cc"/><file name="Null.php" hash="7dc63aa32e13ee72975d68873d87d85d"/><file name="Stream.php" hash="5a287635e4c1d74763215959ba19b70a"/><file name="Syslog.php" hash="06022b333a8ca4d896eaea75f92fe543"/><file name="ZendMonitor.php" hash="3e508d727439f6c10212e70617d68b20"/></dir></dir><file name="Log.php" hash="1c6f8b389780f0bb85202471def93ea7"/><dir name="Mail"><file name="Exception.php" hash="8d01b40eca451bee7c9401d2498ae65d"/><dir name="Header"><file name="HeaderName.php" hash="ecd8c8336e3619779a72d1e1f105675c"/><file name="HeaderValue.php" hash="d55840608558bb29022bca0c565ae55e"/></dir><dir name="Message"><file name="File.php" hash="7415d6300a134322e1f9b5723f456375"/><file name="Interface.php" hash="37f65eeadf5f7d8c46e5740810a91f31"/></dir><file name="Message.php" hash="eea17eeae16ed0696aef9794f947791b"/><dir name="Part"><file name="File.php" hash="2973a0c512d8a12ae250f0310e7ab715"/><file name="Interface.php" hash="5a08dd0d4abfeba0e2b6a3bcd0647cb0"/></dir><file name="Part.php" hash="b948eb534e24b93bb22d34d6dc78c494"/><dir name="Protocol"><file name="Abstract.php" hash="75f76eb34f20aef472da005983e4ade4"/><file name="Exception.php" hash="324b88f119661b2fb45e50e03fdbb797"/><file name="Imap.php" hash="4be011d91db7e932867a9ef04b9e3f1c"/><file name="Pop3.php" hash="a3f36e5260b3fdf15ff91afb4edd06c8"/><dir name="Smtp"><dir name="Auth"><file name="Crammd5.php" hash="989efed470312ec3d252f04f48b13f1f"/><file name="Login.php" hash="eeb279a39d84d0c34b5b3c57a0d8e1fb"/><file name="Plain.php" hash="4e4fb49d2c0a4c3cc6326b9362663812"/></dir></dir><file name="Smtp.php" hash="a99437c462526c3ab7c4a16e6dd73dd5"/></dir><dir name="Storage"><file name="Abstract.php" hash="c80a746bb73014c266f2785247770e77"/><file name="Exception.php" hash="8dfb9dc508a506017fa2aba591171706"/><dir name="Folder"><file name="Interface.php" hash="e46d56b2092b8e66b0de59f089f28dbc"/><file name="Maildir.php" hash="2ffec84ff5cebbc06f42a4bf4e8e49a0"/><file name="Mbox.php" hash="a6bc27702d0e9acbc52d83efdbb623c0"/></dir><file name="Folder.php" hash="710f0f79f55eb9c16523b59b3e46026d"/><file name="Imap.php" hash="63b4ec9c47e81d973c0cecb781a0e398"/><file name="Maildir.php" hash="c298cee3127aebf1d902bc6a263cd67f"/><file name="Mbox.php" hash="96e1d239b5d88772aacd245255d35cc5"/><file name="Pop3.php" hash="fe599c6260e22c23dcd3bfd698271b77"/><dir name="Writable"><file name="Interface.php" hash="a5a3487a8b0dcc8c1f957e10b9535c96"/><file name="Maildir.php" hash="f9dc51e0430fed3cb7fb06a6fc46b4c1"/></dir></dir><file name="Storage.php" hash="bf94dde2f63c2ea5933cff36fd0d96d2"/><dir name="Transport"><file name="Abstract.php" hash="b5e088f0f4a65356307e1e6048558c5a"/><file name="Exception.php" hash="2fc585f21c0c0bbfb8d9218788a99d91"/><file name="File.php" hash="976dec70144df18e87d527ff7e516758"/><file name="Sendmail.php" hash="0a64fedcc87ebe0c9c15695805201bef"/><file name="Smtp.php" hash="6f916608a1b6f93dc6d116e8d8f40b94"/></dir></dir><file name="Mail.php" hash="233f0679a2a5101183c73419cc14e184"/><dir name="Markup"><file name="Exception.php" hash="6acb9e012348c31a98e8016f689bd83b"/><dir name="Parser"><file name="Bbcode.php" hash="fe5258254d43407c8ebf45121d5d3443"/><file name="Exception.php" hash="96b47171a5e4994dcb75bfeb964a3261"/><file name="ParserInterface.php" hash="22f4cab8c966e18965cc16bf1ac58a2e"/></dir><dir name="Renderer"><file name="Exception.php" hash="c27375ebcd69a8eb56a5c3e3229ef88c"/><dir name="Html"><file name="Code.php" hash="c919be3dcefb797b425cd65153302f6e"/><file name="HtmlAbstract.php" hash="7dc1ee614c7d125582f34ded495bd5a3"/><file name="Img.php" hash="6a130ace451a6ed0a2d0a1f1ea3bff58"/><file name="List.php" hash="e8474711d02734026d531708832e1310"/><file name="Url.php" hash="6bb6f2015aa632299941bf9997e8110e"/></dir><file name="Html.php" hash="b607c5add3adcb046c58771b79ecdca5"/><file name="RendererAbstract.php" hash="bf2e4d797e26ef28885babcf2d9e2722"/><file name="TokenConverterInterface.php" hash="e5b38c0b3ba387f0df071a35c7fb1f3f"/></dir><file name="Token.php" hash="925b6878c35fd1e0855a73ecf684f25c"/><file name="TokenList.php" hash="590aa72556941d672184f1aca02ef30c"/></dir><file name="Markup.php" hash="70327a385551a40429dbf98def244565"/><dir name="Measure"><file name="Abstract.php" hash="a844b711aca6638ea933630264ab309f"/><file name="Acceleration.php" hash="f6b1c64dd6bacb4f38d91f72cd8db6d9"/><file name="Angle.php" hash="6c7ec7f864050be14c1735017d149b18"/><file name="Area.php" hash="88b0f14de44d235235da841062691dd1"/><file name="Binary.php" hash="5f9e527c1e8d01535d9bfea7105ac76c"/><file name="Capacitance.php" hash="8bff74324cadcd21836b5acc547a544e"/><dir name="Cooking"><file name="Volume.php" hash="334d3bd9a1023acfed66eb41bf307a15"/><file name="Weight.php" hash="d970ef6d6f08a37db72285917d30ccd6"/></dir><file name="Current.php" hash="1747ffe7532a5c7c060343e3271a27f2"/><file name="Density.php" hash="f4cb05733337475f59762b41a29ae3bc"/><file name="Energy.php" hash="2ed086e65b6f7a4ce1280d8ef9d0f1c3"/><file name="Exception.php" hash="d00039899c6aa43c6b250588bbc07e35"/><dir name="Flow"><file name="Mass.php" hash="2d322913557ff2bfc45afc2ab480babd"/><file name="Mole.php" hash="ff0fe19858605f8c65cbc6f1f377aba4"/><file name="Volume.php" hash="66df34980d0aa473755280393b0f0d7c"/></dir><file name="Force.php" hash="9525a6c47d1e4cbaded7b3477d3c4ba7"/><file name="Frequency.php" hash="80bf10cfe7eeebc3d281b7ed11b397ea"/><file name="Illumination.php" hash="98ee18ab173727ba4dc93a3ada6edd33"/><file name="Length.php" hash="7318f5740bfe039f8c6bda66f172251a"/><file name="Lightness.php" hash="ea419ded90ccd0f5c053262458cc80eb"/><file name="Number.php" hash="7a63c36bbf2089aef5e8ee3e7347e24c"/><file name="Power.php" hash="c896cc783192f260057584f2ba881f87"/><file name="Pressure.php" hash="49c451f9eacd6d162ba6bb629e9118e1"/><file name="Speed.php" hash="c601fe3564d6f3d1f8813a0a7013e335"/><file name="Temperature.php" hash="0d5d33464d00562675fd5d801eebe117"/><file name="Time.php" hash="1c8b825d84b6ccffd76906404d92173a"/><file name="Torque.php" hash="1f530a46616ba82d78541493fb321445"/><dir name="Viscosity"><file name="Dynamic.php" hash="5f002bc79a1c1138cacacec371db37ab"/><file name="Kinematic.php" hash="bd10456069dc6d35a3e1713bd4c6dd71"/></dir><file name="Volume.php" hash="0fbf0ca1290f4aa1af5b23982a6914c3"/><file name="Weight.php" hash="a821fffd5941ccd527cc1d0694336b00"/></dir><dir name="Memory"><file name="AccessController.php" hash="a70d4c42eea7b98f61113d798b55259a"/><dir name="Container"><file name="Interface.php" hash="6068d380217bf27b6453cf894edb8695"/><file name="Locked.php" hash="9bc2f25899430f7ad02853e88dfca0a9"/><file name="Movable.php" hash="4c3c042f5e2bcc2531715dde401171cf"/></dir><file name="Container.php" hash="8feed8c3f2b8f5f0e8d688f13c48c2aa"/><file name="Exception.php" hash="3329d69fccf497932b1a2c27e9919c18"/><file name="Manager.php" hash="1a5c0de427d4436a95fb9d2c0953f279"/><file name="Value.php" hash="697a03309f774813690845eac71d4702"/></dir><file name="Memory.php" hash="2e82b15d077661c5c4b8201ea5bab1fc"/><dir name="Mime"><file name="Decode.php" hash="0cd721f3b84a257348cbfcb73919759e"/><file name="Exception.php" hash="994fc2875e99f10a522cb82e4a54b2b7"/><file name="Message.php" hash="4e3dd5e95f8621955641c7e1b4de46c5"/><file name="Part.php" hash="a11ac478688ef12d8cd0ccecff33670c"/></dir><file name="Mime.php" hash="39042a59c2be063d736a04dac55e903f"/><dir name="Mobile"><file name="Exception.php" hash="519a024f65881a7a4237732573710059"/><dir name="Push"><file name="Abstract.php" hash="456f8a825509d342fcfef1439673f54c"/><file name="Apns.php" hash="d8429732ef082dd5db604fea4c8915b5"/><dir name="Exception"><file name="DeviceQuotaExceeded.php" hash="86b9ff4bc83a799a58f7dffea7382284"/><file name="InvalidAuthToken.php" hash="5ad87658c33a7d9cc6f917d0b5920253"/><file name="InvalidPayload.php" hash="25c5f5d11619d662e9274418d98ed4f8"/><file name="InvalidRegistration.php" hash="8658ffa721150d321de50135d2e5a807"/><file name="InvalidToken.php" hash="713a8d260276537743a4d04b4aa81c11"/><file name="InvalidTopic.php" hash="7c829b73a958a1a5b2727d2819061578"/><file name="QuotaExceeded.php" hash="be67af28f9904f0fc42004751daff33a"/><file name="ServerUnavailable.php" hash="ed4b06b1ef3e3c429b90731ae2920412"/></dir><file name="Exception.php" hash="f894173f4a187922ee49522cf8d3353a"/><file name="Gcm.php" hash="920c224bf5d2829b12e860785f1fcb02"/><file name="Interface.php" hash="8ac308916b40869193bfe9f4924c6d8d"/><dir name="Message"><file name="Abstract.php" hash="60010ad2c300cc7aaeef6e09bd1f0eb7"/><file name="Apns.php" hash="3aa335c6ee551991ad704c6ec1965399"/><file name="Exception.php" hash="14efc16a622ee08a4d66f6b966aa8afc"/><file name="Gcm.php" hash="8e5c08acd168e10c7e0b7be393683846"/><file name="Interface.php" hash="aa9b1e963e71262791a2e85f9d5e03d4"/><dir name="Mpns"><file name="Raw.php" hash="cd49049ab99df63e747b3cf21ce49056"/><file name="Tile.php" hash="eeb12c6d00f840c828e8f928ef28e747"/><file name="Toast.php" hash="6b7b461af1ebd47bc8278388762e186d"/></dir><file name="Mpns.php" hash="bfb031f22738438461df23e002feb93c"/></dir><file name="Mpns.php" hash="d027a3baf86b7808b8f5dd097dd748dc"/><dir name="Response"><file name="Gcm.php" hash="02cdfb00622182c505e7c4916fb51397"/></dir><dir name="Test"><file name="ApnsProxy.php" hash="ef5b18b7cac0826d10cca487ab851180"/></dir></dir></dir><dir name="Navigation"><file name="Container.php" hash="ae908f801587df5bbc7a44d94e290365"/><file name="Exception.php" hash="1f907b7d1a68ca8d29b29f8f9694ca3c"/><dir name="Page"><file name="Mvc.php" hash="bb408e6676cc27d470e41f21084d050f"/><file name="Uri.php" hash="45e78f322e869f7570a82cac147f9985"/></dir><file name="Page.php" hash="ecc7fc65c84c45b552ea81d280fc13d2"/></dir><file name="Navigation.php" hash="bee97615ae02af0c039d61863d0b1e00"/><dir name="Oauth"><file name="Client.php" hash="74d6c02debac4961c253da9d8cc2fe5e"/><dir name="Config"><file name="ConfigInterface.php" hash="1cabd35d6a7f0f92529457b4ea62e17a"/></dir><file name="Config.php" hash="a02e7f37acbb42bc34feebc920d49871"/><file name="Consumer.php" hash="3dc938414065746a37763d2b592e1ee5"/><file name="Exception.php" hash="570bf15ce9b8ccf76e4bcd949adeef50"/><dir name="Http"><file name="AccessToken.php" hash="986d7e25f96d5bed67914e08404bbb5f"/><file name="RequestToken.php" hash="f4f86a01a6e424aaa7e8edb99e518f59"/><file name="UserAuthorization.php" hash="758cc6c3df942ac5ac3b103527a99a10"/><file name="Utility.php" hash="9c69fe9d58add25eda7730460eeb4ae1"/></dir><file name="Http.php" hash="cef52b37622bcfb2efd2a9644babc94d"/><dir name="Signature"><file name="Hmac.php" hash="26331323b06095d36ea1b3d8de214c79"/><file name="Plaintext.php" hash="11266c5bf1d868c63fac84ff14c22061"/><file name="Rsa.php" hash="4ea7e936077c094ee6365ee33707c4fb"/><file name="SignatureAbstract.php" hash="09e632d7cfb30720b43cd8e33ca867f7"/></dir><dir name="Token"><file name="Access.php" hash="974b61753e392b577562e7090dec4102"/><file name="AuthorizedRequest.php" hash="2c5a7071f93bfc03e8098a367c1b95ad"/><file name="Request.php" hash="3253abe4f0340e7fa12d6c26c669e1cf"/></dir><file name="Token.php" hash="19cbcf77a287619c7043efc9cf4cc2fb"/></dir><file name="Oauth.php" hash="239174147ad1cac48ff43b86ca768b5d"/><dir name="OpenId"><dir name="Consumer"><dir name="Storage"><file name="File.php" hash="53a1aec62db8e0bf8153d2363b8afdcd"/></dir><file name="Storage.php" hash="96636f4707d5090dd777ca16ff5f9498"/></dir><file name="Consumer.php" hash="d4129677162161a383a8327a8a5f5cb4"/><file name="Exception.php" hash="9ae51477a152a9993db86a2b3e87a792"/><dir name="Extension"><file name="Sreg.php" hash="a46ab3f654e7718b74f256863398070d"/></dir><file name="Extension.php" hash="d0cbcdb2874105fad8d517731ee682dd"/><dir name="Provider"><dir name="Storage"><file name="File.php" hash="78e54dc83e5862422be8c086458815bb"/></dir><file name="Storage.php" hash="a111906ee39dd25c3e8f03edf73a3f0b"/><dir name="User"><file name="Session.php" hash="184de6934deff211975387b3d0eea0c7"/></dir><file name="User.php" hash="1130cc8407f1607fcc19e0e0e7048953"/></dir><file name="Provider.php" hash="e82af61658678702cf9b92879c70494d"/></dir><file name="OpenId.php" hash="3afe8be181b4ee86ebca1531a1bd8b0b"/><dir name="Paginator"><dir name="Adapter"><file name="Array.php" hash="b19b7013fca38d006a2b638b89312764"/><file name="DbSelect.php" hash="3bd5b7dc7a01b4dcb161f396be0b8670"/><file name="DbTableSelect.php" hash="cab2b30b8210b2979b0c6bed4b123fad"/><file name="Interface.php" hash="5762707d8b9db19faf2a773eb78edd76"/><file name="Iterator.php" hash="3a51f92d688197a2967eef55d802f56e"/><file name="Null.php" hash="2e58e92129e83d96b61e5ba5bf679157"/></dir><file name="AdapterAggregate.php" hash="b6ed68617efff6b9dd41ba5d27cde51f"/><file name="Exception.php" hash="bd8961847f8ea166c7e222e2344d586b"/><dir name="ScrollingStyle"><file name="All.php" hash="7a024155b60bcbb024b3ab8418ea1737"/><file name="Elastic.php" hash="a7d8784429dc1e520b3f98d14c5eac09"/><file name="Interface.php" hash="1d6adbef71c9c1966676ede68de7f977"/><file name="Jumping.php" hash="2e2e9f1633d9ec60e0e111a5794aed93"/><file name="Sliding.php" hash="9f768e8bcaf3bd6f12e0e939c00775d4"/></dir><file name="SerializableLimitIterator.php" hash="411f2359e449e170c5dadaa24803a54b"/></dir><file name="Paginator.php" hash="0d3667499c2f0c3a8c9e5907e812b7a5"/><dir name="Pdf"><dir name="Action"><file name="GoTo.php" hash="d1e30bb7d45aedbeaa31b5dc8b40e287"/><file name="GoTo3DView.php" hash="fcd5460403b8433315caeca12418a5cf"/><file name="GoToE.php" hash="599ebb6d2df80852cfca9a9cedb8d6b0"/><file name="GoToR.php" hash="474402a7102d563261bd914a721b36d2"/><file name="Hide.php" hash="8810efbd459a87d1ee9de7cd007d1644"/><file name="ImportData.php" hash="ecd6feef7d654d60b8efc24bf26d4662"/><file name="JavaScript.php" hash="9bdf7f5f8360300bc95e3e293431f425"/><file name="Launch.php" hash="3e3b49828aefff82b9b44b295084e413"/><file name="Movie.php" hash="b65daa361fc8e77f5ffc4ecedb3becff"/><file name="Named.php" hash="7a1ea555152631327d04a9eb263b4a5a"/><file name="Rendition.php" hash="363bd0314e6d20994934dabd3ad63684"/><file name="ResetForm.php" hash="f4637cd51199245ab14aa6021ffe71be"/><file name="SetOCGState.php" hash="301da63cac76237c91818aac076cbddc"/><file name="Sound.php" hash="ee1e489704abce5aa0dee9047bd8b456"/><file name="SubmitForm.php" hash="657a9f4bc9cd87ca3551370d195b7a35"/><file name="Thread.php" hash="ecee0d4d74deafefed77cd0f6798093a"/><file name="Trans.php" hash="d9f99fb44efc3651ca5e2c56fd7e96b6"/><file name="URI.php" hash="7e52db0fd92d4edb87ab4f4e789d45e3"/><file name="Unknown.php" hash="a8602a55e7a0792d6cd0615c9ac23c41"/></dir><file name="Action.php" hash="ec5a813b9a9a0caf8beb63b890c68450"/><dir name="Annotation"><file name="FileAttachment.php" hash="f3864019953d49d9cd83d322f9a54f4d"/><file name="Link.php" hash="bff1663cb2b899d96d2b5e539f516d63"/><file name="Markup.php" hash="ab0f2e3e12ec5c7e75b2daf9851c59d1"/><file name="Text.php" hash="7b507f12f45421db845a74e91a0c78fb"/></dir><file name="Annotation.php" hash="0d098c2160f4b3267e7fd7f367f30290"/><dir name="Canvas"><file name="Abstract.php" hash="364364cb99b19cdf0d622397424e155d"/><file name="Interface.php" hash="1795a31a88af11db1f8eaefae3751d65"/></dir><file name="Canvas.php" hash="00dcbc00ee5b0678292c40c62709bb37"/><dir name="Cmap"><dir name="ByteEncoding"><file name="Static.php" hash="bca21500f7be22a1c6349cce6b489afa"/></dir><file name="ByteEncoding.php" hash="84d9e9e1afe70befb0b7c193516a7ad6"/><file name="SegmentToDelta.php" hash="34570bbef3c618d344e056a65a86310e"/><file name="TrimmedTable.php" hash="1a8eaed30b4393a4ad1972ccfa586275"/></dir><file name="Cmap.php" hash="9d7432c932a1f5260c8752cd0eb09cb9"/><dir name="Color"><file name="Cmyk.php" hash="9024fe208254093dfedb355f1a56bfa3"/><file name="GrayScale.php" hash="ac29a955a5422d31e3c6342c9ba5df7f"/><file name="Html.php" hash="98c75da7b5c1e27d72029a612973c33b"/><file name="Rgb.php" hash="db12cfc9dfbb80831d4b1e5436ff8323"/></dir><file name="Color.php" hash="104cf49d07c358cc85220fc3122e800e"/><dir name="Destination"><file name="Explicit.php" hash="13bd68687766542d36847199a9dd478a"/><file name="Fit.php" hash="1aa3f00fde3170cae69b69bd17786c3b"/><file name="FitBoundingBox.php" hash="b59f2ed44504d9f3df4a8e05450c0f07"/><file name="FitBoundingBoxHorizontally.php" hash="1271088bf2557a2eb8c18f388e1853ee"/><file name="FitBoundingBoxVertically.php" hash="16948b893fe63488b34891f82d409d52"/><file name="FitHorizontally.php" hash="88e880e0528a4f7060d233e687e90667"/><file name="FitRectangle.php" hash="408a9be40986151fff98af1efabe8a28"/><file name="FitVertically.php" hash="136c71dd521fb51103f98a76734fb8c1"/><file name="Named.php" hash="a65c919e6fa48d4453a9581ebb908adb"/><file name="Unknown.php" hash="1a2e8b67ee995941dc43b43070a3971f"/><file name="Zoom.php" hash="c9325d991fc179afcca30c3636e72e1b"/></dir><file name="Destination.php" hash="b7605192c93386f3fd25520d180343dc"/><dir name="Element"><file name="Array.php" hash="b644069461389d8cffe6d3bd1cc49835"/><file name="Boolean.php" hash="d4a4de598d871b0ae391dd72ee4cbd2a"/><file name="Dictionary.php" hash="fa2156732ab46185f1412c3e22c54c92"/><file name="Name.php" hash="be8084d6e0fec7b6941bfcb2cbc93535"/><file name="Null.php" hash="a982c3b2f79e698e80cccc4cd794219a"/><file name="Numeric.php" hash="020e5a151377a7f95b0ab846f4cf5829"/><dir name="Object"><file name="Stream.php" hash="9a4d7197a43ba30df5e1871cf85a05f2"/></dir><file name="Object.php" hash="f0b69fb983587a2f68a1f40e3e417663"/><dir name="Reference"><file name="Context.php" hash="e15ad61d18c94f11179594e9a58cb6d3"/><file name="Table.php" hash="6a90fd67ff295547877255bf8bfbe2a1"/></dir><file name="Reference.php" hash="0725ddc6094e61656354a949986d4def"/><file name="Stream.php" hash="166a0bef11c118de4591b7436a9e999f"/><dir name="String"><file name="Binary.php" hash="f6a6e7ce998124ba104470dcb4734dec"/></dir><file name="String.php" hash="e776be7acc388a17af23bec80954de82"/></dir><file name="Element.php" hash="3595c5f91616d00f51af614feafda5f5"/><dir name="ElementFactory"><file name="Interface.php" hash="d1a6e36aaeee2b4a4a7f8b6111facbec"/><file name="Proxy.php" hash="a07e4d22cba4810f367ca6b7240fbc83"/></dir><file name="ElementFactory.php" hash="024f30704c4c693597c11f4b032dfedc"/><file name="Exception.php" hash="7b3b6c5890b43cd2fb05b68f6282f521"/><dir name="FileParser"><dir name="Font"><dir name="OpenType"><file name="TrueType.php" hash="b493bcd28a5c4006be3f5c0a1081b28c"/></dir><file name="OpenType.php" hash="a5d6ab27fa54d414b01532d4830ef090"/></dir><file name="Font.php" hash="56634e0dcb7ade369b564643c5a5d171"/><dir name="Image"><file name="Png.php" hash="15d071e3ce65f9eb9936ca4149910fb7"/></dir><file name="Image.php" hash="29748c74077a30e3b3d108c316ee1910"/></dir><file name="FileParser.php" hash="4d54f7155401a9fb7df70998a2da9a50"/><dir name="FileParserDataSource"><file name="File.php" hash="1e9148d68ab81b33f2d88c403d9495a5"/><file name="String.php" hash="e4cd122d052ef39e6da5c38ec452d161"/></dir><file name="FileParserDataSource.php" hash="eb883b69beb455a62c8931a878151085"/><dir name="Filter"><file name="Ascii85.php" hash="b65b7f97285f88f9f11265191cf20849"/><file name="AsciiHex.php" hash="ed846de8708cd7026f551d78de57782d"/><dir name="Compression"><file name="Flate.php" hash="faf5cfc2e9c94444e43d7e6944247988"/><file name="Lzw.php" hash="9c28f750f6600ce94877b78ad7c71324"/></dir><file name="Compression.php" hash="73050021440ac2c7b18bd20513157c3f"/><file name="Interface.php" hash="e90f59d18816fbaacd86b59b392686d4"/><file name="RunLength.php" hash="e80a6edbe6fa87c4702d09d65db1a2ea"/></dir><file name="Font.php" hash="51087d7787fad796537357c3ac69dc73"/><file name="Image.php" hash="7877b76dd9e150104b83037266258658"/><file name="NameTree.php" hash="da4cc3e1566938790d1c613174aa23eb"/><dir name="Outline"><file name="Created.php" hash="9d373dc681d5b2805d30b5685ef862c2"/><file name="Loaded.php" hash="d6d0bcbbbc7125de10670b4e6562b59d"/></dir><file name="Outline.php" hash="f26766891dc3d3bce49b037adcfef12e"/><file name="Page.php" hash="13f4483dfd5d93e7e94d273c662b46ac"/><file name="Parser.php" hash="ba36ebc92a1b6e525ed8c0408e251bef"/><file name="RecursivelyIteratableObjectsContainer.php" hash="715f93a595f54a38111141fd5968213d"/><dir name="Resource"><file name="ContentStream.php" hash="a1749fec0cba8e9cb72efb1304de2346"/><file name="Extractor.php" hash="bb8efb4919fa8775f711f61d183a4e12"/><dir name="Font"><dir name="CidFont"><file name="TrueType.php" hash="1290b18c2ed5643477c1e88b0c76987e"/></dir><file name="CidFont.php" hash="382f00c4a207bea2ffd82a5d77da6304"/><file name="Extracted.php" hash="bd8bedaf4a31c4ae1eddf944644ecce5"/><file name="FontDescriptor.php" hash="9fcedd31b44153c7ad83cae939397e42"/><dir name="Simple"><dir name="Parsed"><file name="TrueType.php" hash="e060a25bc471d15d43a51d580679326d"/></dir><file name="Parsed.php" hash="becce62602415adde90984b7590993ba"/><dir name="Standard"><file name="Courier.php" hash="1a8795c6738e56ecc9b223ed823c0e0a"/><file name="CourierBold.php" hash="271652240d7b89827820060a185aef0d"/><file name="CourierBoldOblique.php" hash="f8e6fa84ffdc7ffcb8069c67e813f09b"/><file name="CourierOblique.php" hash="7b4080d45eff2b8fd5d66db97512a8bd"/><file name="Helvetica.php" hash="fdf4947a20fbf3f694f4fe940cec5df2"/><file name="HelveticaBold.php" hash="1340145daef0b6ed9e4d15ede06a0530"/><file name="HelveticaBoldOblique.php" hash="ae26d6990824525b0cb3c99e87674000"/><file name="HelveticaOblique.php" hash="a05d94e11e3e1db842ac7f1795074373"/><file name="Symbol.php" hash="9443a7d26e4c2a752cf3f4ff883ffa05"/><file name="TimesBold.php" hash="b2619f7edcc8abab8ff28a4009123f84"/><file name="TimesBoldItalic.php" hash="433fcd37d348fa4458cf437ea2cdabad"/><file name="TimesItalic.php" hash="76ec1fbba59e77bb848f8696337aadf0"/><file name="TimesRoman.php" hash="953b76c5e03a7858bd8361872e412ded"/><file name="ZapfDingbats.php" hash="548d057f0040392a4828264f24e243cd"/></dir><file name="Standard.php" hash="f332565c96e87d79436790a096f46aef"/></dir><file name="Simple.php" hash="334a3b36ea5235902d79cdb31cd05d73"/><file name="Type0.php" hash="6c0a83ed854fdbb16bf525fcd219a4ca"/></dir><file name="Font.php" hash="6046881c1057ef05d0a420998a05c1a4"/><file name="GraphicsState.php" hash="b51172933cdb59ea271e7a9ae323fe29"/><dir name="Image"><file name="Jpeg.php" hash="0a1a368f9642c0b98d8ff24f0aae7c3e"/><file name="Png.php" hash="f77b42c714316c69714df0a2a94cfb7c"/><file name="Tiff.php" hash="06e9fd0b542ecc53649d868fbb59372b"/></dir><file name="Image.php" hash="dbec25fbc65e673b12f311785249ae4f"/><file name="ImageFactory.php" hash="45222c4b5170b11e9b1fc9f16700f1a2"/><file name="Unified.php" hash="710f5f418d4939a609144eab68a8b797"/></dir><file name="Resource.php" hash="b71cd04a74a88e040f06ea7663ea5e65"/><file name="StringParser.php" hash="5376c86288c13e706f2c76478ae474f5"/><file name="Style.php" hash="8aceb18b61204e8157a46c41bbcdd7e9"/><file name="Target.php" hash="1a2badb1e3ca52a2368a77b0646efef7"/><dir name="Trailer"><file name="Generator.php" hash="2c12f38db376c57935d09f8527fa786d"/><file name="Keeper.php" hash="df14918b0e392a71bd41817f0abfaf55"/></dir><file name="Trailer.php" hash="8069878c1e9320d2b8533cf1e144f4f5"/><file name="UpdateInfoContainer.php" hash="39f4700c55860bb9ec1b3f122258930f"/></dir><file name="Pdf.php" hash="7f96ca856c0dde6e6074711e0db2487b"/><dir name="ProgressBar"><dir name="Adapter"><file name="Console.php" hash="09f7268da0ecd77f2d174f4a8a3de869"/><file name="Exception.php" hash="6a2ed89846b42f86a235044d05555198"/><file name="JsPull.php" hash="582d2e3d4fe457d4c961701b014886d1"/><file name="JsPush.php" hash="229b568b05cf46950fbb3707ca150c01"/></dir><file name="Adapter.php" hash="8297cf770c0ee628158397e3b089c621"/><file name="Exception.php" hash="6fd9c59515c836a7e044c07b146c1e6d"/></dir><file name="ProgressBar.php" hash="581036cf36019829ad17b626f15344f8"/><dir name="Queue"><dir name="Adapter"><file name="Activemq.php" hash="b419df4c2da5f1188e2f9fc07fa17d6b"/><file name="AdapterAbstract.php" hash="77fdf9a85df53d3a3b2a2f5d22e80626"/><file name="AdapterInterface.php" hash="0dcaaa3d94f0c384a3c37e45c7529b3e"/><file name="Array.php" hash="b3227f915782241e3ebdce389d3f0a18"/><dir name="Db"><file name="Message.php" hash="017e049117119a01fd2acf00fac7c5c4"/><file name="Queue.php" hash="0036c67014f3b5787878ecb638088423"/><file name="mysql.sql" hash="487d5a36b9172382351a7cc39d20d221"/><file name="postgresql.sql" hash="42dfaf91f8a425170c9b4b2c9318c875"/><file name="queue_sqlite.sql" hash="b0e5a2e43dfc9a230a5ec397c351eaf1"/><file name="sqlsrv.sql" hash="646346084e937e9239d911485bc0296c"/></dir><file name="Db.php" hash="876370736f86a93dedc206bdaea8ac05"/><file name="Memcacheq.php" hash="f0a6604c99debe72daf655a2f97ddc03"/><file name="Null.php" hash="abbd08fab4a38429460cd70b6170c492"/><file name="PlatformJobQueue.php" hash="0e9187b14fcb15711fc18e6bf0dd1383"/></dir><file name="Exception.php" hash="279bbedb61b1778812827fb636c62bd2"/><dir name="Message"><file name="Iterator.php" hash="11ea9382769f547d17a66ac1a54d655b"/><file name="PlatformJob.php" hash="2988e7c33a68ff837ffd7dcbd835de3c"/></dir><file name="Message.php" hash="fb9762a45a532513ff209e2b4820f871"/><dir name="Stomp"><dir name="Client"><file name="Connection.php" hash="aff6c9c41035654ec0d4a4887b4dd218"/><file name="ConnectionInterface.php" hash="e4adc375b6e177fafbd45e47b93ad1b1"/></dir><file name="Client.php" hash="1d64509385a30e21abb7df5e31aa11ae"/><file name="Frame.php" hash="d909edb1b42697e4f557de5a68368932"/><file name="FrameInterface.php" hash="16c13ddfcf2b1bcc50b85c61dc546646"/></dir></dir><file name="Queue.php" hash="1c9e3ec5bc7508a98b7de1f77ee61ba2"/><dir name="Reflection"><file name="Class.php" hash="ba4973471396d116ba92824b47d313a8"/><dir name="Docblock"><dir name="Tag"><file name="Param.php" hash="2a51f3907ad2ee281175d3cdb28a2e6b"/><file name="Return.php" hash="b0200cc0b804828031ab3a8582dbdcad"/></dir><file name="Tag.php" hash="0eebe17d3442b754d9422f8c9721231f"/></dir><file name="Docblock.php" hash="d0856efe818bee5c5d39645662312ba6"/><file name="Exception.php" hash="c43315831b3596fc86aba74529571aad"/><file name="Extension.php" hash="f4dd6dbfb0d48aabdbf359fa6bfaee9b"/><file name="File.php" hash="47206736078efdd5eefc6527408bd922"/><file name="Function.php" hash="1713773cab56cf753f7f90a1108953c8"/><file name="Method.php" hash="25ecb48f4e4f7029ea6fd759fba663f9"/><file name="Parameter.php" hash="7a34d5982a0dec35c6323160114dcb62"/><file name="Property.php" hash="7ca9b4aca176f18bf89b711b5f0929d3"/></dir><file name="Registry.php" hash="3b697b3b783d2821e69137c4dc3851b2"/><dir name="Rest"><dir name="Client"><file name="Exception.php" hash="2e86578bbe604d335a622957c1b0ae26"/><dir name="Result"><file name="Exception.php" hash="49193abd246224f975676b9bdd41349a"/></dir><file name="Result.php" hash="ffc3f1ee709136ab403949d4274098e1"/></dir><file name="Client.php" hash="b76ff6282552bcd098403cebc7b08ed6"/><file name="Controller.php" hash="86e1b0b6bc3ad11653dfe9e17c7d075f"/><file name="Exception.php" hash="c62bd750b3b4cd33407d99869c600d14"/><file name="Route.php" hash="20875e10d835e380c294d2edfb56b08f"/><dir name="Server"><file name="Exception.php" hash="235457f9f3a4f7720ac2013b51ad4ee9"/></dir><file name="Server.php" hash="ceb61231f7fc67faa657837a9fb2c9a3"/></dir><dir name="Search"><file name="Exception.php" hash="915c3138aac999bdce9426a8acd40556"/><dir name="Lucene"><dir name="Analysis"><dir name="Analyzer"><dir name="Common"><dir name="Text"><file name="CaseInsensitive.php" hash="307dc051465ca81322c5e85e8ec022cc"/></dir><file name="Text.php" hash="758df150a1df6eba4b64004148a672a4"/><dir name="TextNum"><file name="CaseInsensitive.php" hash="e5940381671ed3f7c321b3fda9862881"/></dir><file name="TextNum.php" hash="36acd4b130e2f8b78e2de06ac9b4f942"/><dir name="Utf8"><file name="CaseInsensitive.php" hash="44697c595e22b385d0a7616e7af30ac6"/></dir><file name="Utf8.php" hash="1b7f394340ca0d04c8e6a19fe22d4d23"/><dir name="Utf8Num"><file name="CaseInsensitive.php" hash="9325aa4566ece4546b23c82d1aedb57d"/></dir><file name="Utf8Num.php" hash="76dfe3f7ab2e55f1e8190054dd788790"/></dir><file name="Common.php" hash="04cd47fabbd6c404aff39664da13df9a"/></dir><file name="Analyzer.php" hash="85a3a397e4d2c53d185523e25e7ae53a"/><file name="Token.php" hash="b7c5544e368acd06d81d7539983ed85b"/><dir name="TokenFilter"><file name="LowerCase.php" hash="d3be32b9f01fa4343a427721fc3b82b3"/><file name="LowerCaseUtf8.php" hash="9293ea00a25a3e7f129723c9f74b3b9a"/><file name="ShortWords.php" hash="1e296157ac5b8dc2f80a441811707202"/><file name="StopWords.php" hash="c935b1d071ab560816f3a591e3a662e9"/></dir><file name="TokenFilter.php" hash="7e7caefe49ee420c8b5c1561e84f012e"/></dir><dir name="Document"><file name="Docx.php" hash="e6730cac4ab560138c45c9db700d28f0"/><file name="Exception.php" hash="d1f92a2cc3ea06517d5626e96429a5af"/><file name="Html.php" hash="64e7ae4d564af7e71f44c01e48c8e03a"/><file name="OpenXml.php" hash="b21a3c28a95e7a0c9980db28bbc65842"/><file name="Pptx.php" hash="5a2b150c6c2a98b80e1e7765cec8297e"/><file name="Xlsx.php" hash="cae7aa77e2e49c47ecf8a89f169c629f"/></dir><file name="Document.php" hash="81e9c33cd2320e8344181ac5bf78819c"/><file name="Exception.php" hash="2d392bf05fe81a16cd8a3b10618bc6bd"/><file name="FSM.php" hash="5009e011f0b10421ef6e9c6b2c509753"/><file name="FSMAction.php" hash="54cc85832b139caef30d62a66a8008c5"/><file name="Field.php" hash="62d99dc9804e4f352bb55f69a61e5764"/><dir name="Index"><file name="DictionaryLoader.php" hash="dd18c7bb937d629cd0960ba4e8156307"/><file name="DocsFilter.php" hash="a464c3ab082438689658bd370ea21887"/><file name="FieldInfo.php" hash="49cdf39b3445b209adc9370a9970d834"/><file name="SegmentInfo.php" hash="3e9803053f230d7309cce21a643c9e76"/><file name="SegmentMerger.php" hash="335a52ca7e40a79dd6cb95f72cbaa140"/><dir name="SegmentWriter"><file name="DocumentWriter.php" hash="5061bbd3c4b375f3304813ff93a6401b"/><file name="StreamWriter.php" hash="0f6d8ea058813929a7448a4958a3c7c7"/></dir><file name="SegmentWriter.php" hash="13a8736ed2991f513e57f68e61926a76"/><file name="Term.php" hash="490ae3da5ccd138e9b060792766646bb"/><file name="TermInfo.php" hash="4930aa466ba2eb3b65dae3c02aa03221"/><file name="TermsPriorityQueue.php" hash="32663e0ebb7d0279bbcea377903c12df"/><dir name="TermsStream"><file name="Interface.php" hash="751e8ab0d56bb26f7b795d9530dd2494"/></dir><file name="Writer.php" hash="b7ef933d12a1b2f5376584b2420d7976"/></dir><dir name="Interface"><file name="MultiSearcher.php" hash="3f40f5b499a8ee03957fb21aada499da"/></dir><file name="Interface.php" hash="a78e2d90755e526ac9db7eb1c4185f3a"/><file name="LockManager.php" hash="5f61443ba5976b5fa021fb36bba30371"/><file name="MultiSearcher.php" hash="2fde43036355b990e0ac0227a00b6c8e"/><file name="PriorityQueue.php" hash="5c915507c33213ddb4b4ac613f1f68c9"/><file name="Proxy.php" hash="11944c7b4d9879615fd4f3a5d768aed3"/><dir name="Search"><file name="BooleanExpressionRecognizer.php" hash="3896532815243d89040fecb2fd65f606"/><dir name="Highlighter"><file name="Default.php" hash="b1dbdc2d70bb032a5d2b9f9e11273ea0"/><file name="Interface.php" hash="7dca815c9e9f444b9a2a9765fe349dd2"/></dir><dir name="Query"><file name="Boolean.php" hash="5be6706e75dd3e9ccdfaa0eb22f93ca4"/><file name="Empty.php" hash="2e16007df371f28191f785ab85d4d103"/><file name="Fuzzy.php" hash="e66032fc9f9cb06422cac6da95f7b8f6"/><file name="Insignificant.php" hash="1f61e2f1ef8ff38101f2a85c87b9529e"/><file name="MultiTerm.php" hash="ec939add6f7d0424029b12106385afd0"/><file name="Phrase.php" hash="424cc7d460f4bac0907d0170b60ba625"/><dir name="Preprocessing"><file name="Fuzzy.php" hash="cae1047630f98baf520483fa68af463a"/><file name="Phrase.php" hash="d8afc95f2e9da2a44d9495cbce775c98"/><file name="Term.php" hash="b099d749d723fbb53d3991e3f61458be"/></dir><file name="Preprocessing.php" hash="83dba0878c9ed171628b7a9ac70d26b3"/><file name="Range.php" hash="d8bda3ad418d24e0db7e59c446be13fc"/><file name="Term.php" hash="54e883c87d7368fa5be1e105723db357"/><file name="Wildcard.php" hash="9c1c8ebeca45a6332ede6fab8d5bee54"/></dir><file name="Query.php" hash="2a9f2ceda3cfacd24f892dd8bccd8d28"/><dir name="QueryEntry"><file name="Phrase.php" hash="407da910b0015ff8d95432cc193d608a"/><file name="Subquery.php" hash="a33d941498f632d859bec94a1cb9c10b"/><file name="Term.php" hash="808b02c1c1aeae4316fee3c9c466facf"/></dir><file name="QueryEntry.php" hash="9620d76904656a0727091f449603c662"/><file name="QueryHit.php" hash="6d1727ed01abc54503badc7176955882"/><file name="QueryLexer.php" hash="57a592ea29129b28d1144063e152c878"/><file name="QueryParser.php" hash="569f6439976128dbc471bd42fa9511d9"/><file name="QueryParserContext.php" hash="45c71a353821fc29101c1ae2f8eba02a"/><file name="QueryParserException.php" hash="358f89eaca92ac3175b26c419b317640"/><file name="QueryToken.php" hash="f85c3ac0ab04b5abff04d034cf127f43"/><dir name="Similarity"><file name="Default.php" hash="43f6f75cb50b7c7f344a5bac85ef172a"/></dir><file name="Similarity.php" hash="194c9c6c1c2815a8491952ece299ef9e"/><dir name="Weight"><file name="Boolean.php" hash="537c06e5f44c3d014d98a88a39c834f3"/><file name="Empty.php" hash="0bfe83149630af587846c7d5df63e72b"/><file name="MultiTerm.php" hash="c95f65634ed9d8c2896f5ba66a833f10"/><file name="Phrase.php" hash="51bc4912b1784bfa58841e4bf14fb177"/><file name="Term.php" hash="2e0f6fc3511928f1e94349d375dec8b8"/></dir><file name="Weight.php" hash="49ece1259ec183d66d2a1ccc8c319299"/></dir><dir name="Storage"><dir name="Directory"><file name="Filesystem.php" hash="7928063a85bf3c53e2afd754c111cc6b"/></dir><file name="Directory.php" hash="25a0d0c262a3c4fa7dbc3f1f11f0a4ab"/><dir name="File"><file name="Filesystem.php" hash="5c2819323a9878475d31eba6992e6abd"/><file name="Memory.php" hash="89bce18491ebcd885736c5c9a790eab6"/></dir><file name="File.php" hash="2b77f8354d79c7dd57330677651f8fc6"/></dir><file name="TermStreamsPriorityQueue.php" hash="a26104e3325d2533afffdfc66dd1ead0"/></dir><file name="Lucene.php" hash="fe6103d1d763df12d670dfe5103defb7"/></dir><dir name="Serializer"><dir name="Adapter"><file name="AdapterAbstract.php" hash="8bd5c797ff2230e804b916545a67694b"/><file name="AdapterInterface.php" hash="cb397638959459eef297b8114ebb0504"/><file name="Amf0.php" hash="734f3143371bffe28f65e144f1d4fde3"/><file name="Amf3.php" hash="05a939a59cad0622a7627572f931e909"/><file name="Igbinary.php" hash="dc0da7256a83c6f0a06582b21b160156"/><file name="Json.php" hash="e62019ed95f69a184f735f1d3d4d32c0"/><file name="PhpCode.php" hash="731fc343849f966c1b532284822060a6"/><file name="PhpSerialize.php" hash="d7bc5453b1c516a6895e62fee2f94ec7"/><file name="PythonPickle.php" hash="8eaa4d904fa3ac33cc3d405f6eeb92bf"/><file name="Wddx.php" hash="4321621736a7d3940a27357608c66c28"/></dir><file name="Exception.php" hash="dd736f6d29e3a1f8d688bdf6b24f8d30"/></dir><file name="Serializer.php" hash="47d6232a605b0fc1b0dfd5bc6738d4a4"/><dir name="Server"><file name="Abstract.php" hash="878b796b9b09bac46361e73e3b76943d"/><file name="Cache.php" hash="8851d8d1c35c11be49192fc875141632"/><file name="Definition.php" hash="c37f863e7395e761f9601a4f918f0fc9"/><file name="Exception.php" hash="1ad53d7cdaadfe1377fe30f61814ce33"/><file name="Interface.php" hash="ef219942e75a7dd72f757ae0fee1fe94"/><dir name="Method"><file name="Callback.php" hash="204c77c05f77dab719f7e8d4d9940990"/><file name="Definition.php" hash="6a7435cbdd3791b656f0f7945e68e724"/><file name="Parameter.php" hash="5bb143b2c5472570019deb5c8df7e13e"/><file name="Prototype.php" hash="e6926328f51c97152380eef1cb9503a1"/></dir><dir name="Reflection"><file name="Class.php" hash="7c3040f1cdaa12303fa3aa8a87bbee33"/><file name="Exception.php" hash="81a1918244112e6992e608c37a128f81"/><dir name="Function"><file name="Abstract.php" hash="baf97034eb2f6541a0b04448cdb0c8ee"/></dir><file name="Function.php" hash="b931e2381290e01a62197a41f7d4a43e"/><file name="Method.php" hash="2589efa5b95e88475509c07460869c1a"/><file name="Node.php" hash="a764c4cdbcfd48911882e73801f55c9f"/><file name="Parameter.php" hash="2cb12fe3fdca85cb9056909277002912"/><file name="Prototype.php" hash="c8f4e9fc01efed6ef3b5a10bab70ddc5"/><file name="ReturnValue.php" hash="bd7392e46dac77ad14597e24fbe9297a"/></dir><file name="Reflection.php" hash="7b01bebd0c5e02694d94946a7ff4cd2a"/></dir><dir name="Service"><file name="Abstract.php" hash="057d0faabba16e34faa0ed6d43ca61af"/><file name="Akismet.php" hash="c63f5c6b7b1be4b2bbedb84a7f026bf7"/><dir name="Amazon"><file name="Abstract.php" hash="16b70230ca4bf9fd43feaedc24416f7c"/><file name="Accessories.php" hash="c0f666b47ccd5ca407ca7ab3e62a28cd"/><dir name="Authentication"><file name="Exception.php" hash="f1ba0e03f16bf019c0246384f6797093"/><file name="S3.php" hash="35c859c9bf7221844df79260142e3e55"/><file name="V1.php" hash="a4f6e5db52a4ae4b8200ac26b1bc413b"/><file name="V2.php" hash="b91365a27a1019d793f3821d50cf0209"/></dir><file name="Authentication.php" hash="5e503da9b9bf0a83fd61326aabaa7bc2"/><file name="CustomerReview.php" hash="970806dbbd0244f317183a7d121dd23b"/><dir name="Ec2"><file name="Abstract.php" hash="add0a48733a5b51010fab03133fcf8a9"/><file name="Availabilityzones.php" hash="0df01ed765ce15c35a783a66d7f8ff44"/><file name="CloudWatch.php" hash="e601ca48308ac50dc3727f992f7e62dd"/><file name="Ebs.php" hash="1f82b128c7b5d35d37b3024b6c42f712"/><file name="Elasticip.php" hash="bfad9fcffa9bcd6ad7d7cff8cec45c64"/><file name="Exception.php" hash="b212f735d14f127feb9a33d220bf2261"/><file name="Image.php" hash="335cf797d7a3a3d49e029ef7ce991bca"/><dir name="Instance"><file name="Reserved.php" hash="6027f89632821d100f27363ffbf293f3"/><file name="Windows.php" hash="f823795a24808167f1b87d91ece5cd1a"/></dir><file name="Instance.php" hash="52e9fb6d557898648a7dd9c71bb9100a"/><file name="Keypair.php" hash="e035010eee1a949d1d2b5b1ddd43e5a6"/><file name="Region.php" hash="7283cb6f54f68c09949e4c0535ed8a3b"/><file name="Response.php" hash="ad34c2acb59516d6075d12294fcf6bd3"/><file name="Securitygroups.php" hash="68c70053d0e4284169a5e2c49cb2ef2e"/></dir><file name="Ec2.php" hash="4a39d1eb801af3fd096582c2428e1371"/><file name="EditorialReview.php" hash="edc54626cf681ff42bdbc3207063e50a"/><file name="Exception.php" hash="25e8e93c6e940a70c57e0d4b6b35271c"/><file name="Image.php" hash="8cb0ff1afc2b9f99b7e4db1c61c27e99"/><file name="Item.php" hash="49164d984e1888291b9a1b0b82df2204"/><file name="ListmaniaList.php" hash="d319a0d6c264c92c22196d6a9a84762e"/><file name="Offer.php" hash="a04c4d2faf859a590fe2e74ef0440429"/><file name="OfferSet.php" hash="cce61ade0766251d602204b65ad5f73e"/><file name="Query.php" hash="a8a6c152fa729f7047f352552bee7367"/><file name="ResultSet.php" hash="b15520c352dfb95481aa26509c84211e"/><dir name="S3"><file name="Exception.php" hash="2fa452933db70802a191be880cec481b"/><file name="Stream.php" hash="62544ad7a8d493023c4a62272a68d4f5"/></dir><file name="S3.php" hash="224a86bfc54f7c6df36b8d5eb3febbd0"/><file name="SimilarProduct.php" hash="abcd839cfcc6c194e0b2ee0461216e12"/><dir name="SimpleDb"><file name="Attribute.php" hash="329401b2dac2ad11141f5077093ce70a"/><file name="Exception.php" hash="72cd6853d02b6c4335292d38f310ea54"/><file name="Page.php" hash="4c6b5dda8a61a932584eaf332ba25ae4"/><file name="Response.php" hash="763d18b153c7296ae4a1acc9dd52fea6"/></dir><file name="SimpleDb.php" hash="26a2419a5c73550f8ef47ac2a7c161ce"/><dir name="Sqs"><file name="Exception.php" hash="4d8c014ecb492938b3234fb250dcc21b"/></dir><file name="Sqs.php" hash="e5a368178455cc62f0c1e6272876e31f"/></dir><file name="Amazon.php" hash="8bf9c8bd3d16372566cc6dda58d26f57"/><file name="Audioscrobbler.php" hash="0931bdaeda5594a4b367fd4901b5444e"/><dir name="Console"><dir name="Command"><dir name="ParameterSource"><file name="Argv.php" hash="6acc204436c9d0de0d1e5d2063dff1d3"/><file name="ConfigFile.php" hash="0ac0fcf2907eed649d9f720d9c98cfb1"/><file name="Env.php" hash="83579d583b977fb4a890933d5795588f"/><file name="ParameterSourceInterface.php" hash="c1161355277be3eefdadb4853d8ee1b2"/><file name="Prompt.php" hash="8a9b67aa3eaa61b7ff33aa0110b129fd"/><file name="StdIn.php" hash="fd5c89a584ce532ae64ce2e607e28e02"/></dir></dir><file name="Command.php" hash="c94204e49bc285a615c281253cb41641"/><file name="Exception.php" hash="e1a199ba28f3255efc3ad5f0c272d247"/></dir><dir name="Delicious"><file name="Exception.php" hash="8b4644f2ad354c3e8c668bf6f4d8757c"/><file name="Post.php" hash="00f3ca873d1da362fe1ed121b1d18c32"/><file name="PostList.php" hash="41dbf9ff7c15a8eaec5153cebc705bb2"/><file name="SimplePost.php" hash="9ae5bac1252734db8bda2c2cbceb901c"/></dir><file name="Delicious.php" hash="2f725816f82a4ba6ebeace7bcaf6e0ff"/><dir name="Ebay"><file name="Abstract.php" hash="2e334688b614c983b6a7ce3592e08899"/><file name="Exception.php" hash="83aa9409ac7d1e2bf9fd83e86c39a6c6"/><dir name="Finding"><file name="Abstract.php" hash="7238678f990b585b50271ceafe5058f3"/><dir name="Aspect"><dir name="Histogram"><file name="Container.php" hash="45aab272db8949fc7ef41c1f5b9a5d65"/><dir name="Value"><file name="Set.php" hash="6a00192243d8ab215f368459e932d145"/></dir><file name="Value.php" hash="ffd36e8de497a77bd42cccb63ce3235b"/></dir><file name="Set.php" hash="c39339e0e65827c882eac9fa8d4d4fff"/></dir><file name="Aspect.php" hash="df96cb57c1c2b88a8244384894f1b9dc"/><dir name="Category"><dir name="Histogram"><file name="Container.php" hash="e99d9fdf2028e7f627fa7692d6e5e5af"/><file name="Set.php" hash="d10aeaf449c591a7884a38a1b5f90399"/></dir><file name="Histogram.php" hash="5fda3e21a2a68bbca36838425d54c454"/></dir><file name="Category.php" hash="aef46c1abec0621af48a4398de94bca0"/><dir name="Error"><dir name="Data"><file name="Set.php" hash="51d6f2c75eb549150dbb4255a747e238"/></dir><file name="Data.php" hash="06579aec01d55e0e27e48b66b32814a5"/><file name="Message.php" hash="f0082bf2e41b9fa997891d55536d6c94"/></dir><file name="Exception.php" hash="0d04308f626b6d80255403034766b93f"/><file name="ListingInfo.php" hash="37689bb7f7f1312e0a8690b1ec55d17f"/><file name="PaginationOutput.php" hash="dbd144ea4155492ca485092140ed7342"/><dir name="Response"><file name="Abstract.php" hash="13c8ef07cd6c8b9e0b54b183099d3c2d"/><file name="Histograms.php" hash="7e67ea07bdf9e34cb277b87cdad8db8c"/><file name="Items.php" hash="87e78262a0463b3689f75ade1a97bf0d"/><file name="Keywords.php" hash="501b1eb2db688abcb8926a924b2467c4"/></dir><dir name="Search"><dir name="Item"><file name="Set.php" hash="72dc95aa03723a96c6ad4e16bb6c1f04"/></dir><file name="Item.php" hash="8cc709c5b81a662e1b42f6fdcfbcd057"/><file name="Result.php" hash="bde45f1eff1c6745093e1fb16a25fa21"/></dir><file name="SellerInfo.php" hash="0a3e7e31682c1b4139860b692e3a7a93"/><file name="SellingStatus.php" hash="40cc9f7feb5534c9b7ffd77cde164d8e"/><dir name="Set"><file name="Abstract.php" hash="d68b570966c8c13d07ecc8e1c093a3f8"/></dir><file name="ShippingInfo.php" hash="ef20bffb5c3917bd631a79f6520aaa47"/><file name="Storefront.php" hash="59e0796869417ef09b2fabf17a0f51a2"/></dir><file name="Finding.php" hash="38297aa7141bd29cb58f499a6f301958"/></dir><file name="Exception.php" hash="065ed88e73a47544f5432781b553b095"/><dir name="Flickr"><file name="Image.php" hash="c18c420085a325a88aa32c6e8940febe"/><file name="Result.php" hash="3dae64d1fed5642f400e5a3ed34001e0"/><file name="ResultSet.php" hash="1141813d476af74ac4482982352df257"/></dir><file name="Flickr.php" hash="80ee3a6a56f644931629923efaa74f58"/><dir name="LiveDocx"><file name="Exception.php" hash="b7c0f8f23822ab34863ae7c8ba65fca0"/><file name="MailMerge.php" hash="9c3df9f5097d2426f98f3e4afd5417b2"/></dir><file name="LiveDocx.php" hash="bb79b5d68e67e91aa7c6678cf9d33fe5"/><dir name="Rackspace"><file name="Abstract.php" hash="38c670e3ba06278b4fed19a7a20ffa09"/><file name="Exception.php" hash="0e02a57f8eb16972b101ec5b2d5ee5c8"/><dir name="Files"><file name="Container.php" hash="59b5965b06c12c8f32f191d6d81578ed"/><file name="ContainerList.php" hash="60cab750d4475f791b0f6ef9487b2b5f"/><file name="Exception.php" hash="ff4c1a6d5b3c15b0134eea798aaebb5a"/><file name="Object.php" hash="fa7d117f207e2a26dfa5db744a098cdf"/><file name="ObjectList.php" hash="d2eaf4ebe570b3ca456844b294cfc6f6"/></dir><file name="Files.php" hash="fba4bd666821a5eec5cf17f5f91dd15a"/><dir name="Servers"><file name="Exception.php" hash="90e7248491ba6728731b35821a6797b3"/><file name="Image.php" hash="6977cee9fc642f32c2a3dd9b99739ab6"/><file name="ImageList.php" hash="0bc789d18d41f62ae1db82159487edc0"/><file name="Server.php" hash="73f6c2a5e062bf36b3b89ed8d1041eaf"/><file name="ServerList.php" hash="f76bf22857872982ce35e7afa2ea49f1"/><file name="SharedIpGroup.php" hash="75bc0d1b089228114a5bdbbc764f6799"/><file name="SharedIpGroupList.php" hash="97feec662c70d87bf02c0dd689d59962"/></dir><file name="Servers.php" hash="d7c9cd6f524ef033e9c4836623171ad4"/></dir><dir name="ReCaptcha"><file name="Exception.php" hash="e49c53a3c431f49911028b571a76bc06"/><dir name="MailHide"><file name="Exception.php" hash="fc56e06dc9697c40498f1015c0e76c08"/></dir><file name="MailHide.php" hash="ff143c31b0aaac1c852ae438ccc57a4a"/><file name="Response.php" hash="10d73062279da9040e445fe8d1820c36"/></dir><file name="ReCaptcha.php" hash="518a917f321d64422010babcdc82921a"/><dir name="ShortUrl"><file name="AbstractShortener.php" hash="7e0fa90e0324b377677bd8847412ffa5"/><file name="BitLy.php" hash="3e07fa8e265d44e7225af2f11ac75607"/><file name="Exception.php" hash="fa58bd8ee297581ecafe8e15d9c41858"/><file name="IsGd.php" hash="5d18b0c134f1da253893391c720144e7"/><file name="JdemCz.php" hash="6892d0e3e81cc3aeca234d4fb5164ac5"/><file name="MetamarkNet.php" hash="747c5d10917401f1d0d11ba38b1af8e2"/><file name="Shortener.php" hash="64e2ceca93f66c375605e62d6431a628"/><file name="TinyUrlCom.php" hash="1b7f09510d1b029c117e6c59c5419714"/></dir><dir name="SlideShare"><file name="Exception.php" hash="67b547c02b4b9c9440f5c11e570171f1"/><file name="SlideShow.php" hash="9d01060ec6c7a7583a21c824a3e74e21"/></dir><file name="SlideShare.php" hash="1cdc74e57a3be59df8d702bc3d9f7362"/><dir name="SqlAzure"><file name="Exception.php" hash="24d9e2d3dfca7d6ce54137652027152c"/><dir name="Management"><file name="Client.php" hash="e46b9564db9ae2344357919b4760ac4f"/><file name="Exception.php" hash="731e875bfd4df360b37ca082877bc1c6"/><file name="FirewallRuleInstance.php" hash="f564f5454ee9cb2b1ffa97499124d0e7"/><file name="ServerInstance.php" hash="7f3198f120d54ca4b70b5f58399cf0ab"/><file name="ServiceEntityAbstract.php" hash="72ca3fc5ef5341bf549685beb08dad5f"/></dir></dir><dir name="StrikeIron"><file name="Base.php" hash="0b1451704136ab44598ac7204bde94a1"/><file name="Decorator.php" hash="68741c986d506462846a6aa007f94cef"/><file name="Exception.php" hash="e61ee74d3ae19b3e61c1894264d6530a"/><file name="SalesUseTaxBasic.php" hash="43823d20d58aaf73be598f5282e7f841"/><file name="USAddressVerification.php" hash="f5dd585a282a046ebfb95125c29ed866"/><file name="ZipCodeInfo.php" hash="76beb6125d1035ffd7e67101cbd9df44"/></dir><file name="StrikeIron.php" hash="7eca35cee7479ac035ec83f456ddb2ec"/><dir name="Twitter"><file name="Exception.php" hash="d5a3fb65437ac5663d5262b19c226483"/><file name="Response.php" hash="f78d457745cd7df85d83b33e9b43a01f"/></dir><file name="Twitter.php" hash="8b3dc7c575b35c1351a9a00afd1b57c5"/><dir name="WindowsAzure"><dir name="CommandLine"><file name="Certificate.php" hash="82f6c9535209f9d9800b1ec5227ea5a8"/><file name="Deployment.php" hash="d77fb324a62e1d5bbec2ce07dbcd6051"/><file name="GetAsynchronousOperation.php" hash="da2b5c820d693a4fdcdc5f53378a317c"/><file name="Package.php" hash="4ed8d218b529fa358b9bad365caeda1c"/><dir name="PackageScaffolder"><file name="PackageScaffolderAbstract.php" hash="077b5928c2f1ff061f447754e17051c9"/></dir><dir name="Scaffolders"><dir name="DefaultScaffolder"><file name="build.bat" hash="651c7fb8b72233f40f4f25ca8905573b"/><file name="index.php" hash="894c44229a940ea713205338f8e490f7"/><dir name="resources"><dir name="PhpOnAzure.Web"><file name="Web.config" hash="65f639e413e4ff122d92623a1c14b2ae"/><dir name="bin"><file name="add-environment-variables.cmd" hash="b0e00d591398ec40968189bc4e35c139"/><file name="add-environment-variables.ps1" hash="19a5afae543fd10d118ad21136fc4bec"/><file name="install-php.cmd" hash="8248bad7c6981ab8f8ad34cbb6e224c3"/></dir><file name="diagnostics.wadcfg" hash="5188e0200f5446cae89c1be78db568c2"/><dir name="resources"><dir name="WebPICmdLine"><file name="Microsoft.Web.Deployment.dll" hash="ce4bedba97839fb3b3991c9e76d9a5f8"/><file name="Microsoft.Web.PlatformInstaller.UI.dll" hash="c692c64ac1ff35a256b05b3d0389d77a"/><file name="Microsoft.Web.PlatformInstaller.dll" hash="b3c7917c493dc73aab9ad4f3b32d3722"/><file name="WebpiCmdLine.exe" hash="23ee0847ce84831042e2094f8bb946a7"/><file name="license.rtf" hash="e19c7c8161a0d2cf8cd2bfa815edd707"/></dir></dir></dir><file name="ServiceConfiguration.cscfg" hash="aef39d43590593be9d2fe5fe4a3b5c80"/><file name="ServiceDefinition.csdef" hash="cc148db5e38df6777513c343f0552408"/></dir></dir><file name="DefaultScaffolder.phar" hash="7213da0e7d624e8c2a4ba1f3b5ff05eb"/></dir><file name="Service.php" hash="ff88b79b64947f883986e77838d8cb24"/><file name="Storage.php" hash="8944ded3eb414aa4826b6f53040049d9"/></dir><dir name="Credentials"><file name="CredentialsAbstract.php" hash="d4f022ee969ebb28059bb4fe1dc15bbd"/><file name="Exception.php" hash="46253077f849f4d86ff19bcd5c4ffbb2"/><file name="SharedAccessSignature.php" hash="b812dfc04bcc4349faa4b684e3c17ffe"/><file name="SharedKey.php" hash="d09970fb25d6649fc3626d016e57a71a"/><file name="SharedKeyLite.php" hash="a7af3a465e3b62edddd79fcfb8b5bfd0"/></dir><dir name="Diagnostics"><file name="ConfigurationDataSources.php" hash="164e443f79bf6b018796cbe4ace8552e"/><file name="ConfigurationDiagnosticInfrastructureLogs.php" hash="5ed3b44951c19fe3899d77e57777ccca"/><file name="ConfigurationDirectories.php" hash="ac9628ef7d6d5291b4a9755ffa83c4bc"/><file name="ConfigurationInstance.php" hash="2ffcb3db9f9ecfe5764d497f08175c1c"/><file name="ConfigurationLogs.php" hash="79cb3324521884a79c422318e9df0996"/><file name="ConfigurationObjectBaseAbstract.php" hash="574ad31edf5de775857d4d9818e09515"/><file name="ConfigurationPerformanceCounters.php" hash="f518fc30a51d61ee73f44fd54304d115"/><file name="ConfigurationWindowsEventLog.php" hash="7b071634e38e532d5faf245310846396"/><file name="DirectoryConfigurationSubscription.php" hash="5c72f815ecb4a4b619a43b05e0767d3e"/><file name="Exception.php" hash="ecc6ffb64bcd2b7e219b9e57ae8261c4"/><file name="LogLevel.php" hash="b63f1b837619bd6475f30b5c2862354b"/><file name="Manager.php" hash="0d92a4ee3426b0a3fa98efabad20850e"/><file name="PerformanceCounterSubscription.php" hash="f3793033b70429e761b5715d26a9b052"/></dir><file name="Exception.php" hash="ae2961639357d61fd0edbb1f8b19e600"/><dir name="Log"><file name="Exception.php" hash="f293efa4c7d400034fdd32b61e398d75"/><dir name="Formatter"><file name="WindowsAzure.php" hash="d2803e471ad8f151337b9b06adf840e2"/></dir><dir name="Writer"><file name="WindowsAzure.php" hash="898cc3aab9ed4a1143ad98af4c82828f"/></dir></dir><dir name="Management"><file name="AffinityGroupInstance.php" hash="999fccb597ded5e9bb1a3a49d0461238"/><file name="CertificateInstance.php" hash="e38186727c337efeb26e1edb3395c3aa"/><file name="Client.php" hash="7ea9a8aeec1b66c29127ce846788caeb"/><file name="DeploymentInstance.php" hash="da71eb3b750c5accba7df6a02a936572"/><file name="Exception.php" hash="e38e9729e738a5c98b7a444377dc390f"/><file name="HostedServiceInstance.php" hash="52a7a4f5e90fcddbba2da67f6ec1a714"/><file name="LocationInstance.php" hash="d7fc5f02f835fbea9bd39e25a2953415"/><file name="OperatingSystemFamilyInstance.php" hash="5463dc6555a2894cf77c15dd015b2bbe"/><file name="OperatingSystemInstance.php" hash="8d8fc32400bbb73a3765f06ccaefc05f"/><file name="OperationStatusInstance.php" hash="acb817c0203ca17237b430c7d086b7b3"/><file name="ServiceEntityAbstract.php" hash="6013b8d4f6378d945e29013d54dc634f"/><file name="StorageServiceInstance.php" hash="6d89ea4e90ac780fce17efba7e38976a"/><file name="SubscriptionOperationInstance.php" hash="9fb50cd722cc80be2d660e78cd42d3de"/></dir><dir name="RetryPolicy"><file name="Exception.php" hash="b83b70d8c828de010cfa12f027a2da23"/><file name="NoRetry.php" hash="faa7ed56468ce39f77162aa1888f8480"/><file name="RetryN.php" hash="340d6ccaa8d41eba0f3cd943dbff201b"/><file name="RetryPolicyAbstract.php" hash="57b861c1f66f83295ce1ae8284b6870c"/></dir><file name="SessionHandler.php" hash="49abc2db2f8cd60249889013eeb6c28f"/><dir name="Storage"><file name="Batch.php" hash="54321d9853919241064631b7fd5e404a"/><file name="BatchStorageAbstract.php" hash="1911d06beacc5afdee2e0214fadb48f7"/><dir name="Blob"><file name="Stream.php" hash="fca729afd6bced397324a092598c4348"/></dir><file name="Blob.php" hash="ba54d4c7b42bfb8536df0ace27d68ac5"/><file name="BlobContainer.php" hash="3762000f605bc3b601d33508d11ba9cb"/><file name="BlobInstance.php" hash="3acc55cc558e3003164dde92463f0f74"/><file name="DynamicTableEntity.php" hash="c0f1e5b79b12857c233299a4445bb168"/><file name="LeaseInstance.php" hash="3d0fc9b5d6808aec75d9aa5bfb537e3d"/><file name="PageRegionInstance.php" hash="ad3d6fda6950c0f1fa6516507ca9662b"/><file name="Queue.php" hash="e0f744f5a2c30c4368babc77282987d1"/><file name="QueueInstance.php" hash="fc1d2fe33c92b9709174fdb78b014839"/><file name="QueueMessage.php" hash="1743f7a02f0d443c7a2f85d87dc43e0f"/><file name="SignedIdentifier.php" hash="cd0fa8a05e3acd402a1e337b1ca7eee0"/><file name="StorageEntityAbstract.php" hash="f3ef81a6dbd64aea38bc60b1f0c7bb8b"/><file name="Table.php" hash="3264067c6ef982f7bb216234451f5781"/><file name="TableEntity.php" hash="c9be1c41776a2ae5892d8f8d14b74fd6"/><file name="TableEntityQuery.php" hash="13880ce0f4c805205dcd10a5283c0539"/><file name="TableInstance.php" hash="54f43c27f93bee83a2c9ba42831d9c27"/></dir><file name="Storage.php" hash="cbac5a9bb9efb6e93a3d9871c8699035"/></dir><dir name="Yahoo"><file name="Image.php" hash="aa6abfa0f447d43f4828dc44c0fdf86f"/><file name="ImageResult.php" hash="7a64eac529ce21090e8b58997fc22041"/><file name="ImageResultSet.php" hash="7ad19487bce9a09855cf7d79707af347"/><file name="InlinkDataResult.php" hash="28305ce865dfb4011a285015a40a6a83"/><file name="InlinkDataResultSet.php" hash="fb09080f12f5348b37fdd5d62fc946fc"/><file name="LocalResult.php" hash="306431d361c2097b3b00cdbaba1bb372"/><file name="LocalResultSet.php" hash="68a4cb69982884c1bd7d6a7df86be90b"/><file name="NewsResult.php" hash="ea496bdeee3021d391df58a3be8636af"/><file name="NewsResultSet.php" hash="f80bcd0b1ac7632f3fb3020a7ff83255"/><file name="PageDataResult.php" hash="c8ea663819efe5ec5d374463f04a8f39"/><file name="PageDataResultSet.php" hash="69c99f8806a98868cb77e9db268eb8d8"/><file name="Result.php" hash="221286f5fbe491b570df8cec1fb7c91c"/><file name="ResultSet.php" hash="4477af82dcaac7fcd93ce9c29c68bdd5"/><file name="VideoResult.php" hash="6ba0d1ebb1c288b11b17ff6a9e434a4d"/><file name="VideoResultSet.php" hash="1a434e1b8bcf9b32e755a32e97e52838"/><file name="WebResult.php" hash="eacd11e6aace9570c6064c8fc1b47750"/><file name="WebResultSet.php" hash="bf5f6f43eb71f0469c961b0f5a6e4094"/></dir><file name="Yahoo.php" hash="27616706be89313b7b5be256be21e095"/></dir><dir name="Session"><file name="Abstract.php" hash="b43880e48ff9ee3040eca09d1458f7d5"/><file name="Exception.php" hash="ce01f1ceaa96bef8c71759f7e6c1e578"/><file name="Namespace.php" hash="b3e6effe8f53d5f9f407a4b5507df31c"/><dir name="SaveHandler"><file name="DbTable.php" hash="5b08339aa3e7f044b5602e725e6c65c0"/><file name="Exception.php" hash="06db90dee9421e4a8e09b946de252d41"/><file name="Interface.php" hash="617704bf38e31d51b79c636480447b91"/></dir><dir name="Validator"><file name="Abstract.php" hash="7bc8436592d308a702f37d64a8afbe72"/><file name="Exception.php" hash="c00d9dfbc04a9250f2359a5f31e726b8"/><file name="HttpUserAgent.php" hash="6a2a83e6baf37967b06cf993170ed03e"/><file name="Interface.php" hash="6e54358cefb41ccb7e591eaba391f74e"/></dir></dir><file name="Session.php" hash="da8c2bc8217bb09a7e86c573fa7a6553"/><dir name="Soap"><dir name="AutoDiscover"><file name="Exception.php" hash="3c71353889e5488f16cd0747a1337882"/></dir><file name="AutoDiscover.php" hash="abdfc4afb277a6e0c23216cb1d894dd1"/><dir name="Client"><file name="Common.php" hash="4c196fc850f65702741c044d12507769"/><file name="DotNet.php" hash="61bacfc1a99fabb15c58d5499c064c72"/><file name="Exception.php" hash="fe48793a358a7201ad7faee3a077a7db"/><file name="Local.php" hash="843caaab790dc3a322e570cae31dfda7"/></dir><file name="Client.php" hash="bb395c77d4e6ca127f48e15953c72f90"/><dir name="Server"><file name="Exception.php" hash="b5366c6128550c6904b5f0d83d9a4495"/><file name="Proxy.php" hash="4e3e39bf6b40e758bb8154900c0be4ae"/></dir><file name="Server.php" hash="2d3adb7e3b01a55889f4a9ccd1226758"/><dir name="Wsdl"><file name="Exception.php" hash="c30308763d2f85ccde3e48c399d977fa"/><dir name="Strategy"><file name="Abstract.php" hash="f09e005c0c35a51dbc906815f298a515"/><file name="AnyType.php" hash="7e0f81e8c1bde45bd858ae5c16b4cd11"/><file name="ArrayOfTypeComplex.php" hash="3b9998427588b55e16496ee51a1d7d5d"/><file name="ArrayOfTypeSequence.php" hash="8ea1226e6138e1d162b647b39daed36d"/><file name="Composite.php" hash="7ea40da650826369c79e7a17ff93da40"/><file name="DefaultComplexType.php" hash="9fefac807dbb4c843feec714a05ac521"/><file name="Interface.php" hash="d4f3ed1447d163ae1eedcfc886662719"/></dir></dir><file name="Wsdl.php" hash="8e4ad5d4d160d770740012ec920e30de"/></dir><dir name="Stdlib"><file name="CallbackHandler.php" hash="f33bb03784021305a529525bf125df09"/><dir name="Exception"><file name="InvalidCallbackException.php" hash="977bd070fc4de8c0bce940a2d0a0c530"/></dir><file name="Exception.php" hash="826ef583632fe8b71ce0916ce4c01030"/><file name="PriorityQueue.php" hash="886161c12418c95bda548c5e484db351"/><file name="SplPriorityQueue.php" hash="4ce44425f16b61d5cfa2b37a36c430b9"/></dir><dir name="Tag"><dir name="Cloud"><dir name="Decorator"><file name="Cloud.php" hash="c03f8a8a9acad9b124508cb5ec762ef6"/><file name="Exception.php" hash="da2286643dd90128c9bafdb55d4874d9"/><file name="HtmlCloud.php" hash="ac29df72f5738876b6c5c3220200aea5"/><file name="HtmlTag.php" hash="1c66e72d27e394b7a67e083a6a7e7635"/><file name="Tag.php" hash="38969d4df8dd12f7c75d5886a4309e2d"/></dir><file name="Exception.php" hash="f1f89e1176804f89966ffa1b6057aadc"/></dir><file name="Cloud.php" hash="b563d184a10c5780ac839964d05f5b70"/><file name="Exception.php" hash="bb95c48a0889e48b9621fc24ece1855d"/><file name="Item.php" hash="4d8899476ff7c0edc26227377437184a"/><file name="ItemList.php" hash="a37b92d4346128d6928c3ed75abe85e3"/><file name="Taggable.php" hash="754d26825a791b7b493479ab96de35ac"/></dir><dir name="Test"><file name="DbAdapter.php" hash="9f14c0c71238db11ce231ec608fa0748"/><file name="DbStatement.php" hash="ae071a2e217641e4431dbaffab4b475c"/><dir name="PHPUnit"><dir name="Constraint"><file name="DomQuery.php" hash="4a372f65097fddc842326acfb0873110"/><file name="DomQuery34.php" hash="4cfc2fccf97dcad8979afdeb5051d99d"/><file name="DomQuery37.php" hash="4918ef15cdbf82e30ee35bce62246f6a"/><file name="DomQuery41.php" hash="0e55e6f6ec4df95712cf6ae2592eaa4d"/><file name="Exception.php" hash="08a569be3229aa317e045e0bb5712aee"/><file name="Redirect.php" hash="bd29ebef3a5193019124cbe48e3b57a4"/><file name="Redirect34.php" hash="7fbaaf229a5e72fd9328b6b3355979e0"/><file name="Redirect37.php" hash="25ae9936724abf4f6c655e79a4b017a7"/><file name="Redirect41.php" hash="b15f5d011531a5f341691400758b7b94"/><file name="ResponseHeader.php" hash="d0c824d1d0825eaff50fbff17ad9fe68"/><file name="ResponseHeader34.php" hash="970159fe86220f6d79ae839787445e76"/><file name="ResponseHeader37.php" hash="b45fcfbc270c1dc1be8af6f967d74055"/><file name="ResponseHeader41.php" hash="d898287c0e3c5c5a29c8dfc23258c357"/></dir><file name="ControllerTestCase.php" hash="a1587e2519d6a108213338a8df626983"/><file name="DatabaseTestCase.php" hash="e660d4e0b896a1349b5b3a7b908abed9"/><dir name="Db"><file name="Connection.php" hash="a376a28b4f32640b77896ed71aa94103"/><dir name="DataSet"><file name="DbRowset.php" hash="619ddf7996bdbae5efe2667bf43f97fd"/><file name="DbTable.php" hash="c2f9df7d0a3cf0d37631d8f06c818bc8"/><file name="DbTableDataSet.php" hash="d4399f69a07e07e1cdf51ee779ed4d25"/><file name="QueryDataSet.php" hash="9923dfa4b4f6ec969e05af835f0c9578"/><file name="QueryTable.php" hash="49db01b854018eed9f97f9e87dd8ef99"/></dir><file name="Exception.php" hash="b4db1bec052e5f4326e4f69f8265b1f6"/><dir name="Metadata"><file name="Generic.php" hash="0d50fe34d4d444504a433c495a10f4c7"/></dir><dir name="Operation"><file name="DeleteAll.php" hash="ad2d32c7274f19ffd7ff00f6a9629831"/><file name="Insert.php" hash="76990ebfd7da444a380ef153fd4ec2c7"/><file name="Truncate.php" hash="aeb7cea4a23f9a4978838834184b827c"/></dir><file name="SimpleTester.php" hash="303a002e44573654515318426f06454c"/></dir></dir></dir><dir name="Text"><file name="Exception.php" hash="63dc12adf35209b68cb541fad9d13339"/><dir name="Figlet"><file name="Exception.php" hash="ce4743f212bc9dd406e7c5abd1499a8c"/><file name="zend-framework.flf" hash="e421545f78033d8a6a4324e54ccf0454"/></dir><file name="Figlet.php" hash="342b1851f3fddf6de881bfdcd6dbdc25"/><file name="MultiByte.php" hash="7beb126807547c59a29ff72918ce4cb6"/><dir name="Table"><file name="Column.php" hash="cb652d404e394051bb9463ef0f5e5fac"/><dir name="Decorator"><file name="Ascii.php" hash="642655dbd861110617fe242a5f5b2e49"/><file name="Interface.php" hash="b246cf5bf0cc2ccb3fd612987dda1ac6"/><file name="Unicode.php" hash="78c514875a100d295a884d52cbff6679"/></dir><file name="Exception.php" hash="a9ad309358591313a0b39a9dc6637ead"/><file name="Row.php" hash="2e1210709f13f36070015bf1e7c4bae8"/></dir><file name="Table.php" hash="fa040e017955cd19728968adc4d3263a"/></dir><dir name="TimeSync"><file name="Exception.php" hash="c5c88b4fa22c7aa853c99e80293d6b56"/><file name="Ntp.php" hash="670a72b056bc3ea5c6ca09fd51e5c0d1"/><file name="Protocol.php" hash="81ebccdcfad278c458e8f801743e8035"/><file name="Sntp.php" hash="f491dc0e0e4ad0a6909cc9518c443855"/></dir><file name="TimeSync.php" hash="e68ddd486d397ad8b8072df003f0dbe9"/><dir name="Tool"><dir name="Framework"><dir name="Action"><file name="Base.php" hash="ca10276b0b663e3946f30a7e85e2437a"/><file name="Exception.php" hash="033fe3dfcbe687a8fc14217124485646"/><file name="Interface.php" hash="4971f7cd01f81557e06c52442d1e10ec"/><file name="Repository.php" hash="763980637bc854efdabe4702cf90429a"/></dir><dir name="Client"><file name="Abstract.php" hash="c6aa9afeb508a90fac77fdd01490c917"/><file name="Config.php" hash="88d068ae943aaa028252208d2ffa9737"/><dir name="Console"><file name="ArgumentParser.php" hash="a7aca2e438a4ea02beea9efe4fc322e6"/><file name="HelpSystem.php" hash="c49dfb3e52bc4dbd0fb981d2d2db7ea0"/><file name="Manifest.php" hash="8ecaf5471c98b4adecf441fd0b239fd1"/><dir name="ResponseDecorator"><file name="AlignCenter.php" hash="aea5fb29315c501c879f1414ab30bdf1"/><file name="Blockize.php" hash="f6510cb7f02bdd000eff5b3cfc7c3f94"/><file name="Colorizer.php" hash="b4370450e0af8f8bc5b70bca3a3140e4"/><file name="Indention.php" hash="9d05c40f3bcf99606a4433c4f2f550c8"/></dir></dir><file name="Console.php" hash="70d696d68e6f889e25661568ae0cafef"/><file name="Exception.php" hash="9fc08df23e990977b31c58157458797f"/><dir name="Interactive"><file name="InputHandler.php" hash="d4a71d517cbdfca13bc442f915eadfa3"/><file name="InputInterface.php" hash="b76636ebb7563e128e1653de60a05e47"/><file name="InputRequest.php" hash="01746459e3c0d5114ba84376641ce516"/><file name="InputResponse.php" hash="fe6fb87211d75ac5d43a0afcd12b3438"/><file name="OutputInterface.php" hash="e6473dcec31887ba9fc189cf5ac4b5cb"/></dir><file name="Manifest.php" hash="a04f5f7452adbe2a7b9f572753c282e1"/><file name="Request.php" hash="337a50f6b8ca0346335666825a138400"/><dir name="Response"><dir name="ContentDecorator"><file name="Interface.php" hash="f5f2e4d82017c916a98e600c0ecf10fa"/><file name="Separator.php" hash="0bdedce341d3dc2456856bedb4e6fbfd"/></dir></dir><file name="Response.php" hash="047455ac32ab5c1f0913bd8be80408e2"/><dir name="Storage"><file name="AdapterInterface.php" hash="cbe1be24e10113b8355be82c17257d74"/><file name="Directory.php" hash="7f818fcabc4dd64292ec750d69a2cab2"/></dir><file name="Storage.php" hash="e1e34565e6f12ef7a6914bea4f21b495"/></dir><file name="Exception.php" hash="e8ab7ccbf5e2a5516a35ca4e887b1f5e"/><dir name="Loader"><file name="Abstract.php" hash="ac9b19649683e89c14f162643680d6d2"/><file name="BasicLoader.php" hash="eb441f57c872d051c8bf4ff334516776"/><dir name="IncludePathLoader"><file name="RecursiveFilterIterator.php" hash="e809fc3ffb30c42bd65defb0b841d5ea"/></dir><file name="IncludePathLoader.php" hash="ba1fdc0c41d1ac3ac9b86f7b295d62fe"/><file name="Interface.php" hash="5a982ccd517b7fa2c5d1e7a181f9a66d"/></dir><dir name="Manifest"><file name="ActionManifestable.php" hash="6b75a1363ec0989198f0577519f2a8d8"/><file name="ActionMetadata.php" hash="55c5c7fd4609c3a2c188c68f2b59996b"/><file name="Exception.php" hash="e4adb9a694c21dd46682009e1a25ba80"/><file name="Indexable.php" hash="f2fdb04e846a873a00178d44dfb7c134"/><file name="Interface.php" hash="65fb779fcdd624b743e1c70370ce1a2f"/><file name="Metadata.php" hash="79d13b52ad9aa5bffe103b61a404296e"/><file name="MetadataManifestable.php" hash="2974762fdea9eec82a74a6d3446f676a"/><file name="ProviderManifestable.php" hash="3d59e772c55a5a791844910d9acbb131"/><file name="ProviderMetadata.php" hash="b1fa45e3f1309e25c3e71e43e1a48263"/><file name="Repository.php" hash="b055ec6bcaa48d3536f376c7d196052b"/></dir><dir name="Metadata"><file name="Attributable.php" hash="3a1ae646ad3127bcd9d7f0b590b49d75"/><file name="Basic.php" hash="f8e243b4883d1f53ef6dd440c0d8b618"/><file name="Dynamic.php" hash="2ae310d375a9f1e29f0322c03350b718"/><file name="Interface.php" hash="dd418e0cfd979aa8caac73abbe8d65d7"/><file name="Tool.php" hash="d4cf6475ece71a871144a646c4653b88"/></dir><dir name="Provider"><file name="Abstract.php" hash="54efa5905a09985cfc5261116cdc808f"/><file name="DocblockManifestable.php" hash="0bb7be516c01ef1df2db65cac6782604"/><file name="Exception.php" hash="8340027bd3f883ce3bc60e5a4a779e1c"/><file name="Initializable.php" hash="21203810d42fc2c661b5a74a4db22afd"/><file name="Interactable.php" hash="1645bf6768d35a154b409e9fc8d23629"/><file name="Interface.php" hash="5acbcaa43439912bfc3f9be9aae48561"/><file name="Pretendable.php" hash="7320be8f080b47a7a3c7768ed5b82655"/><file name="Repository.php" hash="06ac616d5eca5d9769ad7d1d1a7ca9bc"/><file name="Signature.php" hash="5be099c081171cd11a6c5e6a80011f2c"/></dir><dir name="Registry"><file name="EnabledInterface.php" hash="87fe89d72c54ad50ec51bb2d683d2992"/><file name="Exception.php" hash="eccc229c4505a1ed3e85902496e1935e"/><file name="Interface.php" hash="85731cc24ee6598ac544956ba02a4847"/></dir><file name="Registry.php" hash="430ca6afc053d09a02faafa778f05ddc"/><dir name="System"><dir name="Action"><file name="Create.php" hash="ece59a9bf0b39f4c7731dd2c3c6a3687"/><file name="Delete.php" hash="93a02ef0a268f9a46140122e6b658831"/></dir><file name="Manifest.php" hash="2dc6db96a2eaec2f041f73eb9784426e"/><dir name="Provider"><file name="Config.php" hash="0f0ac44a62caaea96bdd741dc8d10fe1"/><file name="Manifest.php" hash="9834badd5250276130dd8f035fa3aa69"/><file name="Phpinfo.php" hash="a18c9de3ae3099a941d257fd8bb83286"/><file name="Version.php" hash="235916637c0ec94a08f86894dd211da4"/></dir></dir></dir><dir name="Project"><dir name="Context"><dir name="Content"><dir name="Engine"><file name="CodeGenerator.php" hash="28294bea1645211c3a55b04b03eb97e5"/><file name="Phtml.php" hash="b635fe45ef2a8b9de27be338ff80e0c8"/></dir><file name="Engine.php" hash="3edec5f50d35068768bd1ddb7cfcb242"/></dir><file name="Exception.php" hash="903019115f2291dac64e2d8316b069d0"/><dir name="Filesystem"><file name="Abstract.php" hash="7de036baa7d7a11fde54ba3d0d9e199c"/><file name="Directory.php" hash="346bbbf87ee7515d0b1ea6d468a23bbb"/><file name="File.php" hash="82a28fef9d3d33f3de763e2f4415ef66"/></dir><file name="Interface.php" hash="ec12cc9de36ab46a2afb96f61f3af90e"/><file name="Repository.php" hash="652c4bea315e3239fd99f22103c51140"/><dir name="System"><file name="Interface.php" hash="9011f3458a2b39fdf8867e639414a7bc"/><file name="NotOverwritable.php" hash="de0a563d5079199bf642b6811b7e5bac"/><file name="ProjectDirectory.php" hash="f5d33f4805cc35574112532f2f262579"/><file name="ProjectProfileFile.php" hash="48ff62386762440129ae4fb7337deb2f"/><file name="ProjectProvidersDirectory.php" hash="b5a9d7bba0ccd8554ca26f0149128acc"/><file name="TopLevelRestrictable.php" hash="2309be1ddaf737de9b7adafa6cb8632a"/></dir><dir name="Zf"><file name="AbstractClassFile.php" hash="22a8a9cc341edc796112df20983a43bc"/><file name="ActionMethod.php" hash="2f16d745e3a323f9ff416e2217358f54"/><file name="ApisDirectory.php" hash="0b39c81c051cc37f5492df965835eba1"/><file name="ApplicationConfigFile.php" hash="677abcc2fc67896b511af1f1181a8f81"/><file name="ApplicationDirectory.php" hash="42a08abbb3ecc267cd883a87f817981b"/><file name="BootstrapFile.php" hash="b76b4cf58705698399d06e8d4c9f6d67"/><file name="CacheDirectory.php" hash="5bb06a72dcd025a283c76c03a1ce9599"/><file name="ConfigFile.php" hash="2462d7d79f673c397d3a2f7284ccde66"/><file name="ConfigsDirectory.php" hash="b1cccd4669781cc33b9171a186236219"/><file name="ControllerFile.php" hash="090e5fe4d3b57933b9e7aed8eeef7cc5"/><file name="ControllersDirectory.php" hash="8543ca965e6d7a4cf78177ef0dcfc4eb"/><file name="DataDirectory.php" hash="5f8d27eca9e789c24dc039ea0f62748e"/><file name="DbTableDirectory.php" hash="92eda9ff83054cc8818bee744ed6e463"/><file name="DbTableFile.php" hash="b936fc7a4dd1e4726f0bb49f01ad931a"/><file name="DocsDirectory.php" hash="f58949c95502bd2ff8c31c59009c92b5"/><file name="FormFile.php" hash="b35ea0268fe07098b794eb24082ef53b"/><file name="FormsDirectory.php" hash="ffe9f7939c29068e7a1932dbc374bb7b"/><file name="HtaccessFile.php" hash="8e933afd24df22e6742aa972f8fc470d"/><file name="LayoutScriptFile.php" hash="8bd850a37a308efa3f4c83927fa5d8f5"/><file name="LayoutScriptsDirectory.php" hash="036f5cc0c38ead9183f7dd3f712848e6"/><file name="LayoutsDirectory.php" hash="c86cd320a91a46d439e4b419bd8ee428"/><file name="LibraryDirectory.php" hash="29a3c5283210c444e65284206b3da79c"/><file name="LocalesDirectory.php" hash="029c2897885aa476bd4103c48894ca87"/><file name="LogsDirectory.php" hash="3ee80aca0572bb9c5f6a44c6c021fcdc"/><file name="ModelFile.php" hash="958ed1603c25bd34ceb3f09ceeb6746f"/><file name="ModelsDirectory.php" hash="82dde848d95e686be57804162c11dc63"/><file name="ModuleDirectory.php" hash="7e219e82a6349ed878042cc17ee1faf5"/><file name="ModulesDirectory.php" hash="00182e9148959046c0a7d2d6e261e0b1"/><file name="ProjectProviderFile.php" hash="f3deaf3adf5c501237f22dc653430f91"/><file name="PublicDirectory.php" hash="e93bb7ed0ef00a864c097993ae1a2a94"/><file name="PublicImagesDirectory.php" hash="d769f00ec21961d66b41fffc8035277e"/><file name="PublicIndexFile.php" hash="4d3cf05ca9d35e24242dbf61d8189579"/><file name="PublicScriptsDirectory.php" hash="ff61ddca598a5ce42907b78140187614"/><file name="PublicStylesheetsDirectory.php" hash="8262d74f0f35523a912d95dd261fbc18"/><file name="SearchIndexesDirectory.php" hash="5ddf8701c47bcc6baf68cfdcc0ff7467"/><file name="ServicesDirectory.php" hash="825c4204f9f44f2280de370b0b156733"/><file name="SessionsDirectory.php" hash="af2fd72fa2bcf4d003c0a6368953cdb7"/><file name="TemporaryDirectory.php" hash="46790ecd95da8518c80dd8715fe7f8ad"/><file name="TestApplicationActionMethod.php" hash="4bbc3a869e69c2093bfa02068b6e057b"/><file name="TestApplicationBootstrapFile.php" hash="6f335bc4e4e047c948e77e8b0708f45e"/><file name="TestApplicationControllerDirectory.php" hash="1976699a04927fa3f5a1686934cdd08e"/><file name="TestApplicationControllerFile.php" hash="8f2956d50a3ba47f0b8c1fa96b361025"/><file name="TestApplicationDirectory.php" hash="09f0536bc206b5305862a21b65301016"/><file name="TestApplicationModuleDirectory.php" hash="da78a9b90b270578a9d36f8d62575a2f"/><file name="TestApplicationModulesDirectory.php" hash="4b54130f6c22e995308da7138d85330b"/><file name="TestLibraryBootstrapFile.php" hash="d78b732c8602c082ad1688c9bc6bf68d"/><file name="TestLibraryDirectory.php" hash="3626bc62a7c1c330369eb0001c4a9b16"/><file name="TestLibraryFile.php" hash="b45dc141518eab43f5c89e64b29aebfb"/><file name="TestLibraryNamespaceDirectory.php" hash="2e70388b581499815e6e2ba2c1cc0c81"/><file name="TestPHPUnitBootstrapFile.php" hash="40d55d88d6c84cd153adb2539ee323a9"/><file name="TestPHPUnitConfigFile.php" hash="1f136f46d817445285994244274f9276"/><file name="TestsDirectory.php" hash="0dec72680dea22074c8d370953effac0"/><file name="UploadsDirectory.php" hash="5d72a25ffd1ee7899fa182ddd7c9e028"/><file name="ViewControllerScriptsDirectory.php" hash="0ce107dd0b77183717845592b5be2550"/><file name="ViewFiltersDirectory.php" hash="59d3134c2b27c136adaa07177a72b28c"/><file name="ViewHelpersDirectory.php" hash="305d6bcc8066a02a658d82a69b73828f"/><file name="ViewScriptFile.php" hash="95b593cd475edcfd2a6ecea8f2668ffe"/><file name="ViewScriptsDirectory.php" hash="9aeac85b2f35bd6a666a4da29b465d45"/><file name="ViewsDirectory.php" hash="f36732d4b125b54a661356327d6850cf"/><file name="ZfStandardLibraryDirectory.php" hash="eea898b019c52dafd72f7de1aaa92d50"/></dir></dir><file name="Exception.php" hash="125c1606112c9ce2cfc8b697fb989d5f"/><dir name="Profile"><file name="Exception.php" hash="907a68043581559d3bf42ccc2c4b1322"/><dir name="FileParser"><file name="Interface.php" hash="325d41a29468a70dfe7476e1fcc8d20f"/><file name="Xml.php" hash="59f053468c48c4d9b881bc1b859ec28c"/></dir><dir name="Iterator"><file name="ContextFilter.php" hash="ff51879dcc3452e49ad8bf2d9e2c4910"/><file name="EnabledResourceFilter.php" hash="8d0d4add1f853aa9cfd89aaf138e2de3"/></dir><dir name="Resource"><file name="Container.php" hash="ab368c4da0867a25770b6f7970a782f4"/><file name="SearchConstraints.php" hash="9e4a7578e2879e6c9da8cfeb1fbfa9ba"/></dir><file name="Resource.php" hash="2a5467d1f6ff134cd8e35a2cb92eaedc"/></dir><file name="Profile.php" hash="db1e9708dc20fe27c3b39b9e6f57f1f5"/><dir name="Provider"><file name="Abstract.php" hash="8c55b9fe14b8d37beac8a5d1356c2cdd"/><file name="Action.php" hash="72581e6e7e4acd0a19f8ba9bbc0e73aa"/><file name="Application.php" hash="64fa6f041e1f5727a88bb9cbc7636f22"/><file name="Controller.php" hash="677b3b817a7fdb644cd150be124e9a96"/><file name="DbAdapter.php" hash="b831929398b67e053a395a548227695f"/><file name="DbTable.php" hash="6d922b240f64a010df894b03a44e0132"/><file name="Exception.php" hash="00d67294ec03f48a1e43fede57faee26"/><file name="Form.php" hash="95362baaf1eb17e9698573f6d7fbcb53"/><file name="Layout.php" hash="40528bb34ab9942db935b59b831ab909"/><file name="Manifest.php" hash="9d3a781e8c917a5cdb9e7dd10641cd35"/><file name="Model.php" hash="f561e3f60741f857d2a0a8d8d8509823"/><file name="Module.php" hash="f3cb636991bdb7fa9d69285ff5370a75"/><file name="Profile.php" hash="2bf881a5c9cf4e1032cb8de9d9297b16"/><file name="Project.php" hash="a7b3b98eeb5b8a38d7b003adde3a3c16"/><file name="ProjectProvider.php" hash="63455c931c8fa909d4a413ae91c99cdd"/><file name="Test.php" hash="ef752345daf66c4d3bfcdf94feea8602"/><file name="View.php" hash="1a8b7de4308dea33a847f1c590238d80"/></dir></dir></dir><dir name="Translate"><dir name="Adapter"><file name="Array.php" hash="539a98b29aa0bbcec264db5e29d810ff"/><file name="Csv.php" hash="698388dd2ac2843c3664586596e248f0"/><file name="Gettext.php" hash="321e228017b8049e94ea89f4e41f35b7"/><file name="Ini.php" hash="c03616b55e55e0c62363c4ee5e6b106f"/><file name="Qt.php" hash="19fd28ff1f5135d08c73c5faca961f96"/><file name="Tbx.php" hash="688c8d48dd29565f46d6f49d160e2f4a"/><file name="Tmx.php" hash="829f33d7444e30e4dc5053890fa22ccf"/><file name="Xliff.php" hash="0af804c51c85eea4b76941587aa673cb"/><file name="XmlTm.php" hash="39a37d7374fe3f0e3bf63a1e1f9ccb44"/></dir><file name="Adapter.php" hash="61940eb09da1bed1e6b8984370ad4088"/><file name="Exception.php" hash="469fbd261b8e8e1b91a8221fad6a79cb"/><file name="Plural.php" hash="4afe3e908bd63c3320fc7c899cd7b139"/></dir><file name="Translate.php" hash="0a7fda94b43cc10499fae10d9ec5d2e2"/><dir name="Uri"><file name="Exception.php" hash="0d12fb53167123e15aacbdddd8b11797"/><file name="Http.php" hash="55fae6ba863159381838ccc7bf8c651a"/></dir><file name="Uri.php" hash="f20bdab5c9c0694f64dd5b69f090e083"/><dir name="Validate"><file name="Abstract.php" hash="3382bfb0c407a0d3b490685a4f85678e"/><file name="Alnum.php" hash="2fe48d28207f9917e69f5edf99a392e1"/><file name="Alpha.php" hash="abeae56166032b791ae499883857d17d"/><dir name="Barcode"><file name="AdapterAbstract.php" hash="7bf5990b4b1dc34fe1fd7bcddd8f0348"/><file name="AdapterInterface.php" hash="c1b8934e5706e958f6e889e7c04a6931"/><file name="Code25.php" hash="f707195d53cd032ba5a9fbde32e75176"/><file name="Code25interleaved.php" hash="0c2ca046d04c43c4204e6cbb9d6dff7b"/><file name="Code39.php" hash="adff9a47dbf44dca5784dc8cdcc3ddc7"/><file name="Code39ext.php" hash="2e69f0103fbda86142024fc7466958be"/><file name="Code93.php" hash="2377845f1bee4dab114519c8f5dd4c5f"/><file name="Code93ext.php" hash="795aad78199cbc0668c70e12defcf9ec"/><file name="Ean12.php" hash="233d2f57fb2b36f1f2c7b3a36b0ead3b"/><file name="Ean13.php" hash="349560c5d4af7178e257a38c3a24735e"/><file name="Ean14.php" hash="30ab956febdabc3c13a7812f6e703bd1"/><file name="Ean18.php" hash="899007801fc5a8f97b577d711e2d692e"/><file name="Ean2.php" hash="0d73987f006070e0d15a573277a812e0"/><file name="Ean5.php" hash="806813312608a4ade42bbfab5d233711"/><file name="Ean8.php" hash="d0f3b4b0305e5dd0a7ba077fbb4978cd"/><file name="Gtin12.php" hash="da6df50e6751f4872604687602cc9695"/><file name="Gtin13.php" hash="dbd9c8a33ed3669917d10dee00a44a13"/><file name="Gtin14.php" hash="ae9c9fccedb5e71c87950c17bc5a3411"/><file name="Identcode.php" hash="9fed06deab51a31d97a66801fc68921e"/><file name="Intelligentmail.php" hash="9f4a16c7b78b3b1e5d9429569ea2aa11"/><file name="Issn.php" hash="e8de22a236a14b191225614ca730d343"/><file name="Itf14.php" hash="958a09981361b0cc8c83c0ae98831008"/><file name="Leitcode.php" hash="581e77d7ff774564ac3961077e40b27f"/><file name="Planet.php" hash="cda7f2f6910606728d4f6b375b17bbff"/><file name="Postnet.php" hash="9182081361daecfe6f0371fc4cabcd9e"/><file name="Royalmail.php" hash="e5bfd9d4ffd4935ca4b988f651270e4d"/><file name="Sscc.php" hash="eabc46811aff1a4a7f4468bd73a3f1e8"/><file name="Upca.php" hash="bb4f503adce344b6d3eb584843d7378a"/><file name="Upce.php" hash="368d3a61898baad1f968d2292a2692af"/></dir><file name="Barcode.php" hash="b3531dde74c28ed55c868d75615a9d3b"/><file name="Between.php" hash="5ccda5b2ac3d35bcc7faa8d8800108df"/><file name="Callback.php" hash="4e6874a0cb4bba53ef8edb9cde9eed18"/><file name="Ccnum.php" hash="1871fdfe01ac8f50e1b76f103297d7fb"/><file name="CreditCard.php" hash="2b68a89fbd9747e2a7308bc08aab9a12"/><file name="Date.php" hash="ac196efe9a75f1f5052881f0ad0fb7fc"/><dir name="Db"><file name="Abstract.php" hash="f32f786acb59d6936c87698c0ac868ad"/><file name="NoRecordExists.php" hash="de3eab3a488154fd14c3aeaad18c58b7"/><file name="RecordExists.php" hash="6203f6b21b338f28420fffd67f007dcf"/></dir><file name="Digits.php" hash="6536e4f93eea9d40663dc5b8308455c3"/><file name="EmailAddress.php" hash="f2fb48bbe83e3fb4288ee0f4825f485b"/><file name="Exception.php" hash="f05330fae73fa8a6fa5eb13b239492ae"/><dir name="File"><file name="Count.php" hash="fd4240625ed05056050c46051750d42a"/><file name="Crc32.php" hash="37be3ed367b5b7d13170fdc56c083488"/><file name="ExcludeExtension.php" hash="cffccfd1fcdae2be7676722ba8af7d9e"/><file name="ExcludeMimeType.php" hash="071a625f92fac84b76467a0eba3c467f"/><file name="Exists.php" hash="f5ab404939714ebf24c992bb3e4db124"/><file name="Extension.php" hash="21bf334b8b2ee214e82709c7bc1bf489"/><file name="FilesSize.php" hash="ab8dd66b1a133b1851d51927eabea61e"/><file name="Hash.php" hash="fd3f0e2888d1266d78da22e7d6647690"/><file name="ImageSize.php" hash="d277f5533a2aa61b2d5132babaf63c43"/><file name="IsCompressed.php" hash="1a0257de13523c8227a809b5673eb217"/><file name="IsImage.php" hash="7cd64b53b6e4a635e71b69e8ed5af7c4"/><file name="Md5.php" hash="4af983e349f6c2bc3a3fb6bc05d51e32"/><file name="MimeType.php" hash="c996e072363c49d15feba2a7ed35684c"/><file name="NotExists.php" hash="66d36bf5981467b276a1d97ae22ba5a9"/><file name="Sha1.php" hash="bf177eb68980e20cdf4a0db90bc32a08"/><file name="Size.php" hash="e6fe4f698bbe20ca0ccabe817462e0e7"/><file name="Upload.php" hash="a4099691c48b3427cdb144e3333b9145"/><file name="WordCount.php" hash="a2c3afef06b310c0b6a61867dfe25ab2"/></dir><file name="Float.php" hash="7d81882373a3c805ea6d890fd23d534d"/><file name="GreaterThan.php" hash="c8abc03e583058774db68388b71654ae"/><file name="Hex.php" hash="b491553d31f5894f2bd1303d685223f5"/><dir name="Hostname"><file name="Biz.php" hash="7696fce32b01be696c7a3f168ebd56de"/><file name="Cn.php" hash="fb00d241ff6f27a84d1c63758be2a14a"/><file name="Com.php" hash="5deccb0b547e92073687530b13870ce2"/><file name="Jp.php" hash="d22c9a1a27cfc135357a79c4608cbbd6"/></dir><file name="Hostname.php" hash="084ca6f450f36d3c76248663351f27dd"/><file name="Iban.php" hash="93312cb157edcb0735182b06a20d22dd"/><file name="Identical.php" hash="35b72f8c75851bb0dddfe4ac2126cef0"/><file name="InArray.php" hash="c75ec63d4745f66be627d1973bd76396"/><file name="Int.php" hash="222edd304fa91776951350e2659597fb"/><file name="Interface.php" hash="dbdfc01be0180334732bf0331fb19468"/><file name="Ip.php" hash="7abc354eed666e6b93c14c9187d2d0a3"/><file name="Isbn.php" hash="aedbe250623c9a9ef228d1863104b839"/><dir name="Ldap"><file name="Dn.php" hash="2716b9bc0c82519ab2fdbb52a0094eaf"/></dir><file name="LessThan.php" hash="e9fd4f35f101acb8fa94df0812ece205"/><file name="NotEmpty.php" hash="84a8e76bc9fd6fce9ce3d93f9e37b36f"/><file name="PostCode.php" hash="4513fb89c9215f1c987354ea552c0925"/><file name="Regex.php" hash="cd9c961f1bc2241a1beb61b8adc6325c"/><dir name="Sitemap"><file name="Changefreq.php" hash="02c174efb2eb92c1f99083d8d8a8201b"/><file name="Lastmod.php" hash="ecb2907a0827ca4f9a902b1842104f0c"/><file name="Loc.php" hash="43a32b211470fd207e614e122b373d5f"/><file name="Priority.php" hash="c4062b2af691dd790e88a80aa5f5400b"/></dir><file name="StringLength.php" hash="b57a08cb0418165feed0c8f3069830dc"/></dir><file name="Validate.php" hash="fdb819323b45ba50c37cefe43410afd6"/><file name="Version.php" hash="4050aa162960c6f935a49ffe910f81bd"/><dir name="View"><file name="Abstract.php" hash="1319cd055a57d8627ff0ed820f17daa9"/><file name="Exception.php" hash="7a4c976601978de749639c8b0914a03f"/><dir name="Helper"><file name="Abstract.php" hash="e1018e0e93049ac253c920888dc1133e"/><file name="Action.php" hash="786799b58e0fc8729abfde4de463e4df"/><file name="BaseUrl.php" hash="183857156a40c84f03eaea0ff24606bf"/><file name="Currency.php" hash="2ffa077bbe17cbda6974509421cd0582"/><file name="Cycle.php" hash="33bb85798e40541bc8e75cde27cf3499"/><file name="DeclareVars.php" hash="3cbcbf5083117f5f1dad9bac8df3b474"/><file name="Doctype.php" hash="b7e492a249f52859e00c287a8973edb9"/><file name="Fieldset.php" hash="4874b3f6f0658d8f9eae3bf750bf9793"/><file name="Form.php" hash="17d5d7e238c33e8e8cb0efbe043c01e0"/><file name="FormButton.php" hash="c62cf4a51db83501c7c7f1e2fad7cabe"/><file name="FormCheckbox.php" hash="3fefb8a82a8183e4cda683231bad496a"/><file name="FormElement.php" hash="9dc8f7fdd07eb031bc7cee049faa49e2"/><file name="FormErrors.php" hash="eb7e95a90d8a438d4b1043fd32a5f3ab"/><file name="FormFile.php" hash="cf7ec88f4ffd6c732a7df42737069d07"/><file name="FormHidden.php" hash="396bbe9d13da93ee84befb08a5c86f55"/><file name="FormImage.php" hash="3c9adc229035b5972678f634f690cd75"/><file name="FormLabel.php" hash="af00a20fba6e72eb035a605e72a814a7"/><file name="FormMultiCheckbox.php" hash="4033cf623ff32c24f0eaac26e96272d9"/><file name="FormNote.php" hash="94c3fe7ae9857d5d1c0f7e67bd817ee2"/><file name="FormPassword.php" hash="e743953bac753960ee4918c34372ede6"/><file name="FormRadio.php" hash="7df9c01b4e3bac15aca3394bd6bb20ae"/><file name="FormReset.php" hash="7463249d29ef3c895e6d73548c0d2250"/><file name="FormSelect.php" hash="b9076b91b3dd8880a74b9a1ff0f6fb2e"/><file name="FormSubmit.php" hash="abb3c753621b09e8251e88dd7d9cfb1b"/><file name="FormText.php" hash="c059e5863263faaa09d4e7fe99ef4fa1"/><file name="FormTextarea.php" hash="b5a12bd7577c3794b4f7536e1721254c"/><file name="Gravatar.php" hash="8b4c4ce3552c48ec148b81ebb4f843d7"/><file name="HeadLink.php" hash="c25bb4abcf60925394a915df38b006a5"/><file name="HeadMeta.php" hash="42d8fed1309297d58411bb7d487ebe28"/><file name="HeadScript.php" hash="c835c0d98daf0f2b89f2f486d22587a5"/><file name="HeadStyle.php" hash="2770400f4d12c2bf7b27c053aa1a6453"/><file name="HeadTitle.php" hash="329e23739809b5a55dc8d28c447dc91c"/><file name="HtmlElement.php" hash="e5e6b362d6001c20bbb805e31beb36e1"/><file name="HtmlFlash.php" hash="dff36a0bf66c600be3004bdd34cc8b08"/><file name="HtmlList.php" hash="f21ac692428d4c457dc2f3d2db5e7304"/><file name="HtmlObject.php" hash="dda5c4a84c32c4cdd73112a33c322c87"/><file name="HtmlPage.php" hash="d49d3e056e0aab1a8179bd2b3f1917e2"/><file name="HtmlQuicktime.php" hash="4455adb547e6d3a1d3fb52d6746df770"/><file name="InlineScript.php" hash="aabae2682812b3ee88a5bfafaa3d00dd"/><file name="Interface.php" hash="52fa974c83ce1fff7c9d56a994b1fbbc"/><file name="Json.php" hash="78621362d2c630ad5b8b7f7ef2cf2124"/><file name="Layout.php" hash="9e98d798baba317de41bc0cdf75cdf60"/><dir name="Navigation"><file name="Breadcrumbs.php" hash="6482ca2aa2565f318b49ce0458072ae4"/><file name="Helper.php" hash="673a27dfb10aa4442dfa2951e0ef0c4a"/><file name="HelperAbstract.php" hash="6bae63e5c54e21b87ebaf8d2622ac1b9"/><file name="Links.php" hash="b2b7b2403670be61982c1a73851ed2eb"/><file name="Menu.php" hash="8f5c5c42c0b10ac7a68c69b4503ecaa2"/><file name="Sitemap.php" hash="960d3bd171fbe2ca66ba073afd33140a"/></dir><file name="Navigation.php" hash="98f3a4adbd4c69df20c127f90e09156c"/><file name="PaginationControl.php" hash="b18eee7e9c52256b27384a982a75f0eb"/><dir name="Partial"><file name="Exception.php" hash="047c658de482d2ae0eb5d21ac0cd0a55"/></dir><file name="Partial.php" hash="abe72103b776eeee4a96ccbca003cabe"/><file name="PartialLoop.php" hash="637e144d4c2d369a35848d681b4b6464"/><dir name="Placeholder"><dir name="Container"><file name="Abstract.php" hash="8d885989d99888fc2798a85f07c9f17a"/><file name="Exception.php" hash="326371b5ef3489904fee8e387e7feb46"/><file name="Standalone.php" hash="637e4d2b742d9902ae6de414c0475237"/></dir><file name="Container.php" hash="16d8237399260e817a542e68a4828d4c"/><dir name="Registry"><file name="Exception.php" hash="b9a3969a1431cf44f4cd03764dd92e32"/></dir><file name="Registry.php" hash="ee6d81b2c630c83baac77a0d619ba7d1"/></dir><file name="Placeholder.php" hash="2fced270eb2e3474b4bd538cd73f517a"/><file name="RenderToPlaceholder.php" hash="5ad5803d78bad07455af8f5d3c876977"/><file name="ServerUrl.php" hash="c6a222f4e795320f6f07c6bb8f80d7f3"/><file name="Translate.php" hash="d341ce0f8809b691728672fe506736e6"/><file name="Url.php" hash="71f6c3948d28f8190bfc27b3586d3f93"/><file name="UserAgent.php" hash="dbee4e1b78fad667479a85e8e2d0cbd1"/></dir><file name="Interface.php" hash="eec709b1a8ebb0256a9f752db1a8ad75"/><file name="Stream.php" hash="6f4c3f620f6e2d2f92cd371db18d3a90"/></dir><file name="View.php" hash="604cd51ea9ba98756064b418d6785a5d"/><dir name="Wildfire"><dir name="Channel"><file name="HttpHeaders.php" hash="62dffc43581615ca6cb052efcb2a43f9"/><file name="Interface.php" hash="0bed6c7ae3ee56a17f5c5187eef3ce10"/></dir><file name="Exception.php" hash="a225536440492a4ef3d37702aea1cb40"/><dir name="Plugin"><dir name="FirePhp"><file name="Message.php" hash="f481d929bbb00bf2bac8dfb008ae37d8"/><file name="TableMessage.php" hash="074faf9136be2ea86add5cdf2b459dd8"/></dir><file name="FirePhp.php" hash="e23b81012ace71de3018a37deb708885"/><file name="Interface.php" hash="c3cb69d35db9a385f7caa140b9634dab"/></dir><dir name="Protocol"><file name="JsonStream.php" hash="38a7d96f9d4ec70f68492f1bcf4022f2"/></dir></dir><dir name="Xml"><file name="Exception.php" hash="2dfb5785f12ed3858b16ab075570d577"/><file name="Security.php" hash="b7b7a240b24574b06f73a59dd8a4e6f0"/></dir><dir name="XmlRpc"><dir name="Client"><file name="Exception.php" hash="8e96419287c2faeeb4412ed9e832d975"/><file name="FaultException.php" hash="28c34f9ec27f280c44d215ee38bd41c3"/><file name="HttpException.php" hash="8c2eac4d043926123b3691562ad47310"/><file name="IntrospectException.php" hash="39d33b723e4fb1d5ce2af5cfd1f41589"/><file name="ServerIntrospection.php" hash="e52c06c394a8c8ac91b5313e5c575024"/><file name="ServerProxy.php" hash="43f25d1783bc1f11462d21ab5a134976"/></dir><file name="Client.php" hash="ea8c5a084405ca13e4f43340e37fe866"/><file name="Exception.php" hash="a04feed37237658eb7c174518a4d9383"/><file name="Fault.php" hash="18685e9a87f2f7750fa968d86ab89625"/><dir name="Generator"><file name="DomDocument.php" hash="5fc0be6304c7a00e58ac39f033d0dd22"/><file name="GeneratorAbstract.php" hash="493eda4b0b32cb59a133c06d63fbef90"/><file name="XmlWriter.php" hash="45013d6c2e24f7ee77439df64a958172"/></dir><dir name="Request"><file name="Http.php" hash="70fcc3ae21a466a9295f42ebae0c2a93"/><file name="Stdin.php" hash="23583af65a719e197a70fcd4c5500ac0"/></dir><file name="Request.php" hash="6945ae9bdf8d76308651611848870e09"/><dir name="Response"><file name="Http.php" hash="50e6859ca7391fd453d7137697f57dc5"/></dir><file name="Response.php" hash="cc7fe267b740ab5c556b7b2d19b6d600"/><dir name="Server"><file name="Cache.php" hash="1cd78db98fe5499e4a64379e97689f77"/><file name="Exception.php" hash="6294a6b1a7d4da4b7a15e7ee489eb119"/><file name="Fault.php" hash="69b89d7568a910f82109b6f3cb0410de"/><file name="System.php" hash="d7b0d17c91367f44eb993da66672dbac"/></dir><file name="Server.php" hash="1087be94c4995db9c38a5335323e922e"/><dir name="Value"><file name="Array.php" hash="b7011fc480c395bfcbc67d68ead94cd7"/><file name="Base64.php" hash="91ea9215e1d57716c0cd79bb1906134e"/><file name="BigInteger.php" hash="10222f3f5cd5eeaaa9813d8ed9f2494c"/><file name="Boolean.php" hash="770874cea876566818fb9135f31e69c5"/><file name="Collection.php" hash="0708fe32732db76ebe9d7e89396b89e0"/><file name="DateTime.php" hash="1a9f56c65375240ee0385ed912731b84"/><file name="Double.php" hash="ee71a5a9eeb026f1eb75387b8158706e"/><file name="Exception.php" hash="b7adf50526128e43c344331e7250b935"/><file name="Integer.php" hash="66c8d75e059a4cf328ff108d15db5c5e"/><file name="Nil.php" hash="ad51cdbcfb5eff5e06d7fc2c6d4661e9"/><file name="Scalar.php" hash="e61890f60aff885a3bed37b093f36e6d"/><file name="String.php" hash="a9d992c1910d76c4ed5330e704a1d438"/><file name="Struct.php" hash="028b64a94eeca406537505ecd52788d1"/></dir><file name="Value.php" hash="7d09b0ce98deeb7a07c01ad1bc94aa0f"/></dir><file name="replace_recursive.php" hash="e886103ea1f75208cc11780718aa3094"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF_Locale</name><channel>community</channel><min>1.12.10.17</min><max>1.12.10.17</max></package></required></dependencies>
-</package>
diff --git a/var/package/Lib_ZF-1.12.10.18.xml b/var/package/Lib_ZF-1.12.10.18.xml
new file mode 100644
index 0000000..55e5c7f
--- /dev/null
+++ b/var/package/Lib_ZF-1.12.10.18.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_ZF</name>
+    <version>1.12.10.18</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Zend Framework</summary>
+    <description>Zend Framework</description>
+    <notes>1.12.10.18</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:04</time>
+    <contents><target name="magelib"><dir name="Zend"><dir name="Acl"><dir name="Assert"><file name="Interface.php" hash="753f4c058211502ad047851c4550a121"/></dir><file name="Exception.php" hash="833945ed22a5631224398ec5d1a51736"/><dir name="Resource"><file name="Interface.php" hash="ec27f75c67a2ddb21ede3e8f5cf2188c"/></dir><file name="Resource.php" hash="1eac5e2cda19d6f595ce678ee9b27065"/><dir name="Role"><file name="Interface.php" hash="e61127c46f87a10799582eb5d58673ca"/><dir name="Registry"><file name="Exception.php" hash="1ab8aea40c56fb9754ea4d76cf022893"/></dir><file name="Registry.php" hash="b13b4d4f96691f26328aba33d2a725f6"/></dir><file name="Role.php" hash="4ffca60ba53123c02874b9f412a1d5a0"/></dir><file name="Acl.php" hash="9362ea321157987e2d667ce6ba6640c4"/><dir name="Amf"><dir name="Adobe"><file name="Auth.php" hash="5f1b8fa4bc0646bfc7e1a0248af99e4d"/><file name="DbInspector.php" hash="c945730a861cc8dfb79affc681d935cd"/><file name="Introspector.php" hash="1faa52d4a734963e2114f0244b4eb0fc"/></dir><dir name="Auth"><file name="Abstract.php" hash="eb1eebcde25e987e8cfd64b097a64438"/></dir><file name="Constants.php" hash="27f591080a8aa87a7603079496b03f31"/><file name="Exception.php" hash="c37e40e651b342f39763d2651a86e907"/><dir name="Parse"><dir name="Amf0"><file name="Deserializer.php" hash="91d9e217cf20c9012993d945e3f7e744"/><file name="Serializer.php" hash="fc6f4e7a3adcee15df87e6f5e918891d"/></dir><dir name="Amf3"><file name="Deserializer.php" hash="63f1c82ab2bf8029208347a5d6188cf9"/><file name="Serializer.php" hash="94893d06b63c1c7b89958790051a96b8"/></dir><file name="Deserializer.php" hash="6bf0ed466d51a8ed7d47842ae56b0c2e"/><file name="InputStream.php" hash="8825ad088d82c7b0e1eec7f1fc2a977f"/><file name="OutputStream.php" hash="f6954a735a7abc530b3d08c3a66a1610"/><dir name="Resource"><file name="MysqlResult.php" hash="f93006c3cf636f4426559266c7254301"/><file name="MysqliResult.php" hash="3ff39905a315dc50438612cdfd044003"/><file name="Stream.php" hash="9fac77c33d3b8a5932618b7140eb480e"/></dir><file name="Serializer.php" hash="89f6dade3493238bcebd57f7aec7c441"/><file name="TypeLoader.php" hash="2eb3de6c0c76a88c84e52d053db1b3c3"/></dir><dir name="Request"><file name="Http.php" hash="3ceb2e9419c58b42b8a91dfa518bdbe6"/></dir><file name="Request.php" hash="210fafeb570fabde64f45367aa2b818f"/><dir name="Response"><file name="Http.php" hash="9165da2b40ea937760d21e82d14fccfd"/></dir><file name="Response.php" hash="df120c6bdcd3624007e264387c3ea49d"/><dir name="Server"><file name="Exception.php" hash="b49d17bc0487b1f94e263edc3cd63b80"/></dir><file name="Server.php" hash="a382bc11323a9e000c8b903609842a60"/><dir name="Util"><file name="BinaryStream.php" hash="2be5bd9b9c7daf56a578bb98c79c4393"/></dir><dir name="Value"><file name="ByteArray.php" hash="3501ce99e15b597c7159a47a166585b3"/><file name="MessageBody.php" hash="8b61f8ee1c39105e5c19ee0c3df1eedf"/><file name="MessageHeader.php" hash="3719e3197128d0db242a664278740de3"/><dir name="Messaging"><file name="AbstractMessage.php" hash="3091614466f82c843414c7f780e2713f"/><file name="AcknowledgeMessage.php" hash="0102f33c15054d697d29ab872d587e75"/><file name="ArrayCollection.php" hash="5070cc263f4b56b4aa6a62110c563ae7"/><file name="AsyncMessage.php" hash="ad0d187dc1179ce2cad255fe5fbd00a6"/><file name="CommandMessage.php" hash="46b117af57383509740a975f1d35a801"/><file name="ErrorMessage.php" hash="cd980b1cc29739aa685d714e3645f5bd"/><file name="RemotingMessage.php" hash="acaa5c29b712d4d24168bb384d512bd8"/></dir><file name="TraitsInfo.php" hash="91da9ed050e8e44979a229eadf433bf4"/></dir></dir><dir name="Application"><dir name="Bootstrap"><file name="Bootstrap.php" hash="a54f574a13568e3b0d79f9792b58a77b"/><file name="BootstrapAbstract.php" hash="85403088f5775085724427f2db4e3f41"/><file name="Bootstrapper.php" hash="f6ffc93f65f911d74273c97480019ebc"/><file name="Exception.php" hash="592efcd13a2430fb8a8051c77af2bdbf"/><file name="ResourceBootstrapper.php" hash="b5697b89f0bee36d64f1323ae0e6fad7"/></dir><file name="Exception.php" hash="33b45075f371aa758ab73043d9bb345b"/><dir name="Module"><file name="Autoloader.php" hash="561bbbddfd1d5d66e9950b1c5435e822"/><file name="Bootstrap.php" hash="a982af99ca3f8583e7e06754c932bee6"/></dir><dir name="Resource"><file name="Cachemanager.php" hash="aed3b8889084e6b3b46b9e1ad2482309"/><file name="Db.php" hash="a5bc7745dd9416c3cee07ca45701672d"/><file name="Dojo.php" hash="ed17a22f02f2b4b52219cb1a8f5f283f"/><file name="Exception.php" hash="e7cc6162f923bea3163ab3c72a9144c2"/><file name="Frontcontroller.php" hash="4096de73ec4a62565475ade369fa2f10"/><file name="Layout.php" hash="cc29553ce7af25e5497433b38cb33d96"/><file name="Locale.php" hash="d9ddba5ce3e52cf74e06bcaa28e9f701"/><file name="Log.php" hash="6425ed565c8ffa8d6a2061b4bed90c77"/><file name="Mail.php" hash="43d891a5921b267f2298392f5de16f2e"/><file name="Modules.php" hash="de2fead30f02effe859de66503972e1a"/><file name="Multidb.php" hash="f958bb43354951af50a592a27c1de9c0"/><file name="Navigation.php" hash="fa7ac38efd17722bb2fd0181131af18d"/><file name="Resource.php" hash="fea870fdc0a7fe568ff6f7d1d10ab523"/><file name="ResourceAbstract.php" hash="5808f3f8a2c6a349aa21e4de678fef40"/><file name="Router.php" hash="54f15d496ef84d800897d8571523e5b5"/><file name="Session.php" hash="714544fe025fa8e5db47686b58fd410b"/><file name="Translate.php" hash="9b75da2a9e3f571a90f30f14bbe72582"/><file name="Useragent.php" hash="17a0a2deba744c0fd4091fb48958b782"/><file name="View.php" hash="18803d667bd908ccfc04edc3e39d209b"/></dir></dir><file name="Application.php" hash="a0c9ea8a48289b2bd9bafd2dfe76765c"/><dir name="Auth"><dir name="Adapter"><file name="DbTable.php" hash="c8b79405b8855b67ffd8d6f82e6a4045"/><file name="Digest.php" hash="bbc1edafb9a244774ca986a2790e5661"/><file name="Exception.php" hash="194d445ab6929d8c5a6faefe604c64a0"/><dir name="Http"><dir name="Resolver"><file name="Exception.php" hash="cf95d8463e66b8dcc7eb679aaa0127cb"/><file name="File.php" hash="56c75079c07a8f3081841dff74f4f8b5"/><file name="Interface.php" hash="136ff303d6f17f676641db12415a679e"/></dir></dir><file name="Http.php" hash="0cfb159e07de35d89ab6754c9e409b1e"/><file name="Interface.php" hash="9baba8292deab88415d58155627009ea"/><file name="Ldap.php" hash="5bec476c61237745110b07a6981f0ba7"/><file name="OpenId.php" hash="9b87324993b0882e8add83140b24799b"/></dir><file name="Exception.php" hash="0cbee6397372cb825d4d2330f1e01cbf"/><file name="Result.php" hash="011bad9ebfb3e12cde52dc199c1b9b0c"/><dir name="Storage"><file name="Exception.php" hash="7c0657994ccacd29c396728dd3e40ead"/><file name="Interface.php" hash="336438156ed6a7db4183fbb365ec24e0"/><file name="NonPersistent.php" hash="88366aa8fd16a4c565e7a6cf467c9d45"/><file name="Session.php" hash="128255a8d51a1d9fa137e137f17b773f"/></dir></dir><file name="Auth.php" hash="6ec79877089d5629bf32dc9cfca8a5ed"/><dir name="Barcode"><file name="Exception.php" hash="5cf74c43e0bb3bda36dab4cdcf435a7c"/><dir name="Object"><file name="Code128.php" hash="989d2bf6723d392c704a9d793a0870c6"/><file name="Code25.php" hash="945a62bd63cefd4bc548aca2175a798e"/><file name="Code25interleaved.php" hash="163795899dd207d6777ed489b3652783"/><file name="Code39.php" hash="6a9d919307643317d2670d0b5a0cfc75"/><file name="Ean13.php" hash="d073b0b3b0d548aa553128e61a8f739e"/><file name="Ean2.php" hash="244bfc6ef32a4d56629c045c929138f1"/><file name="Ean5.php" hash="198f60f22d8bb1d165bff02c5820a20b"/><file name="Ean8.php" hash="8cea912422779ab67e11d8a169063216"/><file name="Error.php" hash="20edaea0778ac6253009722af4bc1ba8"/><file name="Exception.php" hash="4222bc4babead0b78ff6cd53aa72e359"/><file name="Identcode.php" hash="8a1ac5c7c3b04d3e62aa8265c4e1c2f7"/><file name="Itf14.php" hash="9384e00165c9961a203d1f135a3eaa5d"/><file name="Leitcode.php" hash="3c805e7d37dfb51e8de1f35d16ed5da5"/><file name="ObjectAbstract.php" hash="017bd4e5560bfddab60971b889d9f0a0"/><file name="Planet.php" hash="e1c10362fbc9baa5aabede9041060d79"/><file name="Postnet.php" hash="5f6845e59e609f8991fa580bbdc5eefc"/><file name="Royalmail.php" hash="8cc2c93b813ed89f4b0f6cd60df29f77"/><file name="Upca.php" hash="1485da9e266c49e993a00f9d287b4019"/><file name="Upce.php" hash="7cbde278294ce55ff3cb0857f5c014c5"/></dir><dir name="Renderer"><file name="Exception.php" hash="8579d580dcc35ccd16c82590ff39c1b9"/><file name="Image.php" hash="dba737459af451c5c51bad867b77a0a6"/><file name="Pdf.php" hash="1e2d590fe769d9ebf74d901a34635aa7"/><file name="RendererAbstract.php" hash="359cbfacb66cc0fb5ae362845b3fbf58"/><file name="Svg.php" hash="93544d770411772a4dc2c995cced685e"/></dir></dir><file name="Barcode.php" hash="0586994cdf9871ebabd7aa8079566258"/><dir name="Cache"><dir name="Backend"><file name="Apc.php" hash="0770aacd96ff057d06978bcc7a22035e"/><file name="BlackHole.php" hash="f51e1f122876be7d7ba667e39c540901"/><file name="ExtendedInterface.php" hash="fb6c1f28d7049d8ebb5b367586a386b4"/><file name="File.php" hash="292986e780e4b420968b5dfa15267a01"/><file name="Interface.php" hash="9e9a235e4aa33de40ff9fbc97efa468d"/><file name="Libmemcached.php" hash="2f9d3d284be576c031ff2195afaabc20"/><file name="Memcached.php" hash="cbee447e2af7453a2a37ddee2206f971"/><file name="Sqlite.php" hash="8c2ffff28dbe7e5c27a2bfb6fa1a4759"/><file name="Static.php" hash="8b4e8ac2f3e416316d447266e1a6f8dd"/><file name="Test.php" hash="6bcaf9deb1e13215d9fada844fa0bb25"/><file name="TwoLevels.php" hash="1d48225fde0e61fc38401841b28740da"/><file name="WinCache.php" hash="57da7293a57294e3cc2878d872230aea"/><file name="Xcache.php" hash="364f350bb7e58a221a9dda26dfd940d3"/><file name="ZendPlatform.php" hash="dd2264172835c8ac2b1cd0eba670d1ee"/><dir name="ZendServer"><file name="Disk.php" hash="092b29cf8ea2e0391e156ca38a9c8dbd"/><file name="ShMem.php" hash="94d219bd689df1b0ce1f5fe48c0fda7e"/></dir><file name="ZendServer.php" hash="6397a63f6ceba054b9c4c774451109a6"/></dir><file name="Backend.php" hash="046904b4b5c7661bbdcb6c3ec7969af3"/><file name="Core.php" hash="26e9ed27936fe7c894f36a1241b6aa35"/><file name="Exception.php" hash="64896658ade26dbd6b15851aee788379"/><dir name="Frontend"><file name="Capture.php" hash="5e7254e902e587587a9f7c1749787690"/><file name="Class.php" hash="e0fba9da74e040fc5fcbfeede03147d2"/><file name="File.php" hash="291450665f2b240c3a1d0b8f81d9e505"/><file name="Function.php" hash="80926f9d0d94953c8534f381b3e9e92b"/><file name="Output.php" hash="b3902a3f0ddf1b4608b84f6172a317e6"/><file name="Page.php" hash="d447d1e18b8c9ccfe95f5cbd4f8ad0aa"/></dir><file name="Manager.php" hash="bba8e1dfc892616eccc5f033d3849aec"/></dir><file name="Cache.php" hash="dd6b3426e3682f832f5e73a5a5e7bbe4"/><dir name="Captcha"><file name="Adapter.php" hash="c80da3e14f86386865a1a11f386509f0"/><file name="Base.php" hash="f3f587f183c8dbb0f71b588a99f56728"/><file name="Dumb.php" hash="42cf7479a157ab4f6d92f4ea2edd402f"/><file name="Exception.php" hash="a1ea444d80d4629ae987f5120d7b6ab4"/><file name="Figlet.php" hash="9434c31c17fa4558d823f72863bda27e"/><file name="Image.php" hash="8f1bb1448407f673d986cc387846bf3f"/><file name="ReCaptcha.php" hash="7213da2f0082b6a209bf5659d5279036"/><file name="Word.php" hash="2b20aa38f1132306e259f4032ad1de6e"/></dir><dir name="Cloud"><file name="AbstractFactory.php" hash="0360f699d631c5eb6f1f5e117a2a6524"/><dir name="DocumentService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="3679fe7eef0b73516d98565b35e90366"/><dir name="SimpleDb"><file name="Query.php" hash="163f21a702cb5aa76d58682d29559bd2"/></dir><file name="SimpleDb.php" hash="78628ea1029ec6f267c83c302611b6e8"/><dir name="WindowsAzure"><file name="Query.php" hash="657934a415bd7d731906ebb3fa42187d"/></dir><file name="WindowsAzure.php" hash="9a48103bc6327e24a98f27307641c397"/></dir><file name="Adapter.php" hash="22799d67b8935e871e9fcb5403617a9d"/><file name="Document.php" hash="e76315e7e307aa99dae6d634b51c2ece"/><file name="DocumentSet.php" hash="53cabe8e2d6454beab6b476953fb9a58"/><file name="Exception.php" hash="e69eb63ef3ac0476422e553c0f9d0b7c"/><file name="Factory.php" hash="d11189e3ba364466584a8461e9bea29b"/><file name="Query.php" hash="dcf377f4d08e1adc178dcef42a7e21d4"/><file name="QueryAdapter.php" hash="b683d5360841a57b8b58f0ac937b4991"/></dir><file name="Exception.php" hash="baa1da441578d83ef668c947bc26993a"/><dir name="Infrastructure"><dir name="Adapter"><file name="AbstractAdapter.php" hash="1a0c85424e055522ed27fd848641adb9"/><file name="Ec2.php" hash="f702d42320cb2a843124faeff6308673"/><file name="Rackspace.php" hash="12ca011eaa260a98e5f0b021497d6d9f"/></dir><file name="Adapter.php" hash="8fd0db5ff41dd87d2730981cf6a651e6"/><file name="Exception.php" hash="dd74945bd044a9b569715d8b8f33d6c6"/><file name="Factory.php" hash="e35fedab839a9897bd494b4525c70d74"/><file name="Image.php" hash="d0b5a851095a8a6d00cc758e66de65d0"/><file name="ImageList.php" hash="330f4330efa43095c73963860719d8dc"/><file name="Instance.php" hash="aa600d04524311d6da4bfac324aae00f"/><file name="InstanceList.php" hash="9f5c27c450518e4090aa5200261e0804"/></dir><file name="OperationNotAvailableException.php" hash="cb15f6dfb2c6caf15bf3d3c7192a2859"/><dir name="QueueService"><dir name="Adapter"><file name="AbstractAdapter.php" hash="6aafd9d7c44e76e68dd7b8ea83aea6fe"/><file name="Sqs.php" hash="03b431d971a7679aa43dba8d235fd9bb"/><file name="WindowsAzure.php" hash="b4762cebc1460850e73552d5a617ea6d"/><file name="ZendQueue.php" hash="d8aaa2f4ec3302693fcaee2833339bac"/></dir><file name="Adapter.php" hash="c950feca6fdab3f115ba62146e9c4061"/><file name="Exception.php" hash="0406a9d40baf106b1e7c7a52c58622ce"/><file name="Factory.php" hash="1489be14015fdbc7364317e2e6fdb4dc"/><file name="Message.php" hash="48907828e50d23674d1500834ac33d96"/><file name="MessageSet.php" hash="f4371e5f68036dbea532b7899c59679c"/></dir><dir name="StorageService"><dir name="Adapter"><file name="FileSystem.php" hash="c2066ccb70e97bfccf1dc6eca5beabed"/><file name="Rackspace.php" hash="d5b49d598b7a2ca875599df0c07d17e2"/><file name="S3.php" hash="36d663a296803282ec6ffbb4d1f6ecf7"/><file name="WindowsAzure.php" hash="1c266330be81f9034e491cdc5c0becee"/></dir><file name="Adapter.php" hash="4bf256cad4b27a0b4ccd0ea0d2e5df44"/><file name="Exception.php" hash="b1938d4a1d75a132c7896c9d1d49c316"/><file name="Factory.php" hash="e60551fd66495592c25f2143683c0eae"/></dir></dir><dir name="CodeGenerator"><file name="Abstract.php" hash="8bb5c3fb76b0953dad77b8aefd240552"/><file name="Exception.php" hash="2f35c31886c1506cbce95bd48ceb8302"/><dir name="Php"><file name="Abstract.php" hash="7ffc414197119b98d09c089d38b745cf"/><file name="Body.php" hash="4354cf77549e88c8ef742f74df428824"/><file name="Class.php" hash="e96e076b5e9a7a41b9dff5d65d65cbf8"/><dir name="Docblock"><dir name="Tag"><file name="License.php" hash="fa6989bdda9dcc8eed58dfcd5cd11d3e"/><file name="Param.php" hash="c5402463f594b0ada366547e2140c087"/><file name="Return.php" hash="d36a1b1dbd2383043b9703449212218e"/></dir><file name="Tag.php" hash="94c4d5bf7254f1122a9140578562cf4a"/></dir><file name="Docblock.php" hash="3630eee3a36264ed70bb414b1b6659d2"/><file name="Exception.php" hash="4d0d644d274ba0d93c86edabe96a937a"/><file name="File.php" hash="16190c6965142355870ea2d86065c2f3"/><dir name="Member"><file name="Abstract.php" hash="a07d1b1c01755725fd9c670b83e14c6e"/><file name="Container.php" hash="52c0f2936e0dd96e3efaca239e97a537"/></dir><file name="Method.php" hash="facb978030d8ed1148d3fd9b27647a5c"/><dir name="Parameter"><file name="DefaultValue.php" hash="402dc7efb5a973be4b3695d97df9d5e6"/></dir><file name="Parameter.php" hash="f963e92d375973d82c64e9aeeb99aa68"/><dir name="Property"><file name="DefaultValue.php" hash="23583ff2c6b01162f217d3f18e17f5bb"/></dir><file name="Property.php" hash="5d85c620c090d866edd2cc4af3bb0737"/></dir></dir><dir name="Config"><file name="Exception.php" hash="825b93db4d92fc10ff2334d0701ac39a"/><file name="Ini.php" hash="bc377745cc51608820d81f08bb5e622c"/><file name="Json.php" hash="191c7eb21cbb2042491e5548a59087a4"/><dir name="Writer"><file name="Array.php" hash="fa6b3a9d9f68cc5973db7309b93454eb"/><file name="FileAbstract.php" hash="14f344ccee37bac7224aa203e5be6bf5"/><file name="Ini.php" hash="c658c697e401b7fab66edac3e5ab5edf"/><file name="Json.php" hash="675cff174476aab6e44540ce20b9ef6f"/><file name="Xml.php" hash="0ff4954d3f6be816d2911cc236d588de"/><file name="Yaml.php" hash="0a6d7e361af7f4f5cff8a9eb81264318"/></dir><file name="Writer.php" hash="7bca990f32b4a7bf64b6d7bcd6a8b144"/><file name="Xml.php" hash="24d64c4d3269a55f1577d40717069b3f"/><file name="Yaml.php" hash="d559550b7de8c77f03a6d8c5ab1af715"/></dir><file name="Config.php" hash="0ec674c135a25bb65bf7f2f536496373"/><dir name="Console"><dir name="Getopt"><file name="Exception.php" hash="ba4d96e50ff729964f51d3ff320a695b"/></dir><file name="Getopt.php" hash="a8165d6a04ff959844c118bd1517d4af"/></dir><dir name="Controller"><dir name="Action"><file name="Exception.php" hash="5c5bfb99e09c49bfd42afc92cca046a3"/><dir name="Helper"><file name="Abstract.php" hash="2db15ec4775320a42a86fc96ded791f6"/><file name="ActionStack.php" hash="72d618b0c01345a39b86362d00b519e5"/><file name="AjaxContext.php" hash="d25cd19237deee404b1d78c3babc51e6"/><dir name="AutoComplete"><file name="Abstract.php" hash="8265a4c01db3fc5ef8359855b5bc7de7"/></dir><file name="AutoCompleteDojo.php" hash="bc727565a422d34c4ee642604bca989f"/><file name="AutoCompleteScriptaculous.php" hash="423035f705a0ead78f0b508915f9f11d"/><file name="Cache.php" hash="5e1ee2f20930ce3ce6c9ff95c7986fd5"/><file name="ContextSwitch.php" hash="bbde32302aea3a45df7525ee558ba61b"/><file name="FlashMessenger.php" hash="6f60de563b5b400d75b630f359ce09be"/><file name="Json.php" hash="46f702a70e0d5e4ecff66439b34502aa"/><file name="Redirector.php" hash="246b26f4b71cdab25a5992577986b119"/><file name="Url.php" hash="16c5a98afe9f6f14bee59bbb0ee58583"/><file name="ViewRenderer.php" hash="6eac5b3e0152d2c000145c6a4076456a"/></dir><dir name="HelperBroker"><file name="PriorityStack.php" hash="9919f1af00251ac5d7a362dba0a280c8"/></dir><file name="HelperBroker.php" hash="aa9cf211934ac5b4fc9e4220ad26d7ca"/><file name="Interface.php" hash="0cb0ece63ce5a245010b9c79927149fe"/></dir><file name="Action.php" hash="1eff5915284945de72327a06cb10c10a"/><dir name="Dispatcher"><file name="Abstract.php" hash="3a481b8b2beb61d223f1c90757339a6d"/><file name="Exception.php" hash="21e0c2b4a1f642448f391e0601bf8327"/><file name="Interface.php" hash="323c3bfe932dca40b3f0f18ebaa39bf4"/><file name="Standard.php" hash="ccbde33f1d7616c2c35ee556039b12a0"/></dir><file name="Exception.php" hash="75ef40958ca34b2ce0007a6a9bd11b62"/><file name="Front.php" hash="a0cd827d65e2d2cc1d51d96009d61032"/><dir name="Plugin"><file name="Abstract.php" hash="4f9c2a5fcb32f0f02d01559c2900e2ff"/><file name="ActionStack.php" hash="dc0f223ebf96304711e62b0ff066cbe6"/><file name="Broker.php" hash="4558d24e01418e1a7a4a45f8a0419b05"/><file name="ErrorHandler.php" hash="1b86cb0d967cb3a80091271532e5f29f"/><file name="PutHandler.php" hash="5b65c0f667538e81cd5152060b1fc50e"/></dir><dir name="Request"><file name="Abstract.php" hash="479150985f9f5b1ad60da1c627ba5422"/><file name="Apache404.php" hash="6e4073adcf927bc08c36267350259110"/><file name="Exception.php" hash="401a6bfe6ee4f2eef739d5622d457235"/><file name="Http.php" hash="4866762dc4e2d7f2f70ebcf3ec3f3174"/><file name="HttpTestCase.php" hash="fee8b0ea3da866bae3125716977e609a"/><file name="Simple.php" hash="4debb461f0bf9c865b3ef7e9a2f9eec1"/></dir><dir name="Response"><file name="Abstract.php" hash="41812ba5c1950b91ca6db21c36a65022"/><file name="Cli.php" hash="1be9de58bd3af4e70797422c5936b9f0"/><file name="Exception.php" hash="daf74bb0fb6ffed9c50a414b78947388"/><file name="Http.php" hash="1b97675e6f09aca759dd04cadc2ada31"/><file name="HttpTestCase.php" hash="b8e25dbcd9245fce7f9e985aedb53ab2"/></dir><dir name="Router"><file name="Abstract.php" hash="7c3976721fbba2c462793f6152a7952a"/><file name="Exception.php" hash="10f91dd02d28dfb9c5de84d778f5e451"/><file name="Interface.php" hash="3f0e4586ac18e02e172ff65e1228a197"/><file name="Rewrite.php" hash="333634b9f184476914d985f68d06b12a"/><dir name="Route"><file name="Abstract.php" hash="c0437b622e03a117783fc6d8c2a581da"/><file name="Chain.php" hash="eb747ff18f4f5549888a7964b8f16f2e"/><file name="Hostname.php" hash="b54e6b9f68ffa63f9c493f82606ab2ac"/><file name="Interface.php" hash="80dd1da3a1fe916fcf173891716985cc"/><file name="Module.php" hash="dca7ac356221ebd066c5b17a72557551"/><file name="Regex.php" hash="4bcd3642f6ee8d66b9ec9cf591cfa121"/><file name="Static.php" hash="2bc26cb37610470e8fbb0e9302e76175"/></dir><file name="Route.php" hash="9be953ae63b6074535656826c99f88dd"/></dir></dir><dir name="Crypt"><dir name="DiffieHellman"><file name="Exception.php" hash="27066062da23c7b0b5c8ea405d63424f"/></dir><file name="DiffieHellman.php" hash="b146591071090ba7dc2d120c8d7cfcb1"/><file name="Exception.php" hash="98d264f8b46a12e8e1fa644b37488636"/><dir name="Hmac"><file name="Exception.php" hash="3b8bf2fed9087ce573c7d9e461211d01"/></dir><file name="Hmac.php" hash="7beea2bae905ad98fc8212a5a2ba906c"/><dir name="Math"><dir name="BigInteger"><file name="Bcmath.php" hash="7ad0514366aa1cfbbacf9a841d17209d"/><file name="Exception.php" hash="c7047b1ec96c2c5bf9d2ec8fd516c232"/><file name="Gmp.php" hash="1e136ad9748ff4e120be567de7195084"/><file name="Interface.php" hash="a1a15aadc0d1232e19e3660778e25a4e"/></dir><file name="BigInteger.php" hash="5941fbc6fa7558f254212a5c704de46f"/><file name="Exception.php" hash="0a2a9e2cdf2619549bb1891d31565cb4"/></dir><file name="Math.php" hash="0e54c36e33bb980ba251c42719e72e48"/><dir name="Rsa"><file name="Exception.php" hash="9af79ec754f6202584671b395e9898cb"/><dir name="Key"><file name="Private.php" hash="6b8486eba224159d7c05dea23039ec8e"/><file name="Public.php" hash="8cd4ac9225b58e1a2990659f4a97a45d"/></dir><file name="Key.php" hash="a0c0daf511c3a74d1e754faeaace0f83"/></dir><file name="Rsa.php" hash="e46289dffb56184f7c15faa3b24a0a68"/></dir><file name="Crypt.php" hash="ae1d981cb224263c8625604621d0ffc9"/><dir name="Currency"><file name="CurrencyInterface.php" hash="c52c23140b8d66185e2792cb10c65b40"/><file name="Exception.php" hash="f04c4fcb9b9b4117ab0c91e688904a06"/></dir><file name="Currency.php" hash="e380eca83740d28bb55435c3489204cf"/><dir name="Date"><file name="Cities.php" hash="4698b47f264db687c97ea7fa5ccd717e"/><file name="DateObject.php" hash="05ef22746ef2b1925cce51d42a5670b9"/><file name="Exception.php" hash="b91a2d166cf91afa1325a07747bafe57"/></dir><file name="Date.php" hash="6d17472f661d6b599477f215dda67f82"/><dir name="Db"><dir name="Adapter"><file name="Abstract.php" hash="7d5a1b64e9f292c018fec8fca159311b"/><dir name="Db2"><file name="Exception.php" hash="b64143620db1d7e5cd7b90312aeaf7bf"/></dir><file name="Db2.php" hash="d27757593a5be92da47326b25af8b4a4"/><file name="Exception.php" hash="461a43822f24e3e79bf8a844541235a3"/><dir name="Mysqli"><file name="Exception.php" hash="71ae5837eee0e261ba7639dff878845c"/></dir><file name="Mysqli.php" hash="c997a7381205b413a03efba602f2debd"/><dir name="Oracle"><file name="Exception.php" hash="8a08377363d09d1711c31ed0e2b4f220"/></dir><file name="Oracle.php" hash="2c539f9ac5ce7e656f3432c9aa00daae"/><dir name="Pdo"><file name="Abstract.php" hash="1f71eaf0415b750ee0573a80374e61cb"/><dir name="Ibm"><file name="Db2.php" hash="b947c61e9abf1f277adb40dc1aaf6319"/><file name="Ids.php" hash="a2d4fcf42c7b9435515399862224d74c"/></dir><file name="Ibm.php" hash="1042d1f01417241dc09679e1edb3a248"/><file name="Mssql.php" hash="139b7b3957b4e2b347d220b9dc8e959d"/><file name="Mysql.php" hash="0ca1bc627085e101ce51e02328b16347"/><file name="Oci.php" hash="819a1b3d31d7f65ba3f9de49ceecdf30"/><file name="Pgsql.php" hash="1b7fde0593b3799e4afa1f74b63499d7"/><file name="Sqlite.php" hash="efb68039f3e1b9e34a81c3dc9d0e8f20"/></dir><dir name="Sqlsrv"><file name="Exception.php" hash="097530f562d1993a992d6f62aadea809"/></dir><file name="Sqlsrv.php" hash="0fb64191a2d9e688410094c736d5eda6"/></dir><file name="Exception.php" hash="aebb5d861915d6a2494c58fc343f2752"/><file name="Expr.php" hash="2dca05427df6b34d6da9fb872517f684"/><dir name="Profiler"><file name="Exception.php" hash="42d03d9fd63aada757d6dabacdb73cb0"/><file name="Firebug.php" hash="1f5b0198a97091bba6ec8a8f74f3cf1a"/><file name="Query.php" hash="fe0bfc38389c14cecc76d528e33bfe83"/></dir><file name="Profiler.php" hash="e7327368b94ae8e094c602e41f617609"/><dir name="Select"><file name="Exception.php" hash="f8b241a9791bc28c77ca8c14cf80ba84"/></dir><file name="Select.php" hash="0fb5975684da5ea68ed45e4437d759d6"/><dir name="Statement"><dir name="Db2"><file name="Exception.php" hash="05225962b3d3107841d87d0d6c4ca9de"/></dir><file name="Db2.php" hash="36c397903c5e07ebe5b82b5e76030c7a"/><file name="Exception.php" hash="d41110267373d38bb4af77e1785329ae"/><file name="Interface.php" hash="222f50673200f578767b1e0c43d5a6bd"/><dir name="Mysqli"><file name="Exception.php" hash="1932b0ae9232ab79ccacadd46a45f022"/></dir><file name="Mysqli.php" hash="64e3e41642115ec95cce487da79fe737"/><dir name="Oracle"><file name="Exception.php" hash="59588ef7feadf4b0a726d1e1410f10bd"/></dir><file name="Oracle.php" hash="3fd727a08bbb347495dd6a2fb044defb"/><dir name="Pdo"><file name="Ibm.php" hash="aadb46dbcc67223ab9e240c35301cb0d"/><file name="Oci.php" hash="75a7032f82e8e29f52a8994a847e9533"/></dir><file name="Pdo.php" hash="91da6eddeaa94a88bcea2c3c912480bb"/><dir name="Sqlsrv"><file name="Exception.php" hash="925701544428f06183ecbb6718047839"/></dir><file name="Sqlsrv.php" hash="4d49d2edc91902768b1685768ac0421c"/></dir><file name="Statement.php" hash="48578c5307d13998d3b9dc73486bb666"/><dir name="Table"><file name="Abstract.php" hash="d1f0eb94b3a83abab809a132edec8d70"/><file name="Definition.php" hash="056d17187e24f48f42059889802ade8d"/><file name="Exception.php" hash="4ad0192e2759ce865081bfd65fba1537"/><dir name="Row"><file name="Abstract.php" hash="79e1dca4c87a158d36b171b11ec721a5"/><file name="Exception.php" hash="3182c2febc7a67988a02a2f4e3262c7c"/></dir><file name="Row.php" hash="adb2429446ad01b98bf74a1c79802009"/><dir name="Rowset"><file name="Abstract.php" hash="6474578f17e077f0d176de3d41bd43fa"/><file name="Exception.php" hash="c5e373d4e4d06e728572b3ca8c5d7d40"/></dir><file name="Rowset.php" hash="0534466fa3f58d60e28761013df1035d"/><dir name="Select"><file name="Exception.php" hash="c87230b6b7401370de518e6ad7218203"/></dir><file name="Select.php" hash="4a86cf29c8e383613e79caa5ef51ca36"/></dir><file name="Table.php" hash="bddf2a8c1ee791ef8a75fd81362a95b9"/></dir><file name="Db.php" hash="944811d3042ae76f201ce5ccee064693"/><file name="Debug.php" hash="e91277596844e74a3189f72b260d743f"/><dir name="Dojo"><file name="BuildLayer.php" hash="59fd3f007b9ddfe836308735a4fad349"/><file name="Data.php" hash="584f49393cc79deedcd43f36ff7cf68e"/><file name="Exception.php" hash="ce849ec1ac41925ce396495a4c0b5e5f"/><dir name="Form"><dir name="Decorator"><file name="AccordionContainer.php" hash="5ccfa22f987078a553c8334a1751a78e"/><file name="AccordionPane.php" hash="bfb6959fc54968e6e631a7b812f795cc"/><file name="BorderContainer.php" hash="3630699c89e4d611d463952ab7b616af"/><file name="ContentPane.php" hash="f5e7d589fc667a74c537f1c4a1d2f1ee"/><file name="DijitContainer.php" hash="6e30cb3a91ee447e6d9ae587a5b08fdc"/><file name="DijitElement.php" hash="63a591c8ae6f23a5fac3c4c4799849b6"/><file name="DijitForm.php" hash="3107c8e3a51efd7cd960a4d140fd2552"/><file name="SplitContainer.php" hash="32118776073ace34a7a6e6b775f7a41d"/><file name="StackContainer.php" hash="511f80fb7e777c7420df3a33e5d36df3"/><file name="TabContainer.php" hash="bfba332a70e20ac8e4bc1f9a7b488ffe"/></dir><file name="DisplayGroup.php" hash="4fc35365159beb7532119735b43ac5ae"/><dir name="Element"><file name="Button.php" hash="3ed66e9ab5b21731a355a35cc0bdadc5"/><file name="CheckBox.php" hash="cdf55f6261658dc12c508397228c86d5"/><file name="ComboBox.php" hash="ad263405d78671cb38f39a42f4153306"/><file name="CurrencyTextBox.php" hash="8a0101a9a7fdc7504fe882222df91d8b"/><file name="DateTextBox.php" hash="b1a766b9190c2c124d34d59d8c742f04"/><file name="Dijit.php" hash="8389aeca66aecb8a39d9341f81ded916"/><file name="DijitMulti.php" hash="bd0fe55261b57bcd2c92ea196eceaf08"/><file name="Editor.php" hash="bb3636533a931bc1f9a5782ac4c66565"/><file name="FilteringSelect.php" hash="d330a4330b410089733f8c1eeb1839e2"/><file name="HorizontalSlider.php" hash="b23bd0da212335080121f31e318f743d"/><file name="NumberSpinner.php" hash="9ae185b60accc9edb7baed24b93ca540"/><file name="NumberTextBox.php" hash="cc340c040ab7c8eaa02bf401a9a91bc3"/><file name="PasswordTextBox.php" hash="48b304d5bbfb2417adf1724362e032b6"/><file name="RadioButton.php" hash="80e8b86eaf8258626084f54272a7a576"/><file name="SimpleTextarea.php" hash="69791b92fb7d656676266fe53592b6b0"/><file name="Slider.php" hash="21f9f99bb495bcf2997a022f6a43c276"/><file name="SubmitButton.php" hash="52c7e25fd90d33b9501150746b046e14"/><file name="TextBox.php" hash="874413d9bf8c39f9a7a73d7175842cf5"/><file name="Textarea.php" hash="1fab8c9619163b0fd1cdeaf4bf4113c7"/><file name="TimeTextBox.php" hash="6ab9be9f6555bdc14ba9a02fb18c3157"/><file name="ValidationTextBox.php" hash="dd456a154f47bc74e05834800490ad53"/><file name="VerticalSlider.php" hash="c99c979911b12b2907b9ce727d595f42"/></dir><file name="SubForm.php" hash="46b28da42e2447cdf7f23ce8635a6243"/></dir><file name="Form.php" hash="5dc7b152deef6e0fedf0c0caa73f7c68"/><dir name="View"><file name="Exception.php" hash="fed5a27397fd8fb08841c1db38364df7"/><dir name="Helper"><file name="AccordionContainer.php" hash="3b2eaa765a22ea9a2d3d2e507da446b8"/><file name="AccordionPane.php" hash="94b8d5edb317926ca8aee3539c33ce8a"/><file name="BorderContainer.php" hash="f8b3939b919a3f961c8da6196b2166be"/><file name="Button.php" hash="e1e816f2362a2f973acceadb1414de98"/><file name="CheckBox.php" hash="43f1a6ad27883f62cda4bc1b560c9f89"/><file name="ComboBox.php" hash="d2811e390eb44a4f3e953c241949db0e"/><file name="ContentPane.php" hash="041084c11934376f3f759154a1835abf"/><file name="CurrencyTextBox.php" hash="56f2046e985a0d1cd81ba0d045f91a7a"/><file name="CustomDijit.php" hash="34bfe4e1501f8dc1227adcc9b7e2b20b"/><file name="DateTextBox.php" hash="81bdffce0b2acb693a7c2cbd3941f156"/><file name="Dijit.php" hash="7a1eb3742998cbbabac1b2338a590566"/><file name="DijitContainer.php" hash="3091a920fbfb48215a59f73be1988eaa"/><dir name="Dojo"><file name="Container.php" hash="e40d8395af2e395a2e81d593e8f4602c"/></dir><file name="Dojo.php" hash="6303c9d4ede5b67cc828ead89c4016a6"/><file name="Editor.php" hash="f251624a2b798b53eea465d9938ac276"/><file name="FilteringSelect.php" hash="60bbdd84239febff9241199104b4cf1a"/><file name="Form.php" hash="105f502558eb241c81c39be0e5d85a72"/><file name="HorizontalSlider.php" hash="7b3c19156aee3db41dbaee18abe2ded7"/><file name="NumberSpinner.php" hash="cf27c892acfeb8ba60027bba29d8715a"/><file name="NumberTextBox.php" hash="9674fa01666c5622896d4513da69ce8d"/><file name="PasswordTextBox.php" hash="0ba727cff497c3b580bffaf04eecc75b"/><file name="RadioButton.php" hash="ddd9733fd29a47cf20f224115895d2cb"/><file name="SimpleTextarea.php" hash="8162db2b947a8b380099ee4266bd2edb"/><file name="Slider.php" hash="b09cd129a4885cb799978b234e8ef496"/><file name="SplitContainer.php" hash="8fa96d45ff63d2b0f24250856afea806"/><file name="StackContainer.php" hash="f3f24abf9640124f26274b9663eccd5d"/><file name="SubmitButton.php" hash="9083d4797eb4be0a879951a88be9a6f3"/><file name="TabContainer.php" hash="8b6865aa0b8015b220896d3487ec0966"/><file name="TextBox.php" hash="75b65da85221b840ff6f3bd4d38890e2"/><file name="Textarea.php" hash="58421d644f61edc039bdaf8b2d13af7d"/><file name="TimeTextBox.php" hash="7865f42c62fd06ead74987324d2310d0"/><file name="ValidationTextBox.php" hash="59bc7469004e22811c038791462d67a7"/><file name="VerticalSlider.php" hash="9c113d757c1b99048d09ba8949452034"/></dir></dir></dir><file name="Dojo.php" hash="3d5a5b6120bb16fbde6a24fc082bb2e7"/><dir name="Dom"><file name="Exception.php" hash="764e44b0e7b8346387c4b677e725d6bf"/><dir name="Query"><file name="Css2Xpath.php" hash="84d8020779e37ed005fa2ca53052731c"/><file name="Result.php" hash="2c8f3fdb6f945804d2a2b5881b5c0567"/></dir><file name="Query.php" hash="ac0c71f2c7a030485756a780c2ca5904"/></dir><dir name="EventManager"><file name="Event.php" hash="73a22bba4a1536ad0bedb311992ed841"/><file name="EventCollection.php" hash="6846535fe1c08a148593082878839b2b"/><file name="EventDescription.php" hash="6cb5b7a743c322cc486c09de9e2466c1"/><file name="EventManager.php" hash="775973335393a6aab98b63fd7e580f6f"/><file name="EventManagerAware.php" hash="616ae31ca46f1f0206e28851f408e777"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4651b42388b3cc0f6a8c77b8c92a988f"/></dir><file name="Exception.php" hash="a7a76fcb8615694bebfd1b7a6c63cc2e"/><dir name="Filter"><file name="FilterIterator.php" hash="479bdbab563e57ade8718744d6a9eaed"/></dir><file name="Filter.php" hash="a6705be98a15d9abb250329a18bc5f44"/><file name="FilterChain.php" hash="0bbe4e22e4bd7731c91b0d8849e24dd4"/><file name="GlobalEventManager.php" hash="2448f17e7235ad32e0986dccaaf6f21f"/><file name="ListenerAggregate.php" hash="e0bf702bb54b9ba2d54828a2d66d2954"/><file name="ResponseCollection.php" hash="14500f355513b35b17a7dd7e947f5301"/><file name="SharedEventCollection.php" hash="0504cdf3c7168fa6e6a1d164705617c7"/><file name="SharedEventCollectionAware.php" hash="c53dea67b8742191c78911a87cf4c1c5"/><file name="SharedEventManager.php" hash="973daf2597a36f485ec43ae91f53fbef"/><file name="StaticEventManager.php" hash="47bc3c834d44e64eab6ea0b0c0a83eba"/></dir><file name="Exception.php" hash="fdca55eece8acc76af7ec98eca620311"/><dir name="Feed"><file name="Abstract.php" hash="66b85329fd8524fc66b93c16397cc49d"/><file name="Atom.php" hash="24d80774c71e1932b8be5054793d4fd6"/><dir name="Builder"><file name="Entry.php" hash="4871eb1a5d2084552d48b346fb9424ae"/><file name="Exception.php" hash="f8d2074819dd7157b4de4428579958c9"/><dir name="Header"><file name="Itunes.php" hash="da87e20a7e6b587316644377c8cc3c55"/></dir><file name="Header.php" hash="7e1b1053ef90762e3b6d9933cab4964b"/><file name="Interface.php" hash="407dbfd89e522c6e033214974954ad9c"/></dir><file name="Builder.php" hash="9453c5958f2cc22bd37a1e8e8de22ff7"/><file name="Element.php" hash="04f6a067ec047936af106f5a3ee9f0ee"/><dir name="Entry"><file name="Abstract.php" hash="44340d16439984b02edd6f26d7a1885e"/><file name="Atom.php" hash="a2642776469712e0e2dfcc0912e98aa3"/><file name="Rss.php" hash="93e478df77e9c9c43c55334ce2165a8d"/></dir><file name="Exception.php" hash="3ce015184369dd3392923dba02ccb4ab"/><dir name="Pubsubhubbub"><file name="CallbackAbstract.php" hash="5fc3da695c59069c88f54206485038c9"/><file name="CallbackInterface.php" hash="3b8478bc6bac3d9309c0fe7ba6f89dd0"/><file name="Exception.php" hash="028e2d741379246df90e62b96393ffe9"/><file name="HttpResponse.php" hash="6a929e3ac877b89fd0b8664b9894f953"/><dir name="Model"><file name="ModelAbstract.php" hash="ce0a0b0b03f77348b066a947e4d4a087"/><file name="Subscription.php" hash="99c0b396f4e21b0fe2bc3c068220958e"/><file name="SubscriptionInterface.php" hash="63f95bde2e9254d0e3c31b905fea78bc"/></dir><file name="Publisher.php" hash="44d781a089ad5ac1ee949b74badad6ca"/><dir name="Subscriber"><file name="Callback.php" hash="c50e22f4bec18ed4365b7a7fd472db69"/></dir><file name="Subscriber.php" hash="3a06e76251527da315017fd545595ee2"/></dir><file name="Pubsubhubbub.php" hash="9187f4accebd9b1b23010e141485f2c8"/><dir name="Reader"><dir name="Collection"><file name="Author.php" hash="bd0aee1688a6905cfa60ad3df2876d42"/><file name="Category.php" hash="0ac74f5a4ea9492998e7f76e6e959283"/><file name="CollectionAbstract.php" hash="a0d023979ca9ca7c2fdf93e0acb36745"/></dir><file name="Collection.php" hash="6a92b8355578f92468d24f03c33f6e7b"/><dir name="Entry"><file name="Atom.php" hash="c4f9ba356c97d5ad4ad6a5a210fa5d31"/><file name="Rss.php" hash="01b9d9b750ec9c730bc3fa624629deeb"/></dir><file name="EntryAbstract.php" hash="b9e05d05ad657e24bca3947764bf4aba"/><file name="EntryInterface.php" hash="3e33c60c08158ac0398bb9f05ec2090b"/><dir name="Extension"><dir name="Atom"><file name="Entry.php" hash="6baacc2e3ddc23ad3cfa9e190fd54157"/><file name="Feed.php" hash="16e84c49d96b759d10b1fe86982cca2f"/></dir><dir name="Content"><file name="Entry.php" hash="4a01e7b785bc08518739d03825f8c7af"/></dir><dir name="CreativeCommons"><file name="Entry.php" hash="4c7cc6a5ddcb6971e2a7d30c701151b7"/><file name="Feed.php" hash="40b8c9f5146271c2fe7433f7daff07ac"/></dir><dir name="DublinCore"><file name="Entry.php" hash="3ff54fc3fe5df35c8ba4075ed42dabeb"/><file name="Feed.php" hash="56f06a3e2739c70c66da54e7608c9496"/></dir><file name="EntryAbstract.php" hash="fb62ce68f7a440fac11ec666e9e4bc22"/><file name="FeedAbstract.php" hash="c1283a62809662e762cd0a7875b0b913"/><dir name="Podcast"><file name="Entry.php" hash="738c47a9b19c44bedbce6a6e901ee173"/><file name="Feed.php" hash="23c593352bc891c6bbce22e98da18f6e"/></dir><dir name="Slash"><file name="Entry.php" hash="29d24797987342ea6a580a48af0accb5"/></dir><dir name="Syndication"><file name="Feed.php" hash="67ec064681ba8a77b4f6d44a35d4d8f7"/></dir><dir name="Thread"><file name="Entry.php" hash="202da1cb171c55d435b125cfb264d874"/></dir><dir name="WellFormedWeb"><file name="Entry.php" hash="88c3ee8f88632712522d206426a2927c"/></dir></dir><dir name="Feed"><dir name="Atom"><file name="Source.php" hash="71d4bceda67dd3a4acbc45bbee33853a"/></dir><file name="Atom.php" hash="042c93075ae2e933e5241750c101d3de"/><file name="Rss.php" hash="e354bd24fbf48a5bab9d518e3912bd93"/></dir><file name="FeedAbstract.php" hash="e577cfdd039f4025877f12d2d08dcce6"/><file name="FeedInterface.php" hash="7eaed63ef055848aa1b299bc98d8cc11"/><file name="FeedSet.php" hash="5ba5f156ac7607b73929dac85826c659"/></dir><file name="Reader.php" hash="d9bc6e5b898eb8be4fa72e313e89bccb"/><file name="Rss.php" hash="e14ca674ad56d9ce18df5d9728c770bc"/><dir name="Writer"><file name="Deleted.php" hash="35aad5db793b86ca638a81d052c6ae14"/><file name="Entry.php" hash="87c1a1d4b637d4918f5fabe8b56c1a9a"/><dir name="Exception"><file name="InvalidMethodException.php" hash="02419d36ca4d923b7ae46f8cf5e9808b"/></dir><dir name="Extension"><dir name="Atom"><dir name="Renderer"><file name="Feed.php" hash="e1c642e0775de8ace9639daff1a932aa"/></dir></dir><dir name="Content"><dir name="Renderer"><file name="Entry.php" hash="f86cd399902d04ab6652aa952c81916f"/></dir></dir><dir name="DublinCore"><dir name="Renderer"><file name="Entry.php" hash="6f79082f7b75e1d7b73930169ff6d5e0"/><file name="Feed.php" hash="8b6825b40579ce795e0018eac48a0fa6"/></dir></dir><dir name="ITunes"><file name="Entry.php" hash="e23d802f1cc74b432a3c5362be650c55"/><file name="Feed.php" hash="ffa388bb1b1c868a92978ee85f3c8d50"/><dir name="Renderer"><file name="Entry.php" hash="184f5e6f780c987cb55374c6b899dee2"/><file name="Feed.php" hash="c5df3307f99f2349024d3a31612d67a5"/></dir></dir><file name="RendererAbstract.php" hash="427c8bd29a3f0aec64f2034405b8fa89"/><file name="RendererInterface.php" hash="2cbb9d13b450a08098921fe99f5084bf"/><dir name="Slash"><dir name="Renderer"><file name="Entry.php" hash="95b4d946971ccd12e852d36125e241ad"/></dir></dir><dir name="Threading"><dir name="Renderer"><file name="Entry.php" hash="81fa4f73e25ce35482f8ea2d01ceac48"/></dir></dir><dir name="WellFormedWeb"><dir name="Renderer"><file name="Entry.php" hash="45c4795ca01add23d35af6ca1961a27b"/></dir></dir></dir><dir name="Feed"><file name="FeedAbstract.php" hash="65fa012f95547e0e63deb8715038c9c0"/></dir><file name="Feed.php" hash="699463ea19aa24d3cf48d9ddf37d63d4"/><dir name="Renderer"><dir name="Entry"><dir name="Atom"><file name="Deleted.php" hash="65126201b8fb20b29f945956c3c7aa14"/></dir><file name="Atom.php" hash="fd98f2be04963b4a660c49cd0bb9db5e"/><file name="Rss.php" hash="f0e70e6a183416e6c04a1aa58d91b128"/></dir><dir name="Feed"><dir name="Atom"><file name="AtomAbstract.php" hash="2762eb27cc4182026d7cb5d4a2d8e7d0"/><file name="Source.php" hash="b4432fc84152c9922c2a0318043431e2"/></dir><file name="Atom.php" hash="a4e0a7056233cc18c1abcbcf45895b3a"/><file name="Rss.php" hash="b01a32487ec79c8e29848e56d12f4fef"/></dir><file name="RendererAbstract.php" hash="e818b72ef7cccb7e411218194c4a90c2"/><file name="RendererInterface.php" hash="b9d0002ea9fd72117b6438231ca2db9e"/></dir><file name="Source.php" hash="3cce4bf24782f65948e0078eee3af8b8"/></dir><file name="Writer.php" hash="31915fe86b889b38f29cd365dfa2eef8"/></dir><file name="Feed.php" hash="90930372cd8489f1be5480df69e492a3"/><dir name="File"><file name="ClassFileLocator.php" hash="a763041253fb82e55d99e50078f9e791"/><file name="PhpClassFile.php" hash="95812fdfe2ea77215eaf98220970d2bc"/><dir name="Transfer"><dir name="Adapter"><file name="Abstract.php" hash="9f8caf0965ee20c3e394cc9abd39dc64"/><file name="Http.php" hash="98db3d564539a149becd025db2996089"/></dir><file name="Exception.php" hash="825fcee61f10cdfe37140f8053177a3f"/></dir><file name="Transfer.php" hash="3b238f59905a999aa851bd4e7b641d64"/></dir><dir name="Filter"><file name="Alnum.php" hash="4ca46f20de00a3ae2c141f1ceff56bad"/><file name="Alpha.php" hash="5b07ed4ed80ac52058355dc25eab7f17"/><file name="BaseName.php" hash="625ce144adaded5d1a792f2cdff08ddb"/><file name="Boolean.php" hash="8a4ccc8b5fe35cc6371f2a876c1687c4"/><file name="Callback.php" hash="877df95b6818f3919ff98ef2b792beab"/><dir name="Compress"><file name="Bz2.php" hash="85a13672065e12d52a4a53c7d57b5956"/><file name="CompressAbstract.php" hash="e31d6c9f72772def373f5f947ebb4857"/><file name="CompressInterface.php" hash="fea3425ce29a7262ac9aa37ca15e7ccd"/><file name="Gz.php" hash="e1a5c9d4301ba780b0fc2a2ab69b9cef"/><file name="Lzf.php" hash="238dbeb23d34fab2ce1fd53c5728c981"/><file name="Rar.php" hash="ee424491867ca2fce1556bdcf01e0a7f"/><file name="Tar.php" hash="e9fc01174f800ebf4e87294361714fe8"/><file name="Zip.php" hash="1adcddd63511b526c388dbbfb2693ca5"/></dir><file name="Compress.php" hash="17af88fb4588855a0fa2ad0c747e567c"/><file name="Decompress.php" hash="9900b029a91c9c1620903061b15d8b5d"/><file name="Decrypt.php" hash="ea36fb417859a47bc8090908f91c79b0"/><file name="Digits.php" hash="988e652d047ccb2b3f51368702b39932"/><file name="Dir.php" hash="ded6da050ac44e21c8729c4fd74559f0"/><dir name="Encrypt"><file name="Interface.php" hash="02481da5488767e23939a73b434d6728"/><file name="Mcrypt.php" hash="2320868b4e3235e934023f6339edb9ee"/><file name="Openssl.php" hash="37f02c9e5fd864557aca070ca8525e36"/></dir><file name="Encrypt.php" hash="41b1fa4536947b9ce5e4dcadb3bf80b7"/><file name="Exception.php" hash="ee7fa3aa3daed6b376e4fe3ff0533a65"/><dir name="File"><file name="Decrypt.php" hash="f82c770a201d0016ed0054874f39c90f"/><file name="Encrypt.php" hash="63c6232b0c216381bee8c18df751ab59"/><file name="LowerCase.php" hash="664f911dfcba8fb26ad86605eda4ad93"/><file name="Rename.php" hash="d854b8b98abd89db4d4b0eca30a2b496"/><file name="UpperCase.php" hash="9aad43cc07b024188734fe231ec7a80e"/></dir><file name="HtmlEntities.php" hash="6ce1c0425b0b5f48c21649c15ffe1d26"/><file name="Inflector.php" hash="b6b671c8956fe8c359af7739c56867a8"/><file name="Input.php" hash="fc8cc25c2f9da1b1da7b2839eb914c99"/><file name="Int.php" hash="41724f5b9f96f08b6b01281891bc3eab"/><file name="Interface.php" hash="0f810dcab23fc1f455c960af3f317a04"/><file name="LocalizedToNormalized.php" hash="6b98acca5dc278027620e0d5361a316e"/><file name="NormalizedToLocalized.php" hash="27f9795714f46c3d4a143330e77219ce"/><file name="Null.php" hash="fe5c2ff3f08d7ef9ffc140ad251dd6da"/><file name="PregReplace.php" hash="7b0c18825dcc9016d0cc2a0fea8fee53"/><file name="RealPath.php" hash="133f0776eaa042a0712e2d8e7db3ed7c"/><file name="StringToLower.php" hash="9a7352bfa73b4ac825bc2af9fef3c286"/><file name="StringToUpper.php" hash="ec2165f772585dcf346b589bbf9bc716"/><file name="StringTrim.php" hash="ca76b8743fd9ec88290ef11a24d48a03"/><file name="StripNewlines.php" hash="fe69c99129f9bd2b69ea16c0bbfc61c1"/><file name="StripTags.php" hash="78d7393075f2327644e873d4e9196082"/><dir name="Word"><file name="CamelCaseToDash.php" hash="3793e4ef36c6778b9e5df032dfc15b67"/><file name="CamelCaseToSeparator.php" hash="cd445e16f5d3ef145c4b0f35a10b1dcd"/><file name="CamelCaseToUnderscore.php" hash="932bcf0ead2bda7d9ba9544458fe2de8"/><file name="DashToCamelCase.php" hash="705245ae67e4a9eede0bb3c0bf0e6ac4"/><file name="DashToSeparator.php" hash="6edcb2382b8fc7acc8448679d6fb46b4"/><file name="DashToUnderscore.php" hash="1075b2edc67d246d7f300c336a00a745"/><dir name="Separator"><file name="Abstract.php" hash="7c13a127a26229fc8d5e0678e8efcb5f"/></dir><file name="SeparatorToCamelCase.php" hash="87f3c3a2ab24e2146db100710050d873"/><file name="SeparatorToDash.php" hash="d13f2d966ffd8cfb05114fbb9f3906b1"/><file name="SeparatorToSeparator.php" hash="3f70eae82b1616c098cd9aec7be41f9c"/><file name="UnderscoreToCamelCase.php" hash="5f19c37337b901edd5fe5080a8353116"/><file name="UnderscoreToDash.php" hash="2f25783e6e165b827fc113f046f30f44"/><file name="UnderscoreToSeparator.php" hash="b0e92b24b679b3dcbee459cd752a2478"/></dir></dir><file name="Filter.php" hash="383fca34ab08e0a803adb2c7766fad95"/><dir name="Form"><dir name="Decorator"><file name="Abstract.php" hash="8522e625655a35646b477ad4ff99dfe5"/><file name="Callback.php" hash="190782b871a222c75dfc8444b863da11"/><dir name="Captcha"><file name="ReCaptcha.php" hash="39b4156e05bfd86a8bc607c94f437e32"/><file name="Word.php" hash="880894024cfbed08b5f1078076512a25"/></dir><file name="Captcha.php" hash="1d07f76a5ba267e35b801bbfa6437b1f"/><file name="Description.php" hash="4c386b676076f9d5839eea503b633567"/><file name="DtDdWrapper.php" hash="124076232159f0fa26fc9fe67685830f"/><file name="Errors.php" hash="e10d634460b6dae52065a83cd5c3b3a2"/><file name="Exception.php" hash="7540f704e53237cd3a6715d1e480c3b9"/><file name="Fieldset.php" hash="6bd5c5b9ff8e9e489e5a7c560aff175a"/><file name="File.php" hash="c06f2200db61e4ebffa266d99260c726"/><file name="Form.php" hash="c0117ea6a352a32b780baae652d717b9"/><file name="FormElements.php" hash="8cb9c8f03fb877b45696b534c1b39b14"/><file name="FormErrors.php" hash="723036887204776c398e63c715b762fa"/><file name="HtmlTag.php" hash="2b90f769619b1e6624e14922dc2c32ec"/><file name="Image.php" hash="2a1a7dd1624ee71cfc13b7c96b4796e9"/><file name="Interface.php" hash="60d51f6f15d396b5a16519ba5eeec204"/><file name="Label.php" hash="277f64b41efc25890d78eba58db9b780"/><dir name="Marker"><dir name="File"><file name="Interface.php" hash="30667e6ff2ccced89c3b62cf0e13f931"/></dir></dir><file name="PrepareElements.php" hash="0ff6fb16d6c5a748c9c3d3e48037755d"/><file name="Tooltip.php" hash="bb7394628ade765908544c69c6790844"/><file name="ViewHelper.php" hash="c5cc8db2e0cec01b77be69fa2e1b9299"/><file name="ViewScript.php" hash="23ef6fc6fdac5fd8c9105738c5cd3ccf"/></dir><file name="DisplayGroup.php" hash="ee080ba86203eeb41ac17d38877651f5"/><dir name="Element"><file name="Button.php" hash="730df0b76e3957882f877197447d5f1d"/><file name="Captcha.php" hash="0752ad99fb0f43536c91367c70a494df"/><file name="Checkbox.php" hash="e39255d645c7c1b2ac042cc64c2e7cc9"/><file name="Exception.php" hash="c1a78bc6fbcad9d8544ef102ee578bd7"/><file name="File.php" hash="8a78cdb33c6d598fee1f22fe008e7479"/><file name="Hash.php" hash="98a63f7085dc662488f510b8341a450a"/><file name="Hidden.php" hash="4f1b7d49e10c937cbe9bc1f481a24e9e"/><file name="Image.php" hash="050990ff646853c7def62d5912a3a57e"/><file name="Multi.php" hash="546108cee3f938abc94159392b279638"/><file name="MultiCheckbox.php" hash="8da3e1c8f63673889aa82c8a477bc19e"/><file name="Multiselect.php" hash="70685894797a172bfbfeed0b3ca0c8c9"/><file name="Note.php" hash="db0386ab8c66da2df8c912e37b11110f"/><file name="Password.php" hash="4cee94cd5c56812e101f9cae256d79cf"/><file name="Radio.php" hash="088e0a26f8b959fd252edc7080cbe3c6"/><file name="Reset.php" hash="782f1aa0cbe1a792a0d05a51d58d8beb"/><file name="Select.php" hash="ee8919ec27665b02cc44cc0083609878"/><file name="Submit.php" hash="0a97601d86f82bd50d3ea6777937254c"/><file name="Text.php" hash="781ee2e638e37fc613ad760bbd2d30bb"/><file name="Textarea.php" hash="85a7119e8e0fa3377b0576b16aa05c51"/><file name="Xhtml.php" hash="4c20761fbbb7ca24ea9b49ac3cd41e58"/></dir><file name="Element.php" hash="f03fcc6dcd7b3e0da5a36046d36d727f"/><file name="Exception.php" hash="d33a48b9d1ec7e213210383b1f7bca68"/><file name="SubForm.php" hash="ba968be3402ccdf8b4185f4d53234120"/></dir><file name="Form.php" hash="4001592cf753a1170ba2cf1c178c17ce"/><dir name="Gdata"><dir name="Analytics"><file name="AccountEntry.php" hash="e12468f4c63d78e8edecbc473933aa4a"/><file name="AccountFeed.php" hash="a2f9b14dbdc470693a82907f57c4d258"/><file name="AccountQuery.php" hash="8f5b153ae38c2c0598dcdd0f4ca851a4"/><file name="DataEntry.php" hash="e45ec9042ba8356cdf29505e1e9e2d0b"/><file name="DataFeed.php" hash="5db9ffeb61cefb3659e9be8400ed20e8"/><file name="DataQuery.php" hash="f42425d8f43dada50bb8f128d8f975f6"/><dir name="Extension"><file name="Dimension.php" hash="38282ab7af5abb515f4aa658f820fc34"/><file name="Goal.php" hash="2c46c1d7db9b5f507a47e4bb121e2b4c"/><file name="Metric.php" hash="8560747659930f23b28cc94bd837440b"/><file name="Property.php" hash="d1ba271f052e44a1152eed24533824b0"/><file name="TableId.php" hash="60e5a4486c861d393b6f3183c2485267"/></dir></dir><file name="Analytics.php" hash="a97cd7d0faa0f65351e65f55c28fcc60"/><dir name="App"><file name="AuthException.php" hash="6f8d23065cd17d239b2cec093015ad8e"/><file name="BadMethodCallException.php" hash="86fe8ce683680f512145d94a22ab21d5"/><file name="Base.php" hash="109e590e151826d3347d1f2f58dcab56"/><file name="BaseMediaSource.php" hash="d1ec6648e8c89711225d42a07e4738d7"/><file name="CaptchaRequiredException.php" hash="7a3e3893b6f8a9c282d920acb9928e21"/><file name="Entry.php" hash="06786f3fe9e30b60c79888be9c70c067"/><file name="Exception.php" hash="82c41ada4e9863867adb2795fe7b1ca0"/><dir name="Extension"><file name="Author.php" hash="2df6f04ec34d35d1d79bbd189a9c53a8"/><file name="Category.php" hash="273bbd08b463d8394b8528294f2f43ef"/><file name="Content.php" hash="ba2ae463fc480db7c017c495c47f8380"/><file name="Contributor.php" hash="b06a5ee82e874422c7053e9bc4efa7a7"/><file name="Control.php" hash="2215659703162befaa49e7a18ad7abe1"/><file name="Draft.php" hash="45da888e1837d3002d099e483cc4e117"/><file name="Edited.php" hash="94503a1886214c959eb189dc1331a1e3"/><file name="Element.php" hash="1ff84c0f8b8e3e9be1edf28774125044"/><file name="Email.php" hash="f3733ecc80e481cd3e35b93df18a216d"/><file name="Generator.php" hash="aef1362208e44f2be51e4094089b4795"/><file name="Icon.php" hash="36d027f0cf96a2deb42b6c1aab0468ef"/><file name="Id.php" hash="9609dfb9218d0b8263086504e6b0d63c"/><file name="Link.php" hash="de21b9578b8592c5b3e3fcfb84419671"/><file name="Logo.php" hash="23c88a04e6897da7a7606733d5880094"/><file name="Name.php" hash="bcefb468fb70012b66b7322b1b9c618f"/><file name="Person.php" hash="5190427185a73d6cd253d4ad37d3130e"/><file name="Published.php" hash="f5b6d374545f8fea7382644413c786ee"/><file name="Rights.php" hash="add154a43b16eea075f70fef1dc0c614"/><file name="Source.php" hash="9b5c51a557d100b8d32f04c2e631d51e"/><file name="Subtitle.php" hash="87ccbc9582dabb57b4e5254c3cdb5419"/><file name="Summary.php" hash="308fcbd2860bac275a68bbaa455d75e5"/><file name="Text.php" hash="bcb0f1d994917499bb98c2045839cf78"/><file name="Title.php" hash="37736e9d970dbfb6508fe95c8b1d4c4a"/><file name="Updated.php" hash="3a00f1cac5e73b47fe960a4568d753a2"/><file name="Uri.php" hash="c8a0fd8b1e0ef4620dcb4f8d3bdf2f02"/></dir><file name="Extension.php" hash="e8d500cede8625e9a513241cb9340b8b"/><file name="Feed.php" hash="2a9b8a370e645cac248df5cec9752bf4"/><file name="FeedEntryParent.php" hash="03a2448db19430ce9d63af5a794c49ee"/><file name="FeedSourceParent.php" hash="ad513f8bba194a7c597d62332e1b748d"/><file name="HttpException.php" hash="e235854ac6db814217beb8e0f4432bda"/><file name="IOException.php" hash="4fe86dbdc8efd68b4f4e91eb720476fe"/><file name="InvalidArgumentException.php" hash="bb79aa3b093b89f2d1740e3de29c591b"/><file name="LoggingHttpClientAdapterSocket.php" hash="6c6fcbec1d914d2f0f1b4c9f9f9d6ded"/><file name="MediaEntry.php" hash="665829aa3a0b00efad9d39516ac20296"/><file name="MediaFileSource.php" hash="33e29faf6b09ad55399f8c4605de560b"/><file name="MediaSource.php" hash="956d976c017eb2969ec6980ba6a10227"/><file name="Util.php" hash="a978ace39e376ebb7a77168bb980e500"/><file name="VersionException.php" hash="46a96dcdf49d163f2b558f6af76770f8"/></dir><file name="App.php" hash="0611ada3705cf91a416144719aa34f4d"/><file name="AuthSub.php" hash="7d6c8fa90f00569465838f7485e6f8c9"/><dir name="Books"><file name="CollectionEntry.php" hash="e9400464091b197c1406c31904c89f46"/><file name="CollectionFeed.php" hash="50eb4262a08af25008fc23dc8ce38261"/><dir name="Extension"><file name="AnnotationLink.php" hash="229515a8187537875bec1df18a216e70"/><file name="BooksCategory.php" hash="94043b4e41582b92bd585a2f6ca55401"/><file name="BooksLink.php" hash="d4d4d737a079e5a06f9ec239156acc3b"/><file name="Embeddability.php" hash="02ea13af1b4c9e4bdf019cf85bd2e1e3"/><file name="InfoLink.php" hash="e901bc048235143eca51ac93750e148f"/><file name="PreviewLink.php" hash="96cc9f7155d4a8420b59dfab337df144"/><file name="Review.php" hash="8263c22752814fc5b8ed79f5b8fb0c64"/><file name="ThumbnailLink.php" hash="d39c8c46fdcd113b6e78b0a291e3fb7e"/><file name="Viewability.php" hash="00ab00c410d09d756c1f4eac2617dd85"/></dir><file name="VolumeEntry.php" hash="c792cd0a1600d1f82b359e4488ca96d6"/><file name="VolumeFeed.php" hash="df63b570832f03352f8fd9caf5dd0ad9"/><file name="VolumeQuery.php" hash="7c4eafbfe2dffe63d19da553d7116784"/></dir><file name="Books.php" hash="2b24e8b1f35eeb6c045c82aaea8ff279"/><dir name="Calendar"><file name="EventEntry.php" hash="3a8929e9b816b58b948bb27c5f5b7b11"/><file name="EventFeed.php" hash="cb77e63f75b7b00e3ad977160bf1df3b"/><file name="EventQuery.php" hash="c87b0d6fb40e7b41509bbf0c72c35563"/><dir name="Extension"><file name="AccessLevel.php" hash="0c08117546cfc5687e831e7c1c911386"/><file name="Color.php" hash="173b3b7765f71816d9474b4d662fa78b"/><file name="Hidden.php" hash="e013d7fa1de0281467fd342b68d82e47"/><file name="Link.php" hash="9024ffbc848c26dc7142791d334ed4c6"/><file name="QuickAdd.php" hash="b27ef7921a5f849c6d3670e80205a826"/><file name="Selected.php" hash="af19756358007c35c1e97b25d3c40f98"/><file name="SendEventNotifications.php" hash="ad25cf943facb4ca07b5eea08b29d6c0"/><file name="Timezone.php" hash="f42b5243c11888a5ba4075b0e9663d64"/><file name="WebContent.php" hash="b7097ddc1f180e4a85097a414b96bba9"/></dir><file name="ListEntry.php" hash="0579d1450de838b1b893f9720a7dacc1"/><file name="ListFeed.php" hash="e21a404f7d250f78fdac64f729d2b377"/></dir><file name="Calendar.php" hash="507e33fa6d185c57b0c2c351c0fbc060"/><file name="ClientLogin.php" hash="d5025122f58267716ea25d7546da7d62"/><dir name="Docs"><file name="DocumentListEntry.php" hash="08219506950f07c0cb16e1196dc4e09c"/><file name="DocumentListFeed.php" hash="dd7d591781ad9cf3293f73bc94e64e78"/><file name="Query.php" hash="e6c962a8f8cfe02d3ca0701b932dd5c9"/></dir><file name="Docs.php" hash="f29d7a621a95734e8b83a4afa5a6fe42"/><dir name="DublinCore"><dir name="Extension"><file name="Creator.php" hash="c56d34f65d24a0ad25e60a4e913fd54a"/><file name="Date.php" hash="54b46f21e08d7ca7d230c6b7e83e7210"/><file name="Description.php" hash="6f4bb927deae9cb5b501b37e4cbdeca7"/><file name="Format.php" hash="a2eb4fd88c1197f1b122adfcca64e4c5"/><file name="Identifier.php" hash="7900202e14b61bf0323069f736521521"/><file name="Language.php" hash="b47e4dafd3fcebd4d11b4ac0806cea70"/><file name="Publisher.php" hash="1660d7ee8e0fa26d24376ed8414849e3"/><file name="Rights.php" hash="1cddf53544c56ad8a29f012f1501501e"/><file name="Subject.php" hash="a287af1b176e22b3f7001e4a8d69129f"/><file name="Title.php" hash="77bbd2f9afb01b6337b03b12c19cd0ba"/></dir></dir><file name="DublinCore.php" hash="6fa896e35490d67182eb013b08ef6d75"/><file name="Entry.php" hash="b2f85f13672d64d288bbcf9824058488"/><dir name="Exif"><file name="Entry.php" hash="cba9027e69ca0d3431f5fa8e84519d22"/><dir name="Extension"><file name="Distance.php" hash="69d8d71b3c8f02fd85e22e72453f5e7c"/><file name="Exposure.php" hash="5b4f1e1c91ada58e661412e391c9167c"/><file name="FStop.php" hash="78c90acf5134d6a8cd7debc8dfff3942"/><file name="Flash.php" hash="bc1c363115d8ee05fc043ae829ca9398"/><file name="FocalLength.php" hash="ba8dba20995e7ad0dc5fbe056a13a431"/><file name="ImageUniqueId.php" hash="3007c391ed138e7db78cca05ad964cb5"/><file name="Iso.php" hash="9b7340beb6cd2f991d0b590da9929207"/><file name="Make.php" hash="b96528e1c95904dcf7a32b6d2b855c4a"/><file name="Model.php" hash="de354ebd3ac53b26c7ba7d07b7eaf74e"/><file name="Tags.php" hash="0b6dca99d61d601cd89ddfe6d9af5990"/><file name="Time.php" hash="880ab5825cab35d85036460d54b18148"/></dir><file name="Feed.php" hash="d102e026496f926fa8dbf0024e75ea22"/></dir><file name="Exif.php" hash="31c98117fa58af3fbc8a9504aed7f05d"/><dir name="Extension"><file name="AttendeeStatus.php" hash="dac3c0490bccbf09f924948ad44232cd"/><file name="AttendeeType.php" hash="3b42bd943b0536d5bde7e735fd8615d4"/><file name="Comments.php" hash="9afbcf4a4ce1d7dd52706e0e8928a8ee"/><file name="EntryLink.php" hash="5a280e630417eb616c257813c3ead727"/><file name="EventStatus.php" hash="61f988f2bfafa564543cabe4e7f86f29"/><file name="ExtendedProperty.php" hash="2d80f08e6e2e79da98134e959b58fbbd"/><file name="FeedLink.php" hash="679a6f5c9ebed486b6b41bac1522fba3"/><file name="OpenSearchItemsPerPage.php" hash="8430c39b6ce1bfb8deb8d2ff4070edf6"/><file name="OpenSearchStartIndex.php" hash="118645c4f8d38b135ebdd9792ba30234"/><file name="OpenSearchTotalResults.php" hash="8e7bbe094d00d023b1ac76184bbc871c"/><file name="OriginalEvent.php" hash="799806cbff3654b92028550a96d3f418"/><file name="Rating.php" hash="96f79437551070a76a0ffc8cf0ce3f93"/><file name="Recurrence.php" hash="da2e478f7368e9fae3e91aa4975769b9"/><file name="RecurrenceException.php" hash="1565fac963250d130a9a18d0e87a9462"/><file name="Reminder.php" hash="84525523e8827d09cda261f02f4c4214"/><file name="Transparency.php" hash="2c99f3896ceaa90632f565d3910eba43"/><file name="Visibility.php" hash="df49298225481498f3a082cc88092ed6"/><file name="When.php" hash="4a02d7db9ade6210d5d01fd401938732"/><file name="Where.php" hash="5d1d9557f1a8a24be5c6076464f35cda"/><file name="Who.php" hash="8d3c827558b62b6fbbdb1786bc6dc8f0"/></dir><file name="Extension.php" hash="3dbf28598313aea3fbcb6ae0a9218373"/><file name="Feed.php" hash="8ae61588a220ed9e612bd0d306ed7be9"/><dir name="Gapps"><file name="EmailListEntry.php" hash="beeaa4d8624538255fd4fa414bf2aa2b"/><file name="EmailListFeed.php" hash="dae8f9390c01ce354aacf7a03b56faa3"/><file name="EmailListQuery.php" hash="38e4255133125d1c3cd461769ff2bbf6"/><file name="EmailListRecipientEntry.php" hash="5042400a2ccf63b598d11098c08a02a8"/><file name="EmailListRecipientFeed.php" hash="e67f7530086c3c3de9bf49ce731ba816"/><file name="EmailListRecipientQuery.php" hash="6b48a9d58feb39241c63a1c448259894"/><file name="Error.php" hash="2739432a885e3aa64112124acf85666a"/><dir name="Extension"><file name="EmailList.php" hash="d83a001f6b79d69a55a534c352df4518"/><file name="Login.php" hash="068572b0a7d975d816564d334aa6cf07"/><file name="Name.php" hash="b895fe7b562ab015bc391c82be75d63e"/><file name="Nickname.php" hash="12ce7eb02489b501861272c13acec59d"/><file name="Property.php" hash="4517466631d6a91e771e3eba6c4d028e"/><file name="Quota.php" hash="18a9c44fdf6146c74b51d123c00bd7d4"/></dir><file name="GroupEntry.php" hash="5c36b2030c5394629693de197c909286"/><file name="GroupFeed.php" hash="13b68ebe7768fabe2f408b5a317bb088"/><file name="GroupQuery.php" hash="fc3f172f6fda1a3b50c6c8c2f3beebd6"/><file name="MemberEntry.php" hash="987fddd8e68938e62d4fb4c80a0b7586"/><file name="MemberFeed.php" hash="aaec820fc096293a6e6f4e5dc9a213a7"/><file name="MemberQuery.php" hash="1fe4b7f18ca161de836a9bf2b18cf123"/><file name="NicknameEntry.php" hash="f0fbcba505a6cac9d64328acf86c168a"/><file name="NicknameFeed.php" hash="80df6633ccad4aea2f1b0ff1fc56fedc"/><file name="NicknameQuery.php" hash="b3fc90f01854679f692ca2d34f1ef867"/><file name="OwnerEntry.php" hash="a66d48e8d46fddf2a9e3ea0330bcea45"/><file name="OwnerFeed.php" hash="98123454cb3cc6dc134d9ad827d297b2"/><file name="OwnerQuery.php" hash="5c829232390b828f06565012b2af3ce6"/><file name="Query.php" hash="a893bb0bebd43c558fac8f7b58477577"/><file name="ServiceException.php" hash="e62bc29c1a67ab44455ebc10fb033887"/><file name="UserEntry.php" hash="327e60ce8bad4fad8aa9d785902a0488"/><file name="UserFeed.php" hash="12a6e44ebb6b809f1ab17884c957d034"/><file name="UserQuery.php" hash="36d9b6e3c53812f1a0b3ba58b8348d1f"/></dir><file name="Gapps.php" hash="006b69cd2b4bb52efbc481cba3ded85d"/><dir name="Gbase"><file name="Entry.php" hash="d1c0594bd7f509ee8b71a0d4c6e93cef"/><dir name="Extension"><file name="BaseAttribute.php" hash="9860f259d07b1d7c48953ac145e91173"/></dir><file name="Feed.php" hash="a3a9a55b4dafc0c71da475d0b8ab4ed3"/><file name="ItemEntry.php" hash="4ad3d155cdb9fce8010cb9ff27d3ff54"/><file name="ItemFeed.php" hash="44ffbf3810fe7d602fa50a219f4d0c6b"/><file name="ItemQuery.php" hash="d85aa16b033dfc7478cbfa9cd38cbd69"/><file name="Query.php" hash="feaa71301ffc82297a5c768b267ff5b2"/><file name="SnippetEntry.php" hash="023249497ffc22f6fbad8645c50dc78d"/><file name="SnippetFeed.php" hash="5197182ca6edcf33fa8452f809597510"/><file name="SnippetQuery.php" hash="17365d8dc24d1da93b8b730c6fe6d864"/></dir><file name="Gbase.php" hash="78c17b83a499c8c31d31762990d83d3b"/><dir name="Geo"><file name="Entry.php" hash="bf5d39448208c58aba61ec64d6a79ad8"/><dir name="Extension"><file name="GeoRssWhere.php" hash="914e0e1155c117f5908f07dadc6ee889"/><file name="GmlPoint.php" hash="a5bf5b02bdec49c06e1aa44763bba1a8"/><file name="GmlPos.php" hash="8ef27447e497a39031e475372a8cb08a"/></dir><file name="Feed.php" hash="c2adb51ac77e046f74ac15f7bcfb53d3"/></dir><file name="Geo.php" hash="2a5a5a2dfa2462e061234e4946fbc8f4"/><dir name="Health"><dir name="Extension"><file name="Ccr.php" hash="5f6686a6c63958e949db8bf5deb92f2b"/></dir><file name="ProfileEntry.php" hash="a2c0dd3747b54680f62089aa25ca26c0"/><file name="ProfileFeed.php" hash="1a41a46d2871e28239c45f23f0b50868"/><file name="ProfileListEntry.php" hash="ee7b66b18af7f3d7406c10c82dbe903a"/><file name="ProfileListFeed.php" hash="1d15e991cf6dc94a83b52ec64aed7a2a"/><file name="Query.php" hash="6dd89b579a5aa4d35de32e74c0df5502"/></dir><file name="Health.php" hash="6b0a156697fe84a09efbde31eea3f497"/><file name="HttpAdapterStreamingProxy.php" hash="6b2964e32bf7c0e110b8ab25445ed53f"/><file name="HttpAdapterStreamingSocket.php" hash="b5b74e5c1cb8206da4b163666a81fed4"/><file name="HttpClient.php" hash="9cee0a291d6c4b11f7358628923f925f"/><dir name="Kind"><file name="EventEntry.php" hash="1f1204191536089911a984770ce0cb47"/></dir><dir name="Media"><file name="Entry.php" hash="9cc1bd304119ff7d428225d3107c3a34"/><dir name="Extension"><file name="MediaCategory.php" hash="8f9345afe735f43c0936d2741556db13"/><file name="MediaContent.php" hash="947b1ca390fa6021690d0a67f81c0c28"/><file name="MediaCopyright.php" hash="947dadff8c8d2708ccb7af6aaa5d928e"/><file name="MediaCredit.php" hash="6d2b9d4be6e3c896fc9c9f9a9581ce9d"/><file name="MediaDescription.php" hash="eeaf98530facd9f42d2e3c46661db3f3"/><file name="MediaGroup.php" hash="9e6dcb6e453393b23d7efb8dde3fb4b0"/><file name="MediaHash.php" hash="2f84bf6db86d3302709347222ad1eba4"/><file name="MediaKeywords.php" hash="6a1a4c5eee620173c5c1995a8bc0aa25"/><file name="MediaPlayer.php" hash="c7d51126d6604718daec1674785e90af"/><file name="MediaRating.php" hash="915d64d3fa690969aa6697c945ef7b28"/><file name="MediaRestriction.php" hash="8921f3bd9d80f7a530b826ab009668c4"/><file name="MediaText.php" hash="557defecdbd618e8917ed5fcd6ccddbf"/><file name="MediaThumbnail.php" hash="e5e272a715318c877fae805dc78e3fee"/><file name="MediaTitle.php" hash="4134d9c00494d89ba462ae9500d1e2bc"/></dir><file name="Feed.php" hash="f67c9bb85cbfbf098fb53ae50a026044"/></dir><file name="Media.php" hash="752e78b67dca41a50ffb85dee3b3e483"/><file name="MediaMimeStream.php" hash="de9b3dd42e0f9f62341fa075bb900c6c"/><file name="MimeBodyString.php" hash="ea742b4f32d34ddac64454b990d4ef37"/><file name="MimeFile.php" hash="0afbad3bc750c1cc5d3f93c54c3c5019"/><dir name="Photos"><file name="AlbumEntry.php" hash="1ab5e6bdc070df30938e912d52eada85"/><file name="AlbumFeed.php" hash="07c42ecd6819d25e428b94f31882c1a0"/><file name="AlbumQuery.php" hash="5da3a372fe52f8c076e9d97a35f823e1"/><file name="CommentEntry.php" hash="f7822566e08ea7b3f74c955abf89a41f"/><dir name="Extension"><file name="Access.php" hash="8d4c3dfe21dbb25632e87659070125d1"/><file name="AlbumId.php" hash="45b3059567bf5e49a6f8edf6b8a16937"/><file name="BytesUsed.php" hash="fd2a43339909b5c7402208dccbdf68c0"/><file name="Checksum.php" hash="5ca31e3430e2e9b747d91c94c000de8a"/><file name="Client.php" hash="2a3276f0666bc92c7d7155bcfbc74f42"/><file name="CommentCount.php" hash="48176e51ea9b1c3c0de6edcf24e25d19"/><file name="CommentingEnabled.php" hash="5b460e8f02be0079867d34af9ab54bce"/><file name="Height.php" hash="d913feb4798b7f3c8ba645bc6ecd1d59"/><file name="Id.php" hash="c5c6fcef6647a1523b99463cfb0a6ebe"/><file name="Location.php" hash="b2b10096aeca032d37e138b09f4ce18e"/><file name="MaxPhotosPerAlbum.php" hash="d1b61411c47e1eb91cb0b80be60998a0"/><file name="Name.php" hash="7e6637d23584ef1ebc3834940fc2ad52"/><file name="Nickname.php" hash="c4345329b15d815de6527d0f8e0277e6"/><file name="NumPhotos.php" hash="160edc7a3b4837435a36befe5378e01e"/><file name="NumPhotosRemaining.php" hash="a3b358f036c2fbefdf93830c92a027fd"/><file name="PhotoId.php" hash="ff997a353b24d944f439702d4ece0966"/><file name="Position.php" hash="cf9f8b0c29c98c1680b2675ebf47e6b2"/><file name="QuotaCurrent.php" hash="a57ff86ba83287a1f145f272ca463756"/><file name="QuotaLimit.php" hash="00c6e94954fbe136a09d4b7ca8f7128c"/><file name="Rotation.php" hash="513a2712c12e10fb61dde21976824b7e"/><file name="Size.php" hash="ab29ba1766a003c1b3ad22db180d18cc"/><file name="Thumbnail.php" hash="6a59c5bebc192e34992e8058ccfd11c1"/><file name="Timestamp.php" hash="b52abdc854529af5cb545691692375ec"/><file name="User.php" hash="3a21cef935fd5fb42f97e308b1997583"/><file name="Version.php" hash="9625bc1c6aefcf580c5fbe0d2f045b4e"/><file name="Weight.php" hash="a8bc3ed41e626323f92adf87410af458"/><file name="Width.php" hash="06f910c1bb1e4e747c38c26ed409522b"/></dir><file name="PhotoEntry.php" hash="ada12abf9bb991fa672ca9a05cb979a5"/><file name="PhotoFeed.php" hash="3b29ec6d750456cdd799bcbaa751e89b"/><file name="PhotoQuery.php" hash="93b28eba3750d181f44fe41181e45663"/><file name="TagEntry.php" hash="8c088bb0af6e8a14eced2775aa3a291c"/><file name="UserEntry.php" hash="15e59c396a645fc30f03cb42d2efc351"/><file name="UserFeed.php" hash="e1498967cc3f5d361c96a0bcde82437d"/><file name="UserQuery.php" hash="26f3ef6227851523817358a97544ebd6"/></dir><file name="Photos.php" hash="c46ff72fca949809ff42f17b0079c069"/><file name="Query.php" hash="100dee31d0a572c4d2e990a96f7e9a0e"/><dir name="Spreadsheets"><file name="CellEntry.php" hash="93cc5079095d6daa6c2147b62131a890"/><file name="CellFeed.php" hash="ca07b9478e1b6ecae9147bc2105c8bd7"/><file name="CellQuery.php" hash="bc7fbfd4e84481e19df568357bc22e37"/><file name="DocumentQuery.php" hash="fd2935ddca76445d1bea58c4f6799ebc"/><dir name="Extension"><file name="Cell.php" hash="917abed62f74a5101511f4449c805140"/><file name="ColCount.php" hash="dba4f0796d79fe80ff15d4dc9bebcd24"/><file name="Custom.php" hash="8f805dee81206d515ab43097cecedb1b"/><file name="RowCount.php" hash="be76b9f5b367cb349576283ab9765d34"/></dir><file name="ListEntry.php" hash="7b8c759afeb6cee40fc5ce231dcf6f2e"/><file name="ListFeed.php" hash="688c2cd0aab8cffabce85d835e4fe077"/><file name="ListQuery.php" hash="2bd4f1eb97b6b3c92c8d2f52fcdbbccf"/><file name="SpreadsheetEntry.php" hash="e43a1862baadf19907770d4a61a56626"/><file name="SpreadsheetFeed.php" hash="2cd1cf91c61a54ea236e1aaf73877009"/><file name="WorksheetEntry.php" hash="7091ab92f732197dbf7e45dcc9c87bf3"/><file name="WorksheetFeed.php" hash="3a4c334028cc35e76255507be1efe061"/></dir><file name="Spreadsheets.php" hash="5706fa18d101c716c73b5f1f6869f33b"/><dir name="YouTube"><file name="ActivityEntry.php" hash="19c73663008cbcbb141c35e8717521aa"/><file name="ActivityFeed.php" hash="5e45cff4ae0df9e35683067769a26386"/><file name="CommentEntry.php" hash="8f17768b645f4165b9601e59fab4045a"/><file name="CommentFeed.php" hash="a391a8ea8c0b27904e365eace8b03458"/><file name="ContactEntry.php" hash="440d8c1c0196e59dd80c6c52e30b2459"/><file name="ContactFeed.php" hash="ae3698b6ccf9d339f7a30b4a5789f698"/><dir name="Extension"><file name="AboutMe.php" hash="8011ef3b524bea9fff089882ea4ed0ab"/><file name="Age.php" hash="e2a9893b2e911b3db507465320cbcf63"/><file name="Books.php" hash="89b35f4bc0027463f91824b5cd2e47cb"/><file name="Company.php" hash="549c355f976cc892cebc6811fe2580a1"/><file name="Control.php" hash="578a083eabf62931b62d095600b80003"/><file name="CountHint.php" hash="666969cd9d5d77e06c9a115fae9de6b8"/><file name="Description.php" hash="8a7dbf10f59ccd573eb0c90cc5971cf6"/><file name="Duration.php" hash="24f2181f720fe6db1cb22503ffee459c"/><file name="FirstName.php" hash="d28dd3cd580a2fa7c6bfb829e8711166"/><file name="Gender.php" hash="260b84dc18e9c01eac563404d0fa5f5d"/><file name="Hobbies.php" hash="2dd89e1c8199ef743d771702ecc95c8f"/><file name="Hometown.php" hash="fda3ebb42524b3ab8d54467887da61f5"/><file name="LastName.php" hash="f19b93c1d745cafe6ecf20c7bc8d0c3d"/><file name="Link.php" hash="d93c9801f25b8c8cb13d87ff3b3b460e"/><file name="Location.php" hash="20909b4d155c9fd517081322b835f306"/><file name="MediaContent.php" hash="1b53bccaa9f1de51c19378fc8c442868"/><file name="MediaCredit.php" hash="4571da70916493177e72f0aebeaa78ac"/><file name="MediaGroup.php" hash="36cca7fb741bb294f4dcb4142733d100"/><file name="MediaRating.php" hash="099d0984cdb2c9110ca259311047d0de"/><file name="Movies.php" hash="464957a1f90eb56899ec503c4ede6ef9"/><file name="Music.php" hash="947c3294f34d0f35ab88c7f7a9c4f4b3"/><file name="NoEmbed.php" hash="1e6e4a5995de606554e7145a0df0b6d4"/><file name="Occupation.php" hash="b33c3053639572a312fec678395d7436"/><file name="PlaylistId.php" hash="af87bcfda7115ae9c55bf3c1f2986754"/><file name="PlaylistTitle.php" hash="79b89ae7bdce993a758fd1bf45188252"/><file name="Position.php" hash="d92a78e714b2f7afdfabd8d09f73ff1d"/><file name="Private.php" hash="93bd6eeaf228e882ccceda591813228f"/><file name="QueryString.php" hash="5e5c57c2e219ef2e5ca3184997d87ccd"/><file name="Racy.php" hash="ad019d20c5c40d12da9cfc9df9daeaec"/><file name="Recorded.php" hash="7af195c7f3f045946f13504cc38522a0"/><file name="Relationship.php" hash="b42aac9538b504662222635a29149436"/><file name="ReleaseDate.php" hash="beb4a4d9830ff40a06816a341de8dd15"/><file name="School.php" hash="51a1ff928489cc7cd3aacc7a7aaf08a3"/><file name="State.php" hash="04cd3d54d4050aafc5ce27e719d234e9"/><file name="Statistics.php" hash="73270160b45c7ec91914467ccda850ef"/><file name="Status.php" hash="aadcb325d6f3b51cae180406d4caf9a4"/><file name="Token.php" hash="8686b59bd2a0048283389bc01acf77bb"/><file name="Uploaded.php" hash="9ee6ea6660e515f1440d92b2ef4d97dd"/><file name="Username.php" hash="c3782552a9accafea073e8f0081e43f3"/><file name="VideoId.php" hash="30fdd4c5cd5b212a1e4c17cd28fbb12b"/></dir><file name="InboxEntry.php" hash="24eb593b56341f919f0bc0446b4b71f8"/><file name="InboxFeed.php" hash="69487f9424ad1686f1b00e2b1f73ad29"/><file name="MediaEntry.php" hash="924fd5fcbfec4c44e965812618c08b6e"/><file name="PlaylistListEntry.php" hash="367ad32e10ea7203408d99bcfae836a2"/><file name="PlaylistListFeed.php" hash="6a2db1a031b1f749231326b4bd57d9bd"/><file name="PlaylistVideoEntry.php" hash="5453811dc274201e95b9ca6450180669"/><file name="PlaylistVideoFeed.php" hash="54be8eb4c90f3a5a4b6ce1ce578f7e56"/><file name="SubscriptionEntry.php" hash="f602292610ce553fb7493cda0bc25cb0"/><file name="SubscriptionFeed.php" hash="576b63779940d7e3576a1c505bff284f"/><file name="UserProfileEntry.php" hash="4eafc0f86b477f85405429572ba1ba62"/><file name="VideoEntry.php" hash="1ef39076a4e9cd95f91bf8d69bf4f52c"/><file name="VideoFeed.php" hash="aa4889f83dab3ed5524583b48a7a5a22"/><file name="VideoQuery.php" hash="a2a973590b187f7314e994d824a6a288"/></dir><file name="YouTube.php" hash="a8dc12d5116ec45b159b59dacddbf946"/></dir><file name="Gdata.php" hash="f1583b57defcf04cb1b35c2875a95ea1"/><dir name="Http"><dir name="Client"><dir name="Adapter"><file name="Curl.php" hash="a4300f6a2b52d63e0edd1e81c4fe2dd5"/><file name="Exception.php" hash="edeae8782f6926386f145d8a873d23bb"/><file name="Interface.php" hash="588b60a6607675c8698be8b3fd2d4e22"/><file name="Proxy.php" hash="6892b7d0c9de3a441adb25d4fbbd22ec"/><file name="Socket.php" hash="6078a103596ba3a8b2544563d252d505"/><file name="Stream.php" hash="14a0106f768a6388688690a54a3eef27"/><file name="Test.php" hash="35e3087f1d6baa3b6fa2cda8228febf9"/></dir><file name="Exception.php" hash="a5f986ab6d87cb83bed91a1caf56ac00"/></dir><file name="Client.php" hash="26f6df4ccf15f65b213ebd0f5538978a"/><file name="Cookie.php" hash="a56a600d64c9bae67c66ae784de2fe58"/><file name="CookieJar.php" hash="7d93690c2caf40108c35a66b10e25586"/><file name="Exception.php" hash="b345b84b1e9b8a1ae2478ff04f37fc2f"/><dir name="Header"><dir name="Exception"><file name="InvalidArgumentException.php" hash="02d00d00a945c0595a648ea418fe3673"/><file name="RuntimeException.php" hash="8c166ae41ab4e516abda9289f19e973c"/></dir><file name="HeaderValue.php" hash="c0e08b696c63818f37faa68a0f733d32"/><file name="SetCookie.php" hash="5f5620b08a9a298bd60cab553cc4f213"/></dir><dir name="Response"><file name="Stream.php" hash="8a41b22b489629a6766dfb3cb96e0ed2"/></dir><file name="Response.php" hash="a34c934977d3bbc1da1a2153692a5743"/><dir name="UserAgent"><file name="AbstractDevice.php" hash="e52f1ad149795aad5075c4bc6cf977f3"/><file name="Bot.php" hash="e5679a2e30d3f1ef581d508446c1f482"/><file name="Checker.php" hash="0b6bb9cb341b75ca7bfb749cb2c871bd"/><file name="Console.php" hash="93650b34bd1238887e88c238291853c0"/><file name="Desktop.php" hash="9829ee285a2cdc4388326a07644d042c"/><file name="Device.php" hash="72533d95dea2a7fe6366bd2145b5b938"/><file name="Email.php" hash="f0a3fab08e59378c0189073237611af7"/><file name="Exception.php" hash="beb38f75f587ac56cbb7a843f59a84ae"/><dir name="Features"><dir name="Adapter"><file name="Browscap.php" hash="a88ccf8fa0b5aca789f32a08f83c98e7"/><file name="DeviceAtlas.php" hash="725061814353e65cc2d89e2a67a00673"/><file name="TeraWurfl.php" hash="1f91bc3ded39c5b108d8232d18cd17f4"/></dir><file name="Adapter.php" hash="a4dcf44cd31de8969f3e941f9a14d0a5"/><file name="Exception.php" hash="a8fba4a7bf9a1a58225ab313b5fa4dd3"/></dir><file name="Feed.php" hash="716918e5334ac352997eac35ca5956dc"/><file name="Mobile.php" hash="00d3e607c4ac5e298492bd3d7762c555"/><file name="Offline.php" hash="6c1ce88c65a43a63416928292c5f9f5c"/><file name="Probe.php" hash="b4df007dbdeb6ef7c49f599d728eed49"/><file name="Spam.php" hash="a4402ccfc92bdf4c49ed1a27bb1905eb"/><dir name="Storage"><file name="Exception.php" hash="ab40f3958bb905a85cfa5cf14af640d4"/><file name="NonPersistent.php" hash="9c8d459eb114f70df099bd397a542a1f"/><file name="Session.php" hash="6b94c84a472e0a767d42be7e26aec3c7"/></dir><file name="Storage.php" hash="ec42c71aae122ea711cbf87ef261c4e4"/><file name="Text.php" hash="711458780f3c17ad437f3d56b5109321"/><file name="Validator.php" hash="69d6afb8a82293c61a642c791f5a16db"/></dir><file name="UserAgent.php" hash="460734f564ed89053481a1204db01c79"/></dir><dir name="Json"><file name="Decoder.php" hash="be80f4b8fe57afd69752fc51c349dcc8"/><file name="Encoder.php" hash="0282ee4cb81e78771c8829398f64082f"/><file name="Exception.php" hash="949bff931d3430258aa0d8688d70df18"/><file name="Expr.php" hash="5985e830701d7f8d5daeb230ce56b1a3"/><dir name="Server"><file name="Cache.php" hash="149b4bcdb085ccd0d535903aa463a0a6"/><file name="Error.php" hash="f3bec127c343a8e14a7a9b1339ab28aa"/><file name="Exception.php" hash="1b0ac33c450ec1bee800421995576fa7"/><dir name="Request"><file name="Http.php" hash="832d82cb88edefb954c4d4d730d0a95c"/></dir><file name="Request.php" hash="35999aec48306723cd44da4c5a62fe35"/><dir name="Response"><file name="Http.php" hash="a5f156d547e04bd224295be634e864da"/></dir><file name="Response.php" hash="a3c115766d7a5e6e57cb4a27887cad2a"/><dir name="Smd"><file name="Service.php" hash="9aef500f4cef8c72886b6103820397e5"/></dir><file name="Smd.php" hash="c8dce4255950f809a22ee60febb2bc2c"/></dir><file name="Server.php" hash="90dcadb42953db253627a783aafa0b80"/></dir><file name="Json.php" hash="9c8bd17cde28999638cd2f05fe470cbb"/><dir name="Layout"><dir name="Controller"><dir name="Action"><dir name="Helper"><file name="Layout.php" hash="c049699d9228b85c2823d7bfdba7d8de"/></dir></dir><dir name="Plugin"><file name="Layout.php" hash="2af276e070314489ccdd514b841d86ad"/></dir></dir><file name="Exception.php" hash="a479f33598f2c4e1cb228883ae6f22ac"/></dir><file name="Layout.php" hash="6d7b1d2ad0c1bf5d5d1ea058ca5a24f7"/><dir name="Ldap"><file name="Attribute.php" hash="a334347a968defb0fda698c3c54f46d7"/><dir name="Collection"><dir name="Iterator"><file name="Default.php" hash="8f8a4876cf258d6b1f71582a805df017"/></dir></dir><file name="Collection.php" hash="ac57de545867cf7cd1df3d6c113263ca"/><dir name="Converter"><file name="Exception.php" hash="4e029f2da6d5c7df7644bfd2c434c6d0"/></dir><file name="Converter.php" hash="8e09bff7ca34d3051cee4a873f5b58a1"/><file name="Dn.php" hash="b5653205b12da006a91e498ca7fc7dc4"/><file name="Exception.php" hash="e12baa19246087c376b7d5cbf0ab7eca"/><dir name="Filter"><file name="Abstract.php" hash="efc802cd50bc28c4181e5bbab247e725"/><file name="And.php" hash="662ca1c25383de02b569c76bc62a058f"/><file name="Exception.php" hash="4f8ae5e40c68e60f00550dd5ccd7aa34"/><file name="Logical.php" hash="06aad3c5c574bae76adc46927ae21474"/><file name="Mask.php" hash="904d6707c87b202d9b66e1e3532fbd94"/><file name="Not.php" hash="028697704f21551b33dcb7c160369691"/><file name="Or.php" hash="8dec15db06446ad375c61c7f46912d7c"/><file name="String.php" hash="b1cc0c074d1822be6124f6c48e351a86"/></dir><file name="Filter.php" hash="c50df357d992c35c217ac7803ce314b2"/><dir name="Ldif"><file name="Encoder.php" hash="d1116ef8bfa81ce18fd5cbae52942227"/></dir><dir name="Node"><file name="Abstract.php" hash="e84bbf67046f975a1f5775aa0d49348d"/><file name="ChildrenIterator.php" hash="8b0c6775e5111e80938ccc9cb60aed0c"/><file name="Collection.php" hash="11098b8c84df455895877fad99f30a20"/><dir name="RootDse"><file name="ActiveDirectory.php" hash="c5f5e80b8dd2cb1e31ac3e03fc279024"/><file name="OpenLdap.php" hash="dcd6e7ebc3775e6a5cba8485bd78c8d6"/><file name="eDirectory.php" hash="f946fccdb3015b015d3cff00829a6ea6"/></dir><file name="RootDse.php" hash="c247acc47a79441717304abade296309"/><dir name="Schema"><file name="ActiveDirectory.php" hash="85bc7915ab42dae47c2d4fb8e3dba51c"/><dir name="AttributeType"><file name="ActiveDirectory.php" hash="04a142f499e0848e9ae43a64786328d4"/><file name="Interface.php" hash="ae4ab45b50efa4e032e32912d9c6a776"/><file name="OpenLdap.php" hash="a823f4b81c597a3820e4fe67e5454e70"/></dir><file name="Item.php" hash="fe670cbd69aa5863f9f66efadfcd3dd2"/><dir name="ObjectClass"><file name="ActiveDirectory.php" hash="e678fbe8c0e965cf7db01e829adff67f"/><file name="Interface.php" hash="166b71e4032d84ecfc88365d89b1de11"/><file name="OpenLdap.php" hash="428b8707dc060e1f9e7854005c51d58e"/></dir><file name="OpenLdap.php" hash="2e52c69ae03823a1d0f42e83aff2f316"/></dir><file name="Schema.php" hash="2745fb40a9578d326a48718ee91cc5fa"/></dir><file name="Node.php" hash="648c759b832b68b000e8bf08af0339ce"/></dir><file name="Ldap.php" hash="da470d2a2a451bc59b2ed1ecb118ec5d"/><dir name="Loader"><dir name="Autoloader"><file name="Interface.php" hash="5a8847bbf702beb3c5d03d9b6620291a"/><file name="Resource.php" hash="b9e4409e67051a21f4e2ae855c1bd691"/></dir><file name="Autoloader.php" hash="4882de8624fe2953294bb4a2a2a6f8f6"/><file name="AutoloaderFactory.php" hash="3ec199fa5c2dec860143b37f17b5ce65"/><file name="ClassMapAutoloader.php" hash="2acb3037511952ac7eb2bab70501dcd9"/><dir name="Exception"><file name="InvalidArgumentException.php" hash="4286045d7c3bad36fa3e101f0beadfaa"/></dir><file name="Exception.php" hash="81dbec797bf5464d3dd93886de055be3"/><dir name="PluginLoader"><file name="Exception.php" hash="fba867bd38d0dbb235f86cc6899d834e"/><file name="Interface.php" hash="60638720a3d503c41b6679d1a12c9e59"/></dir><file name="PluginLoader.php" hash="6be3d7edad844778eb79c52494f04eb8"/><file name="SplAutoloader.php" hash="b35315f66536a170485d6a91cc962a4f"/><file name="StandardAutoloader.php" hash="181406bd273d500ef771e5f24b0bd909"/></dir><file name="Loader.php" hash="817eebfff3c19cf057a8bd92f0c9c679"/><dir name="Log"><file name="Exception.php" hash="b163db6d6600897c6d7d9675f5b2082a"/><file name="FactoryInterface.php" hash="950fce8f1016b9149a3afa78cb5d6bdd"/><dir name="Filter"><file name="Abstract.php" hash="588c7a33b8cc18516fb09f45b6e4df27"/><file name="Interface.php" hash="8e207e5fde37a093bc429eca471abdb5"/><file name="Message.php" hash="42c00aa794507e263369816ebd6ecfb9"/><file name="Priority.php" hash="3bc818826edb7d8d47778c71534968ca"/><file name="Suppress.php" hash="6198f609922c91844696ad749f8f988b"/></dir><dir name="Formatter"><file name="Abstract.php" hash="f6b6a3a2f08104b92f02916dfae10819"/><file name="Firebug.php" hash="18bf525dd98a338a0068adc7223004aa"/><file name="Interface.php" hash="f304a62a7dc3774938c9a4c0386e312a"/><file name="Simple.php" hash="e99de8b500f61444ef4ffd6bd44f8b28"/><file name="Xml.php" hash="dc3361c1aeaa94dca0dac28920c7ea8d"/></dir><dir name="Writer"><file name="Abstract.php" hash="79ccb8a60f0146adc3d1019487a99a69"/><file name="Db.php" hash="e9dd86777ca1735ccec177c7e385316e"/><file name="Firebug.php" hash="6227fe3e164c36db1829e4afd5fdddd2"/><file name="Mail.php" hash="3f76aaf2c1bfa288b7f126efd127c306"/><file name="Mock.php" hash="be44a2526cd397f294cb3350334479cc"/><file name="Null.php" hash="7dc63aa32e13ee72975d68873d87d85d"/><file name="Stream.php" hash="5a287635e4c1d74763215959ba19b70a"/><file name="Syslog.php" hash="06022b333a8ca4d896eaea75f92fe543"/><file name="ZendMonitor.php" hash="3e508d727439f6c10212e70617d68b20"/></dir></dir><file name="Log.php" hash="1c6f8b389780f0bb85202471def93ea7"/><dir name="Mail"><file name="Exception.php" hash="8d01b40eca451bee7c9401d2498ae65d"/><dir name="Header"><file name="HeaderName.php" hash="ecd8c8336e3619779a72d1e1f105675c"/><file name="HeaderValue.php" hash="d55840608558bb29022bca0c565ae55e"/></dir><dir name="Message"><file name="File.php" hash="7415d6300a134322e1f9b5723f456375"/><file name="Interface.php" hash="37f65eeadf5f7d8c46e5740810a91f31"/></dir><file name="Message.php" hash="eea17eeae16ed0696aef9794f947791b"/><dir name="Part"><file name="File.php" hash="2973a0c512d8a12ae250f0310e7ab715"/><file name="Interface.php" hash="5a08dd0d4abfeba0e2b6a3bcd0647cb0"/></dir><file name="Part.php" hash="b948eb534e24b93bb22d34d6dc78c494"/><dir name="Protocol"><file name="Abstract.php" hash="75f76eb34f20aef472da005983e4ade4"/><file name="Exception.php" hash="324b88f119661b2fb45e50e03fdbb797"/><file name="Imap.php" hash="4be011d91db7e932867a9ef04b9e3f1c"/><file name="Pop3.php" hash="a3f36e5260b3fdf15ff91afb4edd06c8"/><dir name="Smtp"><dir name="Auth"><file name="Crammd5.php" hash="989efed470312ec3d252f04f48b13f1f"/><file name="Login.php" hash="eeb279a39d84d0c34b5b3c57a0d8e1fb"/><file name="Plain.php" hash="4e4fb49d2c0a4c3cc6326b9362663812"/></dir></dir><file name="Smtp.php" hash="a99437c462526c3ab7c4a16e6dd73dd5"/></dir><dir name="Storage"><file name="Abstract.php" hash="c80a746bb73014c266f2785247770e77"/><file name="Exception.php" hash="8dfb9dc508a506017fa2aba591171706"/><dir name="Folder"><file name="Interface.php" hash="e46d56b2092b8e66b0de59f089f28dbc"/><file name="Maildir.php" hash="2ffec84ff5cebbc06f42a4bf4e8e49a0"/><file name="Mbox.php" hash="a6bc27702d0e9acbc52d83efdbb623c0"/></dir><file name="Folder.php" hash="710f0f79f55eb9c16523b59b3e46026d"/><file name="Imap.php" hash="63b4ec9c47e81d973c0cecb781a0e398"/><file name="Maildir.php" hash="c298cee3127aebf1d902bc6a263cd67f"/><file name="Mbox.php" hash="96e1d239b5d88772aacd245255d35cc5"/><file name="Pop3.php" hash="fe599c6260e22c23dcd3bfd698271b77"/><dir name="Writable"><file name="Interface.php" hash="a5a3487a8b0dcc8c1f957e10b9535c96"/><file name="Maildir.php" hash="f9dc51e0430fed3cb7fb06a6fc46b4c1"/></dir></dir><file name="Storage.php" hash="bf94dde2f63c2ea5933cff36fd0d96d2"/><dir name="Transport"><file name="Abstract.php" hash="b5e088f0f4a65356307e1e6048558c5a"/><file name="Exception.php" hash="2fc585f21c0c0bbfb8d9218788a99d91"/><file name="File.php" hash="976dec70144df18e87d527ff7e516758"/><file name="Sendmail.php" hash="0a64fedcc87ebe0c9c15695805201bef"/><file name="Smtp.php" hash="6f916608a1b6f93dc6d116e8d8f40b94"/></dir></dir><file name="Mail.php" hash="233f0679a2a5101183c73419cc14e184"/><dir name="Markup"><file name="Exception.php" hash="6acb9e012348c31a98e8016f689bd83b"/><dir name="Parser"><file name="Bbcode.php" hash="fe5258254d43407c8ebf45121d5d3443"/><file name="Exception.php" hash="96b47171a5e4994dcb75bfeb964a3261"/><file name="ParserInterface.php" hash="22f4cab8c966e18965cc16bf1ac58a2e"/></dir><dir name="Renderer"><file name="Exception.php" hash="c27375ebcd69a8eb56a5c3e3229ef88c"/><dir name="Html"><file name="Code.php" hash="c919be3dcefb797b425cd65153302f6e"/><file name="HtmlAbstract.php" hash="7dc1ee614c7d125582f34ded495bd5a3"/><file name="Img.php" hash="6a130ace451a6ed0a2d0a1f1ea3bff58"/><file name="List.php" hash="e8474711d02734026d531708832e1310"/><file name="Url.php" hash="6bb6f2015aa632299941bf9997e8110e"/></dir><file name="Html.php" hash="b607c5add3adcb046c58771b79ecdca5"/><file name="RendererAbstract.php" hash="bf2e4d797e26ef28885babcf2d9e2722"/><file name="TokenConverterInterface.php" hash="e5b38c0b3ba387f0df071a35c7fb1f3f"/></dir><file name="Token.php" hash="925b6878c35fd1e0855a73ecf684f25c"/><file name="TokenList.php" hash="590aa72556941d672184f1aca02ef30c"/></dir><file name="Markup.php" hash="70327a385551a40429dbf98def244565"/><dir name="Measure"><file name="Abstract.php" hash="a844b711aca6638ea933630264ab309f"/><file name="Acceleration.php" hash="f6b1c64dd6bacb4f38d91f72cd8db6d9"/><file name="Angle.php" hash="6c7ec7f864050be14c1735017d149b18"/><file name="Area.php" hash="88b0f14de44d235235da841062691dd1"/><file name="Binary.php" hash="5f9e527c1e8d01535d9bfea7105ac76c"/><file name="Capacitance.php" hash="8bff74324cadcd21836b5acc547a544e"/><dir name="Cooking"><file name="Volume.php" hash="334d3bd9a1023acfed66eb41bf307a15"/><file name="Weight.php" hash="d970ef6d6f08a37db72285917d30ccd6"/></dir><file name="Current.php" hash="1747ffe7532a5c7c060343e3271a27f2"/><file name="Density.php" hash="f4cb05733337475f59762b41a29ae3bc"/><file name="Energy.php" hash="2ed086e65b6f7a4ce1280d8ef9d0f1c3"/><file name="Exception.php" hash="d00039899c6aa43c6b250588bbc07e35"/><dir name="Flow"><file name="Mass.php" hash="2d322913557ff2bfc45afc2ab480babd"/><file name="Mole.php" hash="ff0fe19858605f8c65cbc6f1f377aba4"/><file name="Volume.php" hash="66df34980d0aa473755280393b0f0d7c"/></dir><file name="Force.php" hash="9525a6c47d1e4cbaded7b3477d3c4ba7"/><file name="Frequency.php" hash="80bf10cfe7eeebc3d281b7ed11b397ea"/><file name="Illumination.php" hash="98ee18ab173727ba4dc93a3ada6edd33"/><file name="Length.php" hash="7318f5740bfe039f8c6bda66f172251a"/><file name="Lightness.php" hash="ea419ded90ccd0f5c053262458cc80eb"/><file name="Number.php" hash="7a63c36bbf2089aef5e8ee3e7347e24c"/><file name="Power.php" hash="c896cc783192f260057584f2ba881f87"/><file name="Pressure.php" hash="49c451f9eacd6d162ba6bb629e9118e1"/><file name="Speed.php" hash="c601fe3564d6f3d1f8813a0a7013e335"/><file name="Temperature.php" hash="0d5d33464d00562675fd5d801eebe117"/><file name="Time.php" hash="1c8b825d84b6ccffd76906404d92173a"/><file name="Torque.php" hash="1f530a46616ba82d78541493fb321445"/><dir name="Viscosity"><file name="Dynamic.php" hash="5f002bc79a1c1138cacacec371db37ab"/><file name="Kinematic.php" hash="bd10456069dc6d35a3e1713bd4c6dd71"/></dir><file name="Volume.php" hash="0fbf0ca1290f4aa1af5b23982a6914c3"/><file name="Weight.php" hash="a821fffd5941ccd527cc1d0694336b00"/></dir><dir name="Memory"><file name="AccessController.php" hash="a70d4c42eea7b98f61113d798b55259a"/><dir name="Container"><file name="Interface.php" hash="6068d380217bf27b6453cf894edb8695"/><file name="Locked.php" hash="9bc2f25899430f7ad02853e88dfca0a9"/><file name="Movable.php" hash="4c3c042f5e2bcc2531715dde401171cf"/></dir><file name="Container.php" hash="8feed8c3f2b8f5f0e8d688f13c48c2aa"/><file name="Exception.php" hash="3329d69fccf497932b1a2c27e9919c18"/><file name="Manager.php" hash="1a5c0de427d4436a95fb9d2c0953f279"/><file name="Value.php" hash="697a03309f774813690845eac71d4702"/></dir><file name="Memory.php" hash="2e82b15d077661c5c4b8201ea5bab1fc"/><dir name="Mime"><file name="Decode.php" hash="0cd721f3b84a257348cbfcb73919759e"/><file name="Exception.php" hash="994fc2875e99f10a522cb82e4a54b2b7"/><file name="Message.php" hash="4e3dd5e95f8621955641c7e1b4de46c5"/><file name="Part.php" hash="a11ac478688ef12d8cd0ccecff33670c"/></dir><file name="Mime.php" hash="39042a59c2be063d736a04dac55e903f"/><dir name="Mobile"><file name="Exception.php" hash="519a024f65881a7a4237732573710059"/><dir name="Push"><file name="Abstract.php" hash="456f8a825509d342fcfef1439673f54c"/><file name="Apns.php" hash="d8429732ef082dd5db604fea4c8915b5"/><dir name="Exception"><file name="DeviceQuotaExceeded.php" hash="86b9ff4bc83a799a58f7dffea7382284"/><file name="InvalidAuthToken.php" hash="5ad87658c33a7d9cc6f917d0b5920253"/><file name="InvalidPayload.php" hash="25c5f5d11619d662e9274418d98ed4f8"/><file name="InvalidRegistration.php" hash="8658ffa721150d321de50135d2e5a807"/><file name="InvalidToken.php" hash="713a8d260276537743a4d04b4aa81c11"/><file name="InvalidTopic.php" hash="7c829b73a958a1a5b2727d2819061578"/><file name="QuotaExceeded.php" hash="be67af28f9904f0fc42004751daff33a"/><file name="ServerUnavailable.php" hash="ed4b06b1ef3e3c429b90731ae2920412"/></dir><file name="Exception.php" hash="f894173f4a187922ee49522cf8d3353a"/><file name="Gcm.php" hash="920c224bf5d2829b12e860785f1fcb02"/><file name="Interface.php" hash="8ac308916b40869193bfe9f4924c6d8d"/><dir name="Message"><file name="Abstract.php" hash="60010ad2c300cc7aaeef6e09bd1f0eb7"/><file name="Apns.php" hash="3aa335c6ee551991ad704c6ec1965399"/><file name="Exception.php" hash="14efc16a622ee08a4d66f6b966aa8afc"/><file name="Gcm.php" hash="8e5c08acd168e10c7e0b7be393683846"/><file name="Interface.php" hash="aa9b1e963e71262791a2e85f9d5e03d4"/><dir name="Mpns"><file name="Raw.php" hash="cd49049ab99df63e747b3cf21ce49056"/><file name="Tile.php" hash="eeb12c6d00f840c828e8f928ef28e747"/><file name="Toast.php" hash="6b7b461af1ebd47bc8278388762e186d"/></dir><file name="Mpns.php" hash="bfb031f22738438461df23e002feb93c"/></dir><file name="Mpns.php" hash="d027a3baf86b7808b8f5dd097dd748dc"/><dir name="Response"><file name="Gcm.php" hash="02cdfb00622182c505e7c4916fb51397"/></dir><dir name="Test"><file name="ApnsProxy.php" hash="ef5b18b7cac0826d10cca487ab851180"/></dir></dir></dir><dir name="Navigation"><file name="Container.php" hash="ae908f801587df5bbc7a44d94e290365"/><file name="Exception.php" hash="1f907b7d1a68ca8d29b29f8f9694ca3c"/><dir name="Page"><file name="Mvc.php" hash="bb408e6676cc27d470e41f21084d050f"/><file name="Uri.php" hash="45e78f322e869f7570a82cac147f9985"/></dir><file name="Page.php" hash="ecc7fc65c84c45b552ea81d280fc13d2"/></dir><file name="Navigation.php" hash="bee97615ae02af0c039d61863d0b1e00"/><dir name="Oauth"><file name="Client.php" hash="74d6c02debac4961c253da9d8cc2fe5e"/><dir name="Config"><file name="ConfigInterface.php" hash="1cabd35d6a7f0f92529457b4ea62e17a"/></dir><file name="Config.php" hash="a02e7f37acbb42bc34feebc920d49871"/><file name="Consumer.php" hash="3dc938414065746a37763d2b592e1ee5"/><file name="Exception.php" hash="570bf15ce9b8ccf76e4bcd949adeef50"/><dir name="Http"><file name="AccessToken.php" hash="986d7e25f96d5bed67914e08404bbb5f"/><file name="RequestToken.php" hash="f4f86a01a6e424aaa7e8edb99e518f59"/><file name="UserAuthorization.php" hash="758cc6c3df942ac5ac3b103527a99a10"/><file name="Utility.php" hash="9c69fe9d58add25eda7730460eeb4ae1"/></dir><file name="Http.php" hash="cef52b37622bcfb2efd2a9644babc94d"/><dir name="Signature"><file name="Hmac.php" hash="26331323b06095d36ea1b3d8de214c79"/><file name="Plaintext.php" hash="11266c5bf1d868c63fac84ff14c22061"/><file name="Rsa.php" hash="4ea7e936077c094ee6365ee33707c4fb"/><file name="SignatureAbstract.php" hash="09e632d7cfb30720b43cd8e33ca867f7"/></dir><dir name="Token"><file name="Access.php" hash="974b61753e392b577562e7090dec4102"/><file name="AuthorizedRequest.php" hash="2c5a7071f93bfc03e8098a367c1b95ad"/><file name="Request.php" hash="3253abe4f0340e7fa12d6c26c669e1cf"/></dir><file name="Token.php" hash="19cbcf77a287619c7043efc9cf4cc2fb"/></dir><file name="Oauth.php" hash="239174147ad1cac48ff43b86ca768b5d"/><dir name="OpenId"><dir name="Consumer"><dir name="Storage"><file name="File.php" hash="53a1aec62db8e0bf8153d2363b8afdcd"/></dir><file name="Storage.php" hash="96636f4707d5090dd777ca16ff5f9498"/></dir><file name="Consumer.php" hash="d4129677162161a383a8327a8a5f5cb4"/><file name="Exception.php" hash="9ae51477a152a9993db86a2b3e87a792"/><dir name="Extension"><file name="Sreg.php" hash="a46ab3f654e7718b74f256863398070d"/></dir><file name="Extension.php" hash="d0cbcdb2874105fad8d517731ee682dd"/><dir name="Provider"><dir name="Storage"><file name="File.php" hash="78e54dc83e5862422be8c086458815bb"/></dir><file name="Storage.php" hash="a111906ee39dd25c3e8f03edf73a3f0b"/><dir name="User"><file name="Session.php" hash="184de6934deff211975387b3d0eea0c7"/></dir><file name="User.php" hash="1130cc8407f1607fcc19e0e0e7048953"/></dir><file name="Provider.php" hash="e82af61658678702cf9b92879c70494d"/></dir><file name="OpenId.php" hash="3afe8be181b4ee86ebca1531a1bd8b0b"/><dir name="Paginator"><dir name="Adapter"><file name="Array.php" hash="b19b7013fca38d006a2b638b89312764"/><file name="DbSelect.php" hash="3bd5b7dc7a01b4dcb161f396be0b8670"/><file name="DbTableSelect.php" hash="cab2b30b8210b2979b0c6bed4b123fad"/><file name="Interface.php" hash="5762707d8b9db19faf2a773eb78edd76"/><file name="Iterator.php" hash="3a51f92d688197a2967eef55d802f56e"/><file name="Null.php" hash="2e58e92129e83d96b61e5ba5bf679157"/></dir><file name="AdapterAggregate.php" hash="b6ed68617efff6b9dd41ba5d27cde51f"/><file name="Exception.php" hash="bd8961847f8ea166c7e222e2344d586b"/><dir name="ScrollingStyle"><file name="All.php" hash="7a024155b60bcbb024b3ab8418ea1737"/><file name="Elastic.php" hash="a7d8784429dc1e520b3f98d14c5eac09"/><file name="Interface.php" hash="1d6adbef71c9c1966676ede68de7f977"/><file name="Jumping.php" hash="2e2e9f1633d9ec60e0e111a5794aed93"/><file name="Sliding.php" hash="9f768e8bcaf3bd6f12e0e939c00775d4"/></dir><file name="SerializableLimitIterator.php" hash="411f2359e449e170c5dadaa24803a54b"/></dir><file name="Paginator.php" hash="0d3667499c2f0c3a8c9e5907e812b7a5"/><dir name="Pdf"><dir name="Action"><file name="GoTo.php" hash="d1e30bb7d45aedbeaa31b5dc8b40e287"/><file name="GoTo3DView.php" hash="fcd5460403b8433315caeca12418a5cf"/><file name="GoToE.php" hash="599ebb6d2df80852cfca9a9cedb8d6b0"/><file name="GoToR.php" hash="474402a7102d563261bd914a721b36d2"/><file name="Hide.php" hash="8810efbd459a87d1ee9de7cd007d1644"/><file name="ImportData.php" hash="ecd6feef7d654d60b8efc24bf26d4662"/><file name="JavaScript.php" hash="9bdf7f5f8360300bc95e3e293431f425"/><file name="Launch.php" hash="3e3b49828aefff82b9b44b295084e413"/><file name="Movie.php" hash="b65daa361fc8e77f5ffc4ecedb3becff"/><file name="Named.php" hash="7a1ea555152631327d04a9eb263b4a5a"/><file name="Rendition.php" hash="363bd0314e6d20994934dabd3ad63684"/><file name="ResetForm.php" hash="f4637cd51199245ab14aa6021ffe71be"/><file name="SetOCGState.php" hash="301da63cac76237c91818aac076cbddc"/><file name="Sound.php" hash="ee1e489704abce5aa0dee9047bd8b456"/><file name="SubmitForm.php" hash="657a9f4bc9cd87ca3551370d195b7a35"/><file name="Thread.php" hash="ecee0d4d74deafefed77cd0f6798093a"/><file name="Trans.php" hash="d9f99fb44efc3651ca5e2c56fd7e96b6"/><file name="URI.php" hash="7e52db0fd92d4edb87ab4f4e789d45e3"/><file name="Unknown.php" hash="a8602a55e7a0792d6cd0615c9ac23c41"/></dir><file name="Action.php" hash="ec5a813b9a9a0caf8beb63b890c68450"/><dir name="Annotation"><file name="FileAttachment.php" hash="f3864019953d49d9cd83d322f9a54f4d"/><file name="Link.php" hash="bff1663cb2b899d96d2b5e539f516d63"/><file name="Markup.php" hash="ab0f2e3e12ec5c7e75b2daf9851c59d1"/><file name="Text.php" hash="7b507f12f45421db845a74e91a0c78fb"/></dir><file name="Annotation.php" hash="0d098c2160f4b3267e7fd7f367f30290"/><dir name="Canvas"><file name="Abstract.php" hash="364364cb99b19cdf0d622397424e155d"/><file name="Interface.php" hash="1795a31a88af11db1f8eaefae3751d65"/></dir><file name="Canvas.php" hash="00dcbc00ee5b0678292c40c62709bb37"/><dir name="Cmap"><dir name="ByteEncoding"><file name="Static.php" hash="bca21500f7be22a1c6349cce6b489afa"/></dir><file name="ByteEncoding.php" hash="84d9e9e1afe70befb0b7c193516a7ad6"/><file name="SegmentToDelta.php" hash="34570bbef3c618d344e056a65a86310e"/><file name="TrimmedTable.php" hash="1a8eaed30b4393a4ad1972ccfa586275"/></dir><file name="Cmap.php" hash="9d7432c932a1f5260c8752cd0eb09cb9"/><dir name="Color"><file name="Cmyk.php" hash="9024fe208254093dfedb355f1a56bfa3"/><file name="GrayScale.php" hash="ac29a955a5422d31e3c6342c9ba5df7f"/><file name="Html.php" hash="98c75da7b5c1e27d72029a612973c33b"/><file name="Rgb.php" hash="db12cfc9dfbb80831d4b1e5436ff8323"/></dir><file name="Color.php" hash="104cf49d07c358cc85220fc3122e800e"/><dir name="Destination"><file name="Explicit.php" hash="13bd68687766542d36847199a9dd478a"/><file name="Fit.php" hash="1aa3f00fde3170cae69b69bd17786c3b"/><file name="FitBoundingBox.php" hash="b59f2ed44504d9f3df4a8e05450c0f07"/><file name="FitBoundingBoxHorizontally.php" hash="1271088bf2557a2eb8c18f388e1853ee"/><file name="FitBoundingBoxVertically.php" hash="16948b893fe63488b34891f82d409d52"/><file name="FitHorizontally.php" hash="88e880e0528a4f7060d233e687e90667"/><file name="FitRectangle.php" hash="408a9be40986151fff98af1efabe8a28"/><file name="FitVertically.php" hash="136c71dd521fb51103f98a76734fb8c1"/><file name="Named.php" hash="a65c919e6fa48d4453a9581ebb908adb"/><file name="Unknown.php" hash="1a2e8b67ee995941dc43b43070a3971f"/><file name="Zoom.php" hash="c9325d991fc179afcca30c3636e72e1b"/></dir><file name="Destination.php" hash="b7605192c93386f3fd25520d180343dc"/><dir name="Element"><file name="Array.php" hash="b644069461389d8cffe6d3bd1cc49835"/><file name="Boolean.php" hash="d4a4de598d871b0ae391dd72ee4cbd2a"/><file name="Dictionary.php" hash="fa2156732ab46185f1412c3e22c54c92"/><file name="Name.php" hash="be8084d6e0fec7b6941bfcb2cbc93535"/><file name="Null.php" hash="a982c3b2f79e698e80cccc4cd794219a"/><file name="Numeric.php" hash="020e5a151377a7f95b0ab846f4cf5829"/><dir name="Object"><file name="Stream.php" hash="9a4d7197a43ba30df5e1871cf85a05f2"/></dir><file name="Object.php" hash="f0b69fb983587a2f68a1f40e3e417663"/><dir name="Reference"><file name="Context.php" hash="e15ad61d18c94f11179594e9a58cb6d3"/><file name="Table.php" hash="6a90fd67ff295547877255bf8bfbe2a1"/></dir><file name="Reference.php" hash="0725ddc6094e61656354a949986d4def"/><file name="Stream.php" hash="166a0bef11c118de4591b7436a9e999f"/><dir name="String"><file name="Binary.php" hash="f6a6e7ce998124ba104470dcb4734dec"/></dir><file name="String.php" hash="e776be7acc388a17af23bec80954de82"/></dir><file name="Element.php" hash="3595c5f91616d00f51af614feafda5f5"/><dir name="ElementFactory"><file name="Interface.php" hash="d1a6e36aaeee2b4a4a7f8b6111facbec"/><file name="Proxy.php" hash="a07e4d22cba4810f367ca6b7240fbc83"/></dir><file name="ElementFactory.php" hash="024f30704c4c693597c11f4b032dfedc"/><file name="Exception.php" hash="7b3b6c5890b43cd2fb05b68f6282f521"/><dir name="FileParser"><dir name="Font"><dir name="OpenType"><file name="TrueType.php" hash="b493bcd28a5c4006be3f5c0a1081b28c"/></dir><file name="OpenType.php" hash="a5d6ab27fa54d414b01532d4830ef090"/></dir><file name="Font.php" hash="56634e0dcb7ade369b564643c5a5d171"/><dir name="Image"><file name="Png.php" hash="15d071e3ce65f9eb9936ca4149910fb7"/></dir><file name="Image.php" hash="29748c74077a30e3b3d108c316ee1910"/></dir><file name="FileParser.php" hash="4d54f7155401a9fb7df70998a2da9a50"/><dir name="FileParserDataSource"><file name="File.php" hash="1e9148d68ab81b33f2d88c403d9495a5"/><file name="String.php" hash="e4cd122d052ef39e6da5c38ec452d161"/></dir><file name="FileParserDataSource.php" hash="eb883b69beb455a62c8931a878151085"/><dir name="Filter"><file name="Ascii85.php" hash="b65b7f97285f88f9f11265191cf20849"/><file name="AsciiHex.php" hash="ed846de8708cd7026f551d78de57782d"/><dir name="Compression"><file name="Flate.php" hash="faf5cfc2e9c94444e43d7e6944247988"/><file name="Lzw.php" hash="9c28f750f6600ce94877b78ad7c71324"/></dir><file name="Compression.php" hash="73050021440ac2c7b18bd20513157c3f"/><file name="Interface.php" hash="e90f59d18816fbaacd86b59b392686d4"/><file name="RunLength.php" hash="e80a6edbe6fa87c4702d09d65db1a2ea"/></dir><file name="Font.php" hash="51087d7787fad796537357c3ac69dc73"/><file name="Image.php" hash="7877b76dd9e150104b83037266258658"/><file name="NameTree.php" hash="da4cc3e1566938790d1c613174aa23eb"/><dir name="Outline"><file name="Created.php" hash="9d373dc681d5b2805d30b5685ef862c2"/><file name="Loaded.php" hash="d6d0bcbbbc7125de10670b4e6562b59d"/></dir><file name="Outline.php" hash="f26766891dc3d3bce49b037adcfef12e"/><file name="Page.php" hash="13f4483dfd5d93e7e94d273c662b46ac"/><file name="Parser.php" hash="ba36ebc92a1b6e525ed8c0408e251bef"/><file name="RecursivelyIteratableObjectsContainer.php" hash="715f93a595f54a38111141fd5968213d"/><dir name="Resource"><file name="ContentStream.php" hash="a1749fec0cba8e9cb72efb1304de2346"/><file name="Extractor.php" hash="bb8efb4919fa8775f711f61d183a4e12"/><dir name="Font"><dir name="CidFont"><file name="TrueType.php" hash="1290b18c2ed5643477c1e88b0c76987e"/></dir><file name="CidFont.php" hash="382f00c4a207bea2ffd82a5d77da6304"/><file name="Extracted.php" hash="bd8bedaf4a31c4ae1eddf944644ecce5"/><file name="FontDescriptor.php" hash="9fcedd31b44153c7ad83cae939397e42"/><dir name="Simple"><dir name="Parsed"><file name="TrueType.php" hash="e060a25bc471d15d43a51d580679326d"/></dir><file name="Parsed.php" hash="becce62602415adde90984b7590993ba"/><dir name="Standard"><file name="Courier.php" hash="1a8795c6738e56ecc9b223ed823c0e0a"/><file name="CourierBold.php" hash="271652240d7b89827820060a185aef0d"/><file name="CourierBoldOblique.php" hash="f8e6fa84ffdc7ffcb8069c67e813f09b"/><file name="CourierOblique.php" hash="7b4080d45eff2b8fd5d66db97512a8bd"/><file name="Helvetica.php" hash="fdf4947a20fbf3f694f4fe940cec5df2"/><file name="HelveticaBold.php" hash="1340145daef0b6ed9e4d15ede06a0530"/><file name="HelveticaBoldOblique.php" hash="ae26d6990824525b0cb3c99e87674000"/><file name="HelveticaOblique.php" hash="a05d94e11e3e1db842ac7f1795074373"/><file name="Symbol.php" hash="9443a7d26e4c2a752cf3f4ff883ffa05"/><file name="TimesBold.php" hash="b2619f7edcc8abab8ff28a4009123f84"/><file name="TimesBoldItalic.php" hash="433fcd37d348fa4458cf437ea2cdabad"/><file name="TimesItalic.php" hash="76ec1fbba59e77bb848f8696337aadf0"/><file name="TimesRoman.php" hash="953b76c5e03a7858bd8361872e412ded"/><file name="ZapfDingbats.php" hash="548d057f0040392a4828264f24e243cd"/></dir><file name="Standard.php" hash="f332565c96e87d79436790a096f46aef"/></dir><file name="Simple.php" hash="334a3b36ea5235902d79cdb31cd05d73"/><file name="Type0.php" hash="6c0a83ed854fdbb16bf525fcd219a4ca"/></dir><file name="Font.php" hash="6046881c1057ef05d0a420998a05c1a4"/><file name="GraphicsState.php" hash="b51172933cdb59ea271e7a9ae323fe29"/><dir name="Image"><file name="Jpeg.php" hash="0a1a368f9642c0b98d8ff24f0aae7c3e"/><file name="Png.php" hash="f77b42c714316c69714df0a2a94cfb7c"/><file name="Tiff.php" hash="06e9fd0b542ecc53649d868fbb59372b"/></dir><file name="Image.php" hash="dbec25fbc65e673b12f311785249ae4f"/><file name="ImageFactory.php" hash="45222c4b5170b11e9b1fc9f16700f1a2"/><file name="Unified.php" hash="710f5f418d4939a609144eab68a8b797"/></dir><file name="Resource.php" hash="b71cd04a74a88e040f06ea7663ea5e65"/><file name="StringParser.php" hash="5376c86288c13e706f2c76478ae474f5"/><file name="Style.php" hash="8aceb18b61204e8157a46c41bbcdd7e9"/><file name="Target.php" hash="1a2badb1e3ca52a2368a77b0646efef7"/><dir name="Trailer"><file name="Generator.php" hash="2c12f38db376c57935d09f8527fa786d"/><file name="Keeper.php" hash="df14918b0e392a71bd41817f0abfaf55"/></dir><file name="Trailer.php" hash="8069878c1e9320d2b8533cf1e144f4f5"/><file name="UpdateInfoContainer.php" hash="39f4700c55860bb9ec1b3f122258930f"/></dir><file name="Pdf.php" hash="7f96ca856c0dde6e6074711e0db2487b"/><dir name="ProgressBar"><dir name="Adapter"><file name="Console.php" hash="09f7268da0ecd77f2d174f4a8a3de869"/><file name="Exception.php" hash="6a2ed89846b42f86a235044d05555198"/><file name="JsPull.php" hash="582d2e3d4fe457d4c961701b014886d1"/><file name="JsPush.php" hash="229b568b05cf46950fbb3707ca150c01"/></dir><file name="Adapter.php" hash="8297cf770c0ee628158397e3b089c621"/><file name="Exception.php" hash="6fd9c59515c836a7e044c07b146c1e6d"/></dir><file name="ProgressBar.php" hash="581036cf36019829ad17b626f15344f8"/><dir name="Queue"><dir name="Adapter"><file name="Activemq.php" hash="b419df4c2da5f1188e2f9fc07fa17d6b"/><file name="AdapterAbstract.php" hash="77fdf9a85df53d3a3b2a2f5d22e80626"/><file name="AdapterInterface.php" hash="0dcaaa3d94f0c384a3c37e45c7529b3e"/><file name="Array.php" hash="b3227f915782241e3ebdce389d3f0a18"/><dir name="Db"><file name="Message.php" hash="017e049117119a01fd2acf00fac7c5c4"/><file name="Queue.php" hash="0036c67014f3b5787878ecb638088423"/><file name="mysql.sql" hash="487d5a36b9172382351a7cc39d20d221"/><file name="postgresql.sql" hash="42dfaf91f8a425170c9b4b2c9318c875"/><file name="queue_sqlite.sql" hash="b0e5a2e43dfc9a230a5ec397c351eaf1"/><file name="sqlsrv.sql" hash="646346084e937e9239d911485bc0296c"/></dir><file name="Db.php" hash="876370736f86a93dedc206bdaea8ac05"/><file name="Memcacheq.php" hash="f0a6604c99debe72daf655a2f97ddc03"/><file name="Null.php" hash="abbd08fab4a38429460cd70b6170c492"/><file name="PlatformJobQueue.php" hash="0e9187b14fcb15711fc18e6bf0dd1383"/></dir><file name="Exception.php" hash="279bbedb61b1778812827fb636c62bd2"/><dir name="Message"><file name="Iterator.php" hash="11ea9382769f547d17a66ac1a54d655b"/><file name="PlatformJob.php" hash="2988e7c33a68ff837ffd7dcbd835de3c"/></dir><file name="Message.php" hash="fb9762a45a532513ff209e2b4820f871"/><dir name="Stomp"><dir name="Client"><file name="Connection.php" hash="aff6c9c41035654ec0d4a4887b4dd218"/><file name="ConnectionInterface.php" hash="e4adc375b6e177fafbd45e47b93ad1b1"/></dir><file name="Client.php" hash="1d64509385a30e21abb7df5e31aa11ae"/><file name="Frame.php" hash="d909edb1b42697e4f557de5a68368932"/><file name="FrameInterface.php" hash="16c13ddfcf2b1bcc50b85c61dc546646"/></dir></dir><file name="Queue.php" hash="1c9e3ec5bc7508a98b7de1f77ee61ba2"/><dir name="Reflection"><file name="Class.php" hash="ba4973471396d116ba92824b47d313a8"/><dir name="Docblock"><dir name="Tag"><file name="Param.php" hash="2a51f3907ad2ee281175d3cdb28a2e6b"/><file name="Return.php" hash="b0200cc0b804828031ab3a8582dbdcad"/></dir><file name="Tag.php" hash="0eebe17d3442b754d9422f8c9721231f"/></dir><file name="Docblock.php" hash="d0856efe818bee5c5d39645662312ba6"/><file name="Exception.php" hash="c43315831b3596fc86aba74529571aad"/><file name="Extension.php" hash="f4dd6dbfb0d48aabdbf359fa6bfaee9b"/><file name="File.php" hash="47206736078efdd5eefc6527408bd922"/><file name="Function.php" hash="1713773cab56cf753f7f90a1108953c8"/><file name="Method.php" hash="25ecb48f4e4f7029ea6fd759fba663f9"/><file name="Parameter.php" hash="7a34d5982a0dec35c6323160114dcb62"/><file name="Property.php" hash="7ca9b4aca176f18bf89b711b5f0929d3"/></dir><file name="Registry.php" hash="3b697b3b783d2821e69137c4dc3851b2"/><dir name="Rest"><dir name="Client"><file name="Exception.php" hash="2e86578bbe604d335a622957c1b0ae26"/><dir name="Result"><file name="Exception.php" hash="49193abd246224f975676b9bdd41349a"/></dir><file name="Result.php" hash="ffc3f1ee709136ab403949d4274098e1"/></dir><file name="Client.php" hash="b76ff6282552bcd098403cebc7b08ed6"/><file name="Controller.php" hash="86e1b0b6bc3ad11653dfe9e17c7d075f"/><file name="Exception.php" hash="c62bd750b3b4cd33407d99869c600d14"/><file name="Route.php" hash="20875e10d835e380c294d2edfb56b08f"/><dir name="Server"><file name="Exception.php" hash="235457f9f3a4f7720ac2013b51ad4ee9"/></dir><file name="Server.php" hash="ceb61231f7fc67faa657837a9fb2c9a3"/></dir><dir name="Search"><file name="Exception.php" hash="915c3138aac999bdce9426a8acd40556"/><dir name="Lucene"><dir name="Analysis"><dir name="Analyzer"><dir name="Common"><dir name="Text"><file name="CaseInsensitive.php" hash="307dc051465ca81322c5e85e8ec022cc"/></dir><file name="Text.php" hash="758df150a1df6eba4b64004148a672a4"/><dir name="TextNum"><file name="CaseInsensitive.php" hash="e5940381671ed3f7c321b3fda9862881"/></dir><file name="TextNum.php" hash="36acd4b130e2f8b78e2de06ac9b4f942"/><dir name="Utf8"><file name="CaseInsensitive.php" hash="44697c595e22b385d0a7616e7af30ac6"/></dir><file name="Utf8.php" hash="1b7f394340ca0d04c8e6a19fe22d4d23"/><dir name="Utf8Num"><file name="CaseInsensitive.php" hash="9325aa4566ece4546b23c82d1aedb57d"/></dir><file name="Utf8Num.php" hash="76dfe3f7ab2e55f1e8190054dd788790"/></dir><file name="Common.php" hash="04cd47fabbd6c404aff39664da13df9a"/></dir><file name="Analyzer.php" hash="85a3a397e4d2c53d185523e25e7ae53a"/><file name="Token.php" hash="b7c5544e368acd06d81d7539983ed85b"/><dir name="TokenFilter"><file name="LowerCase.php" hash="d3be32b9f01fa4343a427721fc3b82b3"/><file name="LowerCaseUtf8.php" hash="9293ea00a25a3e7f129723c9f74b3b9a"/><file name="ShortWords.php" hash="1e296157ac5b8dc2f80a441811707202"/><file name="StopWords.php" hash="c935b1d071ab560816f3a591e3a662e9"/></dir><file name="TokenFilter.php" hash="7e7caefe49ee420c8b5c1561e84f012e"/></dir><dir name="Document"><file name="Docx.php" hash="e6730cac4ab560138c45c9db700d28f0"/><file name="Exception.php" hash="d1f92a2cc3ea06517d5626e96429a5af"/><file name="Html.php" hash="64e7ae4d564af7e71f44c01e48c8e03a"/><file name="OpenXml.php" hash="b21a3c28a95e7a0c9980db28bbc65842"/><file name="Pptx.php" hash="5a2b150c6c2a98b80e1e7765cec8297e"/><file name="Xlsx.php" hash="cae7aa77e2e49c47ecf8a89f169c629f"/></dir><file name="Document.php" hash="81e9c33cd2320e8344181ac5bf78819c"/><file name="Exception.php" hash="2d392bf05fe81a16cd8a3b10618bc6bd"/><file name="FSM.php" hash="5009e011f0b10421ef6e9c6b2c509753"/><file name="FSMAction.php" hash="54cc85832b139caef30d62a66a8008c5"/><file name="Field.php" hash="62d99dc9804e4f352bb55f69a61e5764"/><dir name="Index"><file name="DictionaryLoader.php" hash="dd18c7bb937d629cd0960ba4e8156307"/><file name="DocsFilter.php" hash="a464c3ab082438689658bd370ea21887"/><file name="FieldInfo.php" hash="49cdf39b3445b209adc9370a9970d834"/><file name="SegmentInfo.php" hash="3e9803053f230d7309cce21a643c9e76"/><file name="SegmentMerger.php" hash="335a52ca7e40a79dd6cb95f72cbaa140"/><dir name="SegmentWriter"><file name="DocumentWriter.php" hash="5061bbd3c4b375f3304813ff93a6401b"/><file name="StreamWriter.php" hash="0f6d8ea058813929a7448a4958a3c7c7"/></dir><file name="SegmentWriter.php" hash="13a8736ed2991f513e57f68e61926a76"/><file name="Term.php" hash="490ae3da5ccd138e9b060792766646bb"/><file name="TermInfo.php" hash="4930aa466ba2eb3b65dae3c02aa03221"/><file name="TermsPriorityQueue.php" hash="32663e0ebb7d0279bbcea377903c12df"/><dir name="TermsStream"><file name="Interface.php" hash="751e8ab0d56bb26f7b795d9530dd2494"/></dir><file name="Writer.php" hash="b7ef933d12a1b2f5376584b2420d7976"/></dir><dir name="Interface"><file name="MultiSearcher.php" hash="3f40f5b499a8ee03957fb21aada499da"/></dir><file name="Interface.php" hash="a78e2d90755e526ac9db7eb1c4185f3a"/><file name="LockManager.php" hash="5f61443ba5976b5fa021fb36bba30371"/><file name="MultiSearcher.php" hash="2fde43036355b990e0ac0227a00b6c8e"/><file name="PriorityQueue.php" hash="5c915507c33213ddb4b4ac613f1f68c9"/><file name="Proxy.php" hash="11944c7b4d9879615fd4f3a5d768aed3"/><dir name="Search"><file name="BooleanExpressionRecognizer.php" hash="3896532815243d89040fecb2fd65f606"/><dir name="Highlighter"><file name="Default.php" hash="b1dbdc2d70bb032a5d2b9f9e11273ea0"/><file name="Interface.php" hash="7dca815c9e9f444b9a2a9765fe349dd2"/></dir><dir name="Query"><file name="Boolean.php" hash="5be6706e75dd3e9ccdfaa0eb22f93ca4"/><file name="Empty.php" hash="2e16007df371f28191f785ab85d4d103"/><file name="Fuzzy.php" hash="e66032fc9f9cb06422cac6da95f7b8f6"/><file name="Insignificant.php" hash="1f61e2f1ef8ff38101f2a85c87b9529e"/><file name="MultiTerm.php" hash="ec939add6f7d0424029b12106385afd0"/><file name="Phrase.php" hash="424cc7d460f4bac0907d0170b60ba625"/><dir name="Preprocessing"><file name="Fuzzy.php" hash="cae1047630f98baf520483fa68af463a"/><file name="Phrase.php" hash="d8afc95f2e9da2a44d9495cbce775c98"/><file name="Term.php" hash="b099d749d723fbb53d3991e3f61458be"/></dir><file name="Preprocessing.php" hash="83dba0878c9ed171628b7a9ac70d26b3"/><file name="Range.php" hash="d8bda3ad418d24e0db7e59c446be13fc"/><file name="Term.php" hash="54e883c87d7368fa5be1e105723db357"/><file name="Wildcard.php" hash="9c1c8ebeca45a6332ede6fab8d5bee54"/></dir><file name="Query.php" hash="2a9f2ceda3cfacd24f892dd8bccd8d28"/><dir name="QueryEntry"><file name="Phrase.php" hash="407da910b0015ff8d95432cc193d608a"/><file name="Subquery.php" hash="a33d941498f632d859bec94a1cb9c10b"/><file name="Term.php" hash="808b02c1c1aeae4316fee3c9c466facf"/></dir><file name="QueryEntry.php" hash="9620d76904656a0727091f449603c662"/><file name="QueryHit.php" hash="6d1727ed01abc54503badc7176955882"/><file name="QueryLexer.php" hash="57a592ea29129b28d1144063e152c878"/><file name="QueryParser.php" hash="569f6439976128dbc471bd42fa9511d9"/><file name="QueryParserContext.php" hash="45c71a353821fc29101c1ae2f8eba02a"/><file name="QueryParserException.php" hash="358f89eaca92ac3175b26c419b317640"/><file name="QueryToken.php" hash="f85c3ac0ab04b5abff04d034cf127f43"/><dir name="Similarity"><file name="Default.php" hash="43f6f75cb50b7c7f344a5bac85ef172a"/></dir><file name="Similarity.php" hash="194c9c6c1c2815a8491952ece299ef9e"/><dir name="Weight"><file name="Boolean.php" hash="537c06e5f44c3d014d98a88a39c834f3"/><file name="Empty.php" hash="0bfe83149630af587846c7d5df63e72b"/><file name="MultiTerm.php" hash="c95f65634ed9d8c2896f5ba66a833f10"/><file name="Phrase.php" hash="51bc4912b1784bfa58841e4bf14fb177"/><file name="Term.php" hash="2e0f6fc3511928f1e94349d375dec8b8"/></dir><file name="Weight.php" hash="49ece1259ec183d66d2a1ccc8c319299"/></dir><dir name="Storage"><dir name="Directory"><file name="Filesystem.php" hash="7928063a85bf3c53e2afd754c111cc6b"/></dir><file name="Directory.php" hash="25a0d0c262a3c4fa7dbc3f1f11f0a4ab"/><dir name="File"><file name="Filesystem.php" hash="5c2819323a9878475d31eba6992e6abd"/><file name="Memory.php" hash="89bce18491ebcd885736c5c9a790eab6"/></dir><file name="File.php" hash="2b77f8354d79c7dd57330677651f8fc6"/></dir><file name="TermStreamsPriorityQueue.php" hash="a26104e3325d2533afffdfc66dd1ead0"/></dir><file name="Lucene.php" hash="fe6103d1d763df12d670dfe5103defb7"/></dir><dir name="Serializer"><dir name="Adapter"><file name="AdapterAbstract.php" hash="8bd5c797ff2230e804b916545a67694b"/><file name="AdapterInterface.php" hash="cb397638959459eef297b8114ebb0504"/><file name="Amf0.php" hash="734f3143371bffe28f65e144f1d4fde3"/><file name="Amf3.php" hash="05a939a59cad0622a7627572f931e909"/><file name="Igbinary.php" hash="dc0da7256a83c6f0a06582b21b160156"/><file name="Json.php" hash="e62019ed95f69a184f735f1d3d4d32c0"/><file name="PhpCode.php" hash="731fc343849f966c1b532284822060a6"/><file name="PhpSerialize.php" hash="d7bc5453b1c516a6895e62fee2f94ec7"/><file name="PythonPickle.php" hash="8eaa4d904fa3ac33cc3d405f6eeb92bf"/><file name="Wddx.php" hash="4321621736a7d3940a27357608c66c28"/></dir><file name="Exception.php" hash="dd736f6d29e3a1f8d688bdf6b24f8d30"/></dir><file name="Serializer.php" hash="47d6232a605b0fc1b0dfd5bc6738d4a4"/><dir name="Server"><file name="Abstract.php" hash="878b796b9b09bac46361e73e3b76943d"/><file name="Cache.php" hash="8851d8d1c35c11be49192fc875141632"/><file name="Definition.php" hash="c37f863e7395e761f9601a4f918f0fc9"/><file name="Exception.php" hash="1ad53d7cdaadfe1377fe30f61814ce33"/><file name="Interface.php" hash="ef219942e75a7dd72f757ae0fee1fe94"/><dir name="Method"><file name="Callback.php" hash="204c77c05f77dab719f7e8d4d9940990"/><file name="Definition.php" hash="6a7435cbdd3791b656f0f7945e68e724"/><file name="Parameter.php" hash="5bb143b2c5472570019deb5c8df7e13e"/><file name="Prototype.php" hash="e6926328f51c97152380eef1cb9503a1"/></dir><dir name="Reflection"><file name="Class.php" hash="7c3040f1cdaa12303fa3aa8a87bbee33"/><file name="Exception.php" hash="81a1918244112e6992e608c37a128f81"/><dir name="Function"><file name="Abstract.php" hash="baf97034eb2f6541a0b04448cdb0c8ee"/></dir><file name="Function.php" hash="b931e2381290e01a62197a41f7d4a43e"/><file name="Method.php" hash="2589efa5b95e88475509c07460869c1a"/><file name="Node.php" hash="a764c4cdbcfd48911882e73801f55c9f"/><file name="Parameter.php" hash="2cb12fe3fdca85cb9056909277002912"/><file name="Prototype.php" hash="c8f4e9fc01efed6ef3b5a10bab70ddc5"/><file name="ReturnValue.php" hash="bd7392e46dac77ad14597e24fbe9297a"/></dir><file name="Reflection.php" hash="7b01bebd0c5e02694d94946a7ff4cd2a"/></dir><dir name="Service"><file name="Abstract.php" hash="057d0faabba16e34faa0ed6d43ca61af"/><file name="Akismet.php" hash="c63f5c6b7b1be4b2bbedb84a7f026bf7"/><dir name="Amazon"><file name="Abstract.php" hash="16b70230ca4bf9fd43feaedc24416f7c"/><file name="Accessories.php" hash="c0f666b47ccd5ca407ca7ab3e62a28cd"/><dir name="Authentication"><file name="Exception.php" hash="f1ba0e03f16bf019c0246384f6797093"/><file name="S3.php" hash="35c859c9bf7221844df79260142e3e55"/><file name="V1.php" hash="a4f6e5db52a4ae4b8200ac26b1bc413b"/><file name="V2.php" hash="b91365a27a1019d793f3821d50cf0209"/></dir><file name="Authentication.php" hash="5e503da9b9bf0a83fd61326aabaa7bc2"/><file name="CustomerReview.php" hash="970806dbbd0244f317183a7d121dd23b"/><dir name="Ec2"><file name="Abstract.php" hash="add0a48733a5b51010fab03133fcf8a9"/><file name="Availabilityzones.php" hash="0df01ed765ce15c35a783a66d7f8ff44"/><file name="CloudWatch.php" hash="e601ca48308ac50dc3727f992f7e62dd"/><file name="Ebs.php" hash="1f82b128c7b5d35d37b3024b6c42f712"/><file name="Elasticip.php" hash="bfad9fcffa9bcd6ad7d7cff8cec45c64"/><file name="Exception.php" hash="b212f735d14f127feb9a33d220bf2261"/><file name="Image.php" hash="335cf797d7a3a3d49e029ef7ce991bca"/><dir name="Instance"><file name="Reserved.php" hash="6027f89632821d100f27363ffbf293f3"/><file name="Windows.php" hash="f823795a24808167f1b87d91ece5cd1a"/></dir><file name="Instance.php" hash="52e9fb6d557898648a7dd9c71bb9100a"/><file name="Keypair.php" hash="e035010eee1a949d1d2b5b1ddd43e5a6"/><file name="Region.php" hash="7283cb6f54f68c09949e4c0535ed8a3b"/><file name="Response.php" hash="ad34c2acb59516d6075d12294fcf6bd3"/><file name="Securitygroups.php" hash="68c70053d0e4284169a5e2c49cb2ef2e"/></dir><file name="Ec2.php" hash="4a39d1eb801af3fd096582c2428e1371"/><file name="EditorialReview.php" hash="edc54626cf681ff42bdbc3207063e50a"/><file name="Exception.php" hash="25e8e93c6e940a70c57e0d4b6b35271c"/><file name="Image.php" hash="8cb0ff1afc2b9f99b7e4db1c61c27e99"/><file name="Item.php" hash="49164d984e1888291b9a1b0b82df2204"/><file name="ListmaniaList.php" hash="d319a0d6c264c92c22196d6a9a84762e"/><file name="Offer.php" hash="a04c4d2faf859a590fe2e74ef0440429"/><file name="OfferSet.php" hash="cce61ade0766251d602204b65ad5f73e"/><file name="Query.php" hash="a8a6c152fa729f7047f352552bee7367"/><file name="ResultSet.php" hash="b15520c352dfb95481aa26509c84211e"/><dir name="S3"><file name="Exception.php" hash="2fa452933db70802a191be880cec481b"/><file name="Stream.php" hash="62544ad7a8d493023c4a62272a68d4f5"/></dir><file name="S3.php" hash="224a86bfc54f7c6df36b8d5eb3febbd0"/><file name="SimilarProduct.php" hash="abcd839cfcc6c194e0b2ee0461216e12"/><dir name="SimpleDb"><file name="Attribute.php" hash="329401b2dac2ad11141f5077093ce70a"/><file name="Exception.php" hash="72cd6853d02b6c4335292d38f310ea54"/><file name="Page.php" hash="4c6b5dda8a61a932584eaf332ba25ae4"/><file name="Response.php" hash="763d18b153c7296ae4a1acc9dd52fea6"/></dir><file name="SimpleDb.php" hash="26a2419a5c73550f8ef47ac2a7c161ce"/><dir name="Sqs"><file name="Exception.php" hash="4d8c014ecb492938b3234fb250dcc21b"/></dir><file name="Sqs.php" hash="e5a368178455cc62f0c1e6272876e31f"/></dir><file name="Amazon.php" hash="8bf9c8bd3d16372566cc6dda58d26f57"/><file name="Audioscrobbler.php" hash="0931bdaeda5594a4b367fd4901b5444e"/><dir name="Console"><dir name="Command"><dir name="ParameterSource"><file name="Argv.php" hash="6acc204436c9d0de0d1e5d2063dff1d3"/><file name="ConfigFile.php" hash="0ac0fcf2907eed649d9f720d9c98cfb1"/><file name="Env.php" hash="83579d583b977fb4a890933d5795588f"/><file name="ParameterSourceInterface.php" hash="c1161355277be3eefdadb4853d8ee1b2"/><file name="Prompt.php" hash="8a9b67aa3eaa61b7ff33aa0110b129fd"/><file name="StdIn.php" hash="fd5c89a584ce532ae64ce2e607e28e02"/></dir></dir><file name="Command.php" hash="c94204e49bc285a615c281253cb41641"/><file name="Exception.php" hash="e1a199ba28f3255efc3ad5f0c272d247"/></dir><dir name="Delicious"><file name="Exception.php" hash="8b4644f2ad354c3e8c668bf6f4d8757c"/><file name="Post.php" hash="00f3ca873d1da362fe1ed121b1d18c32"/><file name="PostList.php" hash="41dbf9ff7c15a8eaec5153cebc705bb2"/><file name="SimplePost.php" hash="9ae5bac1252734db8bda2c2cbceb901c"/></dir><file name="Delicious.php" hash="2f725816f82a4ba6ebeace7bcaf6e0ff"/><dir name="Ebay"><file name="Abstract.php" hash="2e334688b614c983b6a7ce3592e08899"/><file name="Exception.php" hash="83aa9409ac7d1e2bf9fd83e86c39a6c6"/><dir name="Finding"><file name="Abstract.php" hash="7238678f990b585b50271ceafe5058f3"/><dir name="Aspect"><dir name="Histogram"><file name="Container.php" hash="45aab272db8949fc7ef41c1f5b9a5d65"/><dir name="Value"><file name="Set.php" hash="6a00192243d8ab215f368459e932d145"/></dir><file name="Value.php" hash="ffd36e8de497a77bd42cccb63ce3235b"/></dir><file name="Set.php" hash="c39339e0e65827c882eac9fa8d4d4fff"/></dir><file name="Aspect.php" hash="df96cb57c1c2b88a8244384894f1b9dc"/><dir name="Category"><dir name="Histogram"><file name="Container.php" hash="e99d9fdf2028e7f627fa7692d6e5e5af"/><file name="Set.php" hash="d10aeaf449c591a7884a38a1b5f90399"/></dir><file name="Histogram.php" hash="5fda3e21a2a68bbca36838425d54c454"/></dir><file name="Category.php" hash="aef46c1abec0621af48a4398de94bca0"/><dir name="Error"><dir name="Data"><file name="Set.php" hash="51d6f2c75eb549150dbb4255a747e238"/></dir><file name="Data.php" hash="06579aec01d55e0e27e48b66b32814a5"/><file name="Message.php" hash="f0082bf2e41b9fa997891d55536d6c94"/></dir><file name="Exception.php" hash="0d04308f626b6d80255403034766b93f"/><file name="ListingInfo.php" hash="37689bb7f7f1312e0a8690b1ec55d17f"/><file name="PaginationOutput.php" hash="dbd144ea4155492ca485092140ed7342"/><dir name="Response"><file name="Abstract.php" hash="13c8ef07cd6c8b9e0b54b183099d3c2d"/><file name="Histograms.php" hash="7e67ea07bdf9e34cb277b87cdad8db8c"/><file name="Items.php" hash="87e78262a0463b3689f75ade1a97bf0d"/><file name="Keywords.php" hash="501b1eb2db688abcb8926a924b2467c4"/></dir><dir name="Search"><dir name="Item"><file name="Set.php" hash="72dc95aa03723a96c6ad4e16bb6c1f04"/></dir><file name="Item.php" hash="8cc709c5b81a662e1b42f6fdcfbcd057"/><file name="Result.php" hash="bde45f1eff1c6745093e1fb16a25fa21"/></dir><file name="SellerInfo.php" hash="0a3e7e31682c1b4139860b692e3a7a93"/><file name="SellingStatus.php" hash="40cc9f7feb5534c9b7ffd77cde164d8e"/><dir name="Set"><file name="Abstract.php" hash="d68b570966c8c13d07ecc8e1c093a3f8"/></dir><file name="ShippingInfo.php" hash="ef20bffb5c3917bd631a79f6520aaa47"/><file name="Storefront.php" hash="59e0796869417ef09b2fabf17a0f51a2"/></dir><file name="Finding.php" hash="38297aa7141bd29cb58f499a6f301958"/></dir><file name="Exception.php" hash="065ed88e73a47544f5432781b553b095"/><dir name="Flickr"><file name="Image.php" hash="c18c420085a325a88aa32c6e8940febe"/><file name="Result.php" hash="3dae64d1fed5642f400e5a3ed34001e0"/><file name="ResultSet.php" hash="1141813d476af74ac4482982352df257"/></dir><file name="Flickr.php" hash="80ee3a6a56f644931629923efaa74f58"/><dir name="LiveDocx"><file name="Exception.php" hash="b7c0f8f23822ab34863ae7c8ba65fca0"/><file name="MailMerge.php" hash="9c3df9f5097d2426f98f3e4afd5417b2"/></dir><file name="LiveDocx.php" hash="bb79b5d68e67e91aa7c6678cf9d33fe5"/><dir name="Rackspace"><file name="Abstract.php" hash="38c670e3ba06278b4fed19a7a20ffa09"/><file name="Exception.php" hash="0e02a57f8eb16972b101ec5b2d5ee5c8"/><dir name="Files"><file name="Container.php" hash="59b5965b06c12c8f32f191d6d81578ed"/><file name="ContainerList.php" hash="60cab750d4475f791b0f6ef9487b2b5f"/><file name="Exception.php" hash="ff4c1a6d5b3c15b0134eea798aaebb5a"/><file name="Object.php" hash="fa7d117f207e2a26dfa5db744a098cdf"/><file name="ObjectList.php" hash="d2eaf4ebe570b3ca456844b294cfc6f6"/></dir><file name="Files.php" hash="fba4bd666821a5eec5cf17f5f91dd15a"/><dir name="Servers"><file name="Exception.php" hash="90e7248491ba6728731b35821a6797b3"/><file name="Image.php" hash="6977cee9fc642f32c2a3dd9b99739ab6"/><file name="ImageList.php" hash="0bc789d18d41f62ae1db82159487edc0"/><file name="Server.php" hash="73f6c2a5e062bf36b3b89ed8d1041eaf"/><file name="ServerList.php" hash="f76bf22857872982ce35e7afa2ea49f1"/><file name="SharedIpGroup.php" hash="75bc0d1b089228114a5bdbbc764f6799"/><file name="SharedIpGroupList.php" hash="97feec662c70d87bf02c0dd689d59962"/></dir><file name="Servers.php" hash="d7c9cd6f524ef033e9c4836623171ad4"/></dir><dir name="ReCaptcha"><file name="Exception.php" hash="e49c53a3c431f49911028b571a76bc06"/><dir name="MailHide"><file name="Exception.php" hash="fc56e06dc9697c40498f1015c0e76c08"/></dir><file name="MailHide.php" hash="ff143c31b0aaac1c852ae438ccc57a4a"/><file name="Response.php" hash="10d73062279da9040e445fe8d1820c36"/></dir><file name="ReCaptcha.php" hash="518a917f321d64422010babcdc82921a"/><dir name="ShortUrl"><file name="AbstractShortener.php" hash="7e0fa90e0324b377677bd8847412ffa5"/><file name="BitLy.php" hash="3e07fa8e265d44e7225af2f11ac75607"/><file name="Exception.php" hash="fa58bd8ee297581ecafe8e15d9c41858"/><file name="IsGd.php" hash="5d18b0c134f1da253893391c720144e7"/><file name="JdemCz.php" hash="6892d0e3e81cc3aeca234d4fb5164ac5"/><file name="MetamarkNet.php" hash="747c5d10917401f1d0d11ba38b1af8e2"/><file name="Shortener.php" hash="64e2ceca93f66c375605e62d6431a628"/><file name="TinyUrlCom.php" hash="1b7f09510d1b029c117e6c59c5419714"/></dir><dir name="SlideShare"><file name="Exception.php" hash="67b547c02b4b9c9440f5c11e570171f1"/><file name="SlideShow.php" hash="9d01060ec6c7a7583a21c824a3e74e21"/></dir><file name="SlideShare.php" hash="1cdc74e57a3be59df8d702bc3d9f7362"/><dir name="SqlAzure"><file name="Exception.php" hash="24d9e2d3dfca7d6ce54137652027152c"/><dir name="Management"><file name="Client.php" hash="e46b9564db9ae2344357919b4760ac4f"/><file name="Exception.php" hash="731e875bfd4df360b37ca082877bc1c6"/><file name="FirewallRuleInstance.php" hash="f564f5454ee9cb2b1ffa97499124d0e7"/><file name="ServerInstance.php" hash="7f3198f120d54ca4b70b5f58399cf0ab"/><file name="ServiceEntityAbstract.php" hash="72ca3fc5ef5341bf549685beb08dad5f"/></dir></dir><dir name="StrikeIron"><file name="Base.php" hash="0b1451704136ab44598ac7204bde94a1"/><file name="Decorator.php" hash="68741c986d506462846a6aa007f94cef"/><file name="Exception.php" hash="e61ee74d3ae19b3e61c1894264d6530a"/><file name="SalesUseTaxBasic.php" hash="43823d20d58aaf73be598f5282e7f841"/><file name="USAddressVerification.php" hash="f5dd585a282a046ebfb95125c29ed866"/><file name="ZipCodeInfo.php" hash="76beb6125d1035ffd7e67101cbd9df44"/></dir><file name="StrikeIron.php" hash="7eca35cee7479ac035ec83f456ddb2ec"/><dir name="Twitter"><file name="Exception.php" hash="d5a3fb65437ac5663d5262b19c226483"/><file name="Response.php" hash="f78d457745cd7df85d83b33e9b43a01f"/></dir><file name="Twitter.php" hash="8b3dc7c575b35c1351a9a00afd1b57c5"/><dir name="WindowsAzure"><dir name="CommandLine"><file name="Certificate.php" hash="82f6c9535209f9d9800b1ec5227ea5a8"/><file name="Deployment.php" hash="d77fb324a62e1d5bbec2ce07dbcd6051"/><file name="GetAsynchronousOperation.php" hash="da2b5c820d693a4fdcdc5f53378a317c"/><file name="Package.php" hash="4ed8d218b529fa358b9bad365caeda1c"/><dir name="PackageScaffolder"><file name="PackageScaffolderAbstract.php" hash="077b5928c2f1ff061f447754e17051c9"/></dir><dir name="Scaffolders"><dir name="DefaultScaffolder"><file name="build.bat" hash="651c7fb8b72233f40f4f25ca8905573b"/><file name="index.php" hash="894c44229a940ea713205338f8e490f7"/><dir name="resources"><dir name="PhpOnAzure.Web"><file name="Web.config" hash="65f639e413e4ff122d92623a1c14b2ae"/><dir name="bin"><file name="add-environment-variables.cmd" hash="b0e00d591398ec40968189bc4e35c139"/><file name="add-environment-variables.ps1" hash="19a5afae543fd10d118ad21136fc4bec"/><file name="install-php.cmd" hash="8248bad7c6981ab8f8ad34cbb6e224c3"/></dir><file name="diagnostics.wadcfg" hash="5188e0200f5446cae89c1be78db568c2"/><dir name="resources"><dir name="WebPICmdLine"><file name="Microsoft.Web.Deployment.dll" hash="ce4bedba97839fb3b3991c9e76d9a5f8"/><file name="Microsoft.Web.PlatformInstaller.UI.dll" hash="c692c64ac1ff35a256b05b3d0389d77a"/><file name="Microsoft.Web.PlatformInstaller.dll" hash="b3c7917c493dc73aab9ad4f3b32d3722"/><file name="WebpiCmdLine.exe" hash="23ee0847ce84831042e2094f8bb946a7"/><file name="license.rtf" hash="e19c7c8161a0d2cf8cd2bfa815edd707"/></dir></dir></dir><file name="ServiceConfiguration.cscfg" hash="aef39d43590593be9d2fe5fe4a3b5c80"/><file name="ServiceDefinition.csdef" hash="cc148db5e38df6777513c343f0552408"/></dir></dir><file name="DefaultScaffolder.phar" hash="7213da0e7d624e8c2a4ba1f3b5ff05eb"/></dir><file name="Service.php" hash="ff88b79b64947f883986e77838d8cb24"/><file name="Storage.php" hash="8944ded3eb414aa4826b6f53040049d9"/></dir><dir name="Credentials"><file name="CredentialsAbstract.php" hash="d4f022ee969ebb28059bb4fe1dc15bbd"/><file name="Exception.php" hash="46253077f849f4d86ff19bcd5c4ffbb2"/><file name="SharedAccessSignature.php" hash="b812dfc04bcc4349faa4b684e3c17ffe"/><file name="SharedKey.php" hash="d09970fb25d6649fc3626d016e57a71a"/><file name="SharedKeyLite.php" hash="a7af3a465e3b62edddd79fcfb8b5bfd0"/></dir><dir name="Diagnostics"><file name="ConfigurationDataSources.php" hash="164e443f79bf6b018796cbe4ace8552e"/><file name="ConfigurationDiagnosticInfrastructureLogs.php" hash="5ed3b44951c19fe3899d77e57777ccca"/><file name="ConfigurationDirectories.php" hash="ac9628ef7d6d5291b4a9755ffa83c4bc"/><file name="ConfigurationInstance.php" hash="2ffcb3db9f9ecfe5764d497f08175c1c"/><file name="ConfigurationLogs.php" hash="79cb3324521884a79c422318e9df0996"/><file name="ConfigurationObjectBaseAbstract.php" hash="574ad31edf5de775857d4d9818e09515"/><file name="ConfigurationPerformanceCounters.php" hash="f518fc30a51d61ee73f44fd54304d115"/><file name="ConfigurationWindowsEventLog.php" hash="7b071634e38e532d5faf245310846396"/><file name="DirectoryConfigurationSubscription.php" hash="5c72f815ecb4a4b619a43b05e0767d3e"/><file name="Exception.php" hash="ecc6ffb64bcd2b7e219b9e57ae8261c4"/><file name="LogLevel.php" hash="b63f1b837619bd6475f30b5c2862354b"/><file name="Manager.php" hash="0d92a4ee3426b0a3fa98efabad20850e"/><file name="PerformanceCounterSubscription.php" hash="f3793033b70429e761b5715d26a9b052"/></dir><file name="Exception.php" hash="ae2961639357d61fd0edbb1f8b19e600"/><dir name="Log"><file name="Exception.php" hash="f293efa4c7d400034fdd32b61e398d75"/><dir name="Formatter"><file name="WindowsAzure.php" hash="d2803e471ad8f151337b9b06adf840e2"/></dir><dir name="Writer"><file name="WindowsAzure.php" hash="898cc3aab9ed4a1143ad98af4c82828f"/></dir></dir><dir name="Management"><file name="AffinityGroupInstance.php" hash="999fccb597ded5e9bb1a3a49d0461238"/><file name="CertificateInstance.php" hash="e38186727c337efeb26e1edb3395c3aa"/><file name="Client.php" hash="7ea9a8aeec1b66c29127ce846788caeb"/><file name="DeploymentInstance.php" hash="da71eb3b750c5accba7df6a02a936572"/><file name="Exception.php" hash="e38e9729e738a5c98b7a444377dc390f"/><file name="HostedServiceInstance.php" hash="52a7a4f5e90fcddbba2da67f6ec1a714"/><file name="LocationInstance.php" hash="d7fc5f02f835fbea9bd39e25a2953415"/><file name="OperatingSystemFamilyInstance.php" hash="5463dc6555a2894cf77c15dd015b2bbe"/><file name="OperatingSystemInstance.php" hash="8d8fc32400bbb73a3765f06ccaefc05f"/><file name="OperationStatusInstance.php" hash="acb817c0203ca17237b430c7d086b7b3"/><file name="ServiceEntityAbstract.php" hash="6013b8d4f6378d945e29013d54dc634f"/><file name="StorageServiceInstance.php" hash="6d89ea4e90ac780fce17efba7e38976a"/><file name="SubscriptionOperationInstance.php" hash="9fb50cd722cc80be2d660e78cd42d3de"/></dir><dir name="RetryPolicy"><file name="Exception.php" hash="b83b70d8c828de010cfa12f027a2da23"/><file name="NoRetry.php" hash="faa7ed56468ce39f77162aa1888f8480"/><file name="RetryN.php" hash="340d6ccaa8d41eba0f3cd943dbff201b"/><file name="RetryPolicyAbstract.php" hash="57b861c1f66f83295ce1ae8284b6870c"/></dir><file name="SessionHandler.php" hash="49abc2db2f8cd60249889013eeb6c28f"/><dir name="Storage"><file name="Batch.php" hash="54321d9853919241064631b7fd5e404a"/><file name="BatchStorageAbstract.php" hash="1911d06beacc5afdee2e0214fadb48f7"/><dir name="Blob"><file name="Stream.php" hash="fca729afd6bced397324a092598c4348"/></dir><file name="Blob.php" hash="ba54d4c7b42bfb8536df0ace27d68ac5"/><file name="BlobContainer.php" hash="3762000f605bc3b601d33508d11ba9cb"/><file name="BlobInstance.php" hash="3acc55cc558e3003164dde92463f0f74"/><file name="DynamicTableEntity.php" hash="c0f1e5b79b12857c233299a4445bb168"/><file name="LeaseInstance.php" hash="3d0fc9b5d6808aec75d9aa5bfb537e3d"/><file name="PageRegionInstance.php" hash="ad3d6fda6950c0f1fa6516507ca9662b"/><file name="Queue.php" hash="e0f744f5a2c30c4368babc77282987d1"/><file name="QueueInstance.php" hash="fc1d2fe33c92b9709174fdb78b014839"/><file name="QueueMessage.php" hash="1743f7a02f0d443c7a2f85d87dc43e0f"/><file name="SignedIdentifier.php" hash="cd0fa8a05e3acd402a1e337b1ca7eee0"/><file name="StorageEntityAbstract.php" hash="f3ef81a6dbd64aea38bc60b1f0c7bb8b"/><file name="Table.php" hash="3264067c6ef982f7bb216234451f5781"/><file name="TableEntity.php" hash="c9be1c41776a2ae5892d8f8d14b74fd6"/><file name="TableEntityQuery.php" hash="13880ce0f4c805205dcd10a5283c0539"/><file name="TableInstance.php" hash="54f43c27f93bee83a2c9ba42831d9c27"/></dir><file name="Storage.php" hash="cbac5a9bb9efb6e93a3d9871c8699035"/></dir><dir name="Yahoo"><file name="Image.php" hash="aa6abfa0f447d43f4828dc44c0fdf86f"/><file name="ImageResult.php" hash="7a64eac529ce21090e8b58997fc22041"/><file name="ImageResultSet.php" hash="7ad19487bce9a09855cf7d79707af347"/><file name="InlinkDataResult.php" hash="28305ce865dfb4011a285015a40a6a83"/><file name="InlinkDataResultSet.php" hash="fb09080f12f5348b37fdd5d62fc946fc"/><file name="LocalResult.php" hash="306431d361c2097b3b00cdbaba1bb372"/><file name="LocalResultSet.php" hash="68a4cb69982884c1bd7d6a7df86be90b"/><file name="NewsResult.php" hash="ea496bdeee3021d391df58a3be8636af"/><file name="NewsResultSet.php" hash="f80bcd0b1ac7632f3fb3020a7ff83255"/><file name="PageDataResult.php" hash="c8ea663819efe5ec5d374463f04a8f39"/><file name="PageDataResultSet.php" hash="69c99f8806a98868cb77e9db268eb8d8"/><file name="Result.php" hash="221286f5fbe491b570df8cec1fb7c91c"/><file name="ResultSet.php" hash="4477af82dcaac7fcd93ce9c29c68bdd5"/><file name="VideoResult.php" hash="6ba0d1ebb1c288b11b17ff6a9e434a4d"/><file name="VideoResultSet.php" hash="1a434e1b8bcf9b32e755a32e97e52838"/><file name="WebResult.php" hash="eacd11e6aace9570c6064c8fc1b47750"/><file name="WebResultSet.php" hash="bf5f6f43eb71f0469c961b0f5a6e4094"/></dir><file name="Yahoo.php" hash="27616706be89313b7b5be256be21e095"/></dir><dir name="Session"><file name="Abstract.php" hash="b43880e48ff9ee3040eca09d1458f7d5"/><file name="Exception.php" hash="ce01f1ceaa96bef8c71759f7e6c1e578"/><file name="Namespace.php" hash="b3e6effe8f53d5f9f407a4b5507df31c"/><dir name="SaveHandler"><file name="DbTable.php" hash="5b08339aa3e7f044b5602e725e6c65c0"/><file name="Exception.php" hash="06db90dee9421e4a8e09b946de252d41"/><file name="Interface.php" hash="617704bf38e31d51b79c636480447b91"/></dir><dir name="Validator"><file name="Abstract.php" hash="7bc8436592d308a702f37d64a8afbe72"/><file name="Exception.php" hash="c00d9dfbc04a9250f2359a5f31e726b8"/><file name="HttpUserAgent.php" hash="6a2a83e6baf37967b06cf993170ed03e"/><file name="Interface.php" hash="6e54358cefb41ccb7e591eaba391f74e"/></dir></dir><file name="Session.php" hash="da8c2bc8217bb09a7e86c573fa7a6553"/><dir name="Soap"><dir name="AutoDiscover"><file name="Exception.php" hash="3c71353889e5488f16cd0747a1337882"/></dir><file name="AutoDiscover.php" hash="abdfc4afb277a6e0c23216cb1d894dd1"/><dir name="Client"><file name="Common.php" hash="4c196fc850f65702741c044d12507769"/><file name="DotNet.php" hash="61bacfc1a99fabb15c58d5499c064c72"/><file name="Exception.php" hash="fe48793a358a7201ad7faee3a077a7db"/><file name="Local.php" hash="843caaab790dc3a322e570cae31dfda7"/></dir><file name="Client.php" hash="bb395c77d4e6ca127f48e15953c72f90"/><dir name="Server"><file name="Exception.php" hash="b5366c6128550c6904b5f0d83d9a4495"/><file name="Proxy.php" hash="4e3e39bf6b40e758bb8154900c0be4ae"/></dir><file name="Server.php" hash="2d3adb7e3b01a55889f4a9ccd1226758"/><dir name="Wsdl"><file name="Exception.php" hash="c30308763d2f85ccde3e48c399d977fa"/><dir name="Strategy"><file name="Abstract.php" hash="f09e005c0c35a51dbc906815f298a515"/><file name="AnyType.php" hash="7e0f81e8c1bde45bd858ae5c16b4cd11"/><file name="ArrayOfTypeComplex.php" hash="3b9998427588b55e16496ee51a1d7d5d"/><file name="ArrayOfTypeSequence.php" hash="8ea1226e6138e1d162b647b39daed36d"/><file name="Composite.php" hash="7ea40da650826369c79e7a17ff93da40"/><file name="DefaultComplexType.php" hash="9fefac807dbb4c843feec714a05ac521"/><file name="Interface.php" hash="d4f3ed1447d163ae1eedcfc886662719"/></dir></dir><file name="Wsdl.php" hash="8e4ad5d4d160d770740012ec920e30de"/></dir><dir name="Stdlib"><file name="CallbackHandler.php" hash="f33bb03784021305a529525bf125df09"/><dir name="Exception"><file name="InvalidCallbackException.php" hash="977bd070fc4de8c0bce940a2d0a0c530"/></dir><file name="Exception.php" hash="826ef583632fe8b71ce0916ce4c01030"/><file name="PriorityQueue.php" hash="886161c12418c95bda548c5e484db351"/><file name="SplPriorityQueue.php" hash="4ce44425f16b61d5cfa2b37a36c430b9"/></dir><dir name="Tag"><dir name="Cloud"><dir name="Decorator"><file name="Cloud.php" hash="c03f8a8a9acad9b124508cb5ec762ef6"/><file name="Exception.php" hash="da2286643dd90128c9bafdb55d4874d9"/><file name="HtmlCloud.php" hash="ac29df72f5738876b6c5c3220200aea5"/><file name="HtmlTag.php" hash="1c66e72d27e394b7a67e083a6a7e7635"/><file name="Tag.php" hash="38969d4df8dd12f7c75d5886a4309e2d"/></dir><file name="Exception.php" hash="f1f89e1176804f89966ffa1b6057aadc"/></dir><file name="Cloud.php" hash="b563d184a10c5780ac839964d05f5b70"/><file name="Exception.php" hash="bb95c48a0889e48b9621fc24ece1855d"/><file name="Item.php" hash="4d8899476ff7c0edc26227377437184a"/><file name="ItemList.php" hash="a37b92d4346128d6928c3ed75abe85e3"/><file name="Taggable.php" hash="754d26825a791b7b493479ab96de35ac"/></dir><dir name="Test"><file name="DbAdapter.php" hash="9f14c0c71238db11ce231ec608fa0748"/><file name="DbStatement.php" hash="ae071a2e217641e4431dbaffab4b475c"/><dir name="PHPUnit"><dir name="Constraint"><file name="DomQuery.php" hash="4a372f65097fddc842326acfb0873110"/><file name="DomQuery34.php" hash="4cfc2fccf97dcad8979afdeb5051d99d"/><file name="DomQuery37.php" hash="4918ef15cdbf82e30ee35bce62246f6a"/><file name="DomQuery41.php" hash="0e55e6f6ec4df95712cf6ae2592eaa4d"/><file name="Exception.php" hash="08a569be3229aa317e045e0bb5712aee"/><file name="Redirect.php" hash="bd29ebef3a5193019124cbe48e3b57a4"/><file name="Redirect34.php" hash="7fbaaf229a5e72fd9328b6b3355979e0"/><file name="Redirect37.php" hash="25ae9936724abf4f6c655e79a4b017a7"/><file name="Redirect41.php" hash="b15f5d011531a5f341691400758b7b94"/><file name="ResponseHeader.php" hash="d0c824d1d0825eaff50fbff17ad9fe68"/><file name="ResponseHeader34.php" hash="970159fe86220f6d79ae839787445e76"/><file name="ResponseHeader37.php" hash="b45fcfbc270c1dc1be8af6f967d74055"/><file name="ResponseHeader41.php" hash="d898287c0e3c5c5a29c8dfc23258c357"/></dir><file name="ControllerTestCase.php" hash="a1587e2519d6a108213338a8df626983"/><file name="DatabaseTestCase.php" hash="e660d4e0b896a1349b5b3a7b908abed9"/><dir name="Db"><file name="Connection.php" hash="a376a28b4f32640b77896ed71aa94103"/><dir name="DataSet"><file name="DbRowset.php" hash="619ddf7996bdbae5efe2667bf43f97fd"/><file name="DbTable.php" hash="c2f9df7d0a3cf0d37631d8f06c818bc8"/><file name="DbTableDataSet.php" hash="d4399f69a07e07e1cdf51ee779ed4d25"/><file name="QueryDataSet.php" hash="9923dfa4b4f6ec969e05af835f0c9578"/><file name="QueryTable.php" hash="49db01b854018eed9f97f9e87dd8ef99"/></dir><file name="Exception.php" hash="b4db1bec052e5f4326e4f69f8265b1f6"/><dir name="Metadata"><file name="Generic.php" hash="0d50fe34d4d444504a433c495a10f4c7"/></dir><dir name="Operation"><file name="DeleteAll.php" hash="ad2d32c7274f19ffd7ff00f6a9629831"/><file name="Insert.php" hash="76990ebfd7da444a380ef153fd4ec2c7"/><file name="Truncate.php" hash="aeb7cea4a23f9a4978838834184b827c"/></dir><file name="SimpleTester.php" hash="303a002e44573654515318426f06454c"/></dir></dir></dir><dir name="Text"><file name="Exception.php" hash="63dc12adf35209b68cb541fad9d13339"/><dir name="Figlet"><file name="Exception.php" hash="ce4743f212bc9dd406e7c5abd1499a8c"/><file name="zend-framework.flf" hash="e421545f78033d8a6a4324e54ccf0454"/></dir><file name="Figlet.php" hash="342b1851f3fddf6de881bfdcd6dbdc25"/><file name="MultiByte.php" hash="7beb126807547c59a29ff72918ce4cb6"/><dir name="Table"><file name="Column.php" hash="cb652d404e394051bb9463ef0f5e5fac"/><dir name="Decorator"><file name="Ascii.php" hash="642655dbd861110617fe242a5f5b2e49"/><file name="Interface.php" hash="b246cf5bf0cc2ccb3fd612987dda1ac6"/><file name="Unicode.php" hash="78c514875a100d295a884d52cbff6679"/></dir><file name="Exception.php" hash="a9ad309358591313a0b39a9dc6637ead"/><file name="Row.php" hash="2e1210709f13f36070015bf1e7c4bae8"/></dir><file name="Table.php" hash="fa040e017955cd19728968adc4d3263a"/></dir><dir name="TimeSync"><file name="Exception.php" hash="c5c88b4fa22c7aa853c99e80293d6b56"/><file name="Ntp.php" hash="670a72b056bc3ea5c6ca09fd51e5c0d1"/><file name="Protocol.php" hash="81ebccdcfad278c458e8f801743e8035"/><file name="Sntp.php" hash="f491dc0e0e4ad0a6909cc9518c443855"/></dir><file name="TimeSync.php" hash="e68ddd486d397ad8b8072df003f0dbe9"/><dir name="Tool"><dir name="Framework"><dir name="Action"><file name="Base.php" hash="ca10276b0b663e3946f30a7e85e2437a"/><file name="Exception.php" hash="033fe3dfcbe687a8fc14217124485646"/><file name="Interface.php" hash="4971f7cd01f81557e06c52442d1e10ec"/><file name="Repository.php" hash="763980637bc854efdabe4702cf90429a"/></dir><dir name="Client"><file name="Abstract.php" hash="c6aa9afeb508a90fac77fdd01490c917"/><file name="Config.php" hash="88d068ae943aaa028252208d2ffa9737"/><dir name="Console"><file name="ArgumentParser.php" hash="a7aca2e438a4ea02beea9efe4fc322e6"/><file name="HelpSystem.php" hash="c49dfb3e52bc4dbd0fb981d2d2db7ea0"/><file name="Manifest.php" hash="8ecaf5471c98b4adecf441fd0b239fd1"/><dir name="ResponseDecorator"><file name="AlignCenter.php" hash="aea5fb29315c501c879f1414ab30bdf1"/><file name="Blockize.php" hash="f6510cb7f02bdd000eff5b3cfc7c3f94"/><file name="Colorizer.php" hash="b4370450e0af8f8bc5b70bca3a3140e4"/><file name="Indention.php" hash="9d05c40f3bcf99606a4433c4f2f550c8"/></dir></dir><file name="Console.php" hash="70d696d68e6f889e25661568ae0cafef"/><file name="Exception.php" hash="9fc08df23e990977b31c58157458797f"/><dir name="Interactive"><file name="InputHandler.php" hash="d4a71d517cbdfca13bc442f915eadfa3"/><file name="InputInterface.php" hash="b76636ebb7563e128e1653de60a05e47"/><file name="InputRequest.php" hash="01746459e3c0d5114ba84376641ce516"/><file name="InputResponse.php" hash="fe6fb87211d75ac5d43a0afcd12b3438"/><file name="OutputInterface.php" hash="e6473dcec31887ba9fc189cf5ac4b5cb"/></dir><file name="Manifest.php" hash="a04f5f7452adbe2a7b9f572753c282e1"/><file name="Request.php" hash="337a50f6b8ca0346335666825a138400"/><dir name="Response"><dir name="ContentDecorator"><file name="Interface.php" hash="f5f2e4d82017c916a98e600c0ecf10fa"/><file name="Separator.php" hash="0bdedce341d3dc2456856bedb4e6fbfd"/></dir></dir><file name="Response.php" hash="047455ac32ab5c1f0913bd8be80408e2"/><dir name="Storage"><file name="AdapterInterface.php" hash="cbe1be24e10113b8355be82c17257d74"/><file name="Directory.php" hash="7f818fcabc4dd64292ec750d69a2cab2"/></dir><file name="Storage.php" hash="e1e34565e6f12ef7a6914bea4f21b495"/></dir><file name="Exception.php" hash="e8ab7ccbf5e2a5516a35ca4e887b1f5e"/><dir name="Loader"><file name="Abstract.php" hash="ac9b19649683e89c14f162643680d6d2"/><file name="BasicLoader.php" hash="eb441f57c872d051c8bf4ff334516776"/><dir name="IncludePathLoader"><file name="RecursiveFilterIterator.php" hash="e809fc3ffb30c42bd65defb0b841d5ea"/></dir><file name="IncludePathLoader.php" hash="ba1fdc0c41d1ac3ac9b86f7b295d62fe"/><file name="Interface.php" hash="5a982ccd517b7fa2c5d1e7a181f9a66d"/></dir><dir name="Manifest"><file name="ActionManifestable.php" hash="6b75a1363ec0989198f0577519f2a8d8"/><file name="ActionMetadata.php" hash="55c5c7fd4609c3a2c188c68f2b59996b"/><file name="Exception.php" hash="e4adb9a694c21dd46682009e1a25ba80"/><file name="Indexable.php" hash="f2fdb04e846a873a00178d44dfb7c134"/><file name="Interface.php" hash="65fb779fcdd624b743e1c70370ce1a2f"/><file name="Metadata.php" hash="79d13b52ad9aa5bffe103b61a404296e"/><file name="MetadataManifestable.php" hash="2974762fdea9eec82a74a6d3446f676a"/><file name="ProviderManifestable.php" hash="3d59e772c55a5a791844910d9acbb131"/><file name="ProviderMetadata.php" hash="b1fa45e3f1309e25c3e71e43e1a48263"/><file name="Repository.php" hash="b055ec6bcaa48d3536f376c7d196052b"/></dir><dir name="Metadata"><file name="Attributable.php" hash="3a1ae646ad3127bcd9d7f0b590b49d75"/><file name="Basic.php" hash="f8e243b4883d1f53ef6dd440c0d8b618"/><file name="Dynamic.php" hash="2ae310d375a9f1e29f0322c03350b718"/><file name="Interface.php" hash="dd418e0cfd979aa8caac73abbe8d65d7"/><file name="Tool.php" hash="d4cf6475ece71a871144a646c4653b88"/></dir><dir name="Provider"><file name="Abstract.php" hash="54efa5905a09985cfc5261116cdc808f"/><file name="DocblockManifestable.php" hash="0bb7be516c01ef1df2db65cac6782604"/><file name="Exception.php" hash="8340027bd3f883ce3bc60e5a4a779e1c"/><file name="Initializable.php" hash="21203810d42fc2c661b5a74a4db22afd"/><file name="Interactable.php" hash="1645bf6768d35a154b409e9fc8d23629"/><file name="Interface.php" hash="5acbcaa43439912bfc3f9be9aae48561"/><file name="Pretendable.php" hash="7320be8f080b47a7a3c7768ed5b82655"/><file name="Repository.php" hash="06ac616d5eca5d9769ad7d1d1a7ca9bc"/><file name="Signature.php" hash="5be099c081171cd11a6c5e6a80011f2c"/></dir><dir name="Registry"><file name="EnabledInterface.php" hash="87fe89d72c54ad50ec51bb2d683d2992"/><file name="Exception.php" hash="eccc229c4505a1ed3e85902496e1935e"/><file name="Interface.php" hash="85731cc24ee6598ac544956ba02a4847"/></dir><file name="Registry.php" hash="430ca6afc053d09a02faafa778f05ddc"/><dir name="System"><dir name="Action"><file name="Create.php" hash="ece59a9bf0b39f4c7731dd2c3c6a3687"/><file name="Delete.php" hash="93a02ef0a268f9a46140122e6b658831"/></dir><file name="Manifest.php" hash="2dc6db96a2eaec2f041f73eb9784426e"/><dir name="Provider"><file name="Config.php" hash="0f0ac44a62caaea96bdd741dc8d10fe1"/><file name="Manifest.php" hash="9834badd5250276130dd8f035fa3aa69"/><file name="Phpinfo.php" hash="a18c9de3ae3099a941d257fd8bb83286"/><file name="Version.php" hash="235916637c0ec94a08f86894dd211da4"/></dir></dir></dir><dir name="Project"><dir name="Context"><dir name="Content"><dir name="Engine"><file name="CodeGenerator.php" hash="28294bea1645211c3a55b04b03eb97e5"/><file name="Phtml.php" hash="b635fe45ef2a8b9de27be338ff80e0c8"/></dir><file name="Engine.php" hash="3edec5f50d35068768bd1ddb7cfcb242"/></dir><file name="Exception.php" hash="903019115f2291dac64e2d8316b069d0"/><dir name="Filesystem"><file name="Abstract.php" hash="7de036baa7d7a11fde54ba3d0d9e199c"/><file name="Directory.php" hash="346bbbf87ee7515d0b1ea6d468a23bbb"/><file name="File.php" hash="82a28fef9d3d33f3de763e2f4415ef66"/></dir><file name="Interface.php" hash="ec12cc9de36ab46a2afb96f61f3af90e"/><file name="Repository.php" hash="652c4bea315e3239fd99f22103c51140"/><dir name="System"><file name="Interface.php" hash="9011f3458a2b39fdf8867e639414a7bc"/><file name="NotOverwritable.php" hash="de0a563d5079199bf642b6811b7e5bac"/><file name="ProjectDirectory.php" hash="f5d33f4805cc35574112532f2f262579"/><file name="ProjectProfileFile.php" hash="48ff62386762440129ae4fb7337deb2f"/><file name="ProjectProvidersDirectory.php" hash="b5a9d7bba0ccd8554ca26f0149128acc"/><file name="TopLevelRestrictable.php" hash="2309be1ddaf737de9b7adafa6cb8632a"/></dir><dir name="Zf"><file name="AbstractClassFile.php" hash="22a8a9cc341edc796112df20983a43bc"/><file name="ActionMethod.php" hash="2f16d745e3a323f9ff416e2217358f54"/><file name="ApisDirectory.php" hash="0b39c81c051cc37f5492df965835eba1"/><file name="ApplicationConfigFile.php" hash="677abcc2fc67896b511af1f1181a8f81"/><file name="ApplicationDirectory.php" hash="42a08abbb3ecc267cd883a87f817981b"/><file name="BootstrapFile.php" hash="b76b4cf58705698399d06e8d4c9f6d67"/><file name="CacheDirectory.php" hash="5bb06a72dcd025a283c76c03a1ce9599"/><file name="ConfigFile.php" hash="2462d7d79f673c397d3a2f7284ccde66"/><file name="ConfigsDirectory.php" hash="b1cccd4669781cc33b9171a186236219"/><file name="ControllerFile.php" hash="090e5fe4d3b57933b9e7aed8eeef7cc5"/><file name="ControllersDirectory.php" hash="8543ca965e6d7a4cf78177ef0dcfc4eb"/><file name="DataDirectory.php" hash="5f8d27eca9e789c24dc039ea0f62748e"/><file name="DbTableDirectory.php" hash="92eda9ff83054cc8818bee744ed6e463"/><file name="DbTableFile.php" hash="b936fc7a4dd1e4726f0bb49f01ad931a"/><file name="DocsDirectory.php" hash="f58949c95502bd2ff8c31c59009c92b5"/><file name="FormFile.php" hash="b35ea0268fe07098b794eb24082ef53b"/><file name="FormsDirectory.php" hash="ffe9f7939c29068e7a1932dbc374bb7b"/><file name="HtaccessFile.php" hash="8e933afd24df22e6742aa972f8fc470d"/><file name="LayoutScriptFile.php" hash="8bd850a37a308efa3f4c83927fa5d8f5"/><file name="LayoutScriptsDirectory.php" hash="036f5cc0c38ead9183f7dd3f712848e6"/><file name="LayoutsDirectory.php" hash="c86cd320a91a46d439e4b419bd8ee428"/><file name="LibraryDirectory.php" hash="29a3c5283210c444e65284206b3da79c"/><file name="LocalesDirectory.php" hash="029c2897885aa476bd4103c48894ca87"/><file name="LogsDirectory.php" hash="3ee80aca0572bb9c5f6a44c6c021fcdc"/><file name="ModelFile.php" hash="958ed1603c25bd34ceb3f09ceeb6746f"/><file name="ModelsDirectory.php" hash="82dde848d95e686be57804162c11dc63"/><file name="ModuleDirectory.php" hash="7e219e82a6349ed878042cc17ee1faf5"/><file name="ModulesDirectory.php" hash="00182e9148959046c0a7d2d6e261e0b1"/><file name="ProjectProviderFile.php" hash="f3deaf3adf5c501237f22dc653430f91"/><file name="PublicDirectory.php" hash="e93bb7ed0ef00a864c097993ae1a2a94"/><file name="PublicImagesDirectory.php" hash="d769f00ec21961d66b41fffc8035277e"/><file name="PublicIndexFile.php" hash="4d3cf05ca9d35e24242dbf61d8189579"/><file name="PublicScriptsDirectory.php" hash="ff61ddca598a5ce42907b78140187614"/><file name="PublicStylesheetsDirectory.php" hash="8262d74f0f35523a912d95dd261fbc18"/><file name="SearchIndexesDirectory.php" hash="5ddf8701c47bcc6baf68cfdcc0ff7467"/><file name="ServicesDirectory.php" hash="825c4204f9f44f2280de370b0b156733"/><file name="SessionsDirectory.php" hash="af2fd72fa2bcf4d003c0a6368953cdb7"/><file name="TemporaryDirectory.php" hash="46790ecd95da8518c80dd8715fe7f8ad"/><file name="TestApplicationActionMethod.php" hash="4bbc3a869e69c2093bfa02068b6e057b"/><file name="TestApplicationBootstrapFile.php" hash="6f335bc4e4e047c948e77e8b0708f45e"/><file name="TestApplicationControllerDirectory.php" hash="1976699a04927fa3f5a1686934cdd08e"/><file name="TestApplicationControllerFile.php" hash="8f2956d50a3ba47f0b8c1fa96b361025"/><file name="TestApplicationDirectory.php" hash="09f0536bc206b5305862a21b65301016"/><file name="TestApplicationModuleDirectory.php" hash="da78a9b90b270578a9d36f8d62575a2f"/><file name="TestApplicationModulesDirectory.php" hash="4b54130f6c22e995308da7138d85330b"/><file name="TestLibraryBootstrapFile.php" hash="d78b732c8602c082ad1688c9bc6bf68d"/><file name="TestLibraryDirectory.php" hash="3626bc62a7c1c330369eb0001c4a9b16"/><file name="TestLibraryFile.php" hash="b45dc141518eab43f5c89e64b29aebfb"/><file name="TestLibraryNamespaceDirectory.php" hash="2e70388b581499815e6e2ba2c1cc0c81"/><file name="TestPHPUnitBootstrapFile.php" hash="40d55d88d6c84cd153adb2539ee323a9"/><file name="TestPHPUnitConfigFile.php" hash="1f136f46d817445285994244274f9276"/><file name="TestsDirectory.php" hash="0dec72680dea22074c8d370953effac0"/><file name="UploadsDirectory.php" hash="5d72a25ffd1ee7899fa182ddd7c9e028"/><file name="ViewControllerScriptsDirectory.php" hash="0ce107dd0b77183717845592b5be2550"/><file name="ViewFiltersDirectory.php" hash="59d3134c2b27c136adaa07177a72b28c"/><file name="ViewHelpersDirectory.php" hash="305d6bcc8066a02a658d82a69b73828f"/><file name="ViewScriptFile.php" hash="95b593cd475edcfd2a6ecea8f2668ffe"/><file name="ViewScriptsDirectory.php" hash="9aeac85b2f35bd6a666a4da29b465d45"/><file name="ViewsDirectory.php" hash="f36732d4b125b54a661356327d6850cf"/><file name="ZfStandardLibraryDirectory.php" hash="eea898b019c52dafd72f7de1aaa92d50"/></dir></dir><file name="Exception.php" hash="125c1606112c9ce2cfc8b697fb989d5f"/><dir name="Profile"><file name="Exception.php" hash="907a68043581559d3bf42ccc2c4b1322"/><dir name="FileParser"><file name="Interface.php" hash="325d41a29468a70dfe7476e1fcc8d20f"/><file name="Xml.php" hash="59f053468c48c4d9b881bc1b859ec28c"/></dir><dir name="Iterator"><file name="ContextFilter.php" hash="ff51879dcc3452e49ad8bf2d9e2c4910"/><file name="EnabledResourceFilter.php" hash="8d0d4add1f853aa9cfd89aaf138e2de3"/></dir><dir name="Resource"><file name="Container.php" hash="ab368c4da0867a25770b6f7970a782f4"/><file name="SearchConstraints.php" hash="9e4a7578e2879e6c9da8cfeb1fbfa9ba"/></dir><file name="Resource.php" hash="2a5467d1f6ff134cd8e35a2cb92eaedc"/></dir><file name="Profile.php" hash="db1e9708dc20fe27c3b39b9e6f57f1f5"/><dir name="Provider"><file name="Abstract.php" hash="8c55b9fe14b8d37beac8a5d1356c2cdd"/><file name="Action.php" hash="72581e6e7e4acd0a19f8ba9bbc0e73aa"/><file name="Application.php" hash="64fa6f041e1f5727a88bb9cbc7636f22"/><file name="Controller.php" hash="677b3b817a7fdb644cd150be124e9a96"/><file name="DbAdapter.php" hash="b831929398b67e053a395a548227695f"/><file name="DbTable.php" hash="6d922b240f64a010df894b03a44e0132"/><file name="Exception.php" hash="00d67294ec03f48a1e43fede57faee26"/><file name="Form.php" hash="95362baaf1eb17e9698573f6d7fbcb53"/><file name="Layout.php" hash="40528bb34ab9942db935b59b831ab909"/><file name="Manifest.php" hash="9d3a781e8c917a5cdb9e7dd10641cd35"/><file name="Model.php" hash="f561e3f60741f857d2a0a8d8d8509823"/><file name="Module.php" hash="f3cb636991bdb7fa9d69285ff5370a75"/><file name="Profile.php" hash="2bf881a5c9cf4e1032cb8de9d9297b16"/><file name="Project.php" hash="a7b3b98eeb5b8a38d7b003adde3a3c16"/><file name="ProjectProvider.php" hash="63455c931c8fa909d4a413ae91c99cdd"/><file name="Test.php" hash="ef752345daf66c4d3bfcdf94feea8602"/><file name="View.php" hash="1a8b7de4308dea33a847f1c590238d80"/></dir></dir></dir><dir name="Translate"><dir name="Adapter"><file name="Array.php" hash="539a98b29aa0bbcec264db5e29d810ff"/><file name="Csv.php" hash="698388dd2ac2843c3664586596e248f0"/><file name="Gettext.php" hash="321e228017b8049e94ea89f4e41f35b7"/><file name="Ini.php" hash="c03616b55e55e0c62363c4ee5e6b106f"/><file name="Qt.php" hash="19fd28ff1f5135d08c73c5faca961f96"/><file name="Tbx.php" hash="688c8d48dd29565f46d6f49d160e2f4a"/><file name="Tmx.php" hash="829f33d7444e30e4dc5053890fa22ccf"/><file name="Xliff.php" hash="0af804c51c85eea4b76941587aa673cb"/><file name="XmlTm.php" hash="39a37d7374fe3f0e3bf63a1e1f9ccb44"/></dir><file name="Adapter.php" hash="61940eb09da1bed1e6b8984370ad4088"/><file name="Exception.php" hash="469fbd261b8e8e1b91a8221fad6a79cb"/><file name="Plural.php" hash="4afe3e908bd63c3320fc7c899cd7b139"/></dir><file name="Translate.php" hash="0a7fda94b43cc10499fae10d9ec5d2e2"/><dir name="Uri"><file name="Exception.php" hash="0d12fb53167123e15aacbdddd8b11797"/><file name="Http.php" hash="55fae6ba863159381838ccc7bf8c651a"/></dir><file name="Uri.php" hash="f20bdab5c9c0694f64dd5b69f090e083"/><dir name="Validate"><file name="Abstract.php" hash="3382bfb0c407a0d3b490685a4f85678e"/><file name="Alnum.php" hash="2fe48d28207f9917e69f5edf99a392e1"/><file name="Alpha.php" hash="abeae56166032b791ae499883857d17d"/><dir name="Barcode"><file name="AdapterAbstract.php" hash="7bf5990b4b1dc34fe1fd7bcddd8f0348"/><file name="AdapterInterface.php" hash="c1b8934e5706e958f6e889e7c04a6931"/><file name="Code25.php" hash="f707195d53cd032ba5a9fbde32e75176"/><file name="Code25interleaved.php" hash="0c2ca046d04c43c4204e6cbb9d6dff7b"/><file name="Code39.php" hash="adff9a47dbf44dca5784dc8cdcc3ddc7"/><file name="Code39ext.php" hash="2e69f0103fbda86142024fc7466958be"/><file name="Code93.php" hash="2377845f1bee4dab114519c8f5dd4c5f"/><file name="Code93ext.php" hash="795aad78199cbc0668c70e12defcf9ec"/><file name="Ean12.php" hash="233d2f57fb2b36f1f2c7b3a36b0ead3b"/><file name="Ean13.php" hash="349560c5d4af7178e257a38c3a24735e"/><file name="Ean14.php" hash="30ab956febdabc3c13a7812f6e703bd1"/><file name="Ean18.php" hash="899007801fc5a8f97b577d711e2d692e"/><file name="Ean2.php" hash="0d73987f006070e0d15a573277a812e0"/><file name="Ean5.php" hash="806813312608a4ade42bbfab5d233711"/><file name="Ean8.php" hash="d0f3b4b0305e5dd0a7ba077fbb4978cd"/><file name="Gtin12.php" hash="da6df50e6751f4872604687602cc9695"/><file name="Gtin13.php" hash="dbd9c8a33ed3669917d10dee00a44a13"/><file name="Gtin14.php" hash="ae9c9fccedb5e71c87950c17bc5a3411"/><file name="Identcode.php" hash="9fed06deab51a31d97a66801fc68921e"/><file name="Intelligentmail.php" hash="9f4a16c7b78b3b1e5d9429569ea2aa11"/><file name="Issn.php" hash="e8de22a236a14b191225614ca730d343"/><file name="Itf14.php" hash="958a09981361b0cc8c83c0ae98831008"/><file name="Leitcode.php" hash="581e77d7ff774564ac3961077e40b27f"/><file name="Planet.php" hash="cda7f2f6910606728d4f6b375b17bbff"/><file name="Postnet.php" hash="9182081361daecfe6f0371fc4cabcd9e"/><file name="Royalmail.php" hash="e5bfd9d4ffd4935ca4b988f651270e4d"/><file name="Sscc.php" hash="eabc46811aff1a4a7f4468bd73a3f1e8"/><file name="Upca.php" hash="bb4f503adce344b6d3eb584843d7378a"/><file name="Upce.php" hash="368d3a61898baad1f968d2292a2692af"/></dir><file name="Barcode.php" hash="b3531dde74c28ed55c868d75615a9d3b"/><file name="Between.php" hash="5ccda5b2ac3d35bcc7faa8d8800108df"/><file name="Callback.php" hash="4e6874a0cb4bba53ef8edb9cde9eed18"/><file name="Ccnum.php" hash="1871fdfe01ac8f50e1b76f103297d7fb"/><file name="CreditCard.php" hash="2b68a89fbd9747e2a7308bc08aab9a12"/><file name="Date.php" hash="ac196efe9a75f1f5052881f0ad0fb7fc"/><dir name="Db"><file name="Abstract.php" hash="f32f786acb59d6936c87698c0ac868ad"/><file name="NoRecordExists.php" hash="de3eab3a488154fd14c3aeaad18c58b7"/><file name="RecordExists.php" hash="6203f6b21b338f28420fffd67f007dcf"/></dir><file name="Digits.php" hash="6536e4f93eea9d40663dc5b8308455c3"/><file name="EmailAddress.php" hash="f2fb48bbe83e3fb4288ee0f4825f485b"/><file name="Exception.php" hash="f05330fae73fa8a6fa5eb13b239492ae"/><dir name="File"><file name="Count.php" hash="fd4240625ed05056050c46051750d42a"/><file name="Crc32.php" hash="37be3ed367b5b7d13170fdc56c083488"/><file name="ExcludeExtension.php" hash="cffccfd1fcdae2be7676722ba8af7d9e"/><file name="ExcludeMimeType.php" hash="071a625f92fac84b76467a0eba3c467f"/><file name="Exists.php" hash="f5ab404939714ebf24c992bb3e4db124"/><file name="Extension.php" hash="21bf334b8b2ee214e82709c7bc1bf489"/><file name="FilesSize.php" hash="ab8dd66b1a133b1851d51927eabea61e"/><file name="Hash.php" hash="fd3f0e2888d1266d78da22e7d6647690"/><file name="ImageSize.php" hash="d277f5533a2aa61b2d5132babaf63c43"/><file name="IsCompressed.php" hash="1a0257de13523c8227a809b5673eb217"/><file name="IsImage.php" hash="7cd64b53b6e4a635e71b69e8ed5af7c4"/><file name="Md5.php" hash="4af983e349f6c2bc3a3fb6bc05d51e32"/><file name="MimeType.php" hash="c996e072363c49d15feba2a7ed35684c"/><file name="NotExists.php" hash="66d36bf5981467b276a1d97ae22ba5a9"/><file name="Sha1.php" hash="bf177eb68980e20cdf4a0db90bc32a08"/><file name="Size.php" hash="e6fe4f698bbe20ca0ccabe817462e0e7"/><file name="Upload.php" hash="a4099691c48b3427cdb144e3333b9145"/><file name="WordCount.php" hash="a2c3afef06b310c0b6a61867dfe25ab2"/></dir><file name="Float.php" hash="7d81882373a3c805ea6d890fd23d534d"/><file name="GreaterThan.php" hash="c8abc03e583058774db68388b71654ae"/><file name="Hex.php" hash="b491553d31f5894f2bd1303d685223f5"/><dir name="Hostname"><file name="Biz.php" hash="7696fce32b01be696c7a3f168ebd56de"/><file name="Cn.php" hash="fb00d241ff6f27a84d1c63758be2a14a"/><file name="Com.php" hash="5deccb0b547e92073687530b13870ce2"/><file name="Jp.php" hash="d22c9a1a27cfc135357a79c4608cbbd6"/></dir><file name="Hostname.php" hash="084ca6f450f36d3c76248663351f27dd"/><file name="Iban.php" hash="93312cb157edcb0735182b06a20d22dd"/><file name="Identical.php" hash="35b72f8c75851bb0dddfe4ac2126cef0"/><file name="InArray.php" hash="c75ec63d4745f66be627d1973bd76396"/><file name="Int.php" hash="222edd304fa91776951350e2659597fb"/><file name="Interface.php" hash="dbdfc01be0180334732bf0331fb19468"/><file name="Ip.php" hash="7abc354eed666e6b93c14c9187d2d0a3"/><file name="Isbn.php" hash="aedbe250623c9a9ef228d1863104b839"/><dir name="Ldap"><file name="Dn.php" hash="2716b9bc0c82519ab2fdbb52a0094eaf"/></dir><file name="LessThan.php" hash="e9fd4f35f101acb8fa94df0812ece205"/><file name="NotEmpty.php" hash="84a8e76bc9fd6fce9ce3d93f9e37b36f"/><file name="PostCode.php" hash="4513fb89c9215f1c987354ea552c0925"/><file name="Regex.php" hash="cd9c961f1bc2241a1beb61b8adc6325c"/><dir name="Sitemap"><file name="Changefreq.php" hash="02c174efb2eb92c1f99083d8d8a8201b"/><file name="Lastmod.php" hash="ecb2907a0827ca4f9a902b1842104f0c"/><file name="Loc.php" hash="43a32b211470fd207e614e122b373d5f"/><file name="Priority.php" hash="c4062b2af691dd790e88a80aa5f5400b"/></dir><file name="StringLength.php" hash="b57a08cb0418165feed0c8f3069830dc"/></dir><file name="Validate.php" hash="fdb819323b45ba50c37cefe43410afd6"/><file name="Version.php" hash="4050aa162960c6f935a49ffe910f81bd"/><dir name="View"><file name="Abstract.php" hash="1319cd055a57d8627ff0ed820f17daa9"/><file name="Exception.php" hash="7a4c976601978de749639c8b0914a03f"/><dir name="Helper"><file name="Abstract.php" hash="e1018e0e93049ac253c920888dc1133e"/><file name="Action.php" hash="786799b58e0fc8729abfde4de463e4df"/><file name="BaseUrl.php" hash="183857156a40c84f03eaea0ff24606bf"/><file name="Currency.php" hash="2ffa077bbe17cbda6974509421cd0582"/><file name="Cycle.php" hash="33bb85798e40541bc8e75cde27cf3499"/><file name="DeclareVars.php" hash="3cbcbf5083117f5f1dad9bac8df3b474"/><file name="Doctype.php" hash="b7e492a249f52859e00c287a8973edb9"/><file name="Fieldset.php" hash="4874b3f6f0658d8f9eae3bf750bf9793"/><file name="Form.php" hash="17d5d7e238c33e8e8cb0efbe043c01e0"/><file name="FormButton.php" hash="c62cf4a51db83501c7c7f1e2fad7cabe"/><file name="FormCheckbox.php" hash="3fefb8a82a8183e4cda683231bad496a"/><file name="FormElement.php" hash="9dc8f7fdd07eb031bc7cee049faa49e2"/><file name="FormErrors.php" hash="eb7e95a90d8a438d4b1043fd32a5f3ab"/><file name="FormFile.php" hash="cf7ec88f4ffd6c732a7df42737069d07"/><file name="FormHidden.php" hash="396bbe9d13da93ee84befb08a5c86f55"/><file name="FormImage.php" hash="3c9adc229035b5972678f634f690cd75"/><file name="FormLabel.php" hash="af00a20fba6e72eb035a605e72a814a7"/><file name="FormMultiCheckbox.php" hash="4033cf623ff32c24f0eaac26e96272d9"/><file name="FormNote.php" hash="94c3fe7ae9857d5d1c0f7e67bd817ee2"/><file name="FormPassword.php" hash="e743953bac753960ee4918c34372ede6"/><file name="FormRadio.php" hash="7df9c01b4e3bac15aca3394bd6bb20ae"/><file name="FormReset.php" hash="7463249d29ef3c895e6d73548c0d2250"/><file name="FormSelect.php" hash="b9076b91b3dd8880a74b9a1ff0f6fb2e"/><file name="FormSubmit.php" hash="abb3c753621b09e8251e88dd7d9cfb1b"/><file name="FormText.php" hash="c059e5863263faaa09d4e7fe99ef4fa1"/><file name="FormTextarea.php" hash="b5a12bd7577c3794b4f7536e1721254c"/><file name="Gravatar.php" hash="8b4c4ce3552c48ec148b81ebb4f843d7"/><file name="HeadLink.php" hash="c25bb4abcf60925394a915df38b006a5"/><file name="HeadMeta.php" hash="42d8fed1309297d58411bb7d487ebe28"/><file name="HeadScript.php" hash="c835c0d98daf0f2b89f2f486d22587a5"/><file name="HeadStyle.php" hash="2770400f4d12c2bf7b27c053aa1a6453"/><file name="HeadTitle.php" hash="329e23739809b5a55dc8d28c447dc91c"/><file name="HtmlElement.php" hash="e5e6b362d6001c20bbb805e31beb36e1"/><file name="HtmlFlash.php" hash="dff36a0bf66c600be3004bdd34cc8b08"/><file name="HtmlList.php" hash="f21ac692428d4c457dc2f3d2db5e7304"/><file name="HtmlObject.php" hash="dda5c4a84c32c4cdd73112a33c322c87"/><file name="HtmlPage.php" hash="d49d3e056e0aab1a8179bd2b3f1917e2"/><file name="HtmlQuicktime.php" hash="4455adb547e6d3a1d3fb52d6746df770"/><file name="InlineScript.php" hash="aabae2682812b3ee88a5bfafaa3d00dd"/><file name="Interface.php" hash="52fa974c83ce1fff7c9d56a994b1fbbc"/><file name="Json.php" hash="78621362d2c630ad5b8b7f7ef2cf2124"/><file name="Layout.php" hash="9e98d798baba317de41bc0cdf75cdf60"/><dir name="Navigation"><file name="Breadcrumbs.php" hash="6482ca2aa2565f318b49ce0458072ae4"/><file name="Helper.php" hash="673a27dfb10aa4442dfa2951e0ef0c4a"/><file name="HelperAbstract.php" hash="6bae63e5c54e21b87ebaf8d2622ac1b9"/><file name="Links.php" hash="b2b7b2403670be61982c1a73851ed2eb"/><file name="Menu.php" hash="8f5c5c42c0b10ac7a68c69b4503ecaa2"/><file name="Sitemap.php" hash="960d3bd171fbe2ca66ba073afd33140a"/></dir><file name="Navigation.php" hash="98f3a4adbd4c69df20c127f90e09156c"/><file name="PaginationControl.php" hash="b18eee7e9c52256b27384a982a75f0eb"/><dir name="Partial"><file name="Exception.php" hash="047c658de482d2ae0eb5d21ac0cd0a55"/></dir><file name="Partial.php" hash="abe72103b776eeee4a96ccbca003cabe"/><file name="PartialLoop.php" hash="637e144d4c2d369a35848d681b4b6464"/><dir name="Placeholder"><dir name="Container"><file name="Abstract.php" hash="8d885989d99888fc2798a85f07c9f17a"/><file name="Exception.php" hash="326371b5ef3489904fee8e387e7feb46"/><file name="Standalone.php" hash="637e4d2b742d9902ae6de414c0475237"/></dir><file name="Container.php" hash="16d8237399260e817a542e68a4828d4c"/><dir name="Registry"><file name="Exception.php" hash="b9a3969a1431cf44f4cd03764dd92e32"/></dir><file name="Registry.php" hash="ee6d81b2c630c83baac77a0d619ba7d1"/></dir><file name="Placeholder.php" hash="2fced270eb2e3474b4bd538cd73f517a"/><file name="RenderToPlaceholder.php" hash="5ad5803d78bad07455af8f5d3c876977"/><file name="ServerUrl.php" hash="c6a222f4e795320f6f07c6bb8f80d7f3"/><file name="Translate.php" hash="d341ce0f8809b691728672fe506736e6"/><file name="Url.php" hash="71f6c3948d28f8190bfc27b3586d3f93"/><file name="UserAgent.php" hash="dbee4e1b78fad667479a85e8e2d0cbd1"/></dir><file name="Interface.php" hash="eec709b1a8ebb0256a9f752db1a8ad75"/><file name="Stream.php" hash="6f4c3f620f6e2d2f92cd371db18d3a90"/></dir><file name="View.php" hash="604cd51ea9ba98756064b418d6785a5d"/><dir name="Wildfire"><dir name="Channel"><file name="HttpHeaders.php" hash="62dffc43581615ca6cb052efcb2a43f9"/><file name="Interface.php" hash="0bed6c7ae3ee56a17f5c5187eef3ce10"/></dir><file name="Exception.php" hash="a225536440492a4ef3d37702aea1cb40"/><dir name="Plugin"><dir name="FirePhp"><file name="Message.php" hash="f481d929bbb00bf2bac8dfb008ae37d8"/><file name="TableMessage.php" hash="074faf9136be2ea86add5cdf2b459dd8"/></dir><file name="FirePhp.php" hash="e23b81012ace71de3018a37deb708885"/><file name="Interface.php" hash="c3cb69d35db9a385f7caa140b9634dab"/></dir><dir name="Protocol"><file name="JsonStream.php" hash="38a7d96f9d4ec70f68492f1bcf4022f2"/></dir></dir><dir name="Xml"><file name="Exception.php" hash="2dfb5785f12ed3858b16ab075570d577"/><file name="Security.php" hash="b7b7a240b24574b06f73a59dd8a4e6f0"/></dir><dir name="XmlRpc"><dir name="Client"><file name="Exception.php" hash="8e96419287c2faeeb4412ed9e832d975"/><file name="FaultException.php" hash="28c34f9ec27f280c44d215ee38bd41c3"/><file name="HttpException.php" hash="8c2eac4d043926123b3691562ad47310"/><file name="IntrospectException.php" hash="39d33b723e4fb1d5ce2af5cfd1f41589"/><file name="ServerIntrospection.php" hash="e52c06c394a8c8ac91b5313e5c575024"/><file name="ServerProxy.php" hash="43f25d1783bc1f11462d21ab5a134976"/></dir><file name="Client.php" hash="ea8c5a084405ca13e4f43340e37fe866"/><file name="Exception.php" hash="a04feed37237658eb7c174518a4d9383"/><file name="Fault.php" hash="18685e9a87f2f7750fa968d86ab89625"/><dir name="Generator"><file name="DomDocument.php" hash="5fc0be6304c7a00e58ac39f033d0dd22"/><file name="GeneratorAbstract.php" hash="493eda4b0b32cb59a133c06d63fbef90"/><file name="XmlWriter.php" hash="45013d6c2e24f7ee77439df64a958172"/></dir><dir name="Request"><file name="Http.php" hash="70fcc3ae21a466a9295f42ebae0c2a93"/><file name="Stdin.php" hash="23583af65a719e197a70fcd4c5500ac0"/></dir><file name="Request.php" hash="6945ae9bdf8d76308651611848870e09"/><dir name="Response"><file name="Http.php" hash="50e6859ca7391fd453d7137697f57dc5"/></dir><file name="Response.php" hash="cc7fe267b740ab5c556b7b2d19b6d600"/><dir name="Server"><file name="Cache.php" hash="1cd78db98fe5499e4a64379e97689f77"/><file name="Exception.php" hash="6294a6b1a7d4da4b7a15e7ee489eb119"/><file name="Fault.php" hash="69b89d7568a910f82109b6f3cb0410de"/><file name="System.php" hash="d7b0d17c91367f44eb993da66672dbac"/></dir><file name="Server.php" hash="1087be94c4995db9c38a5335323e922e"/><dir name="Value"><file name="Array.php" hash="b7011fc480c395bfcbc67d68ead94cd7"/><file name="Base64.php" hash="91ea9215e1d57716c0cd79bb1906134e"/><file name="BigInteger.php" hash="10222f3f5cd5eeaaa9813d8ed9f2494c"/><file name="Boolean.php" hash="770874cea876566818fb9135f31e69c5"/><file name="Collection.php" hash="0708fe32732db76ebe9d7e89396b89e0"/><file name="DateTime.php" hash="1a9f56c65375240ee0385ed912731b84"/><file name="Double.php" hash="ee71a5a9eeb026f1eb75387b8158706e"/><file name="Exception.php" hash="b7adf50526128e43c344331e7250b935"/><file name="Integer.php" hash="66c8d75e059a4cf328ff108d15db5c5e"/><file name="Nil.php" hash="ad51cdbcfb5eff5e06d7fc2c6d4661e9"/><file name="Scalar.php" hash="e61890f60aff885a3bed37b093f36e6d"/><file name="String.php" hash="a9d992c1910d76c4ed5330e704a1d438"/><file name="Struct.php" hash="028b64a94eeca406537505ecd52788d1"/></dir><file name="Value.php" hash="7d09b0ce98deeb7a07c01ad1bc94aa0f"/></dir><file name="replace_recursive.php" hash="e886103ea1f75208cc11780718aa3094"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_ZF_Locale</name><channel>community</channel><min>1.12.10.18</min><max>1.12.10.18</max></package></required></dependencies>
+</package>
diff --git a/var/package/Lib_ZF_Locale-1.12.10.17.xml b/var/package/Lib_ZF_Locale-1.12.10.17.xml
deleted file mode 100644
index 20cd8b9..0000000
--- a/var/package/Lib_ZF_Locale-1.12.10.17.xml
+++ /dev/null
@@ -1,19 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Lib_ZF_Locale</name>
-    <version>1.12.10.17</version>
-    <stability>stable</stability>
-    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Zend Framework Locale</summary>
-    <description>Zend Framework Locale
-splitted from ZF to avoid memory overruns during installation and upgrades</description>
-    <notes>1.12.10.17</notes>
-    <authors><author><name>Magento Enterprise Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:49</time>
-    <contents><target name="magelib"><dir name="Zend"><dir name="Locale"><dir name="Data"><file name="Translation.php" hash="3c4e6ddf022e279cdbc77a860c6cb657"/><file name="aa.xml" hash="6ba5c871d22f64a769c70a1af71a04c3"/><file name="aa_DJ.xml" hash="369c4c2c9eca85c0b60d762a6bc98aa8"/><file name="aa_ER.xml" hash="64dd3e36ee4831d967e49ca2e3acaaff"/><file name="aa_ET.xml" hash="c05abb8269fff734e511dc4d0a11c1a9"/><file name="af.xml" hash="67b34f34749792149e0358fbc902c167"/><file name="af_NA.xml" hash="4034171f9b1450a37ed070aa3d90c5ba"/><file name="af_ZA.xml" hash="6c3da14996bf1b58cd8017df3313b8ea"/><file name="agq.xml" hash="5fd93a5c707e73e4aa5c519c6d64afd4"/><file name="agq_CM.xml" hash="06499c36298cb9eeb23e6dc0dbe20322"/><file name="ak.xml" hash="69320ac48004c58405d12d800a2d81ff"/><file name="ak_GH.xml" hash="5c5c86078d71e30c0399a762e5cf7f0d"/><file name="am.xml" hash="95b934943f754f649861fcc29f378976"/><file name="am_ET.xml" hash="584cb88741cf24321e0c047dcef574e9"/><file name="ar.xml" hash="8ec3de78c7d4ff42daa956025eeebc20"/><file name="ar_001.xml" hash="bc30b0854e32d00739413feb7a5414ec"/><file name="ar_AE.xml" hash="f70fd224cd066586d1b8cf5309774b21"/><file name="ar_BH.xml" hash="0c953018f40ce82e9de064a4cb95a488"/><file name="ar_DJ.xml" hash="66fa3cc4267b7fd0d96a2669a0401d8d"/><file name="ar_DZ.xml" hash="c070ac57992c1611059859954354e256"/><file name="ar_EG.xml" hash="7a422d856e2ec72b9c1494316b89aa02"/><file name="ar_EH.xml" hash="a21177328a2e94087fbae06f1c7471b4"/><file name="ar_ER.xml" hash="0a7472b1683fc78bd1a3a5cafb8b84c6"/><file name="ar_IL.xml" hash="1bca56bc324229351c0089b67d490cb6"/><file name="ar_IQ.xml" hash="0da352ff695a5a3e8e5dd155cd7c4ddc"/><file name="ar_JO.xml" hash="4c7b8b4b5eb54adc1f9c3f6e4dc4dea4"/><file name="ar_KM.xml" hash="e919d368ba30dfdeaa95f70532b4e255"/><file name="ar_KW.xml" hash="9b6ca92c240ea68d66acbb49f91992f0"/><file name="ar_LB.xml" hash="18b007c4b842620480c8bb88aae29b77"/><file name="ar_LY.xml" hash="4da8f8faf728c8a65aae9c4a66008b34"/><file name="ar_MA.xml" hash="f1b35950f3e3e3f4237a5a39c7da2be8"/><file name="ar_MR.xml" hash="f2ffa3c86e1b19b17b09f9099273e9d4"/><file name="ar_OM.xml" hash="ed0e25061367e82694d8cb7c0eaee387"/><file name="ar_PS.xml" hash="e7ee58c19554a466dab9fdb752d24a6f"/><file name="ar_QA.xml" hash="7b180beb5da6eac09e84b58a240d6991"/><file name="ar_SA.xml" hash="d016c7a9ff9de9e45c9136109f8f493c"/><file name="ar_SD.xml" hash="9dfcaa9bb696f5cedc059a4109c8b3ab"/><file name="ar_SO.xml" hash="84afb054141b7c24b7b448b5602359e0"/><file name="ar_SS.xml" hash="6c3734aea87be71cffb4556464be4fd4"/><file name="ar_SY.xml" hash="5a198ba2fef0281de890f996fbf644ef"/><file name="ar_TD.xml" hash="948d829d89a161430f83912af024f141"/><file name="ar_TN.xml" hash="7faf65c744cf5e52bfdb59542bbe7899"/><file name="ar_YE.xml" hash="8c10abba56d6a234a55c654078016a9b"/><file name="as.xml" hash="8fc5e45c11ceac7f52c78ff5166159d6"/><file name="as_IN.xml" hash="694909593f1415ef0e4fda6d5e58be0b"/><file name="asa.xml" hash="67790459fbf5470067fda4eab8703753"/><file name="asa_TZ.xml" hash="a7ff94e5a530dc21c43ab7174ae813d2"/><file name="ast.xml" hash="64deedf1c37b39d07b45a5080fc94190"/><file name="ast_ES.xml" hash="77b6d2a7c40dfcdd70fcd5a48dbc937b"/><file name="az.xml" hash="e5c36c36cb81eca6d5cfa86ef058d989"/><file name="az_Cyrl.xml" hash="4489b815e2f3f628619ccbbe09afe72f"/><file name="az_Cyrl_AZ.xml" hash="827b611f5206f27d79f2c07525340bfa"/><file name="az_Latn.xml" hash="7a9c14a8afa4e30e677b6d588788a515"/><file name="az_Latn_AZ.xml" hash="ef3f0e6fe96210ee2e21ed77c73716a8"/><file name="bas.xml" hash="b5e926cff825d6a19ecdd30aa6ed7309"/><file name="bas_CM.xml" hash="b96cd37b4240f82a00400bceef16106e"/><file name="be.xml" hash="b9e6bfe9f98012d6e2e3adbb8d7f4a33"/><file name="be_BY.xml" hash="f7decbc88e0b84a81c61c33b752f7f35"/><file name="bem.xml" hash="b32d7fab640633d84596c781c5729972"/><file name="bem_ZM.xml" hash="a41416d42e206b3499ed1327002ce5da"/><file name="bez.xml" hash="700611e0dce26a8fc22647aa5708dc74"/><file name="bez_TZ.xml" hash="c767af253038caf4cbfede8a067453f5"/><file name="bg.xml" hash="51b19b644a9796463b91bb8ec236adca"/><file name="bg_BG.xml" hash="05e86d4ebf3b91764d3a0d2551e16bf1"/><file name="bm.xml" hash="09d5b79929820ae15c0c6d5ea4afb6dd"/><file name="bm_ML.xml" hash="4d5e1b37325ed9e57f8c590fe1d3a762"/><file name="bn.xml" hash="199a113c26a1608720ca7e3c660d23e8"/><file name="bn_BD.xml" hash="794e3d0d4fcb61f260ac7bf8673378d5"/><file name="bn_IN.xml" hash="0848d84be54a2646adc33af1c9e4b968"/><file name="bo.xml" hash="febea3f15347297281d6ecfcc5771b73"/><file name="bo_CN.xml" hash="30fd400db11b971da287cea6be2ef3c1"/><file name="bo_IN.xml" hash="d68dac66b5b843ce88da031b16b3afe1"/><file name="br.xml" hash="e870097efcb0cd34bb6e4d1f2dc5b278"/><file name="br_FR.xml" hash="11652862f633f7aec19a1c0433c4b204"/><file name="brx.xml" hash="8047b46746f02a39674f0beefc07e194"/><file name="brx_IN.xml" hash="99404538d96a071935efe231780663dc"/><file name="bs.xml" hash="940b48d89bdb239461bd8b3427469342"/><file name="bs_Cyrl.xml" hash="8580494f42dcf27b664a012d4658982b"/><file name="bs_Cyrl_BA.xml" hash="3f8c9a61ac978bd30d6d64bf86dffec8"/><file name="bs_Latn.xml" hash="0c8b503dcc0f9853d3af20768e662aea"/><file name="bs_Latn_BA.xml" hash="9496b4ae275da058251832af52888167"/><file name="byn.xml" hash="5b73a1af7b8ba27dc8262d81934c3f14"/><file name="byn_ER.xml" hash="4da388f09780d86134689dc5f10a3862"/><file name="ca.xml" hash="581f561afd2a2296430eebbd9cd7cf1f"/><file name="ca_AD.xml" hash="f3f80fa4f38bb72a397d94e6e12175d6"/><file name="ca_ES.xml" hash="24c8e24495f99d3921a5a4e77f8bfb81"/><file name="ca_ES_VALENCIA.xml" hash="e9703c4cedea0d7756a06a653c1c8442"/><file name="ca_FR.xml" hash="84537f1e57ba4476c1f923d12f4f7b42"/><file name="ca_IT.xml" hash="e842526f0ecfcef2904d206b2a810041"/><file name="cgg.xml" hash="054e8d83970f37440d169e964c743447"/><file name="cgg_UG.xml" hash="c6f0a77828c43211f72e10e83f9f666d"/><file name="characters.xml" hash="578bec00fbe6d6416ba89e6fa7986357"/><file name="chr.xml" hash="d5c69b967b2ca2744b8a46d9c95260e8"/><file name="chr_US.xml" hash="53b9e050bf58ab63900197dc8fb43d9c"/><file name="coverageLevels.xml" hash="90d4dc96d148cbd970ac8ff49c209bea"/><file name="cs.xml" hash="23e2ba0f38fbb0021ecd6aaa24db77a1"/><file name="cs_CZ.xml" hash="baa89fb49d1c50a5e7ef632f75d56fa7"/><file name="cy.xml" hash="0657a743b16b94e59c26b692dd79943b"/><file name="cy_GB.xml" hash="9bfe606c96d3d035ad644efe57bc67f6"/><file name="da.xml" hash="507243848cb4398daf768f735cfb432f"/><file name="da_DK.xml" hash="2347254255ce488182e37214c7d0694f"/><file name="da_GL.xml" hash="84ea22e10d4f6aa9ff8a0c6644fd7dd9"/><file name="dav.xml" hash="47ee87a9cdba6d211639776a608c1e86"/><file name="dav_KE.xml" hash="37e7d66af32b1fe4ac81be34fbee5d2e"/><file name="dayPeriods.xml" hash="56449b799dac8fc8daafbb0f3d3d99ef"/><file name="de.xml" hash="198aa0c550d4c41406bd0df6f7b70a7f"/><file name="de_AT.xml" hash="4b960a6fac173340ac276ce5c9d82532"/><file name="de_BE.xml" hash="dce45b8b94a4c3aab891a2c7bf3ca151"/><file name="de_CH.xml" hash="c4e68ad1a19e6e92daa571edb12cb36a"/><file name="de_DE.xml" hash="fa5913f6081a8a4650cef19d22acca20"/><file name="de_LI.xml" hash="0dfda8f44bc729219bb5de48f7694393"/><file name="de_LU.xml" hash="409b134c2c81689c16df1a79c0a4baa2"/><file name="dje.xml" hash="7da22550436ba325fd7b0dfde195b9a7"/><file name="dje_NE.xml" hash="7e318b89d05df66eea3fe59bf75c7ac7"/><file name="dua.xml" hash="ba4657ecd1b3bc014c5dd1622d107e90"/><file name="dua_CM.xml" hash="5bba1b38dc6495219fcb1a0432cc8df3"/><file name="dyo.xml" hash="612804b11d342d9e3b4bb2d58b5f66a7"/><file name="dyo_SN.xml" hash="dc003c4af3987ec2d7255d3c1f541738"/><file name="dz.xml" hash="244f80bfc2f658780ba016281354fe0b"/><file name="dz_BT.xml" hash="9d287c1c61edf1fa5ef3d765b2c7da86"/><file name="ebu.xml" hash="76696c080f20a7db39abc05dd272f090"/><file name="ebu_KE.xml" hash="7c4abeeb255cf7bf2bc500abb12ce387"/><file name="ee.xml" hash="4518057dd1b1b514e3bd12e5b5e85bf2"/><file name="ee_GH.xml" hash="082d3a0d2203319b9e51004a710e3e6a"/><file name="ee_TG.xml" hash="d99900de319d3584f1a115d4b5eb76f0"/><file name="el.xml" hash="1710cdf160e6cab0c4d47c15bab5be18"/><file name="el_CY.xml" hash="6da5d159d499ba4754a2e7d4553d5059"/><file name="el_GR.xml" hash="477e3b1f10320e95a0c12511cb0c8368"/><file name="en.xml" hash="9256d3ec622d04bd406376827d31012b"/><file name="en_001.xml" hash="768d1b54436a379dd71d0239702810a6"/><file name="en_150.xml" hash="7f9a887b30b86016fe8a29cabb6b8ce0"/><file name="en_AG.xml" hash="4d2c7e568ab71d4b4e49c934b47d5c4a"/><file name="en_AI.xml" hash="70e59d70a946d5026659413cecd2da7f"/><file name="en_AS.xml" hash="2b134e308540cf74f34c2aa665112301"/><file name="en_AU.xml" hash="ed81bf367e4f715e9a5c4271bf49822e"/><file name="en_BB.xml" hash="5dff42e201010656bc3dbac5887d015f"/><file name="en_BE.xml" hash="f91d2ce67b1818708d15c091c4c9d720"/><file name="en_BM.xml" hash="2908ee96a408ec7b9d7fd659615d90ff"/><file name="en_BS.xml" hash="91eab1ca2779d23f13df0347f536ca0f"/><file name="en_BW.xml" hash="e37d57c47fd205e31473eb60bb1c973d"/><file name="en_BZ.xml" hash="59d8c1d1deac2a7b0f73992516c999bd"/><file name="en_CA.xml" hash="7f81353970624138037a527f761e6571"/><file name="en_CC.xml" hash="38e31ba2efac50bc06a5caa4bce5fa02"/><file name="en_CK.xml" hash="4a677485a65e531f1468c1543347c1ce"/><file name="en_CM.xml" hash="5a02b7f5fa1bedd6a05f96196e95b711"/><file name="en_CX.xml" hash="fc592a771a64d862c3739a898ce18dd3"/><file name="en_DG.xml" hash="1ec938ecb46bd092323b4f8ce4ba2cc2"/><file name="en_DM.xml" hash="89bee96e1185ba2dbb3ded508dda16a8"/><file name="en_Dsrt.xml" hash="6fbff7ba19f432150086850bc2e2f804"/><file name="en_Dsrt_US.xml" hash="0850b836f2faef6ec3423c7705160ab7"/><file name="en_ER.xml" hash="a99ce4a7be566be0b20822f418a4a589"/><file name="en_FJ.xml" hash="f5cfe8032f32fde1289d2fce5696a6c7"/><file name="en_FK.xml" hash="632a6ac34df2048f5160f1cbb21684e4"/><file name="en_FM.xml" hash="1e288d9366e0ac40b241b90d550d6424"/><file name="en_GB.xml" hash="5b73aa8057d95008d24c3eb91f265fd1"/><file name="en_GD.xml" hash="7d6d4bfad9463d051c6aba6301581460"/><file name="en_GG.xml" hash="a75e2a293cd4eb9e49d495c13b6e37ae"/><file name="en_GH.xml" hash="97e8cffb72f9e6651f8dee6ca086c0ea"/><file name="en_GI.xml" hash="6441468454ea9cf06468b0e19db106aa"/><file name="en_GM.xml" hash="7497ca9f4f962f57dffc9ad93ab78077"/><file name="en_GU.xml" hash="ae33e0859c963b265fdf32cd026ad26b"/><file name="en_GY.xml" hash="50aed051f78b38a1d1156c36d3ad7f9c"/><file name="en_HK.xml" hash="1aa1133bec835a760695dd994a6ca259"/><file name="en_IE.xml" hash="63130f36882b6a6917606b7c6624aa80"/><file name="en_IM.xml" hash="2e981e6e96db2a140dbef95db013522c"/><file name="en_IN.xml" hash="7433385f2bb2afa211e5c33cd9f921bd"/><file name="en_IO.xml" hash="b63a354d390f7b3eb564394b6ea5ebd1"/><file name="en_JE.xml" hash="a37431bab3c66fbc361a775b62627154"/><file name="en_JM.xml" hash="3c59b2850c79e9a7371e8f7a12dd7d75"/><file name="en_KE.xml" hash="2554dd9bd652f9ea57cd18da1a19df18"/><file name="en_KI.xml" hash="f24474b7d06fc2f0220ee7095e6fbff7"/><file name="en_KN.xml" hash="4d68bb1ef92eefad6f2fcc0e0b0d5076"/><file name="en_KY.xml" hash="b686bd51fe232c2107a08e8d9a5f1577"/><file name="en_LC.xml" hash="2ffab8614818ecca5af1c84ddb96a6bc"/><file name="en_LR.xml" hash="eb8f5ac9ca72306127d86db0085a92c0"/><file name="en_LS.xml" hash="8255d2c42f06b2d7c511353e82edf59e"/><file name="en_MG.xml" hash="5d7a723320b05e8fd7a4a1c8017bb57c"/><file name="en_MH.xml" hash="3c762f2aa253bef5b3cd1ad5940c3cc9"/><file name="en_MO.xml" hash="c20af1a8a15c19b9a52dd56c36b5598c"/><file name="en_MP.xml" hash="d535408f7920814d2d2b7c4ddfbba7e5"/><file name="en_MS.xml" hash="d74c01a6b57a68fc4d149b0f2bd5faf2"/><file name="en_MT.xml" hash="a0779f1ed61a4fa24f2549fc37df1523"/><file name="en_MU.xml" hash="484d1081e00dfe315b01368e63a8e547"/><file name="en_MW.xml" hash="6f5546f3143027e27250f1b471f3722c"/><file name="en_NA.xml" hash="43792f7465fd56dff8129154cd568400"/><file name="en_NF.xml" hash="9ced4a796c1db1693c526340fdda01d0"/><file name="en_NG.xml" hash="ba618207a64de97e9420801e8909f076"/><file name="en_NR.xml" hash="56f2eb49dc7a336e5eb0e2f4503dc3ed"/><file name="en_NU.xml" hash="524a420bdbf2d1bfe4ced79e690fadff"/><file name="en_NZ.xml" hash="3960c92d3ef55d1e55bc7bb7808a1c58"/><file name="en_PG.xml" hash="9fdf21ef2f976e068dfddbdd0bfcbbbf"/><file name="en_PH.xml" hash="6d0b1441355b533aa7231a45f330bb68"/><file name="en_PK.xml" hash="48a4db2301d34ccedf58942f3b41b181"/><file name="en_PN.xml" hash="846a0b8c74785cf3ffb562abbd5d5cd3"/><file name="en_PR.xml" hash="76bec34e4f081c2cc6ea562b9d3c3552"/><file name="en_PW.xml" hash="258fb50d80e798ffe19514bceaab9c85"/><file name="en_RW.xml" hash="aaa4befd7267fe5afd6682a00241eca2"/><file name="en_SB.xml" hash="0c50f8257806c71a8fba4cda42acb2ac"/><file name="en_SC.xml" hash="d8769c5bbd31f66c1a40d82ad4f9959e"/><file name="en_SD.xml" hash="9d3a24c9a0bd4f99653130314a6cca29"/><file name="en_SG.xml" hash="f32241b6135eb9e8733ffc80fab1b110"/><file name="en_SH.xml" hash="c35756da3a6effbfa9af4d488f7292c4"/><file name="en_SL.xml" hash="dd9fc72730ab0e6e58086a662fefa69d"/><file name="en_SS.xml" hash="35c730c6f16af1d572ef33bbea15fde3"/><file name="en_SX.xml" hash="d33e0d2eb46c1dc7004b84f6606dff0e"/><file name="en_SZ.xml" hash="a53c6878dcddbc32d37ab6b77e17da36"/><file name="en_TC.xml" hash="55127dfa22212f6abded3dd606af5a85"/><file name="en_TK.xml" hash="64ecd71d4530f1668e9da48f1039f508"/><file name="en_TO.xml" hash="a5e77bc5a7beecf3ff8f6b3156a87668"/><file name="en_TT.xml" hash="8b168ae6e9c3d9c8fceb0582365264af"/><file name="en_TV.xml" hash="7f98c91cd0dd96a66e4c8684d1d60639"/><file name="en_TZ.xml" hash="0cf0401e55af54ff68da8bab8c901182"/><file name="en_UG.xml" hash="a028dc8e13686a9ebafb83ace5315206"/><file name="en_UM.xml" hash="b883319cb6ecd9b1a6cb1deef89db236"/><file name="en_US.xml" hash="6435b96852569c7e355302c17814f77f"/><file name="en_US_POSIX.xml" hash="535c6ed9fd3be4db0fbf7ba3c79533b6"/><file name="en_VC.xml" hash="e745b417ac7ff1c93f281070740e901e"/><file name="en_VG.xml" hash="66ebc85cc70895db528d868b2318e5d6"/><file name="en_VI.xml" hash="3f30ee6f1c7383f6d906106f09cf5eff"/><file name="en_VU.xml" hash="6eea6dd6ac0cc9d00386059ff12a865c"/><file name="en_WS.xml" hash="bdc0360cf4fb7b517dbee39de8d0cd58"/><file name="en_ZA.xml" hash="031afdaa1011735bbc6555c5e76d7ff6"/><file name="en_ZM.xml" hash="c7bdd89484bff8dcf4daf3f57f6d6bc8"/><file name="en_ZW.xml" hash="b3f51877ba7ce7ead43ef50b499b4444"/><file name="eo.xml" hash="82ba66eacea4e98f8923944eddcc1745"/><file name="eo_001.xml" hash="1801937ded337e21aa03e2592deedb46"/><file name="es.xml" hash="a60ed8506871160a17c4fc3b81e53b0a"/><file name="es_419.xml" hash="c1bef1732b664c23cb1b799181cba5a9"/><file name="es_AR.xml" hash="d404e53f4de755d9c09aa856e916f110"/><file name="es_BO.xml" hash="2876119c46a9c697baba1a65240c051e"/><file name="es_CL.xml" hash="e3910edbae206638b9250ecbf9949905"/><file name="es_CO.xml" hash="53be4c39e4a34867fcbaa8fd05c2c881"/><file name="es_CR.xml" hash="1f0e1d3c965de545b50aab4577b038fe"/><file name="es_CU.xml" hash="2380f966916741dcba3c34c04a5d8009"/><file name="es_DO.xml" hash="9ea0a69084ae8dbdd86459e2806a8bdc"/><file name="es_EA.xml" hash="ec6ce434e2fb8f15ab4daa8cb2bc4dff"/><file name="es_EC.xml" hash="efb247470c0fe88c36a7864184a01a8a"/><file name="es_ES.xml" hash="da94ab8a06feb23c6d567dc75f85531c"/><file name="es_GQ.xml" hash="cac80878e350ca7a728940550bd9393f"/><file name="es_GT.xml" hash="d360a7b0a15a0515a21f1e0d5b4dd21e"/><file name="es_HN.xml" hash="fa13c1e703f00b11d038fe3bfe19c08b"/><file name="es_IC.xml" hash="d5324caf07a8db6ba668a1b749baa6e3"/><file name="es_MX.xml" hash="05df2b2f76636b0097cf9431ff9c84eb"/><file name="es_NI.xml" hash="7d59d82986b3ab47e1b7a2dad383a0aa"/><file name="es_PA.xml" hash="21a4164b1d73365f9b63431247053db4"/><file name="es_PE.xml" hash="8df05dafd2807169296d11f75eb74537"/><file name="es_PH.xml" hash="7240ee508f9500d779bd5109450a057f"/><file name="es_PR.xml" hash="de86ff57cd2f3e3c67111b0163a72b6a"/><file name="es_PY.xml" hash="191bbd042c95ef246cda798581ed9598"/><file name="es_SV.xml" hash="9caba354843c2b055f8f5da17082e245"/><file name="es_US.xml" hash="90b97e0328d50ed134c0b36391a4aa99"/><file name="es_UY.xml" hash="a30737900d956dc397357f6463d532a1"/><file name="es_VE.xml" hash="03449a8b82e4d21e0a59836ceb148536"/><file name="et.xml" hash="d3e8e213866259a27ab9511efe348e0c"/><file name="et_EE.xml" hash="3e92af6dec71aa1ae7a3c62c931534ba"/><file name="eu.xml" hash="7111ceef4472ba0c4e52dfc654a2841a"/><file name="eu_ES.xml" hash="66e48ee02f5d1e5a7076cf9cab709d23"/><file name="ewo.xml" hash="8f5e287d463fbbc8711d46265141be36"/><file name="ewo_CM.xml" hash="47ee8a04b5a0327405d006bd1a99266a"/><file name="fa.xml" hash="1bd0e404ad8d9d3cbc943f04676b03dc"/><file name="fa_AF.xml" hash="3736139f38116f0586eb7aae46f6dcfb"/><file name="fa_IR.xml" hash="98698b67604b8e5589fd75601080cd3d"/><file name="ff.xml" hash="8eec6f2da84d33d3236797c62b96a9d0"/><file name="ff_CM.xml" hash="4bcc2690dc2eb5347be28c55fc008f88"/><file name="ff_GN.xml" hash="a56cbd27d6d838338a535a06db281d34"/><file name="ff_MR.xml" hash="17dd52ffc9809b26db2a067612d92d53"/><file name="ff_SN.xml" hash="9ab32fee7af1d2666669efa4386769d3"/><file name="fi.xml" hash="f1e171910ef4c2137d9a6149cf3c2c55"/><file name="fi_FI.xml" hash="8d9498723893c53c1b6a8ede4d3b796c"/><file name="fil.xml" hash="c44f7b3edadc43b02a927e6cd1e780e8"/><file name="fil_PH.xml" hash="233305bd4c15da54bc9b4847fc753165"/><file name="fo.xml" hash="5715134bd8e1798d5f25d165f8a0bd98"/><file name="fo_FO.xml" hash="99e842dbbd201862703a98e160936c8d"/><file name="fr.xml" hash="125a25633190ef898fe18f2827d2397e"/><file name="fr_BE.xml" hash="1f86df32f3eaddd9b139fbacb7c199f5"/><file name="fr_BF.xml" hash="8eaa50ea5da82e3e8cfea4af20946852"/><file name="fr_BI.xml" hash="eb2d856258ead7da474505881452f613"/><file name="fr_BJ.xml" hash="ef18313c305832ea7049ddf758c9d51d"/><file name="fr_BL.xml" hash="ee7f161cc4c9f844448d9da6fcbb349d"/><file name="fr_CA.xml" hash="64a0b0100ee5e8918ca1d502f06ccb3e"/><file name="fr_CD.xml" hash="d5d62a20e80bfc90badec8a72d8a9d1a"/><file name="fr_CF.xml" hash="d0e96516835a44fcfadd25d0db4e48a1"/><file name="fr_CG.xml" hash="e2852122d57450cd7a388a3545709994"/><file name="fr_CH.xml" hash="2fd3f24252e081fc4c74e9e707c00365"/><file name="fr_CI.xml" hash="e72b4fb87bbb5751e49093c24f4fbd5d"/><file name="fr_CM.xml" hash="e06d4dc5c3604d9cd9cc64376e206daf"/><file name="fr_DJ.xml" hash="7e87bdb7669cbf73ac0bb191d43400a4"/><file name="fr_DZ.xml" hash="64558f39d1553f56217f80ec3ef92536"/><file name="fr_FR.xml" hash="3d82e2934dd28c26c7382de85d95ac11"/><file name="fr_GA.xml" hash="87cc610fd5f6a486c63e5cb105cc2d7f"/><file name="fr_GF.xml" hash="cdecac5dac6e7e10336de1dec5982673"/><file name="fr_GN.xml" hash="0ed99a0d3cec1034899413196dde9c06"/><file name="fr_GP.xml" hash="78ffa2393237a67fd202f96784bcea5a"/><file name="fr_GQ.xml" hash="359c388c94381b4bd09868afb8557b43"/><file name="fr_HT.xml" hash="7ecc803d1e947635fcbf0aa1b201ce60"/><file name="fr_KM.xml" hash="ea71c8291e7c8aeaaad03880b7308a2b"/><file name="fr_LU.xml" hash="2f467a6cc20912bea31f2932c26be870"/><file name="fr_MA.xml" hash="a0fcbe1f955e3d76f9e38eef202ffa07"/><file name="fr_MC.xml" hash="9a6304e508d08737c7969b44d9d57939"/><file name="fr_MF.xml" hash="46968723e86571f7455ee534302d3471"/><file name="fr_MG.xml" hash="ff234d4ba2e66cbb7b798ca787c67026"/><file name="fr_ML.xml" hash="7d1c047089abbf427b3635bc977444b1"/><file name="fr_MQ.xml" hash="f8bb16f92cdb67bc46ceb7aa7048d908"/><file name="fr_MR.xml" hash="d838bbdbd611c35862b89899816befb9"/><file name="fr_MU.xml" hash="ead1fa2ecb9031315ac554ca214d551e"/><file name="fr_NC.xml" hash="3d6500c28264363b27bf842259ff8a17"/><file name="fr_NE.xml" hash="f5bec7e22bd5db13346937f58a1312f2"/><file name="fr_PF.xml" hash="d9c7edabd1f8fd52c5320d874c96c021"/><file name="fr_PM.xml" hash="bae26570b49ab5979729a5f5b66ce087"/><file name="fr_RE.xml" hash="0c9b4ea0bf6c26c33ed0cef26f428af4"/><file name="fr_RW.xml" hash="8725f9ee61c3054199536d6d8eec42ba"/><file name="fr_SC.xml" hash="1eeb10b51d815098e01a3f60d71f793f"/><file name="fr_SN.xml" hash="fa6da2f3ae651bd93705f26587ed135c"/><file name="fr_SY.xml" hash="b6ef0c074642c951a04131a3cadfdfe6"/><file name="fr_TD.xml" hash="ff554940988b4f7bd210a2138575c6c8"/><file name="fr_TG.xml" hash="2256df16de2fd7331fbfbeaeaf0ddba3"/><file name="fr_TN.xml" hash="d9996b3dba7d6ca0aa12c1e6766d2f27"/><file name="fr_VU.xml" hash="4f07ba927564fd6d3507816cf3aafe45"/><file name="fr_WF.xml" hash="a6c659de13b695c7e229681b819ed473"/><file name="fr_YT.xml" hash="821b7a10ac601226696fa7d71d0f8247"/><file name="fur.xml" hash="62a65af07d949f1117573e425bee90fd"/><file name="fur_IT.xml" hash="647415f7e2ebd1d55b260dac3823e3f9"/><file name="fy.xml" hash="14a7805cafcf18dc2f21a7925e9d7182"/><file name="fy_NL.xml" hash="dac6922c58516864d0d18df09753b917"/><file name="ga.xml" hash="7cc3d8d5796c554549ea5ebe5fb9cc35"/><file name="ga_IE.xml" hash="49dfc6b41e17ddc6cd93d17b1aad62f6"/><file name="gd.xml" hash="49f89d47c209b25730d8d731973f29b5"/><file name="gd_GB.xml" hash="721b95588bf8f0ab4004d868128cf286"/><file name="genderList.xml" hash="12c8a32237c76cd85cdb15f8cd140023"/><file name="gl.xml" hash="f7c56b822d2cc164b6691956fc79669e"/><file name="gl_ES.xml" hash="05e04a61e62eab6b94d6cfa3ef96ef25"/><file name="gsw.xml" hash="2b9d820569249f8fe88f6f77320223f2"/><file name="gsw_CH.xml" hash="ec2f1146d4fe5125f42c6281bb2f10b7"/><file name="gsw_LI.xml" hash="a6031e3e7ab4512a905d91484d8f5f00"/><file name="gu.xml" hash="8fe2967cebfbb4a19bfdbff9a8029cab"/><file name="gu_IN.xml" hash="0f93d2cd4139a9fa96df164cdf0357ca"/><file name="guz.xml" hash="65566bd2674a999999affe67ddef45a0"/><file name="guz_KE.xml" hash="7891c10bba2ae36ce29ce34f996ded25"/><file name="gv.xml" hash="bdb5556e04a5f2acb2141197e09020ef"/><file name="gv_IM.xml" hash="cf6d862525015e25038f60fc93175e84"/><file name="ha.xml" hash="310c626b795a231ad736c44ffe0df31f"/><file name="ha_Latn.xml" hash="a470076b9866db162e1415aa32350a44"/><file name="ha_Latn_GH.xml" hash="e213acaf6a53ba1d9c33d2ebda346ab3"/><file name="ha_Latn_NE.xml" hash="7983a567b1473874f3bea1dfb045ab29"/><file name="ha_Latn_NG.xml" hash="d2191f02d90e7b9912fe0e66aed70d24"/><file name="haw.xml" hash="5012e655132a7a5a7ad8397052baf955"/><file name="haw_US.xml" hash="5bb77c6692d33c8488fd008640434b2b"/><file name="he.xml" hash="70cd2438f74f6ea64543ec52bbb06e56"/><file name="he_IL.xml" hash="bdc2d75f46f4dced46dd4fbce6cac4f8"/><file name="hi.xml" hash="20e5122052162ec860cd27db34fc1dcb"/><file name="hi_IN.xml" hash="fbc59458d4ad8d295265e79fec26534a"/><file name="hr.xml" hash="ad2c7a5102cb05cec7ae0478d2f5b552"/><file name="hr_BA.xml" hash="bb36010b5b7cb83bf623d27eddc90678"/><file name="hr_HR.xml" hash="0a5068d64bfd804afa623562e6c556b1"/><file name="hu.xml" hash="35260b5e75ed941097710b0a0483e407"/><file name="hu_HU.xml" hash="b816b69e9814d33ad14907c9c3b6316d"/><file name="hy.xml" hash="4dd0bd1e21762124de07651094889237"/><file name="hy_AM.xml" hash="cc2c8134ca77e5bd55315c5faf80c61c"/><file name="ia.xml" hash="a57208d2e90856e670b25cafa90caaa0"/><file name="ia_FR.xml" hash="dbfd4721237b03875d50cb0770f1a5bb"/><file name="id.xml" hash="ad0dbea4ed9c97b2ef44ea451ff43aa5"/><file name="id_ID.xml" hash="349192acc73b4d40b3ea684999c5cd4a"/><file name="ig.xml" hash="0cd19cfcc514c8c5c0d8b8f085e64a72"/><file name="ig_NG.xml" hash="666845e6dc06958bdd682bf40b9a0251"/><file name="ii.xml" hash="db4ca0fa7cd320163163a97946399d6a"/><file name="ii_CN.xml" hash="a112d1ad1b7fa51a30f6cdb0850168b5"/><file name="is.xml" hash="a4587bd0d57e17d1960dba1a45b5e1b4"/><file name="is_IS.xml" hash="5d2fff72bd6199e1e79cdb3fa126b6a3"/><file name="it.xml" hash="dfa19eadbd4b5819453159c12e5bc32c"/><file name="it_CH.xml" hash="da4122fb147f2652de469a3f7703862b"/><file name="it_IT.xml" hash="0fded926a8f00f5f491f4ba2486b0686"/><file name="it_SM.xml" hash="4706ecb3a92e9e05f6d9f54bacbacf34"/><file name="ja.xml" hash="a4bdd8fef7cac5c8ab8a706781d475b8"/><file name="ja_JP.xml" hash="b87ae521fe2527bc9051ee631bd1001f"/><file name="jgo.xml" hash="9471f4b7fa6323bf54a3b8b74813aeb7"/><file name="jgo_CM.xml" hash="8ded303577f1a672dd255dd1fc1490fc"/><file name="jmc.xml" hash="fb1bd646841f4b8af118996f1ffc4591"/><file name="jmc_TZ.xml" hash="fc0d97c3788543fb5a53695be429dd96"/><file name="ka.xml" hash="6223813b9ac5f055c2c682eb79e6e05e"/><file name="ka_GE.xml" hash="b5df45beb8ba26df37d00154fe2e8deb"/><file name="kab.xml" hash="28e3bfe8412eeac7fda8a154c2dc9375"/><file name="kab_DZ.xml" hash="c398b9636cc7716ab1152528de39599f"/><file name="kam.xml" hash="078f9f3de5e4a2e405f91db0580fee61"/><file name="kam_KE.xml" hash="671d06ee91b5451d3bcef26cf6d0962a"/><file name="kde.xml" hash="db0e85e0f1bd852d8d467e13f8a2dfd3"/><file name="kde_TZ.xml" hash="9f41da9a28fdfd1cf618deba5d9e70ee"/><file name="kea.xml" hash="5504f98e950dd836749ecf3eabbb9d03"/><file name="kea_CV.xml" hash="88602da9c4e3bf124a330f1d0fb84113"/><file name="khq.xml" hash="f0deb2302861cb75bfa96b4b11cb6fa9"/><file name="khq_ML.xml" hash="44d6228f6585a0ddfd53f2b13f7f18c7"/><file name="ki.xml" hash="26a88ce1af8c274b1b5ff3a5c11fb3eb"/><file name="ki_KE.xml" hash="2b5e5cf6cd0d7e38ca3d1d1cb63be4fb"/><file name="kk.xml" hash="a298ecc37ae4d60ce87cb0eaad919d3d"/><file name="kk_Cyrl.xml" hash="07046177e2ec5347df348912409e4283"/><file name="kk_Cyrl_KZ.xml" hash="5bfb35389063a05e63ddec93b4ffad82"/><file name="kkj.xml" hash="3a97c2408dfbbbf2ee181c7c70b2ea8a"/><file name="kkj_CM.xml" hash="095d6748ff7c6f070fae30938ef729c5"/><file name="kl.xml" hash="95ed0d90dae8db61f7b46db63aac0a0f"/><file name="kl_GL.xml" hash="ef6c30e0b4063b1b8fad4e4511e3e33c"/><file name="kln.xml" hash="67441932af9b0b24bc2c2ca2e018d5e8"/><file name="kln_KE.xml" hash="f10af3f43ee9aee1bbf52ca5ff1c5196"/><file name="km.xml" hash="dee5bb763d56521b3c2919a340021c62"/><file name="km_KH.xml" hash="8a31a83be02152f33704d7dc2d2e3e4f"/><file name="kn.xml" hash="0b9d9e33559353f7c074672472ad8f7f"/><file name="kn_IN.xml" hash="e4135fa646d16bb15bf8c24919a4122b"/><file name="ko.xml" hash="9f2d95effdc2374377d41ff61f1f8ace"/><file name="ko_KP.xml" hash="cf696a9af609810d08337fb56f4b2a51"/><file name="ko_KR.xml" hash="0e6404f41f456011631a67da431ec48b"/><file name="kok.xml" hash="deea0756950d5465bf3d529ddf533e4b"/><file name="kok_IN.xml" hash="9ae56f19c07124aa5801d3f2d21dbdfc"/><file name="ks.xml" hash="62e4a1072ac6d8a14df457bb325d97bd"/><file name="ks_Arab.xml" hash="2c7ee60c2f9764e87ce01dace3089799"/><file name="ks_Arab_IN.xml" hash="2fea656a91f684489095e5f13d76c778"/><file name="ksb.xml" hash="d4c84ad5e9ce333697588c7cfc6a8ac1"/><file name="ksb_TZ.xml" hash="ccfb53a163d96d54debdaa15d3499027"/><file name="ksf.xml" hash="a8187b83f4ae0a05f0219f6262c38a70"/><file name="ksf_CM.xml" hash="203147426344f510947dcfe51ee77b83"/><file name="ksh.xml" hash="2617cb6c2b91f15403ce462da0021275"/><file name="ksh_DE.xml" hash="8e085f8da562734068ff0141aa759eaa"/><file name="kw.xml" hash="91ad55b87458489c861988b7fb6280c1"/><file name="kw_GB.xml" hash="7e2024541e7aba767e844c0b9663e155"/><file name="ky.xml" hash="a7545fd81340fd75464e271076dc5279"/><file name="ky_Cyrl.xml" hash="2fe62d616b564a7316ef4a8a72210488"/><file name="ky_Cyrl_KG.xml" hash="757d4898a54dcc119b43698784cc8967"/><file name="lag.xml" hash="a8a25a77df5909db3b73340774221cb5"/><file name="lag_TZ.xml" hash="ebd0c62787658dec41e3e49017e2705a"/><file name="languageInfo.xml" hash="9a33723a317db6855c7dc4a37a9fffd5"/><file name="lg.xml" hash="2cc89f3e98775beee70bdd3e3404d9dc"/><file name="lg_UG.xml" hash="d98767310f065c6a3755cfb5fec6b9a0"/><file name="likelySubtags.xml" hash="6a042c9e337512b06f75e101a49981f5"/><file name="lkt.xml" hash="dba6053b63f4c6e3bf2e21f603c8d78b"/><file name="lkt_US.xml" hash="bd6f8a8cc0acca0ad53b85350f2f5b80"/><file name="ln.xml" hash="0cea3d899d3dad394a5e92db22044bc9"/><file name="ln_AO.xml" hash="9eabbf5b540202c5e5b521cdd06564b4"/><file name="ln_CD.xml" hash="5a6fd6126bf58147cdad6a565bae8af5"/><file name="ln_CF.xml" hash="349ec0ad936ee0fc9c5a00530e259390"/><file name="ln_CG.xml" hash="25c98dbc645d64b7cd800fbf6674fc4b"/><file name="lo.xml" hash="52aa20460fe494c813927fdab64feb08"/><file name="lo_LA.xml" hash="0266874e3970a24dab991fc54e111360"/><file name="lt.xml" hash="6d485e98ca9590acf70ea1838e488ad7"/><file name="lt_LT.xml" hash="738d6dfb27e54f7f9a44875b6dacf0e5"/><file name="lu.xml" hash="5ee43a091cdfb35d5f14067f45b0b05c"/><file name="lu_CD.xml" hash="dbe948b08a594210a3d088e414123d86"/><file name="luo.xml" hash="69779720b4294de854bf82a170ffbec9"/><file name="luo_KE.xml" hash="ad6df8710e3b4976c7bc95b0ec739fa3"/><file name="luy.xml" hash="d0e4e4766a744edc1ab08418bec0ee61"/><file name="luy_KE.xml" hash="28a00f1eb2977ad409b0dfca45a0ca9d"/><file name="lv.xml" hash="3a85d69acd0b15e47f9b2df341be7573"/><file name="lv_LV.xml" hash="6e07fe6de844f63ae1605a6a1a5575a5"/><file name="mas.xml" hash="b1ee3c8d903462d3b217b7056a31df20"/><file name="mas_KE.xml" hash="e494f8d43607f742e3a0cf393ad83bcb"/><file name="mas_TZ.xml" hash="a5785e18c75185c28f284f2e18e7f6e0"/><file name="mer.xml" hash="2023c272b2b6e1169d0d45bb195c7d53"/><file name="mer_KE.xml" hash="52600bcaac77d9e6aa9c9741e67323c5"/><file name="metaZones.xml" hash="64a142f5cc668612c9c6ad2ff0af875f"/><file name="mfe.xml" hash="cec57c842e65ebeaf746db91ac55f5b1"/><file name="mfe_MU.xml" hash="990e405c5cae3b6d7226d0482d0b6848"/><file name="mg.xml" hash="fd8b564029dfa72a913ff627c834082c"/><file name="mg_MG.xml" hash="81a7d92eedd7a4d9cb8c8687badf4aec"/><file name="mgh.xml" hash="6008ffd778c2d670383ab125848d5a68"/><file name="mgh_MZ.xml" hash="ed7a568c678bb3ec003732ba4e7c19a8"/><file name="mgo.xml" hash="3e834a9a979970d5c82d963a56947a11"/><file name="mgo_CM.xml" hash="0cf9ba215d10e1f3db255adcccb3d6b8"/><file name="mk.xml" hash="3ee88bf8c02b4f244b5cd1d3ab617f45"/><file name="mk_MK.xml" hash="aeb740a529d8b51b53242d1f1cf59b2e"/><file name="ml.xml" hash="94d67dd84bc66f80d4a6ffaf27a2c508"/><file name="ml_IN.xml" hash="80849e5c197f5dd2b2ea0317f3517ca1"/><file name="mn.xml" hash="e6a18ab3a3c20fe7ab283cf6a901a549"/><file name="mn_Cyrl.xml" hash="9bdcd159b3be6e0ecf96795d5fc1e91e"/><file name="mn_Cyrl_MN.xml" hash="f11f2f4a083ef35c66ff0a10429b5614"/><file name="mr.xml" hash="f2073dc2a11fd9c7be8ba932e45b830a"/><file name="mr_IN.xml" hash="1623ff448071fe23a70309fa70ac531f"/><file name="ms.xml" hash="9b53207db5cc656f53ac5ea3d90195fd"/><file name="ms_Latn.xml" hash="cda2abbda8d3482f36361e946f37b5a8"/><file name="ms_Latn_BN.xml" hash="5740a4fdad13e0eb211736bf0a2f17ec"/><file name="ms_Latn_MY.xml" hash="c537239c8ae70b442dcbf67911f3fd4d"/><file name="ms_Latn_SG.xml" hash="05424711271e51b0e552063edd05b547"/><file name="mt.xml" hash="961881542802dc1cc9f20f8fcb774f45"/><file name="mt_MT.xml" hash="5282b27d9d6a57d726612a09395e6c22"/><file name="mua.xml" hash="8ebb1a4b5ef4baffddb2894b307f2cbc"/><file name="mua_CM.xml" hash="2df1fe2f39dc3402d5892946ab88f2ef"/><file name="my.xml" hash="64f4ef77afb342a522c3b4779ab19486"/><file name="my_MM.xml" hash="02d8bea58fd9bd5e8dc7796477ef5ce0"/><file name="naq.xml" hash="a29dfa41b2e1630f136a18b12d2c2324"/><file name="naq_NA.xml" hash="0ec1dfc6dc7eed7588f1d1bc41ad56dc"/><file name="nb.xml" hash="46eb58f192d18746c09c8c8582ddd8b1"/><file name="nb_NO.xml" hash="626d2f263762cde6e41328a0bf6768e3"/><file name="nb_SJ.xml" hash="02508dd6f1be1de58fefd7b1159564eb"/><file name="nd.xml" hash="db8baa59e10b31daafd068e55ba882da"/><file name="nd_ZW.xml" hash="ccd1724534080cdf1a784ae0435f7785"/><file name="ne.xml" hash="7cb434ada9a049184fd0a2e021012406"/><file name="ne_IN.xml" hash="84558af586315178078c8e91aa410d9d"/><file name="ne_NP.xml" hash="81a679056920fedc05dad2cda150ef53"/><file name="nl.xml" hash="9f122648b0ae9fbf47dc6364311c9b14"/><file name="nl_AW.xml" hash="d44d954375e2f11a3571f0849dc5b116"/><file name="nl_BE.xml" hash="8e255c2c3d01f7680e6b1931521d15c1"/><file name="nl_BQ.xml" hash="05ea3eec1520c8ef9889b627f3c11624"/><file name="nl_CW.xml" hash="b4b444e991046f1e3e3c44eaa6d825bb"/><file name="nl_NL.xml" hash="4e0467c9db5288462ceb8f78611f6fc5"/><file name="nl_SR.xml" hash="ac0e3ff1c6706ecd9ad0b727583e024e"/><file name="nl_SX.xml" hash="3081384591890c797dfc87c4f4ec40d2"/><file name="nmg.xml" hash="96a40607cf05ce8f8ecbd81edfe54188"/><file name="nmg_CM.xml" hash="e4b39732f25ed7f4fd5f8eeab2296cc0"/><file name="nn.xml" hash="df403882fc0d4fbde259805dbb578133"/><file name="nn_NO.xml" hash="bff2529dd25fc5eff4e45c62e57a6102"/><file name="nnh.xml" hash="604802e1f48c5efb5006478f6096cba2"/><file name="nnh_CM.xml" hash="0797c07c5503386e902db37bb81036a1"/><file name="nr.xml" hash="537dfb7c804216084ff12405a79e6363"/><file name="nr_ZA.xml" hash="deaad06361e3310f47a0ae239b2dde45"/><file name="nso.xml" hash="d8d03686f2a5498288ab934b1d23af35"/><file name="nso_ZA.xml" hash="b8d56986c8588034819ce4112447bb7a"/><file name="numberingSystems.xml" hash="978a66b09ff3a7fe924e5220ac632035"/><file name="nus.xml" hash="aeb47a867f44fc22028eea112a9f20d7"/><file name="nus_SD.xml" hash="5b01ebcdeb5e0925420a1ec5a81078e0"/><file name="nyn.xml" hash="7a00226944592e03fbf05992fc97cb37"/><file name="nyn_UG.xml" hash="f98eb55dcdecb237d0d5f4442e967df1"/><file name="om.xml" hash="d7dd5059b280e4e673d39c6681dedae6"/><file name="om_ET.xml" hash="a2bd53f37a0cbde29c75476d11efd951"/><file name="om_KE.xml" hash="6f499797aaf7cddf5c96510055b1cb6b"/><file name="or.xml" hash="a1f44afb1360bea5213e7769b0d555ab"/><file name="or_IN.xml" hash="b8384a249e94ac1d3aeccffe6456d213"/><file name="ordinals.xml" hash="8105f05e542d711fb1c58eda93ee1970"/><file name="os.xml" hash="d3994c255a9ed31b3b485e2a60100bb6"/><file name="os_GE.xml" hash="b707a294c3bda74ce1fe3de56d5a2065"/><file name="os_RU.xml" hash="ed7de0aca2851389edb27ec27cfbff14"/><file name="pa.xml" hash="eb25b28dccb7fc2b9e8a58529383e7ad"/><file name="pa_Arab.xml" hash="d066d05609c4bb72a91b66960df82d4c"/><file name="pa_Arab_PK.xml" hash="af6c1f47b0c9125afa5f1d8b4465afae"/><file name="pa_Guru.xml" hash="3b5761c3adfe0fd8f769757108a33d74"/><file name="pa_Guru_IN.xml" hash="962eb7156fcccfee1c3b62562bcb4c9e"/><file name="pl.xml" hash="4badef8c402fbce8a919fe0345018145"/><file name="pl_PL.xml" hash="9f5e5245cb2b2a52ef56e3fd69363f31"/><file name="plurals.xml" hash="4223a72c769da4553aeaffc82409128d"/><file name="postalCodeData.xml" hash="ee416690bc7b0b51c62a4f60df3c6e49"/><file name="ps.xml" hash="71320ee03ab67c4d86b2042a2a450044"/><file name="ps_AF.xml" hash="e2b047a904f02a454f193f37856e9f6c"/><file name="pt.xml" hash="6c0d496db88b044f4bccea7b2bcf5bb2"/><file name="pt_AO.xml" hash="502a761ed5e5ca0b44403ff8d0e85e94"/><file name="pt_BR.xml" hash="9ec9d29dec55f67013d4e3ce15799d05"/><file name="pt_CV.xml" hash="3f8377d6db982dc7b9cc6294ee963517"/><file name="pt_GW.xml" hash="bec710dffaed02976223f5671fb48ec5"/><file name="pt_MO.xml" hash="1df59a4a05e1141e225a7da25c58ec4b"/><file name="pt_MZ.xml" hash="b5b28ee99e7f12e1c14e015c3ecf5c4d"/><file name="pt_PT.xml" hash="66b28e650fb563d84b53da41a1f261b4"/><file name="pt_ST.xml" hash="7c96e96d8bf1b811ff3358073e3aeb63"/><file name="pt_TL.xml" hash="9e2647ac1cc2d8f949cd000ffc5dd2fd"/><file name="rm.xml" hash="aa5e41d750b8392990ce00c29f4feb4d"/><file name="rm_CH.xml" hash="3bef003a0204b4d2291ee73c46d8f1ee"/><file name="rn.xml" hash="80a76b1975488f778da8abe7dc0292db"/><file name="rn_BI.xml" hash="c5010d52f27f95cf794396339752dda6"/><file name="ro.xml" hash="fd309802d4e90aa4e51d9f014621e5b6"/><file name="ro_MD.xml" hash="4763fe9a5ac2d57fa9cb7bc5aaa09f7a"/><file name="ro_RO.xml" hash="a7f41f443fcc6daed26d608373a0ebcb"/><file name="rof.xml" hash="4d03559ef40f836156f5e516a9eaa5aa"/><file name="rof_TZ.xml" hash="99f8c6ad97c8acbade2a9f3553b57225"/><file name="root.xml" hash="f74f320723d5a31ba06aa2c79de43bd2"/><file name="ru.xml" hash="3aaf7853667c37781e3d886f364968c1"/><file name="ru_BY.xml" hash="931ca3d10a511ea18c705a22c8baaf1d"/><file name="ru_KG.xml" hash="edee35024102c3ffd1c9acd89f0c9c30"/><file name="ru_KZ.xml" hash="7d4138b25f5c8cbafead8f321fd1954e"/><file name="ru_MD.xml" hash="4d629ff877f4c3a1e214548dc7ecccaf"/><file name="ru_RU.xml" hash="ee8433fc8dbc67a22b31c6be08d13402"/><file name="ru_UA.xml" hash="33fe877250fbd7077b4edf45c50bf300"/><file name="rw.xml" hash="73b90e15bea65ad98ac5cea78e878d91"/><file name="rw_RW.xml" hash="c5cb01f5b236208dc96d3268cf85ffbb"/><file name="rwk.xml" hash="af9317a0322bd40302363d5e6bd4b291"/><file name="rwk_TZ.xml" hash="d0f470b223d25203a611bdb7c395c988"/><file name="sah.xml" hash="f4b2cb698fd582845afb18f984089ee7"/><file name="sah_RU.xml" hash="6ee074c02940d5e9a525a7b8a9c2176e"/><file name="saq.xml" hash="130d69870ed3f95808bced7bed701c3b"/><file name="saq_KE.xml" hash="008b90c332f06e019efc1d8e33f401b3"/><file name="sbp.xml" hash="158d785177f949347356d59dc7883ad8"/><file name="sbp_TZ.xml" hash="0d4f52a378680dcd6230f00cc8ed1f61"/><file name="se.xml" hash="10a3649dbfd8bdff0f8b8fe102b444ed"/><file name="se_FI.xml" hash="ea379a5c51168210274b50711f032355"/><file name="se_NO.xml" hash="0a890443d1477c9d275bb945b0c5b589"/><file name="seh.xml" hash="4361fff00579a2efd8d283a152ccc682"/><file name="seh_MZ.xml" hash="a3f4cc61fa6d995fa5d2cc7b193ee1ad"/><file name="ses.xml" hash="00e9cfea10372a6b62590346a596d054"/><file name="ses_ML.xml" hash="dc0cd9eabaf2c08d66007e6c31a6a477"/><file name="sg.xml" hash="e1bda394071d1796efc18e00467e425c"/><file name="sg_CF.xml" hash="ed51c88dd34a233c82150338436c250c"/><file name="shi.xml" hash="b57def0c24096d11985586f621c09159"/><file name="shi_Latn.xml" hash="61054fc24b89c1842a53be5f5e6016e7"/><file name="shi_Latn_MA.xml" hash="d0f90c1ab8e1b3f7340fc2b77f37ff4f"/><file name="shi_Tfng.xml" hash="4670d2933f9ff2b00c787336498fc149"/><file name="shi_Tfng_MA.xml" hash="271bc282c75731c883ea8fbbd72361b8"/><file name="si.xml" hash="8a27b7c7c9bcdb45049974693c8db484"/><file name="si_LK.xml" hash="b637f75035a4fdfe10f0d3fb39781db1"/><file name="sk.xml" hash="c8b930f68837a7fcaa7e0c34aec1235b"/><file name="sk_SK.xml" hash="7beda18d4fd023382190bc9797d51cfc"/><file name="sl.xml" hash="51bf1ccaecc51b117ea843100b2bc782"/><file name="sl_SI.xml" hash="b71c5b3968b50875758dfdf825c6b21a"/><file name="sn.xml" hash="9aa3b734aa010864b0ff582a67e677e8"/><file name="sn_ZW.xml" hash="24a9dfc3030bf253882c9d661eaef17c"/><file name="so.xml" hash="5b1ade5ca9f6416d2a42aaeefe08803b"/><file name="so_DJ.xml" hash="2850875e1e4d197c81948325e8741024"/><file name="so_ET.xml" hash="6210a645a2c598eed597bab39f36d557"/><file name="so_KE.xml" hash="208c20fcd4d27f3ea7a63a1ccd70b64c"/><file name="so_SO.xml" hash="65f7b820f3de2da5fb6adbbf3fed4244"/><file name="sq.xml" hash="9814afac7a465e293306c2036e97397a"/><file name="sq_AL.xml" hash="6b08a2f02bd463c8854d377761d14ad4"/><file name="sq_MK.xml" hash="7b1a4a47c69c2c11539ecf5f2b306dbf"/><file name="sq_XK.xml" hash="a4be94b459a7ddf3c64782b932c43edd"/><file name="sr.xml" hash="a907b6ed4a9233dce8fb2cafacbb9d07"/><file name="sr_Cyrl.xml" hash="df126a848168eebb92d2cb08b0f47051"/><file name="sr_Cyrl_BA.xml" hash="379078c0a256b4f9ec7111cc9f75a2e4"/><file name="sr_Cyrl_ME.xml" hash="fdc47e86343568ccbf1e619800f26614"/><file name="sr_Cyrl_RS.xml" hash="f269bfd320ba2b38a6a614ca4da321a9"/><file name="sr_Cyrl_XK.xml" hash="8e3b5caa0e9997575201e3f7823a81ac"/><file name="sr_Latn.xml" hash="b26fdb85fcea35960444294ab6f10b21"/><file name="sr_Latn_BA.xml" hash="8abd2f52848f701a485ce865e97b851a"/><file name="sr_Latn_ME.xml" hash="49c92f426cc5a5188399c80878686f83"/><file name="sr_Latn_RS.xml" hash="713a42425709d2a2448ed3ceefed8d07"/><file name="sr_Latn_XK.xml" hash="d9f80fc5757c8be78a8bf06b0090bb1e"/><file name="ss.xml" hash="1c8e4708d8197d98b32e84db842531ac"/><file name="ss_SZ.xml" hash="36bd3ae71800ee1509cb005345b7d0d4"/><file name="ss_ZA.xml" hash="929a6fc019f32616331578d55a36412a"/><file name="ssy.xml" hash="4cd34c993f3f737c52ef02dc0c65180c"/><file name="ssy_ER.xml" hash="6500f7ea9752b2272ff4c93530514345"/><file name="st.xml" hash="13de7725514e5dd58f49e0b01ec7858f"/><file name="st_LS.xml" hash="16fac9f2505893a9ae5df24174ec8e94"/><file name="st_ZA.xml" hash="c769d53933a0816218637180bfe3b1e6"/><file name="supplementalData.xml" hash="7c64143e835c0a2facebe573b95c735d"/><file name="supplementalMetadata.xml" hash="89562abe6d40c4c7245a8c465905e618"/><file name="sv.xml" hash="157cbade1293f5bf503b8ce03cac9260"/><file name="sv_AX.xml" hash="eb9596e23c3e3597f9167c56bc456ba8"/><file name="sv_FI.xml" hash="c7985fcaa170e42535eebb8f2821fd8c"/><file name="sv_SE.xml" hash="a234be39c4fe51d5360e867ef057e9cc"/><file name="sw.xml" hash="baa99fb8dae1057541cd174d8c479f63"/><file name="sw_KE.xml" hash="841c4e403526c85c138ec30908f0e639"/><file name="sw_TZ.xml" hash="d8c70853021414f35fff5160e777afc4"/><file name="sw_UG.xml" hash="2f39a025d909e27a3b4d42ada4494f44"/><file name="swc.xml" hash="b78d391b482ebeaaa8d2589248b99475"/><file name="swc_CD.xml" hash="7ef627a3af8e94ce44e118facc634280"/><file name="ta.xml" hash="f14aabe0b254b16a7656cf0eb924a937"/><file name="ta_IN.xml" hash="a3cf28d4dffdfb99fbd06c56f7407690"/><file name="ta_LK.xml" hash="c4cb7d38b9ab64f09398af90233929b6"/><file name="ta_MY.xml" hash="50b7aa25e1de2ba3060cf7f1542dbb1e"/><file name="ta_SG.xml" hash="467cf5081dce3961ff108329da18461f"/><file name="te.xml" hash="9000f302efec5389067682dcb37713ec"/><file name="te_IN.xml" hash="46c5a0f8ad33a8207687131b1e30dbc3"/><file name="telephoneCodeData.xml" hash="df7976ae3ed9a46df9b7a3d153a08782"/><file name="teo.xml" hash="1a54151c61645deebd146ce8167ebb7b"/><file name="teo_KE.xml" hash="28904dbd23feee396d235bddafb88a5f"/><file name="teo_UG.xml" hash="a3c2615908baa53ef6c06c1bbc46d03f"/><file name="tg.xml" hash="b0a784936ff2b4d986bea0a5abaafc41"/><file name="tg_Cyrl.xml" hash="dad9b0de0bca8885769e3eb3b986ed38"/><file name="tg_Cyrl_TJ.xml" hash="ecd76f8a9c11ea36f23aecbd4ba10f94"/><file name="th.xml" hash="93a93b50d5bc06c3aba030a2bc8f3a2c"/><file name="th_TH.xml" hash="16920f2948dfc0169fa4120b6bef4c6c"/><file name="ti.xml" hash="68ba067a766e83fa56b3f8b64e911709"/><file name="ti_ER.xml" hash="fc1625e77b8ee3b39e5a21a5778c6352"/><file name="ti_ET.xml" hash="eda9e0f13702f4f4d6c56bf8702bc158"/><file name="tig.xml" hash="dcbea52ddac1a8641439c191ef8cad3c"/><file name="tig_ER.xml" hash="9e8951b4b641d755277bba697641eeb4"/><file name="tn.xml" hash="5ecf790feae7a56e7d3dda69a3dcdd29"/><file name="tn_BW.xml" hash="5db54fb06600c505374663377ae3c87d"/><file name="tn_ZA.xml" hash="5ffaceb20f45593cf1526096d44811ae"/><file name="to.xml" hash="6abeea01835e1fa2e62a489842917a71"/><file name="to_TO.xml" hash="e17fa8026e023e8614eb6fe68b223300"/><file name="tr.xml" hash="a73038379e7e0396200158e0cb9b2101"/><file name="tr_CY.xml" hash="c02e5d602dc71097faf6e40c43c00df5"/><file name="tr_TR.xml" hash="98e092d092bd6efdacd4c9181bdf1269"/><file name="ts.xml" hash="d4de7842ad3ed50f09e585aeb8fd2b48"/><file name="ts_ZA.xml" hash="a058d38e5fc52060f992a09c44bd2dd4"/><file name="twq.xml" hash="8cb693f4457b01d524eb4dd3a9202fee"/><file name="twq_NE.xml" hash="f3887ed69d01de60ea150fb49741dd7e"/><file name="tzm.xml" hash="184e66cab1c6bfb1c1ede84b1b9b8d5d"/><file name="tzm_Latn.xml" hash="c48b72028daead39c63e06be5940b06f"/><file name="tzm_Latn_MA.xml" hash="adeed44054a352a8a95fb63a47b1277d"/><file name="ug.xml" hash="0048db54db7e96e66309f27990302912"/><file name="ug_Arab.xml" hash="b0916370f9a3dcbe9f9ef7f4941e83ff"/><file name="ug_Arab_CN.xml" hash="ca617ed54b6b547d9cd4929653765e69"/><file name="uk.xml" hash="82e297c9a0e35a239300e9d781246ca7"/><file name="uk_UA.xml" hash="f1f43742973c3e0684078ad1585c09a8"/><file name="ur.xml" hash="4330b97cdc580fd937fb4b48c30138dc"/><file name="ur_IN.xml" hash="620558a8d2b16341b990f739d96fa656"/><file name="ur_PK.xml" hash="4929ef93fcd09c110306500b7b5df200"/><file name="uz.xml" hash="e885a45d72df08108a5fb5553caf5650"/><file name="uz_Arab.xml" hash="bbccf5949290b9a88bdb05112ef0f1f1"/><file name="uz_Arab_AF.xml" hash="e8b2a9bcdfcddf5fe0923bdb79586e3b"/><file name="uz_Cyrl.xml" hash="f11985a357906a9764a2eeae61d87834"/><file name="uz_Cyrl_UZ.xml" hash="e34ac326ca872838cb51f7d95f2cad57"/><file name="uz_Latn.xml" hash="6d1de019d75988a154546b7a6ec4cecb"/><file name="uz_Latn_UZ.xml" hash="9f0dd4f61e4ad966fd33e26c0af5d722"/><file name="vai.xml" hash="4ccc7bd3230a4395017327e278bea5d7"/><file name="vai_Latn.xml" hash="78b6884327d1a568c1dcb55edcc8e8c7"/><file name="vai_Latn_LR.xml" hash="d60cdef15dbd84e66ebf6532935f2735"/><file name="vai_Vaii.xml" hash="4d3b525d05e85213d169a04051aed2cd"/><file name="vai_Vaii_LR.xml" hash="64e621f56506d7b70656d056ed8e8214"/><file name="ve.xml" hash="0238fc0b60b7f9f80a821455e85a26df"/><file name="ve_ZA.xml" hash="cfd73cf7fc6d3bef016b3dea6c1464c2"/><file name="vi.xml" hash="1ec60312f7c6e419dc883676a3cfb10b"/><file name="vi_VN.xml" hash="cfb0ceae9f2e78e0459f062016230998"/><file name="vo.xml" hash="a696981962fe9a84ccf27cd4f46a07a6"/><file name="vo_001.xml" hash="ca84f69da9df24a4e409104c54a8a3d5"/><file name="vun.xml" hash="2838dac67405ebb6515ed35b983f13c5"/><file name="vun_TZ.xml" hash="5c00fe9a927fa96193d8be8f22c4ee99"/><file name="wae.xml" hash="7a6a03e67b505d33af84383427ff1db9"/><file name="wae_CH.xml" hash="bc6ad0fbf82a5317ade928730b115b91"/><file name="wal.xml" hash="5fa5a9a4263c2c0c75cb61e137ec19b7"/><file name="wal_ET.xml" hash="fe6ba6e078852d9949dc023b20e40462"/><file name="windowsZones.xml" hash="bb1d22fd1c7e1073f31559d4ec4f6ea0"/><file name="xh.xml" hash="c4561fd383180394c1719f7af01252ed"/><file name="xh_ZA.xml" hash="7cc6e52fd5bbde7d7a09835462c9005a"/><file name="xog.xml" hash="d159722255a22bf4b113822364e3aa42"/><file name="xog_UG.xml" hash="c9d9ce8325ccd943d17be076e2348509"/><file name="yav.xml" hash="7cd6b28230ea1b592f4f6dc656d7dac6"/><file name="yav_CM.xml" hash="d99d7f9815108fe4040253b525fb1e65"/><file name="yo.xml" hash="94b71c3a56a7d571cdd2cdcca0e3639d"/><file name="yo_BJ.xml" hash="ad14fab000b1bdba3ad0959b41692125"/><file name="yo_NG.xml" hash="1381c16f38223fcd4e645a66f06d3947"/><file name="zgh.xml" hash="47980624ea61e97a271f180c98a7f012"/><file name="zgh_MA.xml" hash="7e72d86646a8b5045dfbedd721e5d0f1"/><file name="zh.xml" hash="7ce5cf9353eaeee426d5d5eb87670dfb"/><file name="zh_Hans.xml" hash="bdb68fe0878c430dc788e383b389dc2c"/><file name="zh_Hans_CN.xml" hash="24a14d8c675ae0c5b2fd211477240405"/><file name="zh_Hans_HK.xml" hash="7c82d550690d9ea63bc19cc76fbb61de"/><file name="zh_Hans_MO.xml" hash="9e4291c5bb0facb592b3ea3c14147e72"/><file name="zh_Hans_SG.xml" hash="01f85db499b693f4d3032e8683db390d"/><file name="zh_Hant.xml" hash="fb57450622d2383ac2f9d0e9c03872d0"/><file name="zh_Hant_HK.xml" hash="8648266bec5d9594fff57e030ff88e53"/><file name="zh_Hant_MO.xml" hash="3625e00e40fe8377de3a9a03628657ad"/><file name="zh_Hant_TW.xml" hash="66f700074df27309b3c6c71701d3b9b0"/><file name="zu.xml" hash="6542a2fe4304ba6289f66b2a68bbbcc7"/><file name="zu_ZA.xml" hash="db4d81680d06e598e322a26e9255ea69"/></dir><file name="Data.php" hash="8fa12d0abbc5557b89cd824b0e18d3bb"/><file name="Exception.php" hash="48210cc1272d8350acafdb8b26e86081"/><file name="Format.php" hash="eb7d886a80ca361bd0c38ec54b5d8bf2"/><dir name="Math"><file name="Exception.php" hash="37609bd0e120bcb0ed890523ac7cd35e"/><file name="PhpMath.php" hash="aa289ad314dc08e0abf97a3f147b6750"/></dir><file name="Math.php" hash="8f03d1a239fa7f642dd43ef7f7c642ad"/></dir><file name="Locale.php" hash="aad364df1a2dcad576c9ae09d94f46d8"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Lib_ZF_Locale-1.12.10.18.xml b/var/package/Lib_ZF_Locale-1.12.10.18.xml
new file mode 100644
index 0000000..dfb3e70
--- /dev/null
+++ b/var/package/Lib_ZF_Locale-1.12.10.18.xml
@@ -0,0 +1,19 @@
+<?xml version="1.0"?>
+<package>
+    <name>Lib_ZF_Locale</name>
+    <version>1.12.10.18</version>
+    <stability>stable</stability>
+    <license uri="http://framework.zend.com/license/new-bsd">New BSD</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Zend Framework Locale</summary>
+    <description>Zend Framework Locale
+splitted from ZF to avoid memory overruns during installation and upgrades</description>
+    <notes>1.12.10.18</notes>
+    <authors><author><name>Magento Enterprise Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:08</time>
+    <contents><target name="magelib"><dir name="Zend"><dir name="Locale"><dir name="Data"><file name="Translation.php" hash="3c4e6ddf022e279cdbc77a860c6cb657"/><file name="aa.xml" hash="6ba5c871d22f64a769c70a1af71a04c3"/><file name="aa_DJ.xml" hash="369c4c2c9eca85c0b60d762a6bc98aa8"/><file name="aa_ER.xml" hash="64dd3e36ee4831d967e49ca2e3acaaff"/><file name="aa_ET.xml" hash="c05abb8269fff734e511dc4d0a11c1a9"/><file name="af.xml" hash="67b34f34749792149e0358fbc902c167"/><file name="af_NA.xml" hash="4034171f9b1450a37ed070aa3d90c5ba"/><file name="af_ZA.xml" hash="6c3da14996bf1b58cd8017df3313b8ea"/><file name="agq.xml" hash="5fd93a5c707e73e4aa5c519c6d64afd4"/><file name="agq_CM.xml" hash="06499c36298cb9eeb23e6dc0dbe20322"/><file name="ak.xml" hash="69320ac48004c58405d12d800a2d81ff"/><file name="ak_GH.xml" hash="5c5c86078d71e30c0399a762e5cf7f0d"/><file name="am.xml" hash="95b934943f754f649861fcc29f378976"/><file name="am_ET.xml" hash="584cb88741cf24321e0c047dcef574e9"/><file name="ar.xml" hash="8ec3de78c7d4ff42daa956025eeebc20"/><file name="ar_001.xml" hash="bc30b0854e32d00739413feb7a5414ec"/><file name="ar_AE.xml" hash="f70fd224cd066586d1b8cf5309774b21"/><file name="ar_BH.xml" hash="0c953018f40ce82e9de064a4cb95a488"/><file name="ar_DJ.xml" hash="66fa3cc4267b7fd0d96a2669a0401d8d"/><file name="ar_DZ.xml" hash="c070ac57992c1611059859954354e256"/><file name="ar_EG.xml" hash="7a422d856e2ec72b9c1494316b89aa02"/><file name="ar_EH.xml" hash="a21177328a2e94087fbae06f1c7471b4"/><file name="ar_ER.xml" hash="0a7472b1683fc78bd1a3a5cafb8b84c6"/><file name="ar_IL.xml" hash="1bca56bc324229351c0089b67d490cb6"/><file name="ar_IQ.xml" hash="0da352ff695a5a3e8e5dd155cd7c4ddc"/><file name="ar_JO.xml" hash="4c7b8b4b5eb54adc1f9c3f6e4dc4dea4"/><file name="ar_KM.xml" hash="e919d368ba30dfdeaa95f70532b4e255"/><file name="ar_KW.xml" hash="9b6ca92c240ea68d66acbb49f91992f0"/><file name="ar_LB.xml" hash="18b007c4b842620480c8bb88aae29b77"/><file name="ar_LY.xml" hash="4da8f8faf728c8a65aae9c4a66008b34"/><file name="ar_MA.xml" hash="f1b35950f3e3e3f4237a5a39c7da2be8"/><file name="ar_MR.xml" hash="f2ffa3c86e1b19b17b09f9099273e9d4"/><file name="ar_OM.xml" hash="ed0e25061367e82694d8cb7c0eaee387"/><file name="ar_PS.xml" hash="e7ee58c19554a466dab9fdb752d24a6f"/><file name="ar_QA.xml" hash="7b180beb5da6eac09e84b58a240d6991"/><file name="ar_SA.xml" hash="d016c7a9ff9de9e45c9136109f8f493c"/><file name="ar_SD.xml" hash="9dfcaa9bb696f5cedc059a4109c8b3ab"/><file name="ar_SO.xml" hash="84afb054141b7c24b7b448b5602359e0"/><file name="ar_SS.xml" hash="6c3734aea87be71cffb4556464be4fd4"/><file name="ar_SY.xml" hash="5a198ba2fef0281de890f996fbf644ef"/><file name="ar_TD.xml" hash="948d829d89a161430f83912af024f141"/><file name="ar_TN.xml" hash="7faf65c744cf5e52bfdb59542bbe7899"/><file name="ar_YE.xml" hash="8c10abba56d6a234a55c654078016a9b"/><file name="as.xml" hash="8fc5e45c11ceac7f52c78ff5166159d6"/><file name="as_IN.xml" hash="694909593f1415ef0e4fda6d5e58be0b"/><file name="asa.xml" hash="67790459fbf5470067fda4eab8703753"/><file name="asa_TZ.xml" hash="a7ff94e5a530dc21c43ab7174ae813d2"/><file name="ast.xml" hash="64deedf1c37b39d07b45a5080fc94190"/><file name="ast_ES.xml" hash="77b6d2a7c40dfcdd70fcd5a48dbc937b"/><file name="az.xml" hash="e5c36c36cb81eca6d5cfa86ef058d989"/><file name="az_Cyrl.xml" hash="4489b815e2f3f628619ccbbe09afe72f"/><file name="az_Cyrl_AZ.xml" hash="827b611f5206f27d79f2c07525340bfa"/><file name="az_Latn.xml" hash="7a9c14a8afa4e30e677b6d588788a515"/><file name="az_Latn_AZ.xml" hash="ef3f0e6fe96210ee2e21ed77c73716a8"/><file name="bas.xml" hash="b5e926cff825d6a19ecdd30aa6ed7309"/><file name="bas_CM.xml" hash="b96cd37b4240f82a00400bceef16106e"/><file name="be.xml" hash="b9e6bfe9f98012d6e2e3adbb8d7f4a33"/><file name="be_BY.xml" hash="f7decbc88e0b84a81c61c33b752f7f35"/><file name="bem.xml" hash="b32d7fab640633d84596c781c5729972"/><file name="bem_ZM.xml" hash="a41416d42e206b3499ed1327002ce5da"/><file name="bez.xml" hash="700611e0dce26a8fc22647aa5708dc74"/><file name="bez_TZ.xml" hash="c767af253038caf4cbfede8a067453f5"/><file name="bg.xml" hash="51b19b644a9796463b91bb8ec236adca"/><file name="bg_BG.xml" hash="05e86d4ebf3b91764d3a0d2551e16bf1"/><file name="bm.xml" hash="09d5b79929820ae15c0c6d5ea4afb6dd"/><file name="bm_ML.xml" hash="4d5e1b37325ed9e57f8c590fe1d3a762"/><file name="bn.xml" hash="199a113c26a1608720ca7e3c660d23e8"/><file name="bn_BD.xml" hash="794e3d0d4fcb61f260ac7bf8673378d5"/><file name="bn_IN.xml" hash="0848d84be54a2646adc33af1c9e4b968"/><file name="bo.xml" hash="febea3f15347297281d6ecfcc5771b73"/><file name="bo_CN.xml" hash="30fd400db11b971da287cea6be2ef3c1"/><file name="bo_IN.xml" hash="d68dac66b5b843ce88da031b16b3afe1"/><file name="br.xml" hash="e870097efcb0cd34bb6e4d1f2dc5b278"/><file name="br_FR.xml" hash="11652862f633f7aec19a1c0433c4b204"/><file name="brx.xml" hash="8047b46746f02a39674f0beefc07e194"/><file name="brx_IN.xml" hash="99404538d96a071935efe231780663dc"/><file name="bs.xml" hash="940b48d89bdb239461bd8b3427469342"/><file name="bs_Cyrl.xml" hash="8580494f42dcf27b664a012d4658982b"/><file name="bs_Cyrl_BA.xml" hash="3f8c9a61ac978bd30d6d64bf86dffec8"/><file name="bs_Latn.xml" hash="0c8b503dcc0f9853d3af20768e662aea"/><file name="bs_Latn_BA.xml" hash="9496b4ae275da058251832af52888167"/><file name="byn.xml" hash="5b73a1af7b8ba27dc8262d81934c3f14"/><file name="byn_ER.xml" hash="4da388f09780d86134689dc5f10a3862"/><file name="ca.xml" hash="581f561afd2a2296430eebbd9cd7cf1f"/><file name="ca_AD.xml" hash="f3f80fa4f38bb72a397d94e6e12175d6"/><file name="ca_ES.xml" hash="24c8e24495f99d3921a5a4e77f8bfb81"/><file name="ca_ES_VALENCIA.xml" hash="e9703c4cedea0d7756a06a653c1c8442"/><file name="ca_FR.xml" hash="84537f1e57ba4476c1f923d12f4f7b42"/><file name="ca_IT.xml" hash="e842526f0ecfcef2904d206b2a810041"/><file name="cgg.xml" hash="054e8d83970f37440d169e964c743447"/><file name="cgg_UG.xml" hash="c6f0a77828c43211f72e10e83f9f666d"/><file name="characters.xml" hash="578bec00fbe6d6416ba89e6fa7986357"/><file name="chr.xml" hash="d5c69b967b2ca2744b8a46d9c95260e8"/><file name="chr_US.xml" hash="53b9e050bf58ab63900197dc8fb43d9c"/><file name="coverageLevels.xml" hash="90d4dc96d148cbd970ac8ff49c209bea"/><file name="cs.xml" hash="23e2ba0f38fbb0021ecd6aaa24db77a1"/><file name="cs_CZ.xml" hash="baa89fb49d1c50a5e7ef632f75d56fa7"/><file name="cy.xml" hash="0657a743b16b94e59c26b692dd79943b"/><file name="cy_GB.xml" hash="9bfe606c96d3d035ad644efe57bc67f6"/><file name="da.xml" hash="507243848cb4398daf768f735cfb432f"/><file name="da_DK.xml" hash="2347254255ce488182e37214c7d0694f"/><file name="da_GL.xml" hash="84ea22e10d4f6aa9ff8a0c6644fd7dd9"/><file name="dav.xml" hash="47ee87a9cdba6d211639776a608c1e86"/><file name="dav_KE.xml" hash="37e7d66af32b1fe4ac81be34fbee5d2e"/><file name="dayPeriods.xml" hash="56449b799dac8fc8daafbb0f3d3d99ef"/><file name="de.xml" hash="198aa0c550d4c41406bd0df6f7b70a7f"/><file name="de_AT.xml" hash="4b960a6fac173340ac276ce5c9d82532"/><file name="de_BE.xml" hash="dce45b8b94a4c3aab891a2c7bf3ca151"/><file name="de_CH.xml" hash="c4e68ad1a19e6e92daa571edb12cb36a"/><file name="de_DE.xml" hash="fa5913f6081a8a4650cef19d22acca20"/><file name="de_LI.xml" hash="0dfda8f44bc729219bb5de48f7694393"/><file name="de_LU.xml" hash="409b134c2c81689c16df1a79c0a4baa2"/><file name="dje.xml" hash="7da22550436ba325fd7b0dfde195b9a7"/><file name="dje_NE.xml" hash="7e318b89d05df66eea3fe59bf75c7ac7"/><file name="dua.xml" hash="ba4657ecd1b3bc014c5dd1622d107e90"/><file name="dua_CM.xml" hash="5bba1b38dc6495219fcb1a0432cc8df3"/><file name="dyo.xml" hash="612804b11d342d9e3b4bb2d58b5f66a7"/><file name="dyo_SN.xml" hash="dc003c4af3987ec2d7255d3c1f541738"/><file name="dz.xml" hash="244f80bfc2f658780ba016281354fe0b"/><file name="dz_BT.xml" hash="9d287c1c61edf1fa5ef3d765b2c7da86"/><file name="ebu.xml" hash="76696c080f20a7db39abc05dd272f090"/><file name="ebu_KE.xml" hash="7c4abeeb255cf7bf2bc500abb12ce387"/><file name="ee.xml" hash="4518057dd1b1b514e3bd12e5b5e85bf2"/><file name="ee_GH.xml" hash="082d3a0d2203319b9e51004a710e3e6a"/><file name="ee_TG.xml" hash="d99900de319d3584f1a115d4b5eb76f0"/><file name="el.xml" hash="1710cdf160e6cab0c4d47c15bab5be18"/><file name="el_CY.xml" hash="6da5d159d499ba4754a2e7d4553d5059"/><file name="el_GR.xml" hash="477e3b1f10320e95a0c12511cb0c8368"/><file name="en.xml" hash="9256d3ec622d04bd406376827d31012b"/><file name="en_001.xml" hash="768d1b54436a379dd71d0239702810a6"/><file name="en_150.xml" hash="7f9a887b30b86016fe8a29cabb6b8ce0"/><file name="en_AG.xml" hash="4d2c7e568ab71d4b4e49c934b47d5c4a"/><file name="en_AI.xml" hash="70e59d70a946d5026659413cecd2da7f"/><file name="en_AS.xml" hash="2b134e308540cf74f34c2aa665112301"/><file name="en_AU.xml" hash="ed81bf367e4f715e9a5c4271bf49822e"/><file name="en_BB.xml" hash="5dff42e201010656bc3dbac5887d015f"/><file name="en_BE.xml" hash="f91d2ce67b1818708d15c091c4c9d720"/><file name="en_BM.xml" hash="2908ee96a408ec7b9d7fd659615d90ff"/><file name="en_BS.xml" hash="91eab1ca2779d23f13df0347f536ca0f"/><file name="en_BW.xml" hash="e37d57c47fd205e31473eb60bb1c973d"/><file name="en_BZ.xml" hash="59d8c1d1deac2a7b0f73992516c999bd"/><file name="en_CA.xml" hash="7f81353970624138037a527f761e6571"/><file name="en_CC.xml" hash="38e31ba2efac50bc06a5caa4bce5fa02"/><file name="en_CK.xml" hash="4a677485a65e531f1468c1543347c1ce"/><file name="en_CM.xml" hash="5a02b7f5fa1bedd6a05f96196e95b711"/><file name="en_CX.xml" hash="fc592a771a64d862c3739a898ce18dd3"/><file name="en_DG.xml" hash="1ec938ecb46bd092323b4f8ce4ba2cc2"/><file name="en_DM.xml" hash="89bee96e1185ba2dbb3ded508dda16a8"/><file name="en_Dsrt.xml" hash="6fbff7ba19f432150086850bc2e2f804"/><file name="en_Dsrt_US.xml" hash="0850b836f2faef6ec3423c7705160ab7"/><file name="en_ER.xml" hash="a99ce4a7be566be0b20822f418a4a589"/><file name="en_FJ.xml" hash="f5cfe8032f32fde1289d2fce5696a6c7"/><file name="en_FK.xml" hash="632a6ac34df2048f5160f1cbb21684e4"/><file name="en_FM.xml" hash="1e288d9366e0ac40b241b90d550d6424"/><file name="en_GB.xml" hash="5b73aa8057d95008d24c3eb91f265fd1"/><file name="en_GD.xml" hash="7d6d4bfad9463d051c6aba6301581460"/><file name="en_GG.xml" hash="a75e2a293cd4eb9e49d495c13b6e37ae"/><file name="en_GH.xml" hash="97e8cffb72f9e6651f8dee6ca086c0ea"/><file name="en_GI.xml" hash="6441468454ea9cf06468b0e19db106aa"/><file name="en_GM.xml" hash="7497ca9f4f962f57dffc9ad93ab78077"/><file name="en_GU.xml" hash="ae33e0859c963b265fdf32cd026ad26b"/><file name="en_GY.xml" hash="50aed051f78b38a1d1156c36d3ad7f9c"/><file name="en_HK.xml" hash="1aa1133bec835a760695dd994a6ca259"/><file name="en_IE.xml" hash="63130f36882b6a6917606b7c6624aa80"/><file name="en_IM.xml" hash="2e981e6e96db2a140dbef95db013522c"/><file name="en_IN.xml" hash="7433385f2bb2afa211e5c33cd9f921bd"/><file name="en_IO.xml" hash="b63a354d390f7b3eb564394b6ea5ebd1"/><file name="en_JE.xml" hash="a37431bab3c66fbc361a775b62627154"/><file name="en_JM.xml" hash="3c59b2850c79e9a7371e8f7a12dd7d75"/><file name="en_KE.xml" hash="2554dd9bd652f9ea57cd18da1a19df18"/><file name="en_KI.xml" hash="f24474b7d06fc2f0220ee7095e6fbff7"/><file name="en_KN.xml" hash="4d68bb1ef92eefad6f2fcc0e0b0d5076"/><file name="en_KY.xml" hash="b686bd51fe232c2107a08e8d9a5f1577"/><file name="en_LC.xml" hash="2ffab8614818ecca5af1c84ddb96a6bc"/><file name="en_LR.xml" hash="eb8f5ac9ca72306127d86db0085a92c0"/><file name="en_LS.xml" hash="8255d2c42f06b2d7c511353e82edf59e"/><file name="en_MG.xml" hash="5d7a723320b05e8fd7a4a1c8017bb57c"/><file name="en_MH.xml" hash="3c762f2aa253bef5b3cd1ad5940c3cc9"/><file name="en_MO.xml" hash="c20af1a8a15c19b9a52dd56c36b5598c"/><file name="en_MP.xml" hash="d535408f7920814d2d2b7c4ddfbba7e5"/><file name="en_MS.xml" hash="d74c01a6b57a68fc4d149b0f2bd5faf2"/><file name="en_MT.xml" hash="a0779f1ed61a4fa24f2549fc37df1523"/><file name="en_MU.xml" hash="484d1081e00dfe315b01368e63a8e547"/><file name="en_MW.xml" hash="6f5546f3143027e27250f1b471f3722c"/><file name="en_NA.xml" hash="43792f7465fd56dff8129154cd568400"/><file name="en_NF.xml" hash="9ced4a796c1db1693c526340fdda01d0"/><file name="en_NG.xml" hash="ba618207a64de97e9420801e8909f076"/><file name="en_NR.xml" hash="56f2eb49dc7a336e5eb0e2f4503dc3ed"/><file name="en_NU.xml" hash="524a420bdbf2d1bfe4ced79e690fadff"/><file name="en_NZ.xml" hash="3960c92d3ef55d1e55bc7bb7808a1c58"/><file name="en_PG.xml" hash="9fdf21ef2f976e068dfddbdd0bfcbbbf"/><file name="en_PH.xml" hash="6d0b1441355b533aa7231a45f330bb68"/><file name="en_PK.xml" hash="48a4db2301d34ccedf58942f3b41b181"/><file name="en_PN.xml" hash="846a0b8c74785cf3ffb562abbd5d5cd3"/><file name="en_PR.xml" hash="76bec34e4f081c2cc6ea562b9d3c3552"/><file name="en_PW.xml" hash="258fb50d80e798ffe19514bceaab9c85"/><file name="en_RW.xml" hash="aaa4befd7267fe5afd6682a00241eca2"/><file name="en_SB.xml" hash="0c50f8257806c71a8fba4cda42acb2ac"/><file name="en_SC.xml" hash="d8769c5bbd31f66c1a40d82ad4f9959e"/><file name="en_SD.xml" hash="9d3a24c9a0bd4f99653130314a6cca29"/><file name="en_SG.xml" hash="f32241b6135eb9e8733ffc80fab1b110"/><file name="en_SH.xml" hash="c35756da3a6effbfa9af4d488f7292c4"/><file name="en_SL.xml" hash="dd9fc72730ab0e6e58086a662fefa69d"/><file name="en_SS.xml" hash="35c730c6f16af1d572ef33bbea15fde3"/><file name="en_SX.xml" hash="d33e0d2eb46c1dc7004b84f6606dff0e"/><file name="en_SZ.xml" hash="a53c6878dcddbc32d37ab6b77e17da36"/><file name="en_TC.xml" hash="55127dfa22212f6abded3dd606af5a85"/><file name="en_TK.xml" hash="64ecd71d4530f1668e9da48f1039f508"/><file name="en_TO.xml" hash="a5e77bc5a7beecf3ff8f6b3156a87668"/><file name="en_TT.xml" hash="8b168ae6e9c3d9c8fceb0582365264af"/><file name="en_TV.xml" hash="7f98c91cd0dd96a66e4c8684d1d60639"/><file name="en_TZ.xml" hash="0cf0401e55af54ff68da8bab8c901182"/><file name="en_UG.xml" hash="a028dc8e13686a9ebafb83ace5315206"/><file name="en_UM.xml" hash="b883319cb6ecd9b1a6cb1deef89db236"/><file name="en_US.xml" hash="6435b96852569c7e355302c17814f77f"/><file name="en_US_POSIX.xml" hash="535c6ed9fd3be4db0fbf7ba3c79533b6"/><file name="en_VC.xml" hash="e745b417ac7ff1c93f281070740e901e"/><file name="en_VG.xml" hash="66ebc85cc70895db528d868b2318e5d6"/><file name="en_VI.xml" hash="3f30ee6f1c7383f6d906106f09cf5eff"/><file name="en_VU.xml" hash="6eea6dd6ac0cc9d00386059ff12a865c"/><file name="en_WS.xml" hash="bdc0360cf4fb7b517dbee39de8d0cd58"/><file name="en_ZA.xml" hash="031afdaa1011735bbc6555c5e76d7ff6"/><file name="en_ZM.xml" hash="c7bdd89484bff8dcf4daf3f57f6d6bc8"/><file name="en_ZW.xml" hash="b3f51877ba7ce7ead43ef50b499b4444"/><file name="eo.xml" hash="82ba66eacea4e98f8923944eddcc1745"/><file name="eo_001.xml" hash="1801937ded337e21aa03e2592deedb46"/><file name="es.xml" hash="a60ed8506871160a17c4fc3b81e53b0a"/><file name="es_419.xml" hash="c1bef1732b664c23cb1b799181cba5a9"/><file name="es_AR.xml" hash="d404e53f4de755d9c09aa856e916f110"/><file name="es_BO.xml" hash="2876119c46a9c697baba1a65240c051e"/><file name="es_CL.xml" hash="e3910edbae206638b9250ecbf9949905"/><file name="es_CO.xml" hash="53be4c39e4a34867fcbaa8fd05c2c881"/><file name="es_CR.xml" hash="1f0e1d3c965de545b50aab4577b038fe"/><file name="es_CU.xml" hash="2380f966916741dcba3c34c04a5d8009"/><file name="es_DO.xml" hash="9ea0a69084ae8dbdd86459e2806a8bdc"/><file name="es_EA.xml" hash="ec6ce434e2fb8f15ab4daa8cb2bc4dff"/><file name="es_EC.xml" hash="efb247470c0fe88c36a7864184a01a8a"/><file name="es_ES.xml" hash="da94ab8a06feb23c6d567dc75f85531c"/><file name="es_GQ.xml" hash="cac80878e350ca7a728940550bd9393f"/><file name="es_GT.xml" hash="d360a7b0a15a0515a21f1e0d5b4dd21e"/><file name="es_HN.xml" hash="fa13c1e703f00b11d038fe3bfe19c08b"/><file name="es_IC.xml" hash="d5324caf07a8db6ba668a1b749baa6e3"/><file name="es_MX.xml" hash="05df2b2f76636b0097cf9431ff9c84eb"/><file name="es_NI.xml" hash="7d59d82986b3ab47e1b7a2dad383a0aa"/><file name="es_PA.xml" hash="21a4164b1d73365f9b63431247053db4"/><file name="es_PE.xml" hash="8df05dafd2807169296d11f75eb74537"/><file name="es_PH.xml" hash="7240ee508f9500d779bd5109450a057f"/><file name="es_PR.xml" hash="de86ff57cd2f3e3c67111b0163a72b6a"/><file name="es_PY.xml" hash="191bbd042c95ef246cda798581ed9598"/><file name="es_SV.xml" hash="9caba354843c2b055f8f5da17082e245"/><file name="es_US.xml" hash="90b97e0328d50ed134c0b36391a4aa99"/><file name="es_UY.xml" hash="a30737900d956dc397357f6463d532a1"/><file name="es_VE.xml" hash="03449a8b82e4d21e0a59836ceb148536"/><file name="et.xml" hash="d3e8e213866259a27ab9511efe348e0c"/><file name="et_EE.xml" hash="3e92af6dec71aa1ae7a3c62c931534ba"/><file name="eu.xml" hash="7111ceef4472ba0c4e52dfc654a2841a"/><file name="eu_ES.xml" hash="66e48ee02f5d1e5a7076cf9cab709d23"/><file name="ewo.xml" hash="8f5e287d463fbbc8711d46265141be36"/><file name="ewo_CM.xml" hash="47ee8a04b5a0327405d006bd1a99266a"/><file name="fa.xml" hash="1bd0e404ad8d9d3cbc943f04676b03dc"/><file name="fa_AF.xml" hash="3736139f38116f0586eb7aae46f6dcfb"/><file name="fa_IR.xml" hash="98698b67604b8e5589fd75601080cd3d"/><file name="ff.xml" hash="8eec6f2da84d33d3236797c62b96a9d0"/><file name="ff_CM.xml" hash="4bcc2690dc2eb5347be28c55fc008f88"/><file name="ff_GN.xml" hash="a56cbd27d6d838338a535a06db281d34"/><file name="ff_MR.xml" hash="17dd52ffc9809b26db2a067612d92d53"/><file name="ff_SN.xml" hash="9ab32fee7af1d2666669efa4386769d3"/><file name="fi.xml" hash="f1e171910ef4c2137d9a6149cf3c2c55"/><file name="fi_FI.xml" hash="8d9498723893c53c1b6a8ede4d3b796c"/><file name="fil.xml" hash="c44f7b3edadc43b02a927e6cd1e780e8"/><file name="fil_PH.xml" hash="233305bd4c15da54bc9b4847fc753165"/><file name="fo.xml" hash="5715134bd8e1798d5f25d165f8a0bd98"/><file name="fo_FO.xml" hash="99e842dbbd201862703a98e160936c8d"/><file name="fr.xml" hash="125a25633190ef898fe18f2827d2397e"/><file name="fr_BE.xml" hash="1f86df32f3eaddd9b139fbacb7c199f5"/><file name="fr_BF.xml" hash="8eaa50ea5da82e3e8cfea4af20946852"/><file name="fr_BI.xml" hash="eb2d856258ead7da474505881452f613"/><file name="fr_BJ.xml" hash="ef18313c305832ea7049ddf758c9d51d"/><file name="fr_BL.xml" hash="ee7f161cc4c9f844448d9da6fcbb349d"/><file name="fr_CA.xml" hash="64a0b0100ee5e8918ca1d502f06ccb3e"/><file name="fr_CD.xml" hash="d5d62a20e80bfc90badec8a72d8a9d1a"/><file name="fr_CF.xml" hash="d0e96516835a44fcfadd25d0db4e48a1"/><file name="fr_CG.xml" hash="e2852122d57450cd7a388a3545709994"/><file name="fr_CH.xml" hash="2fd3f24252e081fc4c74e9e707c00365"/><file name="fr_CI.xml" hash="e72b4fb87bbb5751e49093c24f4fbd5d"/><file name="fr_CM.xml" hash="e06d4dc5c3604d9cd9cc64376e206daf"/><file name="fr_DJ.xml" hash="7e87bdb7669cbf73ac0bb191d43400a4"/><file name="fr_DZ.xml" hash="64558f39d1553f56217f80ec3ef92536"/><file name="fr_FR.xml" hash="3d82e2934dd28c26c7382de85d95ac11"/><file name="fr_GA.xml" hash="87cc610fd5f6a486c63e5cb105cc2d7f"/><file name="fr_GF.xml" hash="cdecac5dac6e7e10336de1dec5982673"/><file name="fr_GN.xml" hash="0ed99a0d3cec1034899413196dde9c06"/><file name="fr_GP.xml" hash="78ffa2393237a67fd202f96784bcea5a"/><file name="fr_GQ.xml" hash="359c388c94381b4bd09868afb8557b43"/><file name="fr_HT.xml" hash="7ecc803d1e947635fcbf0aa1b201ce60"/><file name="fr_KM.xml" hash="ea71c8291e7c8aeaaad03880b7308a2b"/><file name="fr_LU.xml" hash="2f467a6cc20912bea31f2932c26be870"/><file name="fr_MA.xml" hash="a0fcbe1f955e3d76f9e38eef202ffa07"/><file name="fr_MC.xml" hash="9a6304e508d08737c7969b44d9d57939"/><file name="fr_MF.xml" hash="46968723e86571f7455ee534302d3471"/><file name="fr_MG.xml" hash="ff234d4ba2e66cbb7b798ca787c67026"/><file name="fr_ML.xml" hash="7d1c047089abbf427b3635bc977444b1"/><file name="fr_MQ.xml" hash="f8bb16f92cdb67bc46ceb7aa7048d908"/><file name="fr_MR.xml" hash="d838bbdbd611c35862b89899816befb9"/><file name="fr_MU.xml" hash="ead1fa2ecb9031315ac554ca214d551e"/><file name="fr_NC.xml" hash="3d6500c28264363b27bf842259ff8a17"/><file name="fr_NE.xml" hash="f5bec7e22bd5db13346937f58a1312f2"/><file name="fr_PF.xml" hash="d9c7edabd1f8fd52c5320d874c96c021"/><file name="fr_PM.xml" hash="bae26570b49ab5979729a5f5b66ce087"/><file name="fr_RE.xml" hash="0c9b4ea0bf6c26c33ed0cef26f428af4"/><file name="fr_RW.xml" hash="8725f9ee61c3054199536d6d8eec42ba"/><file name="fr_SC.xml" hash="1eeb10b51d815098e01a3f60d71f793f"/><file name="fr_SN.xml" hash="fa6da2f3ae651bd93705f26587ed135c"/><file name="fr_SY.xml" hash="b6ef0c074642c951a04131a3cadfdfe6"/><file name="fr_TD.xml" hash="ff554940988b4f7bd210a2138575c6c8"/><file name="fr_TG.xml" hash="2256df16de2fd7331fbfbeaeaf0ddba3"/><file name="fr_TN.xml" hash="d9996b3dba7d6ca0aa12c1e6766d2f27"/><file name="fr_VU.xml" hash="4f07ba927564fd6d3507816cf3aafe45"/><file name="fr_WF.xml" hash="a6c659de13b695c7e229681b819ed473"/><file name="fr_YT.xml" hash="821b7a10ac601226696fa7d71d0f8247"/><file name="fur.xml" hash="62a65af07d949f1117573e425bee90fd"/><file name="fur_IT.xml" hash="647415f7e2ebd1d55b260dac3823e3f9"/><file name="fy.xml" hash="14a7805cafcf18dc2f21a7925e9d7182"/><file name="fy_NL.xml" hash="dac6922c58516864d0d18df09753b917"/><file name="ga.xml" hash="7cc3d8d5796c554549ea5ebe5fb9cc35"/><file name="ga_IE.xml" hash="49dfc6b41e17ddc6cd93d17b1aad62f6"/><file name="gd.xml" hash="49f89d47c209b25730d8d731973f29b5"/><file name="gd_GB.xml" hash="721b95588bf8f0ab4004d868128cf286"/><file name="genderList.xml" hash="12c8a32237c76cd85cdb15f8cd140023"/><file name="gl.xml" hash="f7c56b822d2cc164b6691956fc79669e"/><file name="gl_ES.xml" hash="05e04a61e62eab6b94d6cfa3ef96ef25"/><file name="gsw.xml" hash="2b9d820569249f8fe88f6f77320223f2"/><file name="gsw_CH.xml" hash="ec2f1146d4fe5125f42c6281bb2f10b7"/><file name="gsw_LI.xml" hash="a6031e3e7ab4512a905d91484d8f5f00"/><file name="gu.xml" hash="8fe2967cebfbb4a19bfdbff9a8029cab"/><file name="gu_IN.xml" hash="0f93d2cd4139a9fa96df164cdf0357ca"/><file name="guz.xml" hash="65566bd2674a999999affe67ddef45a0"/><file name="guz_KE.xml" hash="7891c10bba2ae36ce29ce34f996ded25"/><file name="gv.xml" hash="bdb5556e04a5f2acb2141197e09020ef"/><file name="gv_IM.xml" hash="cf6d862525015e25038f60fc93175e84"/><file name="ha.xml" hash="310c626b795a231ad736c44ffe0df31f"/><file name="ha_Latn.xml" hash="a470076b9866db162e1415aa32350a44"/><file name="ha_Latn_GH.xml" hash="e213acaf6a53ba1d9c33d2ebda346ab3"/><file name="ha_Latn_NE.xml" hash="7983a567b1473874f3bea1dfb045ab29"/><file name="ha_Latn_NG.xml" hash="d2191f02d90e7b9912fe0e66aed70d24"/><file name="haw.xml" hash="5012e655132a7a5a7ad8397052baf955"/><file name="haw_US.xml" hash="5bb77c6692d33c8488fd008640434b2b"/><file name="he.xml" hash="70cd2438f74f6ea64543ec52bbb06e56"/><file name="he_IL.xml" hash="bdc2d75f46f4dced46dd4fbce6cac4f8"/><file name="hi.xml" hash="20e5122052162ec860cd27db34fc1dcb"/><file name="hi_IN.xml" hash="fbc59458d4ad8d295265e79fec26534a"/><file name="hr.xml" hash="ad2c7a5102cb05cec7ae0478d2f5b552"/><file name="hr_BA.xml" hash="bb36010b5b7cb83bf623d27eddc90678"/><file name="hr_HR.xml" hash="0a5068d64bfd804afa623562e6c556b1"/><file name="hu.xml" hash="35260b5e75ed941097710b0a0483e407"/><file name="hu_HU.xml" hash="b816b69e9814d33ad14907c9c3b6316d"/><file name="hy.xml" hash="4dd0bd1e21762124de07651094889237"/><file name="hy_AM.xml" hash="cc2c8134ca77e5bd55315c5faf80c61c"/><file name="ia.xml" hash="a57208d2e90856e670b25cafa90caaa0"/><file name="ia_FR.xml" hash="dbfd4721237b03875d50cb0770f1a5bb"/><file name="id.xml" hash="ad0dbea4ed9c97b2ef44ea451ff43aa5"/><file name="id_ID.xml" hash="349192acc73b4d40b3ea684999c5cd4a"/><file name="ig.xml" hash="0cd19cfcc514c8c5c0d8b8f085e64a72"/><file name="ig_NG.xml" hash="666845e6dc06958bdd682bf40b9a0251"/><file name="ii.xml" hash="db4ca0fa7cd320163163a97946399d6a"/><file name="ii_CN.xml" hash="a112d1ad1b7fa51a30f6cdb0850168b5"/><file name="is.xml" hash="a4587bd0d57e17d1960dba1a45b5e1b4"/><file name="is_IS.xml" hash="5d2fff72bd6199e1e79cdb3fa126b6a3"/><file name="it.xml" hash="dfa19eadbd4b5819453159c12e5bc32c"/><file name="it_CH.xml" hash="da4122fb147f2652de469a3f7703862b"/><file name="it_IT.xml" hash="0fded926a8f00f5f491f4ba2486b0686"/><file name="it_SM.xml" hash="4706ecb3a92e9e05f6d9f54bacbacf34"/><file name="ja.xml" hash="a4bdd8fef7cac5c8ab8a706781d475b8"/><file name="ja_JP.xml" hash="b87ae521fe2527bc9051ee631bd1001f"/><file name="jgo.xml" hash="9471f4b7fa6323bf54a3b8b74813aeb7"/><file name="jgo_CM.xml" hash="8ded303577f1a672dd255dd1fc1490fc"/><file name="jmc.xml" hash="fb1bd646841f4b8af118996f1ffc4591"/><file name="jmc_TZ.xml" hash="fc0d97c3788543fb5a53695be429dd96"/><file name="ka.xml" hash="6223813b9ac5f055c2c682eb79e6e05e"/><file name="ka_GE.xml" hash="b5df45beb8ba26df37d00154fe2e8deb"/><file name="kab.xml" hash="28e3bfe8412eeac7fda8a154c2dc9375"/><file name="kab_DZ.xml" hash="c398b9636cc7716ab1152528de39599f"/><file name="kam.xml" hash="078f9f3de5e4a2e405f91db0580fee61"/><file name="kam_KE.xml" hash="671d06ee91b5451d3bcef26cf6d0962a"/><file name="kde.xml" hash="db0e85e0f1bd852d8d467e13f8a2dfd3"/><file name="kde_TZ.xml" hash="9f41da9a28fdfd1cf618deba5d9e70ee"/><file name="kea.xml" hash="5504f98e950dd836749ecf3eabbb9d03"/><file name="kea_CV.xml" hash="88602da9c4e3bf124a330f1d0fb84113"/><file name="khq.xml" hash="f0deb2302861cb75bfa96b4b11cb6fa9"/><file name="khq_ML.xml" hash="44d6228f6585a0ddfd53f2b13f7f18c7"/><file name="ki.xml" hash="26a88ce1af8c274b1b5ff3a5c11fb3eb"/><file name="ki_KE.xml" hash="2b5e5cf6cd0d7e38ca3d1d1cb63be4fb"/><file name="kk.xml" hash="a298ecc37ae4d60ce87cb0eaad919d3d"/><file name="kk_Cyrl.xml" hash="07046177e2ec5347df348912409e4283"/><file name="kk_Cyrl_KZ.xml" hash="5bfb35389063a05e63ddec93b4ffad82"/><file name="kkj.xml" hash="3a97c2408dfbbbf2ee181c7c70b2ea8a"/><file name="kkj_CM.xml" hash="095d6748ff7c6f070fae30938ef729c5"/><file name="kl.xml" hash="95ed0d90dae8db61f7b46db63aac0a0f"/><file name="kl_GL.xml" hash="ef6c30e0b4063b1b8fad4e4511e3e33c"/><file name="kln.xml" hash="67441932af9b0b24bc2c2ca2e018d5e8"/><file name="kln_KE.xml" hash="f10af3f43ee9aee1bbf52ca5ff1c5196"/><file name="km.xml" hash="dee5bb763d56521b3c2919a340021c62"/><file name="km_KH.xml" hash="8a31a83be02152f33704d7dc2d2e3e4f"/><file name="kn.xml" hash="0b9d9e33559353f7c074672472ad8f7f"/><file name="kn_IN.xml" hash="e4135fa646d16bb15bf8c24919a4122b"/><file name="ko.xml" hash="9f2d95effdc2374377d41ff61f1f8ace"/><file name="ko_KP.xml" hash="cf696a9af609810d08337fb56f4b2a51"/><file name="ko_KR.xml" hash="0e6404f41f456011631a67da431ec48b"/><file name="kok.xml" hash="deea0756950d5465bf3d529ddf533e4b"/><file name="kok_IN.xml" hash="9ae56f19c07124aa5801d3f2d21dbdfc"/><file name="ks.xml" hash="62e4a1072ac6d8a14df457bb325d97bd"/><file name="ks_Arab.xml" hash="2c7ee60c2f9764e87ce01dace3089799"/><file name="ks_Arab_IN.xml" hash="2fea656a91f684489095e5f13d76c778"/><file name="ksb.xml" hash="d4c84ad5e9ce333697588c7cfc6a8ac1"/><file name="ksb_TZ.xml" hash="ccfb53a163d96d54debdaa15d3499027"/><file name="ksf.xml" hash="a8187b83f4ae0a05f0219f6262c38a70"/><file name="ksf_CM.xml" hash="203147426344f510947dcfe51ee77b83"/><file name="ksh.xml" hash="2617cb6c2b91f15403ce462da0021275"/><file name="ksh_DE.xml" hash="8e085f8da562734068ff0141aa759eaa"/><file name="kw.xml" hash="91ad55b87458489c861988b7fb6280c1"/><file name="kw_GB.xml" hash="7e2024541e7aba767e844c0b9663e155"/><file name="ky.xml" hash="a7545fd81340fd75464e271076dc5279"/><file name="ky_Cyrl.xml" hash="2fe62d616b564a7316ef4a8a72210488"/><file name="ky_Cyrl_KG.xml" hash="757d4898a54dcc119b43698784cc8967"/><file name="lag.xml" hash="a8a25a77df5909db3b73340774221cb5"/><file name="lag_TZ.xml" hash="ebd0c62787658dec41e3e49017e2705a"/><file name="languageInfo.xml" hash="9a33723a317db6855c7dc4a37a9fffd5"/><file name="lg.xml" hash="2cc89f3e98775beee70bdd3e3404d9dc"/><file name="lg_UG.xml" hash="d98767310f065c6a3755cfb5fec6b9a0"/><file name="likelySubtags.xml" hash="6a042c9e337512b06f75e101a49981f5"/><file name="lkt.xml" hash="dba6053b63f4c6e3bf2e21f603c8d78b"/><file name="lkt_US.xml" hash="bd6f8a8cc0acca0ad53b85350f2f5b80"/><file name="ln.xml" hash="0cea3d899d3dad394a5e92db22044bc9"/><file name="ln_AO.xml" hash="9eabbf5b540202c5e5b521cdd06564b4"/><file name="ln_CD.xml" hash="5a6fd6126bf58147cdad6a565bae8af5"/><file name="ln_CF.xml" hash="349ec0ad936ee0fc9c5a00530e259390"/><file name="ln_CG.xml" hash="25c98dbc645d64b7cd800fbf6674fc4b"/><file name="lo.xml" hash="52aa20460fe494c813927fdab64feb08"/><file name="lo_LA.xml" hash="0266874e3970a24dab991fc54e111360"/><file name="lt.xml" hash="6d485e98ca9590acf70ea1838e488ad7"/><file name="lt_LT.xml" hash="738d6dfb27e54f7f9a44875b6dacf0e5"/><file name="lu.xml" hash="5ee43a091cdfb35d5f14067f45b0b05c"/><file name="lu_CD.xml" hash="dbe948b08a594210a3d088e414123d86"/><file name="luo.xml" hash="69779720b4294de854bf82a170ffbec9"/><file name="luo_KE.xml" hash="ad6df8710e3b4976c7bc95b0ec739fa3"/><file name="luy.xml" hash="d0e4e4766a744edc1ab08418bec0ee61"/><file name="luy_KE.xml" hash="28a00f1eb2977ad409b0dfca45a0ca9d"/><file name="lv.xml" hash="3a85d69acd0b15e47f9b2df341be7573"/><file name="lv_LV.xml" hash="6e07fe6de844f63ae1605a6a1a5575a5"/><file name="mas.xml" hash="b1ee3c8d903462d3b217b7056a31df20"/><file name="mas_KE.xml" hash="e494f8d43607f742e3a0cf393ad83bcb"/><file name="mas_TZ.xml" hash="a5785e18c75185c28f284f2e18e7f6e0"/><file name="mer.xml" hash="2023c272b2b6e1169d0d45bb195c7d53"/><file name="mer_KE.xml" hash="52600bcaac77d9e6aa9c9741e67323c5"/><file name="metaZones.xml" hash="64a142f5cc668612c9c6ad2ff0af875f"/><file name="mfe.xml" hash="cec57c842e65ebeaf746db91ac55f5b1"/><file name="mfe_MU.xml" hash="990e405c5cae3b6d7226d0482d0b6848"/><file name="mg.xml" hash="fd8b564029dfa72a913ff627c834082c"/><file name="mg_MG.xml" hash="81a7d92eedd7a4d9cb8c8687badf4aec"/><file name="mgh.xml" hash="6008ffd778c2d670383ab125848d5a68"/><file name="mgh_MZ.xml" hash="ed7a568c678bb3ec003732ba4e7c19a8"/><file name="mgo.xml" hash="3e834a9a979970d5c82d963a56947a11"/><file name="mgo_CM.xml" hash="0cf9ba215d10e1f3db255adcccb3d6b8"/><file name="mk.xml" hash="3ee88bf8c02b4f244b5cd1d3ab617f45"/><file name="mk_MK.xml" hash="aeb740a529d8b51b53242d1f1cf59b2e"/><file name="ml.xml" hash="94d67dd84bc66f80d4a6ffaf27a2c508"/><file name="ml_IN.xml" hash="80849e5c197f5dd2b2ea0317f3517ca1"/><file name="mn.xml" hash="e6a18ab3a3c20fe7ab283cf6a901a549"/><file name="mn_Cyrl.xml" hash="9bdcd159b3be6e0ecf96795d5fc1e91e"/><file name="mn_Cyrl_MN.xml" hash="f11f2f4a083ef35c66ff0a10429b5614"/><file name="mr.xml" hash="f2073dc2a11fd9c7be8ba932e45b830a"/><file name="mr_IN.xml" hash="1623ff448071fe23a70309fa70ac531f"/><file name="ms.xml" hash="9b53207db5cc656f53ac5ea3d90195fd"/><file name="ms_Latn.xml" hash="cda2abbda8d3482f36361e946f37b5a8"/><file name="ms_Latn_BN.xml" hash="5740a4fdad13e0eb211736bf0a2f17ec"/><file name="ms_Latn_MY.xml" hash="c537239c8ae70b442dcbf67911f3fd4d"/><file name="ms_Latn_SG.xml" hash="05424711271e51b0e552063edd05b547"/><file name="mt.xml" hash="961881542802dc1cc9f20f8fcb774f45"/><file name="mt_MT.xml" hash="5282b27d9d6a57d726612a09395e6c22"/><file name="mua.xml" hash="8ebb1a4b5ef4baffddb2894b307f2cbc"/><file name="mua_CM.xml" hash="2df1fe2f39dc3402d5892946ab88f2ef"/><file name="my.xml" hash="64f4ef77afb342a522c3b4779ab19486"/><file name="my_MM.xml" hash="02d8bea58fd9bd5e8dc7796477ef5ce0"/><file name="naq.xml" hash="a29dfa41b2e1630f136a18b12d2c2324"/><file name="naq_NA.xml" hash="0ec1dfc6dc7eed7588f1d1bc41ad56dc"/><file name="nb.xml" hash="46eb58f192d18746c09c8c8582ddd8b1"/><file name="nb_NO.xml" hash="626d2f263762cde6e41328a0bf6768e3"/><file name="nb_SJ.xml" hash="02508dd6f1be1de58fefd7b1159564eb"/><file name="nd.xml" hash="db8baa59e10b31daafd068e55ba882da"/><file name="nd_ZW.xml" hash="ccd1724534080cdf1a784ae0435f7785"/><file name="ne.xml" hash="7cb434ada9a049184fd0a2e021012406"/><file name="ne_IN.xml" hash="84558af586315178078c8e91aa410d9d"/><file name="ne_NP.xml" hash="81a679056920fedc05dad2cda150ef53"/><file name="nl.xml" hash="9f122648b0ae9fbf47dc6364311c9b14"/><file name="nl_AW.xml" hash="d44d954375e2f11a3571f0849dc5b116"/><file name="nl_BE.xml" hash="8e255c2c3d01f7680e6b1931521d15c1"/><file name="nl_BQ.xml" hash="05ea3eec1520c8ef9889b627f3c11624"/><file name="nl_CW.xml" hash="b4b444e991046f1e3e3c44eaa6d825bb"/><file name="nl_NL.xml" hash="4e0467c9db5288462ceb8f78611f6fc5"/><file name="nl_SR.xml" hash="ac0e3ff1c6706ecd9ad0b727583e024e"/><file name="nl_SX.xml" hash="3081384591890c797dfc87c4f4ec40d2"/><file name="nmg.xml" hash="96a40607cf05ce8f8ecbd81edfe54188"/><file name="nmg_CM.xml" hash="e4b39732f25ed7f4fd5f8eeab2296cc0"/><file name="nn.xml" hash="df403882fc0d4fbde259805dbb578133"/><file name="nn_NO.xml" hash="bff2529dd25fc5eff4e45c62e57a6102"/><file name="nnh.xml" hash="604802e1f48c5efb5006478f6096cba2"/><file name="nnh_CM.xml" hash="0797c07c5503386e902db37bb81036a1"/><file name="nr.xml" hash="537dfb7c804216084ff12405a79e6363"/><file name="nr_ZA.xml" hash="deaad06361e3310f47a0ae239b2dde45"/><file name="nso.xml" hash="d8d03686f2a5498288ab934b1d23af35"/><file name="nso_ZA.xml" hash="b8d56986c8588034819ce4112447bb7a"/><file name="numberingSystems.xml" hash="978a66b09ff3a7fe924e5220ac632035"/><file name="nus.xml" hash="aeb47a867f44fc22028eea112a9f20d7"/><file name="nus_SD.xml" hash="5b01ebcdeb5e0925420a1ec5a81078e0"/><file name="nyn.xml" hash="7a00226944592e03fbf05992fc97cb37"/><file name="nyn_UG.xml" hash="f98eb55dcdecb237d0d5f4442e967df1"/><file name="om.xml" hash="d7dd5059b280e4e673d39c6681dedae6"/><file name="om_ET.xml" hash="a2bd53f37a0cbde29c75476d11efd951"/><file name="om_KE.xml" hash="6f499797aaf7cddf5c96510055b1cb6b"/><file name="or.xml" hash="a1f44afb1360bea5213e7769b0d555ab"/><file name="or_IN.xml" hash="b8384a249e94ac1d3aeccffe6456d213"/><file name="ordinals.xml" hash="8105f05e542d711fb1c58eda93ee1970"/><file name="os.xml" hash="d3994c255a9ed31b3b485e2a60100bb6"/><file name="os_GE.xml" hash="b707a294c3bda74ce1fe3de56d5a2065"/><file name="os_RU.xml" hash="ed7de0aca2851389edb27ec27cfbff14"/><file name="pa.xml" hash="eb25b28dccb7fc2b9e8a58529383e7ad"/><file name="pa_Arab.xml" hash="d066d05609c4bb72a91b66960df82d4c"/><file name="pa_Arab_PK.xml" hash="af6c1f47b0c9125afa5f1d8b4465afae"/><file name="pa_Guru.xml" hash="3b5761c3adfe0fd8f769757108a33d74"/><file name="pa_Guru_IN.xml" hash="962eb7156fcccfee1c3b62562bcb4c9e"/><file name="pl.xml" hash="4badef8c402fbce8a919fe0345018145"/><file name="pl_PL.xml" hash="9f5e5245cb2b2a52ef56e3fd69363f31"/><file name="plurals.xml" hash="4223a72c769da4553aeaffc82409128d"/><file name="postalCodeData.xml" hash="ee416690bc7b0b51c62a4f60df3c6e49"/><file name="ps.xml" hash="71320ee03ab67c4d86b2042a2a450044"/><file name="ps_AF.xml" hash="e2b047a904f02a454f193f37856e9f6c"/><file name="pt.xml" hash="6c0d496db88b044f4bccea7b2bcf5bb2"/><file name="pt_AO.xml" hash="502a761ed5e5ca0b44403ff8d0e85e94"/><file name="pt_BR.xml" hash="9ec9d29dec55f67013d4e3ce15799d05"/><file name="pt_CV.xml" hash="3f8377d6db982dc7b9cc6294ee963517"/><file name="pt_GW.xml" hash="bec710dffaed02976223f5671fb48ec5"/><file name="pt_MO.xml" hash="1df59a4a05e1141e225a7da25c58ec4b"/><file name="pt_MZ.xml" hash="b5b28ee99e7f12e1c14e015c3ecf5c4d"/><file name="pt_PT.xml" hash="66b28e650fb563d84b53da41a1f261b4"/><file name="pt_ST.xml" hash="7c96e96d8bf1b811ff3358073e3aeb63"/><file name="pt_TL.xml" hash="9e2647ac1cc2d8f949cd000ffc5dd2fd"/><file name="rm.xml" hash="aa5e41d750b8392990ce00c29f4feb4d"/><file name="rm_CH.xml" hash="3bef003a0204b4d2291ee73c46d8f1ee"/><file name="rn.xml" hash="80a76b1975488f778da8abe7dc0292db"/><file name="rn_BI.xml" hash="c5010d52f27f95cf794396339752dda6"/><file name="ro.xml" hash="fd309802d4e90aa4e51d9f014621e5b6"/><file name="ro_MD.xml" hash="4763fe9a5ac2d57fa9cb7bc5aaa09f7a"/><file name="ro_RO.xml" hash="a7f41f443fcc6daed26d608373a0ebcb"/><file name="rof.xml" hash="4d03559ef40f836156f5e516a9eaa5aa"/><file name="rof_TZ.xml" hash="99f8c6ad97c8acbade2a9f3553b57225"/><file name="root.xml" hash="f74f320723d5a31ba06aa2c79de43bd2"/><file name="ru.xml" hash="3aaf7853667c37781e3d886f364968c1"/><file name="ru_BY.xml" hash="931ca3d10a511ea18c705a22c8baaf1d"/><file name="ru_KG.xml" hash="edee35024102c3ffd1c9acd89f0c9c30"/><file name="ru_KZ.xml" hash="7d4138b25f5c8cbafead8f321fd1954e"/><file name="ru_MD.xml" hash="4d629ff877f4c3a1e214548dc7ecccaf"/><file name="ru_RU.xml" hash="ee8433fc8dbc67a22b31c6be08d13402"/><file name="ru_UA.xml" hash="33fe877250fbd7077b4edf45c50bf300"/><file name="rw.xml" hash="73b90e15bea65ad98ac5cea78e878d91"/><file name="rw_RW.xml" hash="c5cb01f5b236208dc96d3268cf85ffbb"/><file name="rwk.xml" hash="af9317a0322bd40302363d5e6bd4b291"/><file name="rwk_TZ.xml" hash="d0f470b223d25203a611bdb7c395c988"/><file name="sah.xml" hash="f4b2cb698fd582845afb18f984089ee7"/><file name="sah_RU.xml" hash="6ee074c02940d5e9a525a7b8a9c2176e"/><file name="saq.xml" hash="130d69870ed3f95808bced7bed701c3b"/><file name="saq_KE.xml" hash="008b90c332f06e019efc1d8e33f401b3"/><file name="sbp.xml" hash="158d785177f949347356d59dc7883ad8"/><file name="sbp_TZ.xml" hash="0d4f52a378680dcd6230f00cc8ed1f61"/><file name="se.xml" hash="10a3649dbfd8bdff0f8b8fe102b444ed"/><file name="se_FI.xml" hash="ea379a5c51168210274b50711f032355"/><file name="se_NO.xml" hash="0a890443d1477c9d275bb945b0c5b589"/><file name="seh.xml" hash="4361fff00579a2efd8d283a152ccc682"/><file name="seh_MZ.xml" hash="a3f4cc61fa6d995fa5d2cc7b193ee1ad"/><file name="ses.xml" hash="00e9cfea10372a6b62590346a596d054"/><file name="ses_ML.xml" hash="dc0cd9eabaf2c08d66007e6c31a6a477"/><file name="sg.xml" hash="e1bda394071d1796efc18e00467e425c"/><file name="sg_CF.xml" hash="ed51c88dd34a233c82150338436c250c"/><file name="shi.xml" hash="b57def0c24096d11985586f621c09159"/><file name="shi_Latn.xml" hash="61054fc24b89c1842a53be5f5e6016e7"/><file name="shi_Latn_MA.xml" hash="d0f90c1ab8e1b3f7340fc2b77f37ff4f"/><file name="shi_Tfng.xml" hash="4670d2933f9ff2b00c787336498fc149"/><file name="shi_Tfng_MA.xml" hash="271bc282c75731c883ea8fbbd72361b8"/><file name="si.xml" hash="8a27b7c7c9bcdb45049974693c8db484"/><file name="si_LK.xml" hash="b637f75035a4fdfe10f0d3fb39781db1"/><file name="sk.xml" hash="c8b930f68837a7fcaa7e0c34aec1235b"/><file name="sk_SK.xml" hash="7beda18d4fd023382190bc9797d51cfc"/><file name="sl.xml" hash="51bf1ccaecc51b117ea843100b2bc782"/><file name="sl_SI.xml" hash="b71c5b3968b50875758dfdf825c6b21a"/><file name="sn.xml" hash="9aa3b734aa010864b0ff582a67e677e8"/><file name="sn_ZW.xml" hash="24a9dfc3030bf253882c9d661eaef17c"/><file name="so.xml" hash="5b1ade5ca9f6416d2a42aaeefe08803b"/><file name="so_DJ.xml" hash="2850875e1e4d197c81948325e8741024"/><file name="so_ET.xml" hash="6210a645a2c598eed597bab39f36d557"/><file name="so_KE.xml" hash="208c20fcd4d27f3ea7a63a1ccd70b64c"/><file name="so_SO.xml" hash="65f7b820f3de2da5fb6adbbf3fed4244"/><file name="sq.xml" hash="9814afac7a465e293306c2036e97397a"/><file name="sq_AL.xml" hash="6b08a2f02bd463c8854d377761d14ad4"/><file name="sq_MK.xml" hash="7b1a4a47c69c2c11539ecf5f2b306dbf"/><file name="sq_XK.xml" hash="a4be94b459a7ddf3c64782b932c43edd"/><file name="sr.xml" hash="a907b6ed4a9233dce8fb2cafacbb9d07"/><file name="sr_Cyrl.xml" hash="df126a848168eebb92d2cb08b0f47051"/><file name="sr_Cyrl_BA.xml" hash="379078c0a256b4f9ec7111cc9f75a2e4"/><file name="sr_Cyrl_ME.xml" hash="fdc47e86343568ccbf1e619800f26614"/><file name="sr_Cyrl_RS.xml" hash="f269bfd320ba2b38a6a614ca4da321a9"/><file name="sr_Cyrl_XK.xml" hash="8e3b5caa0e9997575201e3f7823a81ac"/><file name="sr_Latn.xml" hash="b26fdb85fcea35960444294ab6f10b21"/><file name="sr_Latn_BA.xml" hash="8abd2f52848f701a485ce865e97b851a"/><file name="sr_Latn_ME.xml" hash="49c92f426cc5a5188399c80878686f83"/><file name="sr_Latn_RS.xml" hash="713a42425709d2a2448ed3ceefed8d07"/><file name="sr_Latn_XK.xml" hash="d9f80fc5757c8be78a8bf06b0090bb1e"/><file name="ss.xml" hash="1c8e4708d8197d98b32e84db842531ac"/><file name="ss_SZ.xml" hash="36bd3ae71800ee1509cb005345b7d0d4"/><file name="ss_ZA.xml" hash="929a6fc019f32616331578d55a36412a"/><file name="ssy.xml" hash="4cd34c993f3f737c52ef02dc0c65180c"/><file name="ssy_ER.xml" hash="6500f7ea9752b2272ff4c93530514345"/><file name="st.xml" hash="13de7725514e5dd58f49e0b01ec7858f"/><file name="st_LS.xml" hash="16fac9f2505893a9ae5df24174ec8e94"/><file name="st_ZA.xml" hash="c769d53933a0816218637180bfe3b1e6"/><file name="supplementalData.xml" hash="7c64143e835c0a2facebe573b95c735d"/><file name="supplementalMetadata.xml" hash="89562abe6d40c4c7245a8c465905e618"/><file name="sv.xml" hash="157cbade1293f5bf503b8ce03cac9260"/><file name="sv_AX.xml" hash="eb9596e23c3e3597f9167c56bc456ba8"/><file name="sv_FI.xml" hash="c7985fcaa170e42535eebb8f2821fd8c"/><file name="sv_SE.xml" hash="a234be39c4fe51d5360e867ef057e9cc"/><file name="sw.xml" hash="baa99fb8dae1057541cd174d8c479f63"/><file name="sw_KE.xml" hash="841c4e403526c85c138ec30908f0e639"/><file name="sw_TZ.xml" hash="d8c70853021414f35fff5160e777afc4"/><file name="sw_UG.xml" hash="2f39a025d909e27a3b4d42ada4494f44"/><file name="swc.xml" hash="b78d391b482ebeaaa8d2589248b99475"/><file name="swc_CD.xml" hash="7ef627a3af8e94ce44e118facc634280"/><file name="ta.xml" hash="f14aabe0b254b16a7656cf0eb924a937"/><file name="ta_IN.xml" hash="a3cf28d4dffdfb99fbd06c56f7407690"/><file name="ta_LK.xml" hash="c4cb7d38b9ab64f09398af90233929b6"/><file name="ta_MY.xml" hash="50b7aa25e1de2ba3060cf7f1542dbb1e"/><file name="ta_SG.xml" hash="467cf5081dce3961ff108329da18461f"/><file name="te.xml" hash="9000f302efec5389067682dcb37713ec"/><file name="te_IN.xml" hash="46c5a0f8ad33a8207687131b1e30dbc3"/><file name="telephoneCodeData.xml" hash="df7976ae3ed9a46df9b7a3d153a08782"/><file name="teo.xml" hash="1a54151c61645deebd146ce8167ebb7b"/><file name="teo_KE.xml" hash="28904dbd23feee396d235bddafb88a5f"/><file name="teo_UG.xml" hash="a3c2615908baa53ef6c06c1bbc46d03f"/><file name="tg.xml" hash="b0a784936ff2b4d986bea0a5abaafc41"/><file name="tg_Cyrl.xml" hash="dad9b0de0bca8885769e3eb3b986ed38"/><file name="tg_Cyrl_TJ.xml" hash="ecd76f8a9c11ea36f23aecbd4ba10f94"/><file name="th.xml" hash="93a93b50d5bc06c3aba030a2bc8f3a2c"/><file name="th_TH.xml" hash="16920f2948dfc0169fa4120b6bef4c6c"/><file name="ti.xml" hash="68ba067a766e83fa56b3f8b64e911709"/><file name="ti_ER.xml" hash="fc1625e77b8ee3b39e5a21a5778c6352"/><file name="ti_ET.xml" hash="eda9e0f13702f4f4d6c56bf8702bc158"/><file name="tig.xml" hash="dcbea52ddac1a8641439c191ef8cad3c"/><file name="tig_ER.xml" hash="9e8951b4b641d755277bba697641eeb4"/><file name="tn.xml" hash="5ecf790feae7a56e7d3dda69a3dcdd29"/><file name="tn_BW.xml" hash="5db54fb06600c505374663377ae3c87d"/><file name="tn_ZA.xml" hash="5ffaceb20f45593cf1526096d44811ae"/><file name="to.xml" hash="6abeea01835e1fa2e62a489842917a71"/><file name="to_TO.xml" hash="e17fa8026e023e8614eb6fe68b223300"/><file name="tr.xml" hash="a73038379e7e0396200158e0cb9b2101"/><file name="tr_CY.xml" hash="c02e5d602dc71097faf6e40c43c00df5"/><file name="tr_TR.xml" hash="98e092d092bd6efdacd4c9181bdf1269"/><file name="ts.xml" hash="d4de7842ad3ed50f09e585aeb8fd2b48"/><file name="ts_ZA.xml" hash="a058d38e5fc52060f992a09c44bd2dd4"/><file name="twq.xml" hash="8cb693f4457b01d524eb4dd3a9202fee"/><file name="twq_NE.xml" hash="f3887ed69d01de60ea150fb49741dd7e"/><file name="tzm.xml" hash="184e66cab1c6bfb1c1ede84b1b9b8d5d"/><file name="tzm_Latn.xml" hash="c48b72028daead39c63e06be5940b06f"/><file name="tzm_Latn_MA.xml" hash="adeed44054a352a8a95fb63a47b1277d"/><file name="ug.xml" hash="0048db54db7e96e66309f27990302912"/><file name="ug_Arab.xml" hash="b0916370f9a3dcbe9f9ef7f4941e83ff"/><file name="ug_Arab_CN.xml" hash="ca617ed54b6b547d9cd4929653765e69"/><file name="uk.xml" hash="82e297c9a0e35a239300e9d781246ca7"/><file name="uk_UA.xml" hash="f1f43742973c3e0684078ad1585c09a8"/><file name="ur.xml" hash="4330b97cdc580fd937fb4b48c30138dc"/><file name="ur_IN.xml" hash="620558a8d2b16341b990f739d96fa656"/><file name="ur_PK.xml" hash="4929ef93fcd09c110306500b7b5df200"/><file name="uz.xml" hash="e885a45d72df08108a5fb5553caf5650"/><file name="uz_Arab.xml" hash="bbccf5949290b9a88bdb05112ef0f1f1"/><file name="uz_Arab_AF.xml" hash="e8b2a9bcdfcddf5fe0923bdb79586e3b"/><file name="uz_Cyrl.xml" hash="f11985a357906a9764a2eeae61d87834"/><file name="uz_Cyrl_UZ.xml" hash="e34ac326ca872838cb51f7d95f2cad57"/><file name="uz_Latn.xml" hash="6d1de019d75988a154546b7a6ec4cecb"/><file name="uz_Latn_UZ.xml" hash="9f0dd4f61e4ad966fd33e26c0af5d722"/><file name="vai.xml" hash="4ccc7bd3230a4395017327e278bea5d7"/><file name="vai_Latn.xml" hash="78b6884327d1a568c1dcb55edcc8e8c7"/><file name="vai_Latn_LR.xml" hash="d60cdef15dbd84e66ebf6532935f2735"/><file name="vai_Vaii.xml" hash="4d3b525d05e85213d169a04051aed2cd"/><file name="vai_Vaii_LR.xml" hash="64e621f56506d7b70656d056ed8e8214"/><file name="ve.xml" hash="0238fc0b60b7f9f80a821455e85a26df"/><file name="ve_ZA.xml" hash="cfd73cf7fc6d3bef016b3dea6c1464c2"/><file name="vi.xml" hash="1ec60312f7c6e419dc883676a3cfb10b"/><file name="vi_VN.xml" hash="cfb0ceae9f2e78e0459f062016230998"/><file name="vo.xml" hash="a696981962fe9a84ccf27cd4f46a07a6"/><file name="vo_001.xml" hash="ca84f69da9df24a4e409104c54a8a3d5"/><file name="vun.xml" hash="2838dac67405ebb6515ed35b983f13c5"/><file name="vun_TZ.xml" hash="5c00fe9a927fa96193d8be8f22c4ee99"/><file name="wae.xml" hash="7a6a03e67b505d33af84383427ff1db9"/><file name="wae_CH.xml" hash="bc6ad0fbf82a5317ade928730b115b91"/><file name="wal.xml" hash="5fa5a9a4263c2c0c75cb61e137ec19b7"/><file name="wal_ET.xml" hash="fe6ba6e078852d9949dc023b20e40462"/><file name="windowsZones.xml" hash="bb1d22fd1c7e1073f31559d4ec4f6ea0"/><file name="xh.xml" hash="c4561fd383180394c1719f7af01252ed"/><file name="xh_ZA.xml" hash="7cc6e52fd5bbde7d7a09835462c9005a"/><file name="xog.xml" hash="d159722255a22bf4b113822364e3aa42"/><file name="xog_UG.xml" hash="c9d9ce8325ccd943d17be076e2348509"/><file name="yav.xml" hash="7cd6b28230ea1b592f4f6dc656d7dac6"/><file name="yav_CM.xml" hash="d99d7f9815108fe4040253b525fb1e65"/><file name="yo.xml" hash="94b71c3a56a7d571cdd2cdcca0e3639d"/><file name="yo_BJ.xml" hash="ad14fab000b1bdba3ad0959b41692125"/><file name="yo_NG.xml" hash="1381c16f38223fcd4e645a66f06d3947"/><file name="zgh.xml" hash="47980624ea61e97a271f180c98a7f012"/><file name="zgh_MA.xml" hash="7e72d86646a8b5045dfbedd721e5d0f1"/><file name="zh.xml" hash="7ce5cf9353eaeee426d5d5eb87670dfb"/><file name="zh_Hans.xml" hash="bdb68fe0878c430dc788e383b389dc2c"/><file name="zh_Hans_CN.xml" hash="24a14d8c675ae0c5b2fd211477240405"/><file name="zh_Hans_HK.xml" hash="7c82d550690d9ea63bc19cc76fbb61de"/><file name="zh_Hans_MO.xml" hash="9e4291c5bb0facb592b3ea3c14147e72"/><file name="zh_Hans_SG.xml" hash="01f85db499b693f4d3032e8683db390d"/><file name="zh_Hant.xml" hash="fb57450622d2383ac2f9d0e9c03872d0"/><file name="zh_Hant_HK.xml" hash="8648266bec5d9594fff57e030ff88e53"/><file name="zh_Hant_MO.xml" hash="3625e00e40fe8377de3a9a03628657ad"/><file name="zh_Hant_TW.xml" hash="66f700074df27309b3c6c71701d3b9b0"/><file name="zu.xml" hash="6542a2fe4304ba6289f66b2a68bbbcc7"/><file name="zu_ZA.xml" hash="db4d81680d06e598e322a26e9255ea69"/></dir><file name="Data.php" hash="8fa12d0abbc5557b89cd824b0e18d3bb"/><file name="Exception.php" hash="48210cc1272d8350acafdb8b26e86081"/><file name="Format.php" hash="eb7d886a80ca361bd0c38ec54b5d8bf2"/><dir name="Math"><file name="Exception.php" hash="37609bd0e120bcb0ed890523ac7cd35e"/><file name="PhpMath.php" hash="aa289ad314dc08e0abf97a3f147b6750"/></dir><file name="Math.php" hash="8f03d1a239fa7f642dd43ef7f7c642ad"/></dir><file name="Locale.php" hash="aad364df1a2dcad576c9ae09d94f46d8"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Mage_All_Latest-1.9.4.1.xml b/var/package/Mage_All_Latest-1.9.4.1.xml
deleted file mode 100644
index 7b26480..0000000
--- a/var/package/Mage_All_Latest-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_All_Latest</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Metapackage for latest Magento 1.9.0.0 release</summary>
-    <description>Metapackage for latest Magento 1.9.0.0 release</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:51</time>
-    <contents><target name="mage"><dir name="pkginfo"><file name="Mage_All_Latest.txt" hash=""/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Adminhtml_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Install_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Downloader</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Centinel</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Base_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Phoenix_Moneybookers</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Compiler</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Magento_Mobile</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Cm</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Cm_RedisSession</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Interface_Frontend_Rwd_Default</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_All_Latest-1.9.4.2.xml b/var/package/Mage_All_Latest-1.9.4.2.xml
new file mode 100644
index 0000000..05ba582
--- /dev/null
+++ b/var/package/Mage_All_Latest-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_All_Latest</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Metapackage for latest Magento 1.9.0.0 release</summary>
+    <description>Metapackage for latest Magento 1.9.0.0 release</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:11</time>
+    <contents><target name="mage"><dir name="pkginfo"><file name="Mage_All_Latest.txt" hash=""/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Interface_Adminhtml_Default</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Interface_Frontend_Default</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Interface_Install_Default</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Downloader</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Centinel</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Interface_Frontend_Base_Default</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Phoenix_Moneybookers</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Compiler</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Magento_Mobile</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Cm</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Cm_RedisSession</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Interface_Frontend_Rwd_Default</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Centinel-1.9.4.1.xml b/var/package/Mage_Centinel-1.9.4.1.xml
deleted file mode 100644
index 69b41ba..0000000
--- a/var/package/Mage_Centinel-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Centinel</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>3D Secure Card Validation</summary>
-    <description>An integration with Cardinalcommerce Centinel service. Provides option to validate Visa and Mastercard cards for eliminating possible fraudlent order placement attempts. Adds information about Electronic Commerce Identifier, that designates liability for chargeback.</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:51</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Centinel"><dir name="Block"><dir name="Adminhtml"><dir name="Validation"><file name="Form.php" hash="6fd9bc0ba636aca1277bd74884dec37a"/></dir><file name="Validation.php" hash="ace0940b991411bf8a90aa2dff370af9"/></dir><dir name="Authentication"><file name="Complete.php" hash="92c6cadff8c32007edfe0fbf75f8fac6"/><file name="Start.php" hash="96e03cb1f01a73d2a7bae807d02c6cda"/></dir><file name="Authentication.php" hash="7d2047ae6dff17172adfa3e5fe0f3faa"/><file name="Logo.php" hash="df7454a04c00cebfbc1a70496c264350"/></dir><dir name="Helper"><file name="Data.php" hash="60e2be29acc4f8f1c95650907fc9ff13"/></dir><dir name="Model"><dir name="Api"><file name="Client.php" hash="772a33df44fa004b8bbc5c29f7433eb9"/></dir><file name="Api.php" hash="c59e3344aa844b6b8e16e54bc42bb928"/><file name="Config.php" hash="18fc369415ccaf4d198ad8b9544cb247"/><file name="Observer.php" hash="5b0ec1ebe73e64b1c10cd036821deb4e"/><file name="Service.php" hash="e9d7280d375e3917a6b222da6f8dc8d1"/><file name="Session.php" hash="939f4dd80c193532422168068e3670b2"/><dir name="State"><file name="Jcb.php" hash="bc09bea61265195fed07b56334b4e465"/><file name="Mastercard.php" hash="65f2449e45865b451b0a5c08f405bf27"/><file name="Visa.php" hash="d27c247165853ab9995fe8874787cec1"/></dir><file name="StateAbstract.php" hash="a07849abad50e3904813643fb2e57d52"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Centinel"><file name="IndexController.php" hash="aa97d871be6215308dcb3d2973fb3f3f"/></dir></dir><file name="IndexController.php" hash="683e2aae21a7e65e97caeaa32af7291d"/></dir><dir name="etc"><file name="config.xml" hash="0c19be00fc21ecfe4a2145961024b8e7"/><file name="system.xml" hash="52052df926f875432acc5bb2345672a5"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Centinel.xml" hash="9715db6c2006854333940de409752e25"/></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><dir name="sales"><file name="centinel.js" hash="0d0d4610d5b94cac84a94d17cc9019fa"/></dir></dir></dir></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="a34b644c5d957779a890cb15c12ff17a"/><file name="start.phtml" hash="7b0b93864ab507f7bc4f1ce3e75b1f8f"/></dir><dir name="validation"><file name="form.phtml" hash="bff510bf825b8f035eae39514c061ba2"/></dir></dir></dir><dir name="layout"><file name="centinel.xml" hash="b2ed29dd8d809adc62d920fa6bc8a6cd"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="48266633b7cc79888746a6e215a91993"/><file name="start.phtml" hash="88b0735a527b685af293b8a99562e469"/></dir><file name="authentication.phtml" hash="fd9646f787de09b08eebeba75fa1269c"/><file name="logo.phtml" hash="55803993cec3af6f659b7529e8e76528"/></dir></dir><dir name="layout"><file name="centinel.xml" hash="89cd014042e539a36aa384b35702cec5"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Centinel.csv" hash="20f331c149ccf32faabdd406626805e0"/></dir></target><target name="magelib"><dir name="3Dsecure"><file name="CentinelClient.php" hash="e8459bd7d542e38058529e9bbb27ca25"/><file name="CentinelErrors.php" hash="e99aa9e865cc56beb2cf99d616ff0ceb"/><file name="XMLParser.php" hash="d089f3a81ac81378c889eee73a52f413"/></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="centinel"><file name="sc_learn_62x34.png" hash="7d6ec4b19f8eeb6baa2cddd5d4274f87"/><file name="v_activate_steps.gif" hash="005312b14c6aed41e8a47c4acaac7c1a"/><file name="vbv_ltbg_71x57.png" hash="324e5de7f6c75dc3cecb61646113ac41"/></dir></dir></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Centinel-1.9.4.2.xml b/var/package/Mage_Centinel-1.9.4.2.xml
new file mode 100644
index 0000000..abbe3ff
--- /dev/null
+++ b/var/package/Mage_Centinel-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Centinel</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>3D Secure Card Validation</summary>
+    <description>An integration with Cardinalcommerce Centinel service. Provides option to validate Visa and Mastercard cards for eliminating possible fraudlent order placement attempts. Adds information about Electronic Commerce Identifier, that designates liability for chargeback.</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:11</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Centinel"><dir name="Block"><dir name="Adminhtml"><dir name="Validation"><file name="Form.php" hash="6fd9bc0ba636aca1277bd74884dec37a"/></dir><file name="Validation.php" hash="ace0940b991411bf8a90aa2dff370af9"/></dir><dir name="Authentication"><file name="Complete.php" hash="92c6cadff8c32007edfe0fbf75f8fac6"/><file name="Start.php" hash="96e03cb1f01a73d2a7bae807d02c6cda"/></dir><file name="Authentication.php" hash="7d2047ae6dff17172adfa3e5fe0f3faa"/><file name="Logo.php" hash="df7454a04c00cebfbc1a70496c264350"/></dir><dir name="Helper"><file name="Data.php" hash="60e2be29acc4f8f1c95650907fc9ff13"/></dir><dir name="Model"><dir name="Api"><file name="Client.php" hash="772a33df44fa004b8bbc5c29f7433eb9"/></dir><file name="Api.php" hash="c59e3344aa844b6b8e16e54bc42bb928"/><file name="Config.php" hash="18fc369415ccaf4d198ad8b9544cb247"/><file name="Observer.php" hash="5b0ec1ebe73e64b1c10cd036821deb4e"/><file name="Service.php" hash="e9d7280d375e3917a6b222da6f8dc8d1"/><file name="Session.php" hash="939f4dd80c193532422168068e3670b2"/><dir name="State"><file name="Jcb.php" hash="bc09bea61265195fed07b56334b4e465"/><file name="Mastercard.php" hash="65f2449e45865b451b0a5c08f405bf27"/><file name="Visa.php" hash="d27c247165853ab9995fe8874787cec1"/></dir><file name="StateAbstract.php" hash="a07849abad50e3904813643fb2e57d52"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Centinel"><file name="IndexController.php" hash="aa97d871be6215308dcb3d2973fb3f3f"/></dir></dir><file name="IndexController.php" hash="683e2aae21a7e65e97caeaa32af7291d"/></dir><dir name="etc"><file name="config.xml" hash="0c19be00fc21ecfe4a2145961024b8e7"/><file name="system.xml" hash="52052df926f875432acc5bb2345672a5"/></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Centinel.xml" hash="9715db6c2006854333940de409752e25"/></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><dir name="sales"><file name="centinel.js" hash="0d0d4610d5b94cac84a94d17cc9019fa"/></dir></dir></dir></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="a34b644c5d957779a890cb15c12ff17a"/><file name="start.phtml" hash="7b0b93864ab507f7bc4f1ce3e75b1f8f"/></dir><dir name="validation"><file name="form.phtml" hash="bff510bf825b8f035eae39514c061ba2"/></dir></dir></dir><dir name="layout"><file name="centinel.xml" hash="b2ed29dd8d809adc62d920fa6bc8a6cd"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="centinel"><dir name="authentication"><file name="complete.phtml" hash="48266633b7cc79888746a6e215a91993"/><file name="start.phtml" hash="88b0735a527b685af293b8a99562e469"/></dir><file name="authentication.phtml" hash="fd9646f787de09b08eebeba75fa1269c"/><file name="logo.phtml" hash="55803993cec3af6f659b7529e8e76528"/></dir></dir><dir name="layout"><file name="centinel.xml" hash="89cd014042e539a36aa384b35702cec5"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Centinel.csv" hash="20f331c149ccf32faabdd406626805e0"/></dir></target><target name="magelib"><dir name="3Dsecure"><file name="CentinelClient.php" hash="e8459bd7d542e38058529e9bbb27ca25"/><file name="CentinelErrors.php" hash="e99aa9e865cc56beb2cf99d616ff0ceb"/><file name="XMLParser.php" hash="d089f3a81ac81378c889eee73a52f413"/></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="centinel"><file name="sc_learn_62x34.png" hash="7d6ec4b19f8eeb6baa2cddd5d4274f87"/><file name="v_activate_steps.gif" hash="005312b14c6aed41e8a47c4acaac7c1a"/><file name="vbv_ltbg_71x57.png" hash="324e5de7f6c75dc3cecb61646113ac41"/></dir></dir></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Compiler-1.9.4.1.xml b/var/package/Mage_Compiler-1.9.4.1.xml
deleted file mode 100644
index 4bfe825..0000000
--- a/var/package/Mage_Compiler-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Compiler</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>This module compiles all files of a Magento installation and creates a single include path to increase performance</summary>
-    <description>This module compiles all files of a Magento installation and creates a single include path to increase performance</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:51</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Compiler"><dir name="Block"><file name="Process.php" hash="79cc3d9a2d244127b319875d052da4f6"/></dir><dir name="Helper"><file name="Data.php" hash="cd4cbd2162100486a8c990610627fbff"/></dir><dir name="Model"><file name="Process.php" hash="8e6c24f7292dc203b2bafe8201a57c14"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Compiler"><file name="ProcessController.php" hash="4bf432496465a488fefef18f308a5867"/></dir></dir><file name="ProcessController.php" hash="10870e0636c294e1ae6733ac332f6e6c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9d044840914fa8a941aa741ab75217e7"/><file name="compilation.xml" hash="878103b6f50bf2cc1f3075b60a8cccb5"/><file name="config.xml" hash="b2b7469ba9b92e9656d4c828feacdd0c"/></dir></dir></dir></target><target name="mage"><dir name="includes"><file name="config.php" hash="7a7b61cc43b0775e70fb9e556cbe2c37"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Compiler.xml" hash="f90a06b926ba6e34d37959842938089f"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="compiler.xml" hash="fcf972e9bc3e481a1a52f29763d89ea8"/></dir><dir name="template"><dir name="compiler"><file name="process.phtml" hash="5d5d9577753849bba49da416bcfc5e19"/></dir></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Compiler.csv" hash="caa1d67e6c508421a8c8c234ae204c5d"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Compiler-1.9.4.2.xml b/var/package/Mage_Compiler-1.9.4.2.xml
new file mode 100644
index 0000000..193631f
--- /dev/null
+++ b/var/package/Mage_Compiler-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Compiler</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>This module compiles all files of a Magento installation and creates a single include path to increase performance</summary>
+    <description>This module compiles all files of a Magento installation and creates a single include path to increase performance</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:11</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Compiler"><dir name="Block"><file name="Process.php" hash="79cc3d9a2d244127b319875d052da4f6"/></dir><dir name="Helper"><file name="Data.php" hash="cd4cbd2162100486a8c990610627fbff"/></dir><dir name="Model"><file name="Process.php" hash="014b38806198b89195964d3bb7524a42"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Compiler"><file name="ProcessController.php" hash="4bf432496465a488fefef18f308a5867"/></dir></dir><file name="ProcessController.php" hash="10870e0636c294e1ae6733ac332f6e6c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9d044840914fa8a941aa741ab75217e7"/><file name="compilation.xml" hash="878103b6f50bf2cc1f3075b60a8cccb5"/><file name="config.xml" hash="b2b7469ba9b92e9656d4c828feacdd0c"/></dir></dir></dir></target><target name="mage"><dir name="includes"><file name="config.php" hash="7a7b61cc43b0775e70fb9e556cbe2c37"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_Compiler.xml" hash="f90a06b926ba6e34d37959842938089f"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="compiler.xml" hash="fcf972e9bc3e481a1a52f29763d89ea8"/></dir><dir name="template"><dir name="compiler"><file name="process.phtml" hash="5d5d9577753849bba49da416bcfc5e19"/></dir></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Compiler.csv" hash="caa1d67e6c508421a8c8c234ae204c5d"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Core_Adminhtml</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Core_Adminhtml-1.9.4.1.xml b/var/package/Mage_Core_Adminhtml-1.9.4.1.xml
deleted file mode 100644
index 9683ef3..0000000
--- a/var/package/Mage_Core_Adminhtml-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Core_Adminhtml</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Administration Panel</summary>
-    <description>Magento Administration Panel</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:51</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Adminhtml"><dir name="Block"><file name="Abstract.php" hash="1d12544ff9a4179ec26ea38df2f705a1"/><dir name="Api"><file name="Buttons.php" hash="2bfed92fbddff63dc671c27b5d75ce93"/><file name="Editroles.php" hash="a1d4db198e2e99ecc9afa2f058b30e71"/><file name="Edituser.php" hash="1585e1dd89f71aed9d84c704cf9945f9"/><dir name="Grid"><file name="Role.php" hash="979c32b3dea09126c937e588d7ec0c0a"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="5fab40b01ca6d75c853417f6f182243f"/></dir></dir><file name="Role.php" hash="c6d7bd3e76b94c4f4df8ba70d8f87cbc"/><file name="Roles.php" hash="1f9b226104fc7015d6a752b12c95f5d8"/><dir name="Tab"><file name="Roleinfo.php" hash="068f8a4c1914a134ace5faa00094cf31"/><file name="Rolesedit.php" hash="29b4cbd98c0ca82453f02b4627a95c0c"/><file name="Rolesusers.php" hash="767b7483660096254eb486f5d2be927b"/><file name="Userroles.php" hash="03cc0352d61d676a30662564a5ce839f"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e797303af20e9b4c72de379330fdd76c"/><dir name="Tab"><file name="Main.php" hash="b6c71ac2f96d87c0d0a586258e9301d4"/><file name="Roles.php" hash="2817cb16b57964c029cdc991061168fb"/></dir><file name="Tabs.php" hash="83b36d6858b78b3ef1ef56102e733ece"/></dir><file name="Edit.php" hash="742b1c24fa349177cc5379f7c0eb5d0f"/><file name="Grid.php" hash="3a58107458d582950e14cfa51513077e"/></dir><file name="User.php" hash="adf9a33ed18d3c60e9ffc284f98ff6dd"/><file name="Users.php" hash="4d3ccf7be3cc39c720fa032abb0af6aa"/></dir><dir name="Backup"><file name="Dialogs.php" hash="468b3514651887904849a6e9f7d81e8c"/><file name="Grid.php" hash="d7a48a3580321c5a502950255b7965dc"/></dir><file name="Backup.php" hash="25b24ec94e7fc2b5c04b694b884597a8"/><dir name="Cache"><file name="Additional.php" hash="140342a012f58cb93e0ac7d82d02b53f"/><file name="Grid.php" hash="d6eb94996a6dd177f09a95525ceeeee4"/><file name="Notifications.php" hash="18205ad9e6a0b21ee467dcc789d19864"/></dir><file name="Cache.php" hash="2eba478582fb0d66d6732f21fd95c715"/><dir name="Catalog"><dir name="Category"><file name="Abstract.php" hash="b4d5029756e0c8e8de149156a8cde6ab"/><dir name="Checkboxes"><file name="Tree.php" hash="a30396e16cad9fc4a3d924fc81587f51"/></dir><dir name="Edit"><file name="Form.php" hash="a0cff1b2848881be054ed580ea0492ab"/></dir><file name="Edit.php" hash="28f749e9c1bf2066878b9cc7f4c44a71"/><dir name="Helper"><file name="Image.php" hash="97826fd95b6704961f976c3755ff63f3"/><file name="Pricestep.php" hash="0fbb5ec65a9fd2c13b17d9054116e0ec"/><dir name="Sortby"><file name="Available.php" hash="3baa0f9586e319e5be5ec7f1d77318f4"/><file name="Default.php" hash="8d2654ee619e84385a78b8f077b95817"/></dir></dir><dir name="Tab"><file name="Attributes.php" hash="8c37ae6f103e435d176713614cfc2732"/><file name="Design.php" hash="758a748b925e1bc5977b2c422eff7629"/><file name="General.php" hash="19f6ba72a075162228fe7606729944fa"/><file name="Product.php" hash="d18af8055e288e6537226a03f9f4f14d"/></dir><file name="Tabs.php" hash="84c926a493661a0a34fd409e20d96d10"/><file name="Tree.php" hash="4874a7a762c32f84d87c84ea63ca838c"/><dir name="Widget"><file name="Chooser.php" hash="4a8fa415e03bad3b179987b859eb8c27"/></dir></dir><dir name="Form"><dir name="Renderer"><dir name="Attribute"><file name="Urlkey.php" hash="ff7e37b0d7aa89165cae9fa598028c8a"/></dir><dir name="Config"><file name="DateFieldsOrder.php" hash="325392687355326b76a6d6b4d714958f"/><file name="YearRange.php" hash="81fc92362f8322bfe7cd478c8407744c"/></dir><dir name="Fieldset"><file name="Element.php" hash="9eed80102cc6a7e281e208aa86e99ab5"/></dir></dir></dir><file name="Form.php" hash="25150307aaef45477c387305f5e4f68f"/><dir name="Helper"><dir name="Form"><dir name="Wysiwyg"><file name="Content.php" hash="171b45a02d0f5bf62bde1358ac5e7a2a"/></dir><file name="Wysiwyg.php" hash="d3ce33132bc4220ec9b10b90f1769ac9"/></dir></dir><dir name="Product"><dir name="Attribute"><dir name="Edit"><file name="Form.php" hash="cdf3e0c7a1ec95b04888c84a1f778ebc"/><dir name="Tab"><file name="Front.php" hash="8f55cbf6f064086aadbbe74866acc26f"/><file name="Main.php" hash="4e8e7760214a3e176fd8eabbcd6a9e86"/><file name="Options.php" hash="f39e935918e8e668d5a8c54527c78232"/><file name="System.php" hash="e04ed3d2db33f456af71ad202dd78bbd"/></dir><file name="Tabs.php" hash="d9f123df155992923a370d2b5bee265e"/></dir><file name="Edit.php" hash="e53f99431ac23771abe61d4b0bfc406d"/><file name="Grid.php" hash="6ca85f95807da51938179cb20394f977"/><dir name="New"><dir name="Product"><file name="Attributes.php" hash="e84f1a4d60c284ae8849880d989c0afc"/><file name="Created.php" hash="71dfab2069f92429c1b08d50fa8145ef"/></dir></dir><dir name="Set"><file name="Grid.php" hash="f2fc5d5670e5817b2cf1cc9d26d726cb"/><dir name="Main"><file name="Formattribute.php" hash="0b1e150657f35428872d92bcc20fcec9"/><file name="Formgroup.php" hash="6ee05aa130ec4e0d26853d973185f4cc"/><file name="Formset.php" hash="203488f4962df9e69bbe67be46ad486b"/><dir name="Tree"><file name="Attribute.php" hash="85ed149d0074c657697be04bb69f2520"/><file name="Group.php" hash="bae5d15420a2b086b3710c8eb79bb99c"/></dir></dir><file name="Main.php" hash="307a3b737e4bcd2e5550e54407ebf658"/><dir name="Toolbar"><file name="Add.php" hash="16612d7c0e6efc62ae75142a6bf3cd64"/><dir name="Main"><file name="Filter.php" hash="c6eecdaacbcc665868f4a1e2114f6224"/></dir><file name="Main.php" hash="45d9726e9a6845a7911146586de27e25"/></dir></dir></dir><file name="Attribute.php" hash="35bda03c081d6583355e84b2a652aebc"/><dir name="Composite"><file name="Configure.php" hash="b67bd03a727caab2d99cbec59eb6c15a"/><file name="Error.php" hash="a11b9e86c20d87c7881e6c10821c651d"/><dir name="Fieldset"><file name="Configurable.php" hash="b66dc415373b803e75cacc0fe302f865"/><file name="Grouped.php" hash="a886ae59748a6bd05712599d9e36f59d"/><file name="Options.php" hash="6e3c0d7be774973bb7c14bc3aaf16e63"/><file name="Qty.php" hash="9475558d479812c1255f3459233dc92f"/></dir><file name="Fieldset.php" hash="f11d5ce88b7c2b2b10df891dfdffcdb7"/><dir name="Update"><file name="Result.php" hash="04d1f852a68190de43d0a7875db17722"/></dir></dir><file name="Created.php" hash="b47f62987dd532eb78540fb1ae149482"/><dir name="Edit"><dir name="Action"><dir name="Attribute"><dir name="Tab"><file name="Attributes.php" hash="c28f819e42ee059b0e0807f8c073c7e6"/><file name="Inventory.php" hash="28b622520b546658b1ce1201b4ab07cf"/><file name="Websites.php" hash="d122b9fead07ce717b812866c46adcf4"/></dir><file name="Tabs.php" hash="ee4ac2b9077429db8832401b2ebcc4ae"/></dir><file name="Attribute.php" hash="0ca8963be70c599d760e6f34520e1ca1"/></dir><file name="Js.php" hash="e261073dc1e135d7287c48a3ac6024fe"/><dir name="Tab"><dir name="Ajax"><file name="Serializer.php" hash="407bce164538ebb2699a4f630919f544"/></dir><dir name="Alerts"><file name="Price.php" hash="61d24a11322b7334f9d9159b0d54a270"/><file name="Stock.php" hash="39f246d0007135c96569cc0f677e8200"/></dir><file name="Alerts.php" hash="71877f70f839bc3311400a8b0f74ad1c"/><dir name="Attributes"><file name="Create.php" hash="abd39e94d61a77f718a447d16a00a911"/></dir><file name="Attributes.php" hash="452ab3f3424dc9693e4f1cb3f8f0bd84"/><file name="Categories.php" hash="96e5cb356bb207156dad4ca8fd953239"/><file name="Crosssell.php" hash="3fb1a2644748deac0667915369a125b4"/><file name="Inventory.php" hash="f6dc9b47afa451a07fcaee2bee4b4c90"/><dir name="Options"><file name="Option.php" hash="b1f8e3381c100602006315d01fdfae9b"/><dir name="Type"><file name="Abstract.php" hash="03e4e1f2a23529b61d9cd6b2356048f3"/><file name="Date.php" hash="486db1c7e03c9009933622a04f93b4b1"/><file name="File.php" hash="bdc8a288f3612adc368a1eec9555ea60"/><file name="Select.php" hash="73477e9768fae45a4d53b074d23760a5"/><file name="Text.php" hash="2171a4e312504df88008d4bcda2d7e4b"/></dir></dir><file name="Options.php" hash="a62eb8c69acc3164765a2a58380d4eed"/><dir name="Price"><dir name="Group"><file name="Abstract.php" hash="7fcb2806533cf4005992cd5f6aba2c93"/></dir><file name="Group.php" hash="1861d97732bdee01154cc39c3bf4b345"/><file name="Recurring.php" hash="4a03f89a26555b68be76e630de5347c6"/><file name="Tier.php" hash="f214bc620608440dc393092faf045094"/></dir><file name="Price.php" hash="fa49ddddedc8937e9db216713dc50742"/><file name="Related.php" hash="58139c20fb9deffb1b28aa7d4081be30"/><file name="Reviews.php" hash="89efeb2d1d07e92aea33e26b0c91b0ac"/><file name="Settings.php" hash="be4f8669f07a1a1951b1ecacd9fc328b"/><dir name="Super"><dir name="Config"><dir name="Grid"><dir name="Filter"><file name="Inventory.php" hash="02c8d622fdb61b9c4dbacca7a7b2cfdc"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="9ee83d276e1f9e851450ef377f1051a9"/><file name="Inventory.php" hash="2c305eed32d570d0743b2ded6ff77c40"/></dir></dir><file name="Grid.php" hash="9080fb1a0e252b37f6424ae05ac23fe9"/><file name="Simple.php" hash="4f4c795463b3bf7e302210163b85b4e8"/></dir><file name="Config.php" hash="9d21bfac241042373e81b36b7cd81fa9"/><file name="Group.php" hash="96d08a2ea0ff1fea50370f3741d6d1de"/><file name="Settings.php" hash="199168163f1340c262863bbfdcac7361"/></dir><dir name="Tag"><file name="Customer.php" hash="d1bc2fff71591e0938f7897a9d5e7435"/></dir><file name="Tag.php" hash="5a9a5345a8820830974f7701e42157f8"/><file name="Upsell.php" hash="78025ebd67d64b038b4d7a4082b99b2d"/><file name="Websites.php" hash="69d0d1aa6951622e378ec284e968bca5"/></dir><dir name="Tabs"><file name="Configurable.php" hash="a9b9ff4f7e7c8e76b6eb63a1022e5298"/><file name="Grouped.php" hash="4b0d7e5766e03b7ec4e13892cce63e35"/></dir><file name="Tabs.php" hash="990c3877e7ac14972c42b1615b6d2f61"/></dir><file name="Edit.php" hash="a77985102f5bc9500d8d999bdb640aa8"/><dir name="Frontend"><dir name="Product"><file name="Watermark.php" hash="c8fdddc408ff23b4a2e0cc9940452532"/></dir></dir><file name="Grid.php" hash="4415c85c4c6cfe9ebad25dbb4a570a7d"/><dir name="Helper"><dir name="Form"><file name="Apply.php" hash="ebdec21e1d86ebb91f61f05235b02c0d"/><file name="Boolean.php" hash="b3790b5b035c6d68c7478cb9362dd196"/><file name="Config.php" hash="0c59e94f97e820a46bb5f21e548363d2"/><dir name="Gallery"><file name="Content.php" hash="4ed8b17993adda5daccaec874cf516d2"/></dir><file name="Gallery.php" hash="cad37730c4c135877ce4467a7d01176b"/><file name="Image.php" hash="6241be43f381a5a0821f4dcab824f8eb"/><dir name="Msrp"><file name="Enabled.php" hash="a44f68cbf40a6c4b8d730349e5dea567"/><file name="Price.php" hash="c8fe461530d7de62b64a4f0d5d313d21"/></dir><file name="Price.php" hash="eee51e79b5c100190b1ac01090cb8ac4"/><file name="Weight.php" hash="0c7bf1ab444bd1af1d7fdbd7bcbfe828"/></dir></dir><file name="Price.php" hash="63b3d5a6a44de5108c06a15a58166d7f"/><dir name="Widget"><dir name="Chooser"><file name="Container.php" hash="162b5430206fdb7dcaa404ce8f122660"/></dir><file name="Chooser.php" hash="a13ab5cc27f3b108c83da378799c7845"/></dir></dir><file name="Product.php" hash="6221f39a3224f6c5ab50d0c906dfc6f8"/><dir name="Search"><dir name="Edit"><file name="Form.php" hash="a42b407c9a9f47092df32f565297b3b6"/></dir><file name="Edit.php" hash="bdb5ad67da655778ffacd912a07df423"/><file name="Grid.php" hash="f3ebd37ea9b57148d2f233f4d6d132b0"/></dir><file name="Search.php" hash="96a2febc55af4f9a3445def312b2f4d1"/></dir><file name="Catalog.php" hash="28eb5e6b2060460cc0308a9115ce4874"/><dir name="Checkout"><dir name="Agreement"><dir name="Edit"><file name="Form.php" hash="9151175340c1cf3787cbff6f52d31895"/></dir><file name="Edit.php" hash="64f603054370f2a77077249828a7bd6e"/><file name="Grid.php" hash="c56ef0e787a8d2f2555663e950f17fd1"/></dir><file name="Agreement.php" hash="ef6402bcc1e58c9b1598c8dc606b977d"/><file name="Formkey.php" hash="33506381a0bc723b94bd4635fc1fc555"/></dir><dir name="Cms"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="a9a37434f2f77967cb1d71dc725cc2f0"/></dir><file name="Edit.php" hash="dce0c8f690bdd9f5f0a7f781e15bb8da"/><file name="Grid.php" hash="8535d143498e9361d46364210f40aa60"/><dir name="Widget"><file name="Chooser.php" hash="55b9d76cbb369cdb0263a53f964fc564"/></dir></dir><file name="Block.php" hash="3f6f0192cd2a00850d9af6f3e825c3fd"/><dir name="Page"><dir name="Edit"><file name="Form.php" hash="31930639349c990f654e48fb7691a36f"/><dir name="Tab"><file name="Content.php" hash="e4e99ec295b2bb66cac94dd13410c0ab"/><file name="Design.php" hash="5545e1f1b1b716fff48325c364d795b3"/><file name="Main.php" hash="c1204a5bb8cb4bec6b7cb957374863d7"/><file name="Meta.php" hash="71472514e5e64d34807485bd9d4a12fe"/></dir><file name="Tabs.php" hash="6028f105ec1c60a4a41379fa41fef0f0"/></dir><file name="Edit.php" hash="283dd2ba93961f05baafa9ae641e99e2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="b69a369f078299372a0dc2684ddbba87"/></dir></dir><file name="Grid.php" hash="d2580f2a2a20a80ebf446191da59d9bf"/><dir name="Widget"><file name="Chooser.php" hash="3861c825efbae550f7c5b874a832973a"/></dir></dir><file name="Page.php" hash="44c1d2c7672727bcb5f617f4895e067a"/><dir name="Wysiwyg"><dir name="Images"><dir name="Content"><file name="Files.php" hash="dfe9b5f9cc1e88b7a92c89cae607ca56"/><file name="Newfolder.php" hash="abf8f9db9780ae6d4795c323225abb24"/><file name="Uploader.php" hash="c90b036837f00ee86c18d5e03cf56c56"/></dir><file name="Content.php" hash="18332e1d078c402dfd6db5b97c1f33d5"/><file name="Tree.php" hash="cabff9304c30720fe46e55e9f97fa6bd"/></dir></dir></dir><dir name="Customer"><dir name="Edit"><file name="Form.php" hash="88a9be8c62c08488c6f827d6e265b969"/><dir name="Renderer"><file name="Adminpass.php" hash="360c3517de650b9ec57a7f4f6730fcf8"/><dir name="Attribute"><file name="Group.php" hash="3161a779443b4944aed44ed266212aa9"/></dir><file name="Newpass.php" hash="445763b68a969eaae5ad2b780304d845"/><file name="Region.php" hash="e042b4f141569c7bb2ca7c309cd78c8f"/></dir><dir name="Tab"><file name="Account.php" hash="c3b7b882e2d87695d8f204d57ff2ffcc"/><file name="Addresses.php" hash="6be0f07b01c229f200ca47723c991567"/><file name="Cart.php" hash="6dbd28473e97889cbb12d799f992e84b"/><file name="Carts.php" hash="b487cfbfa014ecac68c1772b8dcafbb9"/><dir name="Newsletter"><dir name="Grid"><dir name="Filter"><file name="Status.php" hash="b75c661699fab3163db9b05484f184a6"/></dir><dir name="Renderer"><file name="Action.php" hash="83f1619271d589cf2f98266eb2b298b1"/><file name="Status.php" hash="12cc0385800c2654faca3e1b3191a36b"/></dir></dir><file name="Grid.php" hash="e6bfbaab166055bc97ca6a430fc24f57"/></dir><file name="Newsletter.php" hash="0b4a34626577789ab75efea769dcaa7d"/><file name="Orders.php" hash="61aac0bcd2a87580599e1cd4d0bb2e51"/><file name="Reviews.php" hash="31efe9289ff7e87eff54c179c24dba6f"/><file name="Tag.php" hash="5b1b636cae3e66210eba1bc6a3e39c36"/><file name="Tags.php" hash="f90b0d2468019f8dbaea8c576936b547"/><dir name="View"><file name="Accordion.php" hash="81facad941d92464a28f6fd5614fb608"/><file name="Cart.php" hash="8d9b2b37138a6fd89b983c7f270b03ae"/><dir name="Grid"><dir name="Renderer"><file name="Item.php" hash="f2d36c6018a1975b0f9d983adfe245ee"/></dir></dir><file name="Orders.php" hash="fed6b2896c91e422e69f1a600ec8d9cc"/><file name="Sales.php" hash="b731082a6fc2dfa9b3fe8a5d6bf309e8"/><file name="Wishlist.php" hash="961d8c040d2292cb7197c89e63b144a3"/></dir><file name="View.php" hash="f96caeaa728561efb18187444b7b0685"/><dir name="Wishlist"><dir name="Grid"><dir name="Renderer"><file name="Description.php" hash="f53f9167df22e37e68faca9d2ce333bb"/></dir></dir></dir><file name="Wishlist.php" hash="10461d6a242274497dd19094c022df58"/></dir><file name="Tabs.php" hash="3ded30ea877555bff0ca42610af96bfa"/></dir><file name="Edit.php" hash="5ea2cb0668eec0f0c7146ba39960a715"/><dir name="Form"><dir name="Element"><file name="Boolean.php" hash="fc6a5684ed07f3f41e4c06e7344d908c"/><file name="File.php" hash="4eb0ff4d329073aad2265381c01a0f0c"/><file name="Image.php" hash="2de933a0ef21a707e21381dbe2419b22"/></dir></dir><dir name="Grid"><dir name="Filter"><file name="Country.php" hash="0f1bc3cfad87222867e25a52cd605172"/></dir><dir name="Renderer"><file name="Multiaction.php" hash="4efa42b2e04948a2f64e85309c85cb1d"/></dir></dir><file name="Grid.php" hash="c3bb6f389beb5e149f919fc69c6627e9"/><dir name="Group"><dir name="Edit"><file name="Form.php" hash="e6fea58502cdea637c0157ea59f16c0f"/></dir><file name="Edit.php" hash="d2f99b544dc8b14184f2e9f6cce51d1a"/><file name="Grid.php" hash="12c7160547939438100ef7ae261ac225"/></dir><file name="Group.php" hash="eaec4acad81f69ff1a27a54122610050"/><dir name="Online"><file name="Filter.php" hash="ffe20662f60e0b779c926abe5ff6d971"/><dir name="Grid"><dir name="Renderer"><file name="Ip.php" hash="61400fedbbe4636ffb8a5bc1c6e75490"/><file name="Type.php" hash="150f363f91d9fb883f44b5dba8b141eb"/><file name="Url.php" hash="26161955ae6ad2c9d54d86ca20915b59"/></dir></dir><file name="Grid.php" hash="1eacff4ddfd493f6c221e0f165bab92b"/></dir><file name="Online.php" hash="089a608976c37ba29631514fd95365ca"/><dir name="Sales"><dir name="Order"><dir name="Address"><dir name="Form"><dir name="Renderer"><file name="Vat.php" hash="673cd679f9d5d7a8eb49968dfdff866f"/></dir></dir></dir></dir></dir><dir name="System"><dir name="Config"><file name="Validatevat.php" hash="6c44b4cf2a4532dfef9f33a40d527f40"/></dir></dir></dir><file name="Customer.php" hash="0bd1275ae095c7f5b48d0dafd013cce0"/><dir name="Dashboard"><file name="Abstract.php" hash="e9b622f22beaede0e7d097444be1f744"/><file name="Bar.php" hash="55433f04b2b15053d07f6b6d80ca6e8e"/><file name="Diagrams.php" hash="15341f9925a159eca333fed855d569f1"/><file name="Graph.php" hash="f20a65054e9186820dc0527092f7b30f"/><file name="Grid.php" hash="9468ed7c5da000af3cd3354dbcfbe3e9"/><file name="Grids.php" hash="2235cdd24831e25fad2aaac38789ecc7"/><dir name="Orders"><file name="Grid.php" hash="f92d2a66236995ae2e3951c54b24c436"/></dir><file name="Sales.php" hash="f3365fc3d801700304cee4aa373e9ce9"/><dir name="Searches"><file name="Last.php" hash="9bb819e172cbea12c16e4cda910f24b0"/><dir name="Renderer"><file name="Searchquery.php" hash="01e38618ae9218a3ad748a0a8d22fc7a"/></dir><file name="Top.php" hash="e9db73d797a14f1494e152ebf7269f72"/></dir><dir name="Tab"><file name="Amounts.php" hash="de998abe0165fb810473b79a1f1bc52b"/><dir name="Customers"><file name="Most.php" hash="a95156aa6735fffae2e592b17833cda6"/><file name="Newest.php" hash="d59d800b48df42ae85c886c76e9cd840"/></dir><file name="Orders.php" hash="95dc17af38b3fe3ad4be51fd191e6b52"/><dir name="Products"><file name="Ordered.php" hash="1ecba3f7f07991aabd7be7b185c71894"/><file name="Viewed.php" hash="3d68267acd0253df57f17deff5408d19"/></dir></dir><file name="Totals.php" hash="3dd71832f902929b1a06defb8b2e4887"/></dir><file name="Dashboard.php" hash="3fca911a8afb8417625a04318171f6a5"/><file name="Denied.php" hash="55a2dc1b2b2839eece570dd602ee040a"/><dir name="Html"><file name="Date.php" hash="147063fc866d415b9376a07fbee91a8d"/><file name="Select.php" hash="48b825c9be24ec326febf95f5c9449fc"/></dir><dir name="Media"><file name="Editor.php" hash="6e1604888e79ece680f2764aa2a7dd39"/><file name="Uploader.php" hash="0c0851fbef753a9b982d225b498c7fd9"/></dir><file name="Messages.php" hash="917f968f40fde4c6d94b639deed48bdb"/><dir name="Newsletter"><dir name="Problem"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="a3ee987724942adc84bfe94f8c6139ed"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="b1a2993d634b5db32a8140c18f673868"/></dir></dir><file name="Grid.php" hash="7159ed12e2b23ddfa9061061f5e9fd54"/></dir><file name="Problem.php" hash="0ee1f8f1267589d18f0ad4b3356ae886"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="dfdf35631ee8819a94119def8e936d2d"/></dir><file name="Edit.php" hash="b9de2cb9df47de6d328fb3ebe079e85f"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="25d234ab87104931892193f5c2ff307a"/></dir></dir><file name="Grid.php" hash="f193f8d007edbe4ee0ef0f496de1bb01"/><dir name="Preview"><file name="Form.php" hash="e4f8a2f7926bc6459b427d082a9bfd1b"/></dir><file name="Preview.php" hash="f51c6a0924a89de4776b659bdc1e69cd"/></dir><file name="Queue.php" hash="b24837a0549af04763b22fac18f900c1"/><dir name="Subscriber"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="81d31d0057e780de4ddd38beab5bac38"/><file name="Website.php" hash="18a46ee8a8cbef2af8da175d84fcfb8c"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="7889c89f8832a14518e3329ffc81e657"/></dir></dir><file name="Grid.php" hash="372b9dee90b9f94802f8f9248e131eaa"/></dir><file name="Subscriber.php" hash="5d02591f5d99b9a034d35274546b2cfe"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="239143579f0958e949bb9a7d1215c947"/></dir><file name="Edit.php" hash="a8f026033bff8c435c5a90ea9684c55d"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="af0f7297d0de92d7e0ca2eb97b4b195e"/><file name="Sender.php" hash="cc7e96026bf1a720199994ac121ec236"/></dir></dir><file name="Grid.php" hash="8adf36fa829d54964b79c902c35cc4b5"/><dir name="Preview"><file name="Form.php" hash="3aae730608509c2de996e87f33535bdc"/></dir><file name="Preview.php" hash="ad20db0f12048a51d398f71ba2880768"/></dir><file name="Template.php" hash="52e9a3e5ba6a48950bec070e7108de08"/></dir><dir name="Notification"><file name="Baseurl.php" hash="f465f0f939bacf140e17e2a73c68f648"/><file name="Curl.php" hash="5562dffe8f544de14477d633c58d11a5"/><dir name="Grid"><dir name="Renderer"><file name="Actions.php" hash="8a92a77ba89231ce3875212b265feb2f"/><file name="Notice.php" hash="d9d8f4a5657ac3ea69460beb094fab44"/><file name="Severity.php" hash="49a1c0f2b3e3dac83ea17bc415700737"/></dir></dir><file name="Grid.php" hash="b69968b2ffc329bd0d04e6e92cf3c389"/><file name="Inbox.php" hash="cf88df1189b59b5d80e3d80f5c5b5ee2"/><file name="Security.php" hash="a9bf2769b39a9fea4a4ee3ef3d1d9e30"/><file name="Survey.php" hash="1e212b6d13543cd10be01e2b15d60aa6"/><file name="Symlink.php" hash="9666c29f2f3fe03eaf4eaf9ffde45ef4"/><file name="Toolbar.php" hash="a32fa374fd13357033a99c4e41328ed7"/><file name="Window.php" hash="ae90e32783c39946ae4dc1bea9f8ca93"/></dir><dir name="Page"><file name="Footer.php" hash="d1a4e2acaf969095729041c182ca097e"/><file name="Head.php" hash="fe8b20f2fc855b15eab3ebae500b6c4d"/><file name="Header.php" hash="4043dddbd522d15fcbf30fa6b905941d"/><file name="Menu.php" hash="93fc054fa2e6052f07897cd941adb515"/><file name="Notices.php" hash="7298bcaba60c7a5433cccc0ef8fb4869"/></dir><file name="Page.php" hash="79ff758d432530488292c1d04d45be3f"/><dir name="Permissions"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="250070fd2e5ff2b561696484204f1b26"/></dir><file name="Edit.php" hash="84137babee7bfaf5d74ec8d1abe7bc94"/><file name="Grid.php" hash="2af86b670dfa0daafa87c68549248c42"/></dir><file name="Block.php" hash="ba75e154ab0dacea1a496f5dddff3ee5"/><file name="Buttons.php" hash="cc95103c467e1690fa1a3af947d41934"/><file name="Editroles.php" hash="7000bd2a967324d4d8f59d9fba69e994"/><file name="Edituser.php" hash="37fd49b06155831e001aa72616c59334"/><dir name="Grid"><file name="Role.php" hash="e664e65f34a4a2388646dbc1593f2459"/><file name="User.php" hash="ff6e1722cf7d2dfabbc81714030e0900"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="d4c1d8bd47dcef72be788628e4691b75"/></dir></dir><file name="Role.php" hash="af24afd4eb11f6285219e4b0f49ea70d"/><file name="Roles.php" hash="97918d7e78298f17f35d7443d5bd0397"/><dir name="Tab"><file name="Roleinfo.php" hash="d3d1b327c9ee471c97b8c811024df0f5"/><file name="Rolesedit.php" hash="94acaaef7675950120a511958a16e3fe"/><file name="Rolesusers.php" hash="1162dcc0461c5d27aa79632950888a48"/><file name="Useredit.php" hash="d299e6842fe7c46578c54e0987c79429"/><file name="Userroles.php" hash="99621d6b7b827435b75ebdd609b9b558"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e56981d6fca4121ddc406e8c4888191d"/><dir name="Tab"><file name="Main.php" hash="14a3fc3b16f5834c34840ec6af6fe852"/><file name="Roles.php" hash="39263f8d830d709a68c1d3ddb3c5023c"/></dir><file name="Tabs.php" hash="dec4daa38e5951c969353b03f2d651e6"/></dir><file name="Edit.php" hash="bb570d5036d34531b46fd29c813f9234"/><file name="Grid.php" hash="66f37feace5315656052e355cf1030d7"/></dir><file name="User.php" hash="e566d45d3baba405d9c8d464c0face4c"/><file name="Usernroles.php" hash="5db4ffc12fef23f814dd5402e74e738f"/><file name="Users.php" hash="ee78f2adc119a2fc2ffe8a89ceebd57b"/><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="c386f51bfb9ce0bd67f6f85750bca473"/></dir><file name="Edit.php" hash="9cebf0be6ab18ef6682bae2c95ec316f"/><file name="Grid.php" hash="6768cd076848b08656653fac8c9304dc"/></dir><file name="Variable.php" hash="854436ed296fa61143eaad2012e00be2"/></dir><dir name="Poll"><dir name="Answer"><dir name="Edit"><file name="Form.php" hash="d1d567516ad5d195f58118d74a3c9485"/></dir><file name="Edit.php" hash="ea60da414febac398ad8a5f7e960a4d4"/></dir><dir name="Edit"><file name="Form.php" hash="f49681920874b6306db0b84bcddf29fb"/><dir name="Tab"><dir name="Answers"><file name="Form.php" hash="e4352cb54881242eeb76e16d3d0d57bf"/><file name="Grid.php" hash="72fe16bf15a5afba06165e359dafb80e"/><file name="List.php" hash="2689aa93a8757a2c622930cc30578fe6"/></dir><file name="Answers.php" hash="16b63468731527503a41202fa1210462"/><file name="Form.php" hash="fb78e237210fc3aaacafa7a260e08aaf"/></dir><file name="Tabs.php" hash="5d78bfe8c000e5dc45436bafa25d3006"/></dir><file name="Edit.php" hash="cf70265c9750388d2cdd235c5a92696a"/><file name="Grid.php" hash="37e4d5a930b9f642f3b5a98edcd667cd"/><file name="Poll.php" hash="438e44affda9859ccc07067d873e6640"/></dir><dir name="Promo"><dir name="Catalog"><dir name="Edit"><file name="Form.php" hash="8a71206ef66c7370119b4f2b348edabe"/><file name="Js.php" hash="0489e9289d574d351faf222342f3e5c2"/><dir name="Tab"><file name="Actions.php" hash="756556f16aae2e7d5099dd9ac0d6c3d9"/><file name="Conditions.php" hash="9fc57c4ed418a0cec1bd2006983d57bf"/><file name="Main.php" hash="068a51f801b94b4fdd7f2352f838c2ef"/></dir><file name="Tabs.php" hash="98c91073906792a0c6296fb83a7ab330"/></dir><file name="Edit.php" hash="99dbb202deb0b9f05801a63e42d31b0d"/><file name="Grid.php" hash="22be7c2ac5741cbe5d060c89cfd39f49"/></dir><file name="Catalog.php" hash="1ae39c43c5f75785edf1c5324a4290fc"/><dir name="Quote"><dir name="Edit"><file name="Form.php" hash="4a8463187cb19e25ea975cc2ed11d664"/><dir name="Tab"><file name="Actions.php" hash="ed58616f357944eb2f73a28f7efc1e39"/><file name="Conditions.php" hash="7febefb8d3f16e24e2bd3fa260135955"/><dir name="Coupons"><file name="Form.php" hash="d98e35ad0a8920bfbd3ef6c71978859f"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Used.php" hash="226bef3f5347cf5f87223f15602fcb58"/></dir></dir></dir><file name="Grid.php" hash="b8f3bb64730a0ad22621d4de28e4934a"/></dir><file name="Coupons.php" hash="6b15976a6d1f15012490237346d6057f"/><file name="Labels.php" hash="0374ba4e22cb6afe418cd0a2a85020cc"/><dir name="Main"><dir name="Renderer"><file name="Checkbox.php" hash="18855aea907c954a5475117a205635ea"/></dir></dir><file name="Main.php" hash="2bdacfbe90630bdd2ee8f23a66b64dd3"/></dir><file name="Tabs.php" hash="1bd68564db436b417f488bac6e097758"/></dir><file name="Edit.php" hash="8ce5af06e914dae03f0886ea05866af2"/><file name="Grid.php" hash="2a5f9302cce1fb40f796cc592299a524"/></dir><file name="Quote.php" hash="13e7c6d67080c994fb2a1cc59404406c"/><dir name="Widget"><dir name="Chooser"><file name="Daterange.php" hash="70bf48e3059b5118e63343e17948229d"/><file name="Sku.php" hash="2f0b0875caa8efd274aa26efa2334fe8"/></dir><file name="Chooser.php" hash="7db7b478b3c1b1595c483b4268aecdc4"/></dir></dir><dir name="Rating"><dir name="Edit"><file name="Form.php" hash="e21a9307f72c2026b066d7557ce9c57f"/><dir name="Tab"><file name="Form.php" hash="d7d970cc0d7d9dd10d7a03e808a8aed4"/><file name="Options.php" hash="106e1377ecef0876c9bd2542335c6435"/></dir><file name="Tabs.php" hash="f9210a4da76b60fc6446f5cb7addccad"/></dir><file name="Edit.php" hash="c72a2464231e82c381f94454562eebbc"/><file name="Grid.php" hash="eb80f7c545a4a0071addfe7f015da33c"/><file name="Rating.php" hash="39bb6e11d3bae43bfb4d35169ee4e41b"/></dir><dir name="Report"><dir name="Config"><dir name="Form"><dir name="Field"><file name="MtdStart.php" hash="a924ee763c18e3ed80b87d748f282cb2"/><file name="YtdStart.php" hash="cdb5ef1ce2da5813d13fe8f72a7079f7"/></dir></dir></dir><dir name="Customer"><dir name="Accounts"><file name="Grid.php" hash="125f58e5a98c21f5c7f41af2f18e1ba5"/></dir><file name="Accounts.php" hash="ba03c8be6d24be78a3348205d7b1c59b"/><dir name="Orders"><file name="Grid.php" hash="3b6c90bf0a2d500f55c37c463476e022"/></dir><file name="Orders.php" hash="b2bcb3c005b9d3b5e79640eb56b3085c"/><dir name="Totals"><file name="Grid.php" hash="53a10e918398bb631825e0834fffcfd8"/></dir><file name="Totals.php" hash="d6922f6143aeb8edc9b420afed078929"/></dir><dir name="Filter"><file name="Form.php" hash="d5b993228db6ed19ef0db663fe9e7815"/></dir><dir name="Grid"><file name="Abstract.php" hash="33f0615bff06d6080788293420ae1e03"/><dir name="Column"><dir name="Renderer"><file name="Blanknumber.php" hash="264f57bbe36d99209dbe4a459c860c9a"/><file name="Currency.php" hash="e6f4db3f02df326305086b0fb4a0af56"/><file name="Customer.php" hash="9347c243bfbe02bbf19b86e1eec157e6"/><file name="Product.php" hash="f9addb0013529e496f972c221f32ad40"/></dir></dir><file name="Shopcart.php" hash="897da04c70099203dc40de8f5c75706c"/></dir><file name="Grid.php" hash="7f61478562abc700c6e845e3a5f6dd63"/><dir name="Product"><dir name="Downloads"><file name="Grid.php" hash="09b580cf3a9b12333b637671c3d6a977"/><dir name="Renderer"><file name="Purchases.php" hash="31ebc48790ea8d1796aff7a0a26a98b0"/></dir></dir><file name="Downloads.php" hash="2601b484b6ec5f115f2c134b3ed56c6c"/><file name="Grid.php" hash="9739764d528da1173b74476aeaa90343"/><dir name="Lowstock"><file name="Grid.php" hash="d0cc3ec79ae288d3480dfeeb49396c0d"/></dir><file name="Lowstock.php" hash="606e6f1affec1d43c4a2d2169a0c2219"/><dir name="Ordered"><file name="Grid.php" hash="654181d62c7cc2623e3f97ab10e86d26"/></dir><file name="Ordered.php" hash="a16dad58467e0e2226a414dbfc4c00b0"/><dir name="Sold"><file name="Grid.php" hash="1966a5e024bca07b470fbd397c872be3"/></dir><file name="Sold.php" hash="7a6e7b04579774dadc2be4047b3ae258"/><dir name="Viewed"><file name="Grid.php" hash="b1d1e9daae03ff525976ef8bc1241688"/></dir><file name="Viewed.php" hash="44359a7eb23f239951867a192ffb73a6"/></dir><file name="Product.php" hash="b12b9b84f824c934beb2aa12f65047e3"/><dir name="Refresh"><dir name="Statistics"><file name="Grid.php" hash="464179727ceb08e438e264b02ab15883"/></dir><file name="Statistics.php" hash="c481a493b5a1bcacfc6667e1e3375ae5"/></dir><dir name="Review"><dir name="Customer"><file name="Grid.php" hash="eaeb6261c45a8a129afc019a40571971"/></dir><file name="Customer.php" hash="df0464f31e9650434fbe505d2b5d6fc6"/><dir name="Detail"><file name="Grid.php" hash="48a704b1a6307f9997d1c401e071a188"/></dir><file name="Detail.php" hash="e92d6d12ad04061df9a012d4d2427b6e"/><dir name="Product"><file name="Grid.php" hash="49466f8a9c3731ea13ae75b354da2388"/></dir><file name="Product.php" hash="36570e05c5e34a57de894ae2ce35157f"/></dir><dir name="Sales"><dir name="Bestsellers"><file name="Grid.php" hash="29dbb485598a8d96cbdfb9876d189443"/></dir><file name="Bestsellers.php" hash="dece62b23890be79025bce175a8873ad"/><dir name="Coupons"><file name="Grid.php" hash="2aa7f3681c09b4d48f3d9d17d71f5a99"/></dir><file name="Coupons.php" hash="231ae689b8b1369b863751203f5f6e56"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Date.php" hash="57689030e9f44bd0253341acc821f4e4"/></dir></dir></dir><dir name="Invoiced"><file name="Grid.php" hash="490362b3d8b9474ded06a9af9176222c"/></dir><file name="Invoiced.php" hash="cad6ff9f84bd43374ca9b1f47fa5265c"/><dir name="Refunded"><file name="Grid.php" hash="104056775346b260c39b570e2c29c77b"/></dir><file name="Refunded.php" hash="53cf2c3212b5414a8448e53d327d739b"/><dir name="Sales"><file name="Grid.php" hash="1771f104565bc2a606cbcf662b5a6f95"/></dir><file name="Sales.php" hash="b564b60052182d9d7989c810250c1525"/><dir name="Shipping"><file name="Grid.php" hash="179ac71bc9e787df09c2d697d844fd50"/></dir><file name="Shipping.php" hash="c7650cc6c9ad2e168856e6bdbfd60d31"/><dir name="Tax"><file name="Grid.php" hash="13f4fce239c6834032118bbb95a85746"/></dir><file name="Tax.php" hash="03bb6ddb944a0f6cb818b8cb765ba928"/></dir><dir name="Search"><file name="Grid.php" hash="db8fb084a7392cffb50c8988b255048d"/></dir><file name="Search.php" hash="3d903ea0062a23a38afdb6257277ef69"/><dir name="Shopcart"><dir name="Abandoned"><file name="Grid.php" hash="11bfeff5565ac8391cbe21ad8dbc634e"/></dir><file name="Abandoned.php" hash="6c275144d3c233203b915836a99b9256"/><dir name="Customer"><file name="Grid.php" hash="33f38ff6795ca48a865be1ba8c1b626b"/></dir><file name="Customer.php" hash="46176721eeaf6b1d13cbd2ee4aac9c32"/><dir name="Product"><file name="Grid.php" hash="9863a30d2c53906b3a650bc4944fb60d"/></dir><file name="Product.php" hash="8db7478a73364dbe0f6b743eb796eeb4"/></dir><dir name="Tag"><dir name="Customer"><dir name="Detail"><file name="Grid.php" hash="e7ae098944aaede6d0e634ec58d7b1ba"/></dir><file name="Detail.php" hash="6c1d2a0744e3c1e47bd0d0b4e7f94896"/><file name="Grid.php" hash="38856f03efc67f4a26af2172a1af3a0a"/></dir><file name="Customer.php" hash="46ff79f5e4a9f582bce155b0f7b8ae1f"/><dir name="Popular"><dir name="Detail"><file name="Grid.php" hash="b03fc43b10d29d5a398b73cd1c2dbea3"/></dir><file name="Detail.php" hash="27d0cbb728aac205394a42c1ab85c5c4"/><file name="Grid.php" hash="d18cf3969a7adad625b60b28941a7270"/></dir><file name="Popular.php" hash="bb4e3f5e49419d3c8eda46df6aaa4f70"/><dir name="Product"><dir name="Detail"><file name="Grid.php" hash="b1450dab9226d4a9b2e84c1ce6cf6e5c"/></dir><file name="Detail.php" hash="5e836c4da0c50d12e616d5b6a129acea"/><file name="Grid.php" hash="ab880e5c3a6cc0b4e3efb3933e42b1c1"/></dir><file name="Product.php" hash="622c74aba260ccb80b7cd0466b254740"/></dir><dir name="Wishlist"><file name="Grid.php" hash="30c6507df24b9530e52d9abf2d72db92"/></dir><file name="Wishlist.php" hash="29c55462d5a7ba74bf944920ba32b88e"/></dir><dir name="Review"><dir name="Add"><file name="Form.php" hash="afaad3889588d19e78c5358ca31053bf"/></dir><file name="Add.php" hash="bed0d84fbce29827765e870bff16db74"/><dir name="Edit"><file name="Form.php" hash="d94544827780e99378670555538e6b12"/></dir><file name="Edit.php" hash="5131aae643eb8061ce598c127cff9fa4"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="7768070f8509625a9a2cc0178fbb42a2"/></dir><dir name="Renderer"><file name="Type.php" hash="a5871202c5a258f69c23fd938d840062"/></dir></dir><file name="Grid.php" hash="973b7c8444c20e7c6cd2fb3b5bee8320"/><file name="Main.php" hash="486e69de5935dc1233cb6272437d90cd"/><dir name="Product"><file name="Grid.php" hash="045dbe8bfe4482d83b8a1d41622908bd"/></dir><dir name="Rating"><file name="Detailed.php" hash="086e949db4cb03112b61ef64fa4f7c28"/><file name="Summary.php" hash="bed407f557d7f647e62f53a0afd67f0e"/></dir></dir><dir name="Sales"><dir name="Creditmemo"><file name="Grid.php" hash="9cc7ca73c39a2eb2f9ccd663443d9a11"/></dir><file name="Creditmemo.php" hash="7077674f1b98929a1746a2e0a2205c36"/><dir name="Invoice"><file name="Grid.php" hash="d71c2db826d77e3cb9fd025e39d0a97c"/></dir><file name="Invoice.php" hash="6433788709a2896617beba8246c69024"/><dir name="Items"><file name="Abstract.php" hash="d250e9f03e6ba5df3f5575ac3d669c86"/><dir name="Column"><file name="Default.php" hash="e59a6699310b93569c5769e59c448e8d"/><dir name="Name"><file name="Grouped.php" hash="73fabc3f2ef4e076b7a44da3ec74232e"/></dir><file name="Name.php" hash="93365a10779ab90b16cb70aa7cb76f77"/><file name="Qty.php" hash="fd55983a3475987721b675907117e114"/></dir><dir name="Renderer"><file name="Configurable.php" hash="4f21e2b3302da7ae358538833d511241"/><file name="Default.php" hash="e2538c0044a3f905ecc11060a8e4c4d1"/></dir></dir><dir name="Order"><file name="Abstract.php" hash="45739bf1bea027fe45a88d5fb74bc1c4"/><dir name="Address"><file name="Form.php" hash="82c5e9cea0dc8b5c9f975751dba3202a"/></dir><file name="Address.php" hash="5223e26b8bf7b30acdaedddf211eea56"/><dir name="Comments"><file name="View.php" hash="039130ef6c6a23a631f4d96029671e90"/></dir><dir name="Create"><file name="Abstract.php" hash="ec59e0b6e9acd1a548555f9c6799ef6f"/><dir name="Billing"><file name="Address.php" hash="0df1e25bb08dad32e2bfb8a0f9a167ad"/><dir name="Method"><file name="Form.php" hash="a2bb4ecb917e3a761412193d5b742c6f"/></dir><file name="Method.php" hash="199760457b7473e0467d8c214ed11dae"/></dir><file name="Comment.php" hash="6e5f5722608c3338627724fdb4586632"/><dir name="Coupons"><file name="Form.php" hash="69d16bbe72563d8521e6e5c43abd3917"/></dir><file name="Coupons.php" hash="c01e37e722548e4a1a7ea157d71d48b8"/><dir name="Customer"><file name="Grid.php" hash="42df68f6d1fa8156711d8cf3b7cb2987"/></dir><file name="Customer.php" hash="b1cdeeee9cd91ac572963f0290230054"/><file name="Data.php" hash="a53aa485b2e4608e5523efbac2ba510e"/><dir name="Form"><file name="Abstract.php" hash="8342b7df4b622a5c5109ca720be19e76"/><file name="Account.php" hash="bf0f8022c18fec7c2ff2f0467cdbb2bd"/><file name="Address.php" hash="2652debcdd91d9a68eb12f3d14953146"/></dir><file name="Form.php" hash="37cce5735e6474c8f7a318cfea2bcb85"/><dir name="Giftmessage"><file name="Form.php" hash="e6ff0f1c7094056a3659b2fb34f2f6f4"/></dir><file name="Giftmessage.php" hash="5e4419f5ecb48733015043167176cccd"/><file name="Header.php" hash="94f8aede089e59bc3cfcc9383e83cc94"/><dir name="Items"><file name="Grid.php" hash="c59b6769d698d9dc758a1d3fbf8b1480"/></dir><file name="Items.php" hash="d70ba8b7eaa08b74fdf180a19066d542"/><file name="Load.php" hash="edeee2ea6deb6fc3751088d80e5dec6d"/><file name="Messages.php" hash="52bfb9f025f9d872f4eb33366957fc6d"/><dir name="Newsletter"><file name="Form.php" hash="c690ca5f1dd244de31d6b72232f9eea6"/></dir><file name="Newsletter.php" hash="8b2bee63e50417114d5dbce7fc71cd6c"/><dir name="Search"><dir name="Grid"><dir name="Renderer"><file name="Giftmessage.php" hash="04e63b8afe6cbd37db3129f4e8c699ab"/><file name="Price.php" hash="5281d1c8a312ca741d58d14fbe3deced"/><file name="Product.php" hash="0b76bf90a8f2d5cdbd4b18fb16b2eaeb"/><file name="Qty.php" hash="54cee680adfc48caf551e4a8cb2fdec0"/></dir></dir><file name="Grid.php" hash="fa13dba8c6b9700b46f29aede759923d"/></dir><file name="Search.php" hash="fa316633bbf0f02bb4d2baa6468b67c5"/><dir name="Shipping"><file name="Address.php" hash="644215db3b8a9085255f789305f5381a"/><dir name="Method"><file name="Form.php" hash="08be11adb3b48c77c52a4df4e5e66a26"/></dir><file name="Method.php" hash="61ea096b05b007410b26237b5dac302c"/></dir><dir name="Sidebar"><file name="Abstract.php" hash="f5b8c9e2b61f4f0efea22f739a196d88"/><file name="Cart.php" hash="c784182a9c3558519fd56a968a19deb6"/><file name="Compared.php" hash="b844720f38bb949d43a32dc773b15da7"/><file name="Pcompared.php" hash="8ebcbb054c9f682c0c2e10d206ad94bf"/><file name="Pviewed.php" hash="bbc071c18335ae066a5aefab212a07d4"/><file name="Reorder.php" hash="e09f2c7ee365800730e50e8d95cd6cb3"/><file name="Viewed.php" hash="8e2b366150e6802afdec9685d65ff409"/><file name="Wishlist.php" hash="daf7e737f3141d392d83e387a3ad6fd5"/></dir><file name="Sidebar.php" hash="5aadf67f34a30f866cc04cb8ef00f1ab"/><dir name="Store"><file name="Select.php" hash="58494c02e8b891e02250cebcdd60362c"/></dir><file name="Store.php" hash="52ed6a59d9094d816a28ab1e01352588"/><dir name="Totals"><file name="Default.php" hash="87c47abc5ae14e81b6e51726085b790c"/><file name="Discount.php" hash="333db7abe6b23ea11f6a4babad105817"/><file name="Grandtotal.php" hash="bf2e0c7eeecf93046d19881d27eb626d"/><file name="Shipping.php" hash="644e308ae7d0d73ab849225dfcdc2cd3"/><file name="Subtotal.php" hash="629e99987933be9751e043fc485a420e"/><file name="Table.php" hash="06c746d4bf94f0d9b2a102da6548b6ae"/><file name="Tax.php" hash="4e92963bcb4172c5877542c7e061da98"/></dir><file name="Totals.php" hash="95ef4744840cb78571bfe7e4f8dd397c"/></dir><file name="Create.php" hash="e8b2a62d41a7968f5b25ddce7d9b45cf"/><dir name="Creditmemo"><dir name="Create"><file name="Adjustments.php" hash="32d1fe6ba59c5490be8f8cf1a4292616"/><file name="Form.php" hash="761e40421c230555e96f10159985fb83"/><file name="Items.php" hash="71e02814cd463899e34002ca04774338"/></dir><file name="Create.php" hash="bc2bf938b2dde5b09bd71cd8192a04e1"/><file name="Totals.php" hash="88425527934940def2f62e07c8376174"/><dir name="View"><file name="Comments.php" hash="02a18178e6ce9a20b8220531b602fe86"/><file name="Form.php" hash="369deccfac5176136831e3a4c2c8f386"/><file name="Items.php" hash="ffe3820202c8615cc98e6b10f966d93d"/></dir><file name="View.php" hash="e7a412b2d713bf9da23f38c9eacdfd18"/></dir><file name="Grid.php" hash="2c4ae6a5eb2199ddba27c56cc74bd141"/><dir name="Invoice"><dir name="Create"><file name="Form.php" hash="0bb4ca3c8652753a67265fa508e024ae"/><file name="Items.php" hash="b331e20e32951de332b145322da16c6a"/><file name="Tracking.php" hash="176fce657283fe3ab46a978880f37e4e"/></dir><file name="Create.php" hash="d8f4edc6611556d11bec056520979148"/><file name="Totals.php" hash="89ea1b4adccd1527742ef3a635f3e768"/><dir name="View"><file name="Comments.php" hash="231315629330662ac0d4ecfc4b94b956"/><file name="Form.php" hash="fae7a3587b2e65750b78453c202eba62"/><file name="Items.php" hash="e4b7bf50b026c03e5bc6077a41b73ec0"/></dir><file name="View.php" hash="e11d21463b5a54d766bd7156c4b77300"/></dir><file name="Payment.php" hash="bf73b8efb03db49e7981917f58e1999e"/><dir name="Shipment"><dir name="Create"><file name="Form.php" hash="19d7ab1eab9a39680ebb0babc4f889f1"/><file name="Items.php" hash="4d7604a86a11dc60212460a91860eb35"/><file name="Tracking.php" hash="e15d81cff93fad63f6fe9dc4b0936872"/></dir><file name="Create.php" hash="e1eaf308de67d85cebde2bcdfac55ee4"/><dir name="Packaging"><file name="Grid.php" hash="708e82d58d7de322ab128c79d690810c"/></dir><file name="Packaging.php" hash="95b1a24a1177c96a0ba0a3994e07f7f4"/><dir name="Tracking"><file name="Info.php" hash="1e9e750fbc5b8dc0eda1300a4fb943ce"/></dir><dir name="View"><file name="Comments.php" hash="3ded55f91490c01aa222a64eb40a9515"/><file name="Form.php" hash="4434a74139f4cb9845feee89840c58f5"/><file name="Items.php" hash="ecff7af6d51846f9be730666df5144fb"/><file name="Tracking.php" hash="d7eb5eb9ccd5fa455e7e734a57956fcc"/></dir><file name="View.php" hash="ece7ff35488a5ef159d67579270f7ec2"/></dir><dir name="Status"><dir name="Assign"><file name="Form.php" hash="9b4e30d3fc1a42c7a6792f22a769852c"/></dir><file name="Assign.php" hash="348bf62626f5a27a803bcca48f20be2d"/><dir name="Edit"><file name="Form.php" hash="17fce0de94d4ad003b94e7c201b46427"/></dir><file name="Edit.php" hash="02492e82607134bf42f0e07a4ee4920d"/><file name="Grid.php" hash="52d5bfd055d4c8fefe78840014442d4a"/><dir name="New"><file name="Form.php" hash="aafe74d46855d19aec5938d4f1391a11"/></dir><file name="New.php" hash="f7256daa0364107d4fab1ac3608138c7"/></dir><file name="Status.php" hash="a9678b586a0e1c0ab78e8c253badf901"/><file name="Totalbar.php" hash="942e16a2630b93ae9d9bf4108896cb84"/><dir name="Totals"><file name="Item.php" hash="b96cedf974257076ea4de13f1ad555e3"/><file name="Tax.php" hash="45e0955cd679c47e17df955dbc9f3145"/></dir><file name="Totals.php" hash="3e21f4a401e6db9a90886f3198b33858"/><dir name="View"><file name="Form.php" hash="0de281fce53e6ce5b974c4750e487a06"/><file name="Giftmessage.php" hash="d72e07778f70449e525bc42cee5b5d1b"/><file name="History.php" hash="5a08d199d187a98156f1510c6a0fb209"/><file name="Info.php" hash="9211aaa0e8640093595a8df1ec7c6a9a"/><dir name="Items"><dir name="Renderer"><file name="Default.php" hash="e27e98952b037349c5ed44bb5d128cff"/></dir></dir><file name="Items.php" hash="b3956ac7700aa0db02a50506f944aabd"/><file name="Messages.php" hash="84d48df928eb3207d26d3d5b48ce4897"/><dir name="Tab"><file name="Creditmemos.php" hash="06b931ce1dfd688af78e108a890a51ef"/><file name="History.php" hash="9e94bfc713c545507825a9de373d367e"/><file name="Info.php" hash="10390772fe22959257922236601cb23d"/><file name="Invoices.php" hash="62d3958b62be9d3143d9955fca3775a7"/><file name="Shipments.php" hash="783fc711e7aa66954429dd618d893c8b"/><file name="Transactions.php" hash="24aec6ab4d074a51f832fe7c3306ceab"/></dir><file name="Tabs.php" hash="5a80c1873ef2d212436e79ba3365fcba"/></dir><file name="View.php" hash="13eb259102e63ccd15e577449c166579"/></dir><file name="Order.php" hash="867a3d05a32de0ff1951a61495263663"/><dir name="Reorder"><dir name="Renderer"><file name="Action.php" hash="4ade6495da0d4c7861d76d0feebf0754"/></dir></dir><dir name="Shipment"><file name="Grid.php" hash="9a56f8e66e9702d613efb45d82e25f84"/></dir><file name="Shipment.php" hash="2e4802c132a7b74b7624b5d8eca65852"/><file name="Totals.php" hash="af26a6ae487a2c19212f27dcc203d754"/><dir name="Transactions"><dir name="Child"><file name="Grid.php" hash="422f95a665f1402a96df6dd41e48c625"/></dir><dir name="Detail"><file name="Grid.php" hash="ac07bd664ec30c7cd9cc776dd91df9a7"/></dir><file name="Detail.php" hash="466d909abf726e521ebf4a26ea30634d"/><file name="Grid.php" hash="d1b68ce93f6c0d26982ec6af6b40b722"/></dir><file name="Transactions.php" hash="759dc094205d6f50e306ee8895a8e1c1"/></dir><file name="Sales.php" hash="85e41bd256030dc381bf41937229b2c8"/><dir name="Shipping"><dir name="Carrier"><dir name="Tablerate"><file name="Grid.php" hash="215ad38165d867ae249379a4aa14df0f"/></dir></dir></dir><dir name="Sitemap"><dir name="Edit"><file name="Form.php" hash="9298d64b4d901d31349e814185114c17"/></dir><file name="Edit.php" hash="f32576c26bbe22bcdcb0d0e906b501d2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="049bafed18d2a6fc243f321e2e5f910b"/><file name="Link.php" hash="860fc688a2e32b4748995803ac626e2e"/><file name="Time.php" hash="8f7abc65d6b76ab7afe860ab973f0f1b"/></dir></dir><file name="Grid.php" hash="7fcaa769f080c3af1a7ac6ba05acf035"/></dir><file name="Sitemap.php" hash="0eb9104cbb4a1083a08c2f80e06a3655"/><dir name="Store"><dir name="Switcher"><dir name="Form"><dir name="Renderer"><dir name="Fieldset"><file name="Element.php" hash="178f45f348a82528daa1512ad6398914"/></dir><file name="Fieldset.php" hash="4da413d2e88f9e9327a8f9f3d49c5206"/></dir></dir></dir><file name="Switcher.php" hash="abdfb8b0b9d50e1d26bf670c7cc52d04"/></dir><dir name="System"><dir name="Account"><dir name="Edit"><file name="Form.php" hash="724d0ef86dc2c8c6162211a9ab014898"/></dir><file name="Edit.php" hash="1c0133fdd5deb83b037f59e5e81d147b"/></dir><dir name="Cache"><file name="Edit.php" hash="c460241a6e8b297afdd79869b00ff3ed"/><file name="Form.php" hash="9e04a6ffa820d5226c59fa5b18c20711"/></dir><dir name="Config"><file name="Dwstree.php" hash="9dc81b84d226f9488df3191857731a63"/><file name="Edit.php" hash="62a74fc635fbbc827eca2a4fea3f063b"/><dir name="Form"><dir name="Field"><dir name="Array"><file name="Abstract.php" hash="2d7e1f8baf6b40cf99eabee0bf6ee026"/></dir><file name="Datetime.php" hash="9dcfda6124cf0f25dba073b32826b610"/><file name="Export.php" hash="608bf1d1cfd31f10ebf78da291884ac5"/><file name="File.php" hash="3e31f49c77e40d674ca3f3db948c93c6"/><file name="Heading.php" hash="1cf79e6c2edd686b11be095bd5d4268f"/><file name="Image.php" hash="fe9ffa0ad2172d26a9684dcc7cb00a4a"/><file name="Import.php" hash="d291487bc5eb16f732f5e41884b498d4"/><file name="Notification.php" hash="062c73fd8066aff6b5f9650f97a71fa9"/><file name="Regexceptions.php" hash="4373b8ee96f0cc0d7a7dcfcf228b6b49"/><dir name="Select"><file name="Allowspecific.php" hash="0ef107ae4c63c0e016908359bf69a0f9"/><file name="Flatcatalog.php" hash="a246011eedf68f0cd42bbc73c71de0c2"/><file name="Flatproduct.php" hash="4f3784430bd835136e33988cc4bc3a84"/></dir></dir><file name="Field.php" hash="4f8d09202ed37588f4cf00923e14dfc2"/><dir name="Fieldset"><dir name="Modules"><file name="DisableOutput.php" hash="e302059fa3248cc48e520b4cc1554799"/></dir><dir name="Order"><file name="Statuses.php" hash="39de6497e1e23218883690ebc1c211d6"/></dir></dir><file name="Fieldset.php" hash="cc88cdd430c4a2d1036797f53d001adf"/></dir><file name="Form.php" hash="a4a4dfcbdf301c3c580e177713a7717e"/><file name="Switcher.php" hash="47be4380f93f25f25c08f7a9489c4a53"/><dir name="System"><dir name="Storage"><dir name="Media"><file name="Synchronize.php" hash="3ba97d2aeae4e2b987533a688769ba3f"/></dir></dir></dir><file name="Tabs.php" hash="7a76ed4c223c359a3a6a08c33d0d2650"/></dir><dir name="Convert"><dir name="Gui"><dir name="Edit"><file name="Form.php" hash="34a1d852071e8a668f9a918233934ef5"/><dir name="Tab"><file name="Upload.php" hash="066c77626c21cd66040bdbf6b7166f65"/><file name="View.php" hash="69b9e0b0604d36be0f2c5813252a3c58"/><file name="Wizard.php" hash="238c81cd7d8005aa5880d9a19d4e4db7"/></dir><file name="Tabs.php" hash="6522c80d035883c2281e1e909369f2c3"/></dir><file name="Edit.php" hash="d19f3f451824a9cc61ad4ce2f43e363f"/><file name="Grid.php" hash="d9b48baef0ed72de626ac7f436200047"/></dir><file name="Gui.php" hash="4350827a669efe856906d9ab68b6e385"/><dir name="Profile"><dir name="Edit"><dir name="Filter"><file name="Action.php" hash="bde22deee315064248611ed6b2ad16ab"/></dir><file name="Form.php" hash="4a2e8ed06a8d59c0c2100d0ed7c53a63"/><dir name="Renderer"><file name="Action.php" hash="8c9b0e1db555843b1c83a492c3abd778"/></dir><dir name="Tab"><file name="Edit.php" hash="69cd410e98c0786054a0b79e8b7ce271"/><file name="History.php" hash="2c5916e829b695ef6a70de18b00cbd4e"/><file name="Run.php" hash="931a4d60bf3a8617e7ffa6897ca4433e"/></dir><file name="Tabs.php" hash="73fd658cee413fc7188d164621bdd0a2"/></dir><file name="Edit.php" hash="b36ff98cebc8065a3adc2761061b47e2"/><file name="Grid.php" hash="9398722801c514cfc9dce17de92da075"/><file name="Run.php" hash="69c6338a4f4c3a0798c4c8aa4e3b579a"/></dir><file name="Profile.php" hash="3e3d88171cb6bd5f5e65de243f7ca0bc"/></dir><dir name="Currency"><dir name="Edit"><file name="Form.php" hash="2aa4d9904e2605aef4518e673543c2d5"/><dir name="Tab"><file name="Main.php" hash="25aaab5e589d6188c1b5c518e83a1e8e"/><file name="Rates.php" hash="a00b269f40e627cfce099601de20a91f"/></dir><file name="Tabs.php" hash="5e83f641504801a639f8328b03e13b3a"/></dir><dir name="Rate"><file name="Matrix.php" hash="57b842fd652808ba57af02beba73eed9"/><file name="Services.php" hash="d627271f20ed93d2b8e21ed3f92da34e"/></dir></dir><file name="Currency.php" hash="e8c5e50cfd955cae70566f634e73955f"/><dir name="Design"><dir name="Edit"><dir name="Tab"><file name="General.php" hash="d9401ff15ad83db694e9a675a8b79930"/></dir><file name="Tabs.php" hash="ca472f52eeed68ee4cfc7c2e11fe40ba"/></dir><file name="Edit.php" hash="cb2793aae1f1928305a810504025ac25"/><file name="Grid.php" hash="ecb9e5c60a2662eb67072da076b9f8e7"/></dir><file name="Design.php" hash="8d2e0a9860c04659ac9bb5b00a8d36e4"/><dir name="Email"><dir name="Template"><dir name="Edit"><file name="Form.php" hash="4047d7b28bb1012fe744352cff61e5f1"/></dir><file name="Edit.php" hash="d41764fc3f30dc19e94b3fac784ea5a5"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="3a65e0cb2c719ce6cdcbffe7a8d39f0f"/></dir><dir name="Renderer"><file name="Action.php" hash="57385d1912ed259f426016c3c672efb2"/><file name="Sender.php" hash="a66f1b1e1640834752075fa9a25bfaa5"/><file name="Type.php" hash="149b001b475f99f68a8adb4121ad1a0f"/></dir></dir><file name="Grid.php" hash="299c926a54231aca1fda3218a57b98f1"/><file name="Preview.php" hash="838ca945ed5df147d2d95cb65f638057"/></dir><file name="Template.php" hash="070f119a1cf4cec9086dbf3622884659"/></dir><dir name="Store"><dir name="Delete"><file name="Form.php" hash="1b12724f41ddc9804df3b1adc6aaf3b4"/><file name="Group.php" hash="a98de1773de879fe1802c191eb3dcb47"/><file name="Website.php" hash="712be69f55e4eb7497d00503f90dfa62"/></dir><file name="Delete.php" hash="950ce6a762483f6a9bc170ebe05c2cee"/><dir name="Edit"><file name="Form.php" hash="ff454cbc44bac6db7fe60cee729a65bb"/></dir><file name="Edit.php" hash="f934328a7507894c6ac16220e4fbaf21"/><dir name="Grid"><dir name="Render"><file name="Group.php" hash="a646b1e1c09442a6cd35b7ade3d1c58b"/><file name="Store.php" hash="af46fe92709138edaa34b7879f706b21"/><file name="Website.php" hash="2d9611dd6962917458dc27f1d0316547"/></dir></dir><file name="Grid.php" hash="aae919b8ddc65ed826860c12ee490818"/><file name="Store.php" hash="b9dce08fb5186579db7c0a2f141ebb0e"/><file name="Tree.php" hash="83f34a90883f0b5564542578827e9573"/></dir><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="afe3ac35fcc2392f59bbf6149edeac43"/></dir><file name="Edit.php" hash="925d823e86aaf0e826634293d7215f00"/><file name="Grid.php" hash="4b7ea75f0c7c529adc1e46d1558bf99c"/></dir><file name="Variable.php" hash="8e26f5d1efad4bae053f03be0f610080"/></dir><dir name="Tag"><dir name="Assigned"><file name="Grid.php" hash="6fa9719638788074f2fe3e6c6f4ecdda"/></dir><dir name="Customer"><file name="Grid.php" hash="a69779f7f5b3fd4b5468a2987f4d5cb5"/></dir><file name="Customer.php" hash="fac677a42c59f5b7c0db6ae3e41a28a5"/><dir name="Edit"><file name="Accordion.php" hash="c09b6c3363882b5f4ca602206e20bdd4"/><file name="Assigned.php" hash="c581c8584f80bce4b4edf844f2d799de"/><file name="Form.php" hash="969c221079de8c9389d192015fc1b363"/></dir><file name="Edit.php" hash="c3c5820f753a002280969f08684adf2c"/><dir name="Grid"><file name="All.php" hash="244719441585726e8832ec01aa28489a"/><file name="Customers.php" hash="024dc8c415e729da49c4c6f7efea6224"/><file name="Pending.php" hash="b31394982859de98ff2286e92c55e5c8"/><file name="Products.php" hash="2bc99ba096bf8c4b2c86e950972a4982"/></dir><file name="Pending.php" hash="f34333f6bd655698aeb7300560c2dfbc"/><dir name="Product"><file name="Grid.php" hash="9f48afaacded433fc2ab57aa44a324ba"/></dir><file name="Product.php" hash="e6662e0fa5c8aef9d635e0bc0335e5ce"/><dir name="Store"><file name="Switcher.php" hash="7ba7c60103ea6392fc3e084bd7f0c356"/></dir><dir name="Tag"><dir name="Edit"><file name="Form.php" hash="c2fd548e26992867848bbeaa57fd025c"/></dir><file name="Edit.php" hash="26d55cbf55b3f3d277211dcfad794b06"/><file name="Grid.php" hash="98b5ca760618f3b79f6c8fdc88ae4e18"/></dir><file name="Tag.php" hash="3d27c57ce9b27289afed85ac471ab0ef"/></dir><file name="Tag.php" hash="5c2b86b81776c7ec3b2330855d2131cf"/><dir name="Tax"><dir name="Class"><dir name="Edit"><file name="Form.php" hash="c73474e1fc6a2fc4c0b9f711a7d184b5"/></dir><file name="Edit.php" hash="114a8bb193e2997625dce40dc511df51"/><file name="Grid.php" hash="4221025a57309a6a5d22fa8182339fc7"/></dir><file name="Class.php" hash="358ecb085cbf35c3bf9b86aab272e649"/><dir name="Rate"><file name="Form.php" hash="735b3fcccc099415edc49f14a9af7930"/><dir name="Grid"><dir name="Renderer"><file name="Country.php" hash="bd524126080e5ad5ed76d9248088bca1"/><file name="Data.php" hash="ffb41b73434fd919d306b80f7401314f"/></dir></dir><file name="Grid.php" hash="bf204ae63b3141dda2c7b94cb23a9671"/><file name="ImportExport.php" hash="a9cb8e94f63288d5a29c0c869d08147e"/><dir name="Title"><file name="Fieldset.php" hash="e72758c8f41e5194766181af24dcd262"/></dir><file name="Title.php" hash="a0cdd4e6d31a66bdabc019a226a20a2e"/><dir name="Toolbar"><file name="Add.php" hash="6aca1ecf71403052514123d02cd4f63c"/><file name="Save.php" hash="d30485a1be9d7a6b98470eac448a21d3"/></dir></dir><dir name="Rule"><dir name="Edit"><file name="Form.php" hash="05f178eb2ea1a3a9f43a16ae80f9055e"/></dir><file name="Edit.php" hash="470b4b4dfe09841c7a1fe4d892b17aa3"/><file name="Grid.php" hash="b30e13cbf1bb1c9fd92b7a285a6422a8"/></dir><file name="Rule.php" hash="28c4e8a83882aafe18d4343de91830be"/></dir><file name="Template.php" hash="65e2a243ea8ccafb068eec480cb8264a"/><dir name="Text"><file name="List.php" hash="5b923aafef84752e8274560dde17b89c"/></dir><dir name="Urlrewrite"><dir name="Category"><file name="Tree.php" hash="bce8f4744813be70932966b5948dd779"/></dir><dir name="Edit"><file name="Form.php" hash="f3c8420dce816fea6c2220933c2176fd"/></dir><file name="Edit.php" hash="0dc9b099d51583d6bb77931db9dee2a5"/><file name="Grid.php" hash="6e12625945f32cd3d3c4cfc34e5e3da0"/><file name="Link.php" hash="0311e1099bc46104d3af6b2ad234f257"/><dir name="Product"><file name="Grid.php" hash="b353f6dffd20c5255b7910e2e9860632"/></dir><file name="Selector.php" hash="abfe917849402fda943214cb238d9f7c"/></dir><file name="Urlrewrite.php" hash="96f5cc86bb6657cb7671fb8d40e8dda8"/><dir name="Widget"><dir name="Accordion"><file name="Item.php" hash="862b7ac1ae6da1ff3396d7eaa6476fc7"/></dir><file name="Accordion.php" hash="2bfd91842c44da9c2d928ee59d99d424"/><file name="Breadcrumbs.php" hash="f2e9c982e431beef24e9531ea282a65b"/><file name="Button.php" hash="e41efda16c0c57798b0c92329e8449bd"/><file name="Container.php" hash="519866b42615db90c75f953abface41d"/><dir name="Form"><file name="Container.php" hash="1e11d0757aa1b79dd549630a39b59196"/><dir name="Element"><file name="Dependence.php" hash="0bd48ed91f763b4cee92b7def6c1e0ec"/><file name="Gallery.php" hash="9bd81ae35f97f0c8865ba4065d727a99"/></dir><file name="Element.php" hash="2de7b0945e2fdab89265ffec97dac5ae"/><dir name="Renderer"><file name="Element.php" hash="1337caa569089562b6fc3fcb84fd30d4"/><dir name="Fieldset"><file name="Element.php" hash="1bdbf1b7b6f9b7f00e7954c5bf62380d"/></dir><file name="Fieldset.php" hash="3c5376aebd05abd599f989f02623203c"/></dir></dir><file name="Form.php" hash="f15c69923ae2f35b3bc98b0243c9cbc1"/><dir name="Grid"><file name="Block.php" hash="b1d3f1e3b1f35b26291a6986dc700756"/><dir name="Column"><dir name="Filter"><file name="Abstract.php" hash="9ec8d38af2e0a97aca97bd840338dbad"/><file name="Checkbox.php" hash="0c8d8bc032276d22d8a23b1cb5cb4ee3"/><file name="Country.php" hash="5c41e9bc49b829817fc6c6e0b3bb1301"/><file name="Date.php" hash="4d432d04c21e356ada833fedb11a8d32"/><file name="Datetime.php" hash="8b4e170ce510dff4672f566a0c6006d8"/><file name="Interface.php" hash="ecb2182f785bab42bce0aab1e9aeffb5"/><file name="Massaction.php" hash="be4a354269953c27b5651307a00b356e"/><file name="Price.php" hash="f7ef1bda31e33231ac8349172a22c885"/><file name="Radio.php" hash="5f60bbeba611df2280756e89e3edaf4d"/><file name="Range.php" hash="e3671131adcae3b8191b0ee12fc4479b"/><file name="Select.php" hash="bf0b958af6c17cf87acce2139594007e"/><file name="Store.php" hash="9e3391cef3d7e6b571ddb0ff1ce31e95"/><file name="Text.php" hash="decc14e17a7efe47df5627d6266d82eb"/><file name="Theme.php" hash="a2c1c6b7e7531ab123a59dbae9edfa82"/></dir><dir name="Renderer"><file name="Abstract.php" hash="2b97d78c9cb1f594c785b7b35297638c"/><file name="Action.php" hash="9af11dec7785235d252a4ed4be6f615d"/><file name="Checkbox.php" hash="c75ff15abb158fc0739592af7ea7422c"/><file name="Concat.php" hash="0c98188f755ed33c3099b0e4a290a22e"/><file name="Country.php" hash="282ed653192f3e0967454a500b1d6c55"/><file name="Currency.php" hash="88f51735c3b03ed176d8f4e9f4fb68f3"/><file name="Date.php" hash="7b36c06c450f56de09a2a0e2e2003080"/><file name="Datetime.php" hash="1b0a1a0a77fe3503dec6bb89846e97fc"/><file name="Input.php" hash="54efcf346dcaefd0421d0fdfb3d35c31"/><file name="Interface.php" hash="064fb4d2541597d669b9d18f2f39cc1d"/><file name="Ip.php" hash="135fceb308bfae5a72e723efba31efdd"/><file name="Longtext.php" hash="512f23de2d3c820889b3d87afda9599f"/><file name="Massaction.php" hash="05fd267920703792920e5346e7ca0fb1"/><file name="Number.php" hash="1bcfc1fa0ce52b58757204c0d119f868"/><file name="Options.php" hash="66ed26d285706fe39a0022294972bf5e"/><file name="Price.php" hash="801e02cf3a66f89c02e9c90b925b81b5"/><file name="Radio.php" hash="762d232eda0a59fd4db6d570ae6a11cb"/><file name="Select.php" hash="3d0acd16d0323ef3d114a7aca647330c"/><file name="Store.php" hash="edada7e10d9635a8592dd76135f0f33c"/><file name="Text.php" hash="f08ff907545ff447f429214a5760ab8b"/><file name="Theme.php" hash="8e2ba7495c4161f44e1899d74b6f9f8a"/><file name="Wrapline.php" hash="3a7edf01eb91fd42305bf256d93531e7"/></dir></dir><file name="Column.php" hash="d04226c35fde4b31769656cdfff8cfe9"/><file name="Container.php" hash="7efc13b32c9d7c9f235c0194b9814f11"/><dir name="Massaction"><file name="Abstract.php" hash="04c79067f07388582101ce565644344b"/><dir name="Item"><dir name="Additional"><file name="Default.php" hash="53e9468b19a71f8e44920a0a0a39ea17"/><file name="Interface.php" hash="0b995f29e3c068cdffbdc93dc4d965e8"/></dir></dir><file name="Item.php" hash="f9da9045c7c77e625ba312d065dedb26"/></dir><file name="Massaction.php" hash="1e4b83485d7f0b556c88a5898c40e516"/><file name="Serializer.php" hash="7e2185abd12832c169fd42e89caade33"/></dir><file name="Grid.php" hash="6ac41f9c52e6fdc3fe7f01037f9aed2e"/><dir name="Tab"><file name="Interface.php" hash="094aaa32090cbcf7865c0641a1e2baa9"/></dir><file name="Tabs.php" hash="c09d2afbbcb4bfd78462723bb6972e6b"/><file name="Tree.php" hash="4ee77de449208f8bb2f1c4ee4656ab90"/><dir name="View"><file name="Container.php" hash="973b7b77e228a28bcff88520a3bbf43e"/></dir></dir><file name="Widget.php" hash="670978a7c059808e49191ad21d42cab6"/></dir><dir name="Controller"><file name="Action.php" hash="ea2630204852617ff41e4e1f948ede68"/><dir name="Report"><file name="Abstract.php" hash="c9dadae96c4f5bb9443167a5e4c0ac58"/></dir><dir name="Rss"><file name="Abstract.php" hash="5b04702be27869ce7af05581c6ac473a"/></dir><dir name="Sales"><file name="Creditmemo.php" hash="9baf9dd1d7003e5919acd7fd8be3c8de"/><file name="Invoice.php" hash="e18f2e1dbf17f766c3aa6a30d1b8b330"/><file name="Shipment.php" hash="4f115f033c90b1f0f05244c87892174d"/></dir></dir><file name="Exception.php" hash="1bf87284314f84a2e9dddbc6aa02d929"/><dir name="Helper"><file name="Addresses.php" hash="94dea4d61e921f74e574a13f35fa526f"/><dir name="Catalog"><dir name="Product"><file name="Composite.php" hash="5ebb5be492e23577a083518cdc4ebbb7"/><dir name="Edit"><dir name="Action"><file name="Attribute.php" hash="8fa9acfe18c721e80c067ff290fb4423"/></dir></dir></dir></dir><file name="Catalog.php" hash="7c43ea78a71e27be4c9e9275930d4c49"/><dir name="Dashboard"><file name="Abstract.php" hash="c2d2e0f8fe77177016afd7195e0c7bfb"/><file name="Data.php" hash="0cd9341123775b408eb2d870cbb6b152"/><file name="Order.php" hash="4ae6c3d63a209d9031aff5e3f69ff01c"/></dir><file name="Data.php" hash="abe5fffa5546a517c1ca60a201ace9c1"/><dir name="Help"><file name="Mapping.php" hash="4c5d3127d193a1f2c37e6d3af9eeb7e7"/></dir><file name="Js.php" hash="72316dae9a20494eb546340cbc838730"/><dir name="Media"><file name="Js.php" hash="94b127033b3975f6063cfb201aaa7210"/></dir><file name="Rss.php" hash="0ec2e6fc3c0f3a36207665a5440493b6"/><file name="Sales.php" hash="3c04f74983d4c7142c781cd89df71d12"/></dir><dir name="Model"><dir name="Config"><file name="Data.php" hash="d687ffbbc02a98cba695382e4894dedc"/></dir><file name="Config.php" hash="5830b87d46656f515b6d3fd6e1ac52c6"/><dir name="Customer"><dir name="Renderer"><file name="Region.php" hash="6b0653f92868441704b4dc8c990707de"/></dir></dir><dir name="Email"><file name="PathValidator.php" hash="28d73ea32531762160b56571a7946d98"/><file name="Template.php" hash="bcf8708d5b38c13fb750bb7f54d92258"/></dir><file name="Extension.php" hash="d38d90a931c22ad4210fc88f9007ea38"/><dir name="Giftmessage"><file name="Save.php" hash="f96d2f3f24b9509f6094417d66843c4f"/></dir><dir name="LayoutUpdate"><file name="Validator.php" hash="511832527843ff905055bd0092295fa6"/></dir><dir name="Newsletter"><dir name="Renderer"><file name="Text.php" hash="5580b8c1af8552494f0a356c58bd38c1"/></dir></dir><file name="Observer.php" hash="2600edcd9b2ed84d8eef48bfe3137f77"/><dir name="Report"><file name="Item.php" hash="89d084e5c5bf665524c2605b6828f2d4"/></dir><dir name="Sales"><dir name="Order"><file name="Create.php" hash="f19d6d9aa7e79dfa8b3a2a8c95649cf4"/><file name="Random.php" hash="fe59bc31d04b4069dae013662a928355"/></dir><file name="Order.php" hash="be50cd145aa949efe0dbb8907ca2c66d"/></dir><dir name="Search"><file name="Catalog.php" hash="5d9a903fe56bca27c094929acc8807b9"/><file name="Customer.php" hash="c2b8935fcf7aef9bd4cc10be40e465a8"/><file name="Order.php" hash="958a0e0b7e7ebf02fe067fda4b8823a2"/></dir><dir name="Session"><file name="Quote.php" hash="41b0bd0c9fb61cc8130a413a09a2d79f"/></dir><file name="Session.php" hash="85361ee383f9c79986bbec474b8a1f3f"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Admin"><file name="Custom.php" hash="2e046894406289aa907ae0035e46b1c8"/><file name="Custompath.php" hash="ead8d3a1df593bd69890ea79bd9b3829"/><file name="Observer.php" hash="cf571f4c0de3b6360a0efb9515a0bfe2"/><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="a86613c9c07371cf3fac211fb19d6f24"/></dir></dir><file name="Usecustom.php" hash="fff1bebb0e91904cb26c63df391a1235"/><file name="Usecustompath.php" hash="fc23817391f632789cf63c822f57dd71"/><file name="Usesecretkey.php" hash="e21072aee647c809471f6e2893298cdb"/></dir><file name="Baseurl.php" hash="304bd2df6d53224b7bf31b39c40190ad"/><file name="Cache.php" hash="f1936cb90a793bda1b6a35255edd96b3"/><dir name="Catalog"><dir name="Inventory"><file name="Managestock.php" hash="e5944356c0ff4dd9741690152719d3ea"/></dir><dir name="Search"><file name="Type.php" hash="7a6f20cd3be131670abf8b99566e60da"/></dir></dir><file name="Category.php" hash="fbda292baa5daaacb284a8fe715bfe9b"/><file name="Cookie.php" hash="81a5b71978c0ed23e1fa8b291c23306a"/><dir name="Currency"><file name="Abstract.php" hash="37d41ca094ad7a593ed70abe124d5ec6"/><file name="Allow.php" hash="68bd67c886ba2000f395c55c816a9b46"/><file name="Base.php" hash="af6b18eee844e76f329d4c51e933d4fa"/><file name="Cron.php" hash="17eb00bccbd61beca4581acf7416f022"/><file name="Default.php" hash="bee4b5c43f2f3e36db81043e1a4e38f0"/></dir><dir name="Customer"><dir name="Address"><file name="Street.php" hash="206e706118ee6655401b9b42c61f8506"/></dir><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="5abc0ac6ea5ea85848797706e06e99d9"/></dir></dir><dir name="Show"><file name="Address.php" hash="feeec998fd621ea03edf460fea1634bc"/><file name="Customer.php" hash="e61f0a53ee55ced4ac33c2ac0221370f"/></dir></dir><file name="Datashare.php" hash="25913fe52b59a4bd39e46c4428854c12"/><dir name="Design"><file name="Exception.php" hash="68565707472fe642dd4b7a40e2d0b925"/><file name="Package.php" hash="93e0526fcc2c9bad6826c18a36fb2ad5"/></dir><dir name="Email"><file name="Address.php" hash="421366b7e3a6b4c0244fbc6188d11f92"/><file name="Logo.php" hash="33b719f143c2903cee686388d3d060e7"/><file name="Sender.php" hash="79b079bd76cbea2d998738859784ab5e"/></dir><file name="Encrypted.php" hash="84b385dd684b85612707b4fa9db51ad0"/><file name="File.php" hash="f42cccdb5023090f46ae2607532e5368"/><file name="Filename.php" hash="96f867e0997f10d83febcfcba0004e52"/><file name="Gatewayurl.php" hash="dff96ccdae32aaff1d2535a1e7157a3e"/><dir name="Image"><file name="Favicon.php" hash="bcf45a7d93048d325b0f7f4ad1cf0eb2"/><file name="Pdf.php" hash="355ffa084fa7bac2f97436743f097f60"/></dir><file name="Image.php" hash="3ef32a5d2650336e8cbfc4093c54f221"/><dir name="Layer"><file name="Children.php" hash="7c2edbbd89dba4e5c46ca7332ac2ab2f"/></dir><dir name="Locale"><file name="Timezone.php" hash="4876cce3ad44db1787c159706166b597"/></dir><file name="Locale.php" hash="c36f4de4e2340ffa1c2d360d2e917443"/><dir name="Log"><file name="Cron.php" hash="0960c63fb46cdbc57554d68d01129032"/></dir><dir name="Price"><file name="Scope.php" hash="6e8849ccddcd5195481bb44ba194f543"/></dir><dir name="Product"><dir name="Alert"><file name="Cron.php" hash="536cae440b551a5c8b52988bd41dd679"/></dir></dir><file name="Protected.php" hash="824f1696606927d8b43da42477bad8a4"/><file name="Secure.php" hash="a036733f115c60ff74d92cf9e142ba60"/><dir name="Seo"><file name="Product.php" hash="28f4ed01035ff820777cc6ced55f3d87"/></dir><dir name="Serialized"><file name="Array.php" hash="d68727325451f37b3bc8a631bd87984e"/></dir><file name="Serialized.php" hash="df3b2f9a6d931bc5262960ad2c68b822"/><dir name="Shipping"><file name="Tablerate.php" hash="91656cfd86831cd8a26a5e57f3475edc"/></dir><dir name="Sitemap"><file name="Cron.php" hash="cb06d56d24023876fa771022d6ecbb2a"/></dir><file name="Sitemap.php" hash="c74a82773ad66c1495d24817a47c4c96"/><dir name="Storage"><dir name="Media"><file name="Database.php" hash="6923e70725113267e3deeba1cfb6da9c"/></dir></dir><file name="Store.php" hash="6e79f5835127803c134b82b3c4961d78"/><file name="Symlink.php" hash="95b9d98e178f4b8f927680b0791b631a"/><file name="Translate.php" hash="b6b6241975ad904fcb6dad072ba94ce5"/><dir name="Web"><dir name="Secure"><file name="Offloaderheader.php" hash="724df1bd4f97398e50223342ec786f4d"/></dir></dir></dir><dir name="Clone"><dir name="Media"><file name="Image.php" hash="5578699345bb7524f1fb182e442653d0"/></dir></dir><dir name="Source"><dir name="Admin"><file name="Page.php" hash="42d6d50d365de5f67652e34e9840b4a8"/></dir><file name="Allregion.php" hash="d797110c372e988ff1a6e49d08ce4b88"/><dir name="Catalog"><file name="GridPerPage.php" hash="34c1553061fc5ff78eebde96a405bfa5"/><file name="ListMode.php" hash="04af817c1308371fcff319df9d1657f2"/><file name="ListPerPage.php" hash="ecb52706a68b4f173d6841fd697aa27b"/><file name="ListSort.php" hash="b79668ebc442a45cbffd7b7d3bd5d596"/><dir name="Search"><file name="Type.php" hash="f1b3abe3363b407f0d227843f70e8e2f"/></dir><file name="TimeFormat.php" hash="52b6b587880e91136d62c9d00a0b9163"/></dir><file name="Category.php" hash="919d4a332eb1253e37eacd987a93dda6"/><file name="Checktype.php" hash="19755a1389a9f8cae1f4aa6461881f26"/><dir name="Cms"><file name="Page.php" hash="dff5ebe6df33c59bafbee5cf6743b244"/><dir name="Wysiwyg"><file name="Enabled.php" hash="7131f228f3b3d4200af27a9268a858c5"/></dir></dir><dir name="Country"><file name="Full.php" hash="fb170bf789af8e5473b8c8bc0815760d"/></dir><file name="Country.php" hash="03f0ce0aa5bcbbcf7f4166a5ef538ad6"/><dir name="Cron"><file name="Frequency.php" hash="f696f381b430183990d02c8842816373"/></dir><dir name="Currency"><file name="Service.php" hash="ba5b791f1f54723cd4f230e867b1fd83"/></dir><file name="Currency.php" hash="7a62eaf4aea976f5980ce25ff84966a4"/><dir name="Customer"><dir name="Address"><file name="Type.php" hash="50e978ba85a6b055bd286f1546bdc82e"/></dir><file name="Forgotpassword.php" hash="1173581eb58ff0233680da25f0dba5a0"/><dir name="Group"><file name="Multiselect.php" hash="262832009eab525d249b1549c8a2b966"/></dir><file name="Group.php" hash="516d462794a85a4f55a0b0b924f6a4a8"/></dir><dir name="Date"><file name="Short.php" hash="0ecb55ea74e7f0635cf9656bd4a79f56"/></dir><dir name="Design"><file name="Package.php" hash="92b1341793a9470fa4868f08ed054768"/><file name="Robots.php" hash="932beab930045a12398cec1af767edad"/></dir><dir name="Dev"><file name="Dbautoup.php" hash="b6466ce08c8de924d7d73302a1c4e395"/></dir><dir name="Email"><file name="Identity.php" hash="f7cf7b723bbc82a236adca740249e12b"/><file name="Method.php" hash="28d64e5cfed2865385d38c60a6d59c3f"/><file name="Smtpauth.php" hash="1379a68f7463a688da3559a56c0c62ef"/><file name="Template.php" hash="546603ce87c833f85c2886fa78c4da3f"/></dir><file name="Enabledisable.php" hash="e4ba4eefa3c92dcd4f6088df73e852b5"/><file name="Frequency.php" hash="b45cac5c61aa1c76f02354fa354c2e59"/><file name="Language.php" hash="cf4973e113cf46bf582ba866b0c84bd6"/><dir name="Locale"><file name="Country.php" hash="3f5882e3e02a1cfceb94e44dec5154a9"/><dir name="Currency"><file name="All.php" hash="f17029b7a993196608692c62074d357f"/></dir><file name="Currency.php" hash="e65f20d6b8dcc9b92eecc3773288b29a"/><file name="Timezone.php" hash="8a91c04de34b595b523b2744bafad7e8"/><file name="Weekdaycodes.php" hash="2dcb2f68f9676e7757511cfc52fae914"/><file name="Weekdays.php" hash="fd1c10e7451311bda4439bce1aaa4889"/></dir><file name="Locale.php" hash="7c1997cc0bd57c0e19a3049d2602ff16"/><file name="Nooptreq.php" hash="129aa8240d6dcf7610cf5aebce742014"/><dir name="Notification"><file name="Frequency.php" hash="992ad115d486c15b4e49d1c713c5fbe5"/></dir><dir name="Order"><dir name="Status"><file name="New.php" hash="b13e716a54aafb4debe2e39f862d1a6b"/><file name="Newprocessing.php" hash="98351a23d0cfc885f6ae955bc8497a79"/><file name="Processing.php" hash="463d61baa271f0be702d99496a9cc474"/></dir><file name="Status.php" hash="d51560e7f3996d42858d2234c71a46d3"/></dir><dir name="Payment"><file name="Allmethods.php" hash="bb56b4469058373f44333efbda871155"/><file name="Allowedmethods.php" hash="1c3df6f913320f5863c6ce5a895ab038"/><file name="Allspecificcountries.php" hash="e033d3d9881675523f824b520ed0c6e5"/><file name="Cctype.php" hash="bd508e1461321c62a8bc13d8009fcb40"/></dir><dir name="Price"><file name="Scope.php" hash="67a80549b00e35bb3cb2e1e1e5a19b82"/><file name="Step.php" hash="4f3c8edc0c9ffaaa2e1c876cdc4a1f12"/></dir><dir name="Product"><dir name="Options"><file name="Price.php" hash="675c24d90116fe01ca667b7c282ee480"/><file name="Type.php" hash="5e5b7e26c1582a5ec4414b9e8d234521"/></dir><file name="Thumbnail.php" hash="3055686e20099ff6e89291834a2adace"/></dir><dir name="Reports"><file name="Scope.php" hash="069a3499c4298db920ba405fa11c0ea4"/></dir><dir name="Security"><file name="Domainpolicy.php" hash="8077bae576aa62e2be69321140bb0177"/></dir><dir name="Shipping"><file name="Allmethods.php" hash="f1b6cc6e499d22ad0d09f12126a57ae7"/><file name="Allowedmethods.php" hash="cde3eb6702c5b55d004e6798294304dd"/><file name="Allspecificcountries.php" hash="b9ddf5a44b9f7b04295384365fe09103"/><file name="Flatrate.php" hash="c881e1fd1f4ae6c5d5e5195a7726fd4d"/><file name="Tablerate.php" hash="5b089f80b770d155ce1ce130904f6cd0"/><file name="Taxclass.php" hash="e3995dd47b8356e54438aa5172d4c53f"/></dir><dir name="Storage"><dir name="Media"><file name="Database.php" hash="168fa52133880bdd0a5b9940bd5eb419"/><file name="Storage.php" hash="0f9612972aad64996f79b073f6aa51ed"/></dir></dir><file name="Store.php" hash="58122ea3b33c37ec9ea19a7bcf52ec48"/><dir name="Tax"><dir name="Apply"><file name="On.php" hash="9895d966f0a3594f146e2143a75d9164"/></dir><file name="Basedon.php" hash="a439e01f07d6485c890e02630f98a758"/><file name="Catalog.php" hash="2fe2fdda4bcc8b445fe48c009342e642"/></dir><dir name="Watermark"><file name="Position.php" hash="2c04100eb63d9e8cbf3c88085fd2f996"/></dir><dir name="Web"><file name="Protocol.php" hash="df2fbf74d4e484c19a2813b3b9eb2b22"/><file name="Redirect.php" hash="182130c27530d8c8fd9f19a00cdc3b8a"/></dir><file name="Website.php" hash="29e00fba750aa9fed121702446994918"/><file name="Yesno.php" hash="3e3d9290c8a907608b9d5a58028b338d"/><file name="Yesnocustom.php" hash="8a5bc93d4c803e3fa20df139869096bc"/></dir></dir><file name="Store.php" hash="fd2a829b6c24413772706d9f74a227ca"/></dir><file name="Url.php" hash="9099e82b420afdd2b332029423541671"/></dir><dir name="controllers"><file name="AjaxController.php" hash="21aa2331850549a0d56a0f34e126672d"/><dir name="Api"><file name="RoleController.php" hash="dd71ee700489808549abbda71255d9b4"/><file name="UserController.php" hash="ada4455c4277dd842949e1d8393a945d"/></dir><file name="CacheController.php" hash="82ffba0759bca1498d810db6cbdbae9f"/><dir name="Catalog"><dir name="Category"><file name="WidgetController.php" hash="d7274f61d984ca38d10f3f89abdaa38b"/></dir><file name="CategoryController.php" hash="c52faa77117d63bad16a2fcf08203cd8"/><dir name="Product"><dir name="Action"><file name="AttributeController.php" hash="f85caaa4837b6e123d3f595cb7ff0cea"/></dir><file name="AttributeController.php" hash="3805ddafadbf0c58f4225bc61ea87412"/><file name="DatafeedsController.php" hash="b6f1fb27951ccc158ebf1e27b0be9f65"/><file name="GalleryController.php" hash="2bf4baf9369aadbc9357117b48d08a11"/><file name="GroupController.php" hash="08c4d556258752769c14a8da3e8360a6"/><file name="ReviewController.php" hash="9b0e7354ca4f68e60598ee57a04a7175"/><file name="SetController.php" hash="052505c1fac2a67a21f04451bfaf212b"/><file name="WidgetController.php" hash="ab47a3fd2d409fa3590aa1ff866e0515"/></dir><file name="ProductController.php" hash="4f293523f888ccb2df82374a36e2e8c6"/><file name="SearchController.php" hash="8f0be8ea2dda17161f44a244e7721b65"/></dir><file name="CatalogController.php" hash="247369a9fa2674f1660c92f630b7343a"/><dir name="Checkout"><file name="AgreementController.php" hash="8ac0324efd3a81443d32f36178c815ea"/></dir><dir name="Cms"><dir name="Block"><file name="WidgetController.php" hash="45aad6354caa2b7a5608a14d8b86a6ce"/></dir><file name="BlockController.php" hash="117f2f823bd437abf534f2fc4200c50f"/><dir name="Page"><file name="WidgetController.php" hash="27e2d88da95bf627dc94e2eb4c62f7bb"/></dir><file name="PageController.php" hash="f68ee1a38644bceec232f23c961aa9cc"/><dir name="Wysiwyg"><file name="ImagesController.php" hash="0002d34d5a20602f947029710c003e94"/></dir><file name="WysiwygController.php" hash="52937e9d1c6c2e60abf4f6f4e506ea3e"/></dir><dir name="Customer"><dir name="Cart"><dir name="Product"><dir name="Composite"><file name="CartController.php" hash="00aec88f5179e17aaa2cb32410d4e627"/></dir></dir></dir><file name="ConfigController.php" hash="75fc248de6217cec3dc7115a6d3c7871"/><file name="GroupController.php" hash="300e16d47af15dfdc72d3a72d6a8b425"/><file name="OnlineController.php" hash="c582c470171c6f22930874ace2212fbb"/><dir name="System"><dir name="Config"><file name="ValidatevatController.php" hash="9ec588e2864cf7584f86e7ea03ef859b"/></dir></dir><dir name="Wishlist"><dir name="Product"><dir name="Composite"><file name="WishlistController.php" hash="312e61c120d15fa6b9beff8d013669a5"/></dir></dir></dir></dir><file name="CustomerController.php" hash="840b12a524c3c4ddcbb33a84eec8e5c0"/><file name="DashboardController.php" hash="cccdc39d1b4256bc6d3fdc3f312b469c"/><file name="IndexController.php" hash="93d25be27f7172e4b91be4e29b1667d5"/><file name="JsonController.php" hash="2a0884d78d11507f5ca8617ab60a65fb"/><dir name="Media"><file name="EditorController.php" hash="08217fbb9baea7eadf7e1c2fa9d37ed0"/><file name="UploaderController.php" hash="5a3f8a7627dce0832bf279ee0bb29aec"/></dir><dir name="Newsletter"><file name="ProblemController.php" hash="666980a1414023c417422a9354854ca7"/><file name="QueueController.php" hash="84615826588fd8d919efce2d5f261953"/><file name="SubscriberController.php" hash="012dfabbe5188395de3d4934db9d8f1f"/><file name="TemplateController.php" hash="ea1674e2d186bddad77aaa693dd51047"/></dir><file name="NotificationController.php" hash="d7a410e9d20a264e4d9515b1a86f7d30"/><dir name="Permissions"><file name="BlockController.php" hash="185535dffd66b8d8ef1068019eb3eff8"/><file name="RoleController.php" hash="9606953d4410722d615ac816820fa340"/><file name="UserController.php" hash="50f7bdedd11f5682e275bc2139461ca6"/><file name="VariableController.php" hash="c92ad3f6d684b0766cd43d3a31f4c1fa"/></dir><dir name="Poll"><file name="AnswerController.php" hash="9287852777f2b860e531374d94e45157"/></dir><file name="PollController.php" hash="b430f477bc4bfb01ccaf060ea4ffdf99"/><dir name="Promo"><file name="CatalogController.php" hash="c8fdcea935fe0c754f27644e0e78e07f"/><file name="QuoteController.php" hash="b28ffe79f88fb1a6d01aad9c80ae72fe"/><file name="WidgetController.php" hash="d91c5d5958237820bcfa78c89cac16c2"/></dir><file name="PromoController.php" hash="ed7e53ece75726b7a31e675748540a84"/><file name="RatingController.php" hash="315660eb3bda08558a3f609a5596d7c2"/><dir name="Report"><file name="CustomerController.php" hash="9f5dfc9f1f6ed652d59c420b5c069502"/><file name="ProductController.php" hash="0c615feb915eb56af10fc75c00feb0c3"/><file name="ReviewController.php" hash="7da2ab6db4eae2bfdf9ecccd3c87e7f5"/><file name="SalesController.php" hash="d1c582fa4d0df0af89b528012fee1c2b"/><file name="ShopcartController.php" hash="525c2321b21e62a3c1f686d62559c01b"/><file name="StatisticsController.php" hash="91a77e722297e68b0ad1ba54ad359b2a"/><file name="TagController.php" hash="3c1aec074c4eb53d14f77f549339dbfd"/></dir><file name="ReportController.php" hash="63feec302514efa918d1a80f8f7e9cca"/><dir name="Rss"><file name="CatalogController.php" hash="c007de3af2772afd0af741b3be6c8a79"/><file name="OrderController.php" hash="608bc4c2de1d4785ffec32805c10368c"/></dir><dir name="Sales"><dir name="Billing"><file name="AgreementController.php" hash="2da3d500f2049c5ece840fbbfca9647d"/></dir><file name="CreditmemoController.php" hash="2d688eee9da7ccfcefaf9788def48b1a"/><file name="InvoiceController.php" hash="19a9445cabc5f9059d6e550b8f58b873"/><dir name="Order"><file name="CreateController.php" hash="bdf67443df772d984dc1c51135ae1199"/><file name="CreditmemoController.php" hash="4445b5dc62da541f2f847beb0d1bbaec"/><file name="EditController.php" hash="0b7c20984714ac732162c98bf89850fc"/><file name="InvoiceController.php" hash="1f1a90c7f42c23debcf804b1be6defff"/><file name="ShipmentController.php" hash="fbf45e3a33640447a07b66744f9c1346"/><file name="StatusController.php" hash="39ea9de1b69ab854ddc481948281d94a"/><dir name="View"><file name="GiftmessageController.php" hash="99aa2e8b8abc4e517817d4a206f66994"/></dir></dir><file name="OrderController.php" hash="6d237944b46c4cda0a259371732ef925"/><dir name="Recurring"><file name="ProfileController.php" hash="9cb710bd52e9a0ffe2e3f7471a7344f0"/></dir><file name="ShipmentController.php" hash="fd91d81711fc1dff84ab77ead90cbe42"/><file name="TransactionsController.php" hash="2804baa76fb26d4ef1bb52b4657623a2"/></dir><file name="SalesController.php" hash="0af897e1b6c86b1a333ade2d42c7132f"/><file name="SitemapController.php" hash="b5b322f6be561056e015130fefaadfcf"/><file name="SurveyController.php" hash="1f472bbf45c9b2c5b0871da68a64747d"/><dir name="System"><file name="AccountController.php" hash="065a0d935e4eb62882fb1c0e581509b0"/><file name="BackupController.php" hash="a978f19979f623f2db52a4cd2521461b"/><file name="CacheController.php" hash="75ddb06e7d3aa12d387bad621b5a69f8"/><dir name="Config"><dir name="System"><file name="StorageController.php" hash="07f6a5f5ad1ace3aa724902656de99cf"/></dir></dir><file name="ConfigController.php" hash="35ff2d7f2282dd7983f832d215dc4257"/><dir name="Convert"><file name="GuiController.php" hash="9c3a90e18ad3b405779df0dc3b32f3a0"/><file name="ProfileController.php" hash="535281019f5bb6e456f7dee19952ff29"/></dir><file name="CurrencyController.php" hash="51394cd2c6721baa9f9a88c6a5d10377"/><file name="DesignController.php" hash="47108670fb51eb5a66d626e9a48a816c"/><dir name="Email"><file name="TemplateController.php" hash="2d5834d5c3559158a7222759d5bd0706"/></dir><file name="StoreController.php" hash="2b0bb94e5c7a359e9109bc5e038ef621"/><file name="VariableController.php" hash="4399817273fe7e92bd3e7aebcd3c23ad"/></dir><file name="SystemController.php" hash="968204b11a8efb93c13ff3a36ea3aa0a"/><file name="TagController.php" hash="b427319c9cc848023e2894ff98cf6e77"/><dir name="Tax"><dir name="Class"><file name="CustomerController.php" hash="e11693950ace13f570c97f46110d671b"/><file name="ProductController.php" hash="ff329c1879ae3ba19b3cbc2d20f4d93e"/></dir><file name="ClassController.php" hash="f30d45900d180019a6e2f2d9d5edad9e"/><file name="RateController.php" hash="bba20ae7c52d95d3f6add60eb7785388"/><file name="RuleController.php" hash="6a24cb90bec2d0878c23530593ff50e5"/></dir><file name="TaxController.php" hash="2bcb2c6c6164bc91a14711f13808ceda"/><file name="UrlrewriteController.php" hash="8728bfac026517f44f522deafc102c78"/></dir><dir name="etc"><file name="adminhtml.xml" hash="eacc179395f301ba856c22b7ae75d4b1"/><file name="config.xml" hash="cee3689bb30fbde7f0b28a519cb004a6"/><file name="jstranslator.xml" hash="bc2b74495321e4a736d063e9ddc71693"/></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Adminhtml.csv" hash="b65baff79fbf0ae5e5945ce1e2ff975b"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.18</min><max>1.51.1.18</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_LinLibertineFont</name><channel>community</channel><min>2.8.14.18</min><max>2.8.14.18</max></package><package><name>Lib_Js_TinyMCE</name><channel>community</channel><min>3.5.11.17</min><max>3.5.11.17</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Core_Adminhtml-1.9.4.2.xml b/var/package/Mage_Core_Adminhtml-1.9.4.2.xml
new file mode 100644
index 0000000..e84723e
--- /dev/null
+++ b/var/package/Mage_Core_Adminhtml-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Core_Adminhtml</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Administration Panel</summary>
+    <description>Magento Administration Panel</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:11</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Adminhtml"><dir name="Block"><file name="Abstract.php" hash="1d12544ff9a4179ec26ea38df2f705a1"/><dir name="Api"><file name="Buttons.php" hash="2bfed92fbddff63dc671c27b5d75ce93"/><file name="Editroles.php" hash="a1d4db198e2e99ecc9afa2f058b30e71"/><file name="Edituser.php" hash="1585e1dd89f71aed9d84c704cf9945f9"/><dir name="Grid"><file name="Role.php" hash="979c32b3dea09126c937e588d7ec0c0a"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="17a8582ac7857698bebad817a62db96f"/></dir></dir><file name="Role.php" hash="c6d7bd3e76b94c4f4df8ba70d8f87cbc"/><file name="Roles.php" hash="1f9b226104fc7015d6a752b12c95f5d8"/><dir name="Tab"><file name="Roleinfo.php" hash="068f8a4c1914a134ace5faa00094cf31"/><file name="Rolesedit.php" hash="29b4cbd98c0ca82453f02b4627a95c0c"/><file name="Rolesusers.php" hash="767b7483660096254eb486f5d2be927b"/><file name="Userroles.php" hash="03cc0352d61d676a30662564a5ce839f"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e797303af20e9b4c72de379330fdd76c"/><dir name="Tab"><file name="Main.php" hash="b6c71ac2f96d87c0d0a586258e9301d4"/><file name="Roles.php" hash="2817cb16b57964c029cdc991061168fb"/></dir><file name="Tabs.php" hash="83b36d6858b78b3ef1ef56102e733ece"/></dir><file name="Edit.php" hash="742b1c24fa349177cc5379f7c0eb5d0f"/><file name="Grid.php" hash="3a58107458d582950e14cfa51513077e"/></dir><file name="User.php" hash="adf9a33ed18d3c60e9ffc284f98ff6dd"/><file name="Users.php" hash="4d3ccf7be3cc39c720fa032abb0af6aa"/></dir><dir name="Backup"><file name="Dialogs.php" hash="468b3514651887904849a6e9f7d81e8c"/><file name="Grid.php" hash="d7a48a3580321c5a502950255b7965dc"/></dir><file name="Backup.php" hash="25b24ec94e7fc2b5c04b694b884597a8"/><dir name="Cache"><file name="Additional.php" hash="140342a012f58cb93e0ac7d82d02b53f"/><file name="Grid.php" hash="d6eb94996a6dd177f09a95525ceeeee4"/><file name="Notifications.php" hash="18205ad9e6a0b21ee467dcc789d19864"/></dir><file name="Cache.php" hash="2eba478582fb0d66d6732f21fd95c715"/><dir name="Catalog"><dir name="Category"><file name="Abstract.php" hash="b4d5029756e0c8e8de149156a8cde6ab"/><dir name="Checkboxes"><file name="Tree.php" hash="a30396e16cad9fc4a3d924fc81587f51"/></dir><dir name="Edit"><file name="Form.php" hash="a0cff1b2848881be054ed580ea0492ab"/></dir><file name="Edit.php" hash="28f749e9c1bf2066878b9cc7f4c44a71"/><dir name="Helper"><file name="Image.php" hash="97826fd95b6704961f976c3755ff63f3"/><file name="Pricestep.php" hash="0fbb5ec65a9fd2c13b17d9054116e0ec"/><dir name="Sortby"><file name="Available.php" hash="3baa0f9586e319e5be5ec7f1d77318f4"/><file name="Default.php" hash="8d2654ee619e84385a78b8f077b95817"/></dir></dir><dir name="Tab"><file name="Attributes.php" hash="8c37ae6f103e435d176713614cfc2732"/><file name="Design.php" hash="758a748b925e1bc5977b2c422eff7629"/><file name="General.php" hash="19f6ba72a075162228fe7606729944fa"/><file name="Product.php" hash="d18af8055e288e6537226a03f9f4f14d"/></dir><file name="Tabs.php" hash="84c926a493661a0a34fd409e20d96d10"/><file name="Tree.php" hash="4874a7a762c32f84d87c84ea63ca838c"/><dir name="Widget"><file name="Chooser.php" hash="4a8fa415e03bad3b179987b859eb8c27"/></dir></dir><dir name="Form"><dir name="Renderer"><dir name="Attribute"><file name="Urlkey.php" hash="ff7e37b0d7aa89165cae9fa598028c8a"/></dir><dir name="Config"><file name="DateFieldsOrder.php" hash="325392687355326b76a6d6b4d714958f"/><file name="YearRange.php" hash="81fc92362f8322bfe7cd478c8407744c"/></dir><dir name="Fieldset"><file name="Element.php" hash="9eed80102cc6a7e281e208aa86e99ab5"/></dir></dir></dir><file name="Form.php" hash="25150307aaef45477c387305f5e4f68f"/><dir name="Helper"><dir name="Form"><dir name="Wysiwyg"><file name="Content.php" hash="171b45a02d0f5bf62bde1358ac5e7a2a"/></dir><file name="Wysiwyg.php" hash="d3ce33132bc4220ec9b10b90f1769ac9"/></dir></dir><dir name="Product"><dir name="Attribute"><dir name="Edit"><file name="Form.php" hash="cdf3e0c7a1ec95b04888c84a1f778ebc"/><dir name="Tab"><file name="Front.php" hash="8f55cbf6f064086aadbbe74866acc26f"/><file name="Main.php" hash="4e8e7760214a3e176fd8eabbcd6a9e86"/><file name="Options.php" hash="f39e935918e8e668d5a8c54527c78232"/><file name="System.php" hash="e04ed3d2db33f456af71ad202dd78bbd"/></dir><file name="Tabs.php" hash="d9f123df155992923a370d2b5bee265e"/></dir><file name="Edit.php" hash="e53f99431ac23771abe61d4b0bfc406d"/><file name="Grid.php" hash="6ca85f95807da51938179cb20394f977"/><dir name="New"><dir name="Product"><file name="Attributes.php" hash="e84f1a4d60c284ae8849880d989c0afc"/><file name="Created.php" hash="71dfab2069f92429c1b08d50fa8145ef"/></dir></dir><dir name="Set"><file name="Grid.php" hash="f2fc5d5670e5817b2cf1cc9d26d726cb"/><dir name="Main"><file name="Formattribute.php" hash="0b1e150657f35428872d92bcc20fcec9"/><file name="Formgroup.php" hash="6ee05aa130ec4e0d26853d973185f4cc"/><file name="Formset.php" hash="203488f4962df9e69bbe67be46ad486b"/><dir name="Tree"><file name="Attribute.php" hash="85ed149d0074c657697be04bb69f2520"/><file name="Group.php" hash="bae5d15420a2b086b3710c8eb79bb99c"/></dir></dir><file name="Main.php" hash="307a3b737e4bcd2e5550e54407ebf658"/><dir name="Toolbar"><file name="Add.php" hash="16612d7c0e6efc62ae75142a6bf3cd64"/><dir name="Main"><file name="Filter.php" hash="c6eecdaacbcc665868f4a1e2114f6224"/></dir><file name="Main.php" hash="45d9726e9a6845a7911146586de27e25"/></dir></dir></dir><file name="Attribute.php" hash="35bda03c081d6583355e84b2a652aebc"/><dir name="Composite"><file name="Configure.php" hash="b67bd03a727caab2d99cbec59eb6c15a"/><file name="Error.php" hash="a11b9e86c20d87c7881e6c10821c651d"/><dir name="Fieldset"><file name="Configurable.php" hash="b66dc415373b803e75cacc0fe302f865"/><file name="Grouped.php" hash="a886ae59748a6bd05712599d9e36f59d"/><file name="Options.php" hash="6e3c0d7be774973bb7c14bc3aaf16e63"/><file name="Qty.php" hash="9475558d479812c1255f3459233dc92f"/></dir><file name="Fieldset.php" hash="f11d5ce88b7c2b2b10df891dfdffcdb7"/><dir name="Update"><file name="Result.php" hash="04d1f852a68190de43d0a7875db17722"/></dir></dir><file name="Created.php" hash="b47f62987dd532eb78540fb1ae149482"/><dir name="Edit"><dir name="Action"><dir name="Attribute"><dir name="Tab"><file name="Attributes.php" hash="c28f819e42ee059b0e0807f8c073c7e6"/><file name="Inventory.php" hash="28b622520b546658b1ce1201b4ab07cf"/><file name="Websites.php" hash="d122b9fead07ce717b812866c46adcf4"/></dir><file name="Tabs.php" hash="ee4ac2b9077429db8832401b2ebcc4ae"/></dir><file name="Attribute.php" hash="0ca8963be70c599d760e6f34520e1ca1"/></dir><file name="Js.php" hash="e261073dc1e135d7287c48a3ac6024fe"/><dir name="Tab"><dir name="Ajax"><file name="Serializer.php" hash="407bce164538ebb2699a4f630919f544"/></dir><dir name="Alerts"><file name="Price.php" hash="61d24a11322b7334f9d9159b0d54a270"/><file name="Stock.php" hash="39f246d0007135c96569cc0f677e8200"/></dir><file name="Alerts.php" hash="71877f70f839bc3311400a8b0f74ad1c"/><dir name="Attributes"><file name="Create.php" hash="abd39e94d61a77f718a447d16a00a911"/></dir><file name="Attributes.php" hash="452ab3f3424dc9693e4f1cb3f8f0bd84"/><file name="Categories.php" hash="96e5cb356bb207156dad4ca8fd953239"/><file name="Crosssell.php" hash="3fb1a2644748deac0667915369a125b4"/><file name="Inventory.php" hash="f6dc9b47afa451a07fcaee2bee4b4c90"/><dir name="Options"><file name="Option.php" hash="b1f8e3381c100602006315d01fdfae9b"/><dir name="Type"><file name="Abstract.php" hash="03e4e1f2a23529b61d9cd6b2356048f3"/><file name="Date.php" hash="486db1c7e03c9009933622a04f93b4b1"/><file name="File.php" hash="bdc8a288f3612adc368a1eec9555ea60"/><file name="Select.php" hash="73477e9768fae45a4d53b074d23760a5"/><file name="Text.php" hash="2171a4e312504df88008d4bcda2d7e4b"/></dir></dir><file name="Options.php" hash="a62eb8c69acc3164765a2a58380d4eed"/><dir name="Price"><dir name="Group"><file name="Abstract.php" hash="7fcb2806533cf4005992cd5f6aba2c93"/></dir><file name="Group.php" hash="1861d97732bdee01154cc39c3bf4b345"/><file name="Recurring.php" hash="4a03f89a26555b68be76e630de5347c6"/><file name="Tier.php" hash="f214bc620608440dc393092faf045094"/></dir><file name="Price.php" hash="fa49ddddedc8937e9db216713dc50742"/><file name="Related.php" hash="58139c20fb9deffb1b28aa7d4081be30"/><file name="Reviews.php" hash="89efeb2d1d07e92aea33e26b0c91b0ac"/><file name="Settings.php" hash="be4f8669f07a1a1951b1ecacd9fc328b"/><dir name="Super"><dir name="Config"><dir name="Grid"><dir name="Filter"><file name="Inventory.php" hash="02c8d622fdb61b9c4dbacca7a7b2cfdc"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="9ee83d276e1f9e851450ef377f1051a9"/><file name="Inventory.php" hash="2c305eed32d570d0743b2ded6ff77c40"/></dir></dir><file name="Grid.php" hash="9080fb1a0e252b37f6424ae05ac23fe9"/><file name="Simple.php" hash="4f4c795463b3bf7e302210163b85b4e8"/></dir><file name="Config.php" hash="f1a3aeef321498b1da650c6052082da3"/><file name="Group.php" hash="96d08a2ea0ff1fea50370f3741d6d1de"/><file name="Settings.php" hash="199168163f1340c262863bbfdcac7361"/></dir><dir name="Tag"><file name="Customer.php" hash="d1bc2fff71591e0938f7897a9d5e7435"/></dir><file name="Tag.php" hash="5a9a5345a8820830974f7701e42157f8"/><file name="Upsell.php" hash="78025ebd67d64b038b4d7a4082b99b2d"/><file name="Websites.php" hash="69d0d1aa6951622e378ec284e968bca5"/></dir><dir name="Tabs"><file name="Configurable.php" hash="a9b9ff4f7e7c8e76b6eb63a1022e5298"/><file name="Grouped.php" hash="4b0d7e5766e03b7ec4e13892cce63e35"/></dir><file name="Tabs.php" hash="990c3877e7ac14972c42b1615b6d2f61"/></dir><file name="Edit.php" hash="a77985102f5bc9500d8d999bdb640aa8"/><dir name="Frontend"><dir name="Product"><file name="Watermark.php" hash="c8fdddc408ff23b4a2e0cc9940452532"/></dir></dir><file name="Grid.php" hash="4415c85c4c6cfe9ebad25dbb4a570a7d"/><dir name="Helper"><dir name="Form"><file name="Apply.php" hash="ebdec21e1d86ebb91f61f05235b02c0d"/><file name="Boolean.php" hash="b3790b5b035c6d68c7478cb9362dd196"/><file name="Config.php" hash="0c59e94f97e820a46bb5f21e548363d2"/><dir name="Gallery"><file name="Content.php" hash="4ed8b17993adda5daccaec874cf516d2"/></dir><file name="Gallery.php" hash="cad37730c4c135877ce4467a7d01176b"/><file name="Image.php" hash="6241be43f381a5a0821f4dcab824f8eb"/><dir name="Msrp"><file name="Enabled.php" hash="a44f68cbf40a6c4b8d730349e5dea567"/><file name="Price.php" hash="c8fe461530d7de62b64a4f0d5d313d21"/></dir><file name="Price.php" hash="eee51e79b5c100190b1ac01090cb8ac4"/><file name="Weight.php" hash="0c7bf1ab444bd1af1d7fdbd7bcbfe828"/></dir></dir><file name="Price.php" hash="63b3d5a6a44de5108c06a15a58166d7f"/><dir name="Widget"><dir name="Chooser"><file name="Container.php" hash="162b5430206fdb7dcaa404ce8f122660"/></dir><file name="Chooser.php" hash="a13ab5cc27f3b108c83da378799c7845"/></dir></dir><file name="Product.php" hash="6221f39a3224f6c5ab50d0c906dfc6f8"/><dir name="Search"><dir name="Edit"><file name="Form.php" hash="a42b407c9a9f47092df32f565297b3b6"/></dir><file name="Edit.php" hash="bdb5ad67da655778ffacd912a07df423"/><file name="Grid.php" hash="f3ebd37ea9b57148d2f233f4d6d132b0"/></dir><file name="Search.php" hash="96a2febc55af4f9a3445def312b2f4d1"/></dir><file name="Catalog.php" hash="28eb5e6b2060460cc0308a9115ce4874"/><dir name="Checkout"><dir name="Agreement"><dir name="Edit"><file name="Form.php" hash="9151175340c1cf3787cbff6f52d31895"/></dir><file name="Edit.php" hash="64f603054370f2a77077249828a7bd6e"/><file name="Grid.php" hash="c56ef0e787a8d2f2555663e950f17fd1"/></dir><file name="Agreement.php" hash="ef6402bcc1e58c9b1598c8dc606b977d"/><file name="Formkey.php" hash="33506381a0bc723b94bd4635fc1fc555"/></dir><dir name="Cms"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="a9a37434f2f77967cb1d71dc725cc2f0"/></dir><file name="Edit.php" hash="dce0c8f690bdd9f5f0a7f781e15bb8da"/><file name="Grid.php" hash="8535d143498e9361d46364210f40aa60"/><dir name="Widget"><file name="Chooser.php" hash="55b9d76cbb369cdb0263a53f964fc564"/></dir></dir><file name="Block.php" hash="3f6f0192cd2a00850d9af6f3e825c3fd"/><dir name="Page"><dir name="Edit"><file name="Form.php" hash="31930639349c990f654e48fb7691a36f"/><dir name="Tab"><file name="Content.php" hash="e4e99ec295b2bb66cac94dd13410c0ab"/><file name="Design.php" hash="5545e1f1b1b716fff48325c364d795b3"/><file name="Main.php" hash="c1204a5bb8cb4bec6b7cb957374863d7"/><file name="Meta.php" hash="71472514e5e64d34807485bd9d4a12fe"/></dir><file name="Tabs.php" hash="6028f105ec1c60a4a41379fa41fef0f0"/></dir><file name="Edit.php" hash="283dd2ba93961f05baafa9ae641e99e2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="b69a369f078299372a0dc2684ddbba87"/></dir></dir><file name="Grid.php" hash="d2580f2a2a20a80ebf446191da59d9bf"/><dir name="Widget"><file name="Chooser.php" hash="3861c825efbae550f7c5b874a832973a"/></dir></dir><file name="Page.php" hash="44c1d2c7672727bcb5f617f4895e067a"/><dir name="Wysiwyg"><dir name="Images"><dir name="Content"><file name="Files.php" hash="dfe9b5f9cc1e88b7a92c89cae607ca56"/><file name="Newfolder.php" hash="abf8f9db9780ae6d4795c323225abb24"/><file name="Uploader.php" hash="c90b036837f00ee86c18d5e03cf56c56"/></dir><file name="Content.php" hash="18332e1d078c402dfd6db5b97c1f33d5"/><file name="Tree.php" hash="cabff9304c30720fe46e55e9f97fa6bd"/></dir></dir></dir><dir name="Customer"><dir name="Edit"><file name="Form.php" hash="88a9be8c62c08488c6f827d6e265b969"/><dir name="Renderer"><file name="Adminpass.php" hash="360c3517de650b9ec57a7f4f6730fcf8"/><dir name="Attribute"><file name="Group.php" hash="3161a779443b4944aed44ed266212aa9"/></dir><file name="Newpass.php" hash="445763b68a969eaae5ad2b780304d845"/><file name="Region.php" hash="e042b4f141569c7bb2ca7c309cd78c8f"/></dir><dir name="Tab"><file name="Account.php" hash="c3b7b882e2d87695d8f204d57ff2ffcc"/><file name="Addresses.php" hash="6be0f07b01c229f200ca47723c991567"/><file name="Cart.php" hash="6dbd28473e97889cbb12d799f992e84b"/><file name="Carts.php" hash="b487cfbfa014ecac68c1772b8dcafbb9"/><dir name="Newsletter"><dir name="Grid"><dir name="Filter"><file name="Status.php" hash="b75c661699fab3163db9b05484f184a6"/></dir><dir name="Renderer"><file name="Action.php" hash="83f1619271d589cf2f98266eb2b298b1"/><file name="Status.php" hash="12cc0385800c2654faca3e1b3191a36b"/></dir></dir><file name="Grid.php" hash="e6bfbaab166055bc97ca6a430fc24f57"/></dir><file name="Newsletter.php" hash="0b4a34626577789ab75efea769dcaa7d"/><file name="Orders.php" hash="61aac0bcd2a87580599e1cd4d0bb2e51"/><file name="Reviews.php" hash="31efe9289ff7e87eff54c179c24dba6f"/><file name="Tag.php" hash="5b1b636cae3e66210eba1bc6a3e39c36"/><file name="Tags.php" hash="f90b0d2468019f8dbaea8c576936b547"/><dir name="View"><file name="Accordion.php" hash="81facad941d92464a28f6fd5614fb608"/><file name="Cart.php" hash="8d9b2b37138a6fd89b983c7f270b03ae"/><dir name="Grid"><dir name="Renderer"><file name="Item.php" hash="f2d36c6018a1975b0f9d983adfe245ee"/></dir></dir><file name="Orders.php" hash="fed6b2896c91e422e69f1a600ec8d9cc"/><file name="Sales.php" hash="b731082a6fc2dfa9b3fe8a5d6bf309e8"/><file name="Wishlist.php" hash="961d8c040d2292cb7197c89e63b144a3"/></dir><file name="View.php" hash="f96caeaa728561efb18187444b7b0685"/><dir name="Wishlist"><dir name="Grid"><dir name="Renderer"><file name="Description.php" hash="f53f9167df22e37e68faca9d2ce333bb"/></dir></dir></dir><file name="Wishlist.php" hash="10461d6a242274497dd19094c022df58"/></dir><file name="Tabs.php" hash="3ded30ea877555bff0ca42610af96bfa"/></dir><file name="Edit.php" hash="5ea2cb0668eec0f0c7146ba39960a715"/><dir name="Form"><dir name="Element"><file name="Boolean.php" hash="fc6a5684ed07f3f41e4c06e7344d908c"/><file name="File.php" hash="4eb0ff4d329073aad2265381c01a0f0c"/><file name="Image.php" hash="2de933a0ef21a707e21381dbe2419b22"/></dir></dir><dir name="Grid"><dir name="Filter"><file name="Country.php" hash="0f1bc3cfad87222867e25a52cd605172"/></dir><dir name="Renderer"><file name="Multiaction.php" hash="4efa42b2e04948a2f64e85309c85cb1d"/></dir></dir><file name="Grid.php" hash="c3bb6f389beb5e149f919fc69c6627e9"/><dir name="Group"><dir name="Edit"><file name="Form.php" hash="e6fea58502cdea637c0157ea59f16c0f"/></dir><file name="Edit.php" hash="d2f99b544dc8b14184f2e9f6cce51d1a"/><file name="Grid.php" hash="12c7160547939438100ef7ae261ac225"/></dir><file name="Group.php" hash="eaec4acad81f69ff1a27a54122610050"/><dir name="Online"><file name="Filter.php" hash="ffe20662f60e0b779c926abe5ff6d971"/><dir name="Grid"><dir name="Renderer"><file name="Ip.php" hash="61400fedbbe4636ffb8a5bc1c6e75490"/><file name="Type.php" hash="150f363f91d9fb883f44b5dba8b141eb"/><file name="Url.php" hash="26161955ae6ad2c9d54d86ca20915b59"/></dir></dir><file name="Grid.php" hash="1eacff4ddfd493f6c221e0f165bab92b"/></dir><file name="Online.php" hash="089a608976c37ba29631514fd95365ca"/><dir name="Sales"><dir name="Order"><dir name="Address"><dir name="Form"><dir name="Renderer"><file name="Vat.php" hash="673cd679f9d5d7a8eb49968dfdff866f"/></dir></dir></dir></dir></dir><dir name="System"><dir name="Config"><file name="Validatevat.php" hash="6c44b4cf2a4532dfef9f33a40d527f40"/></dir></dir></dir><file name="Customer.php" hash="0bd1275ae095c7f5b48d0dafd013cce0"/><dir name="Dashboard"><file name="Abstract.php" hash="e9b622f22beaede0e7d097444be1f744"/><file name="Bar.php" hash="55433f04b2b15053d07f6b6d80ca6e8e"/><file name="Diagrams.php" hash="15341f9925a159eca333fed855d569f1"/><file name="Graph.php" hash="f20a65054e9186820dc0527092f7b30f"/><file name="Grid.php" hash="9468ed7c5da000af3cd3354dbcfbe3e9"/><file name="Grids.php" hash="2235cdd24831e25fad2aaac38789ecc7"/><dir name="Orders"><file name="Grid.php" hash="f92d2a66236995ae2e3951c54b24c436"/></dir><file name="Sales.php" hash="f3365fc3d801700304cee4aa373e9ce9"/><dir name="Searches"><file name="Last.php" hash="9bb819e172cbea12c16e4cda910f24b0"/><dir name="Renderer"><file name="Searchquery.php" hash="01e38618ae9218a3ad748a0a8d22fc7a"/></dir><file name="Top.php" hash="e9db73d797a14f1494e152ebf7269f72"/></dir><dir name="Tab"><file name="Amounts.php" hash="de998abe0165fb810473b79a1f1bc52b"/><dir name="Customers"><file name="Most.php" hash="a95156aa6735fffae2e592b17833cda6"/><file name="Newest.php" hash="d59d800b48df42ae85c886c76e9cd840"/></dir><file name="Orders.php" hash="95dc17af38b3fe3ad4be51fd191e6b52"/><dir name="Products"><file name="Ordered.php" hash="1ecba3f7f07991aabd7be7b185c71894"/><file name="Viewed.php" hash="3d68267acd0253df57f17deff5408d19"/></dir></dir><file name="Totals.php" hash="3dd71832f902929b1a06defb8b2e4887"/></dir><file name="Dashboard.php" hash="3fca911a8afb8417625a04318171f6a5"/><file name="Denied.php" hash="55a2dc1b2b2839eece570dd602ee040a"/><dir name="Html"><file name="Date.php" hash="147063fc866d415b9376a07fbee91a8d"/><file name="Select.php" hash="48b825c9be24ec326febf95f5c9449fc"/></dir><dir name="Media"><file name="Editor.php" hash="6e1604888e79ece680f2764aa2a7dd39"/><file name="Uploader.php" hash="0c0851fbef753a9b982d225b498c7fd9"/></dir><file name="Messages.php" hash="917f968f40fde4c6d94b639deed48bdb"/><dir name="Newsletter"><dir name="Problem"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="a3ee987724942adc84bfe94f8c6139ed"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="b1a2993d634b5db32a8140c18f673868"/></dir></dir><file name="Grid.php" hash="7159ed12e2b23ddfa9061061f5e9fd54"/></dir><file name="Problem.php" hash="0ee1f8f1267589d18f0ad4b3356ae886"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="dfdf35631ee8819a94119def8e936d2d"/></dir><file name="Edit.php" hash="b9de2cb9df47de6d328fb3ebe079e85f"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="25d234ab87104931892193f5c2ff307a"/></dir></dir><file name="Grid.php" hash="f193f8d007edbe4ee0ef0f496de1bb01"/><dir name="Preview"><file name="Form.php" hash="e4f8a2f7926bc6459b427d082a9bfd1b"/></dir><file name="Preview.php" hash="d4ce6dd7a8c03a63b1b40982214ef7a8"/></dir><file name="Queue.php" hash="b24837a0549af04763b22fac18f900c1"/><dir name="Subscriber"><dir name="Grid"><dir name="Filter"><file name="Checkbox.php" hash="81d31d0057e780de4ddd38beab5bac38"/><file name="Website.php" hash="18a46ee8a8cbef2af8da175d84fcfb8c"/></dir><dir name="Renderer"><file name="Checkbox.php" hash="7889c89f8832a14518e3329ffc81e657"/></dir></dir><file name="Grid.php" hash="372b9dee90b9f94802f8f9248e131eaa"/></dir><file name="Subscriber.php" hash="5d02591f5d99b9a034d35274546b2cfe"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="239143579f0958e949bb9a7d1215c947"/></dir><file name="Edit.php" hash="a8f026033bff8c435c5a90ea9684c55d"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="af0f7297d0de92d7e0ca2eb97b4b195e"/><file name="Sender.php" hash="cc7e96026bf1a720199994ac121ec236"/></dir></dir><file name="Grid.php" hash="8adf36fa829d54964b79c902c35cc4b5"/><dir name="Preview"><file name="Form.php" hash="3aae730608509c2de996e87f33535bdc"/></dir><file name="Preview.php" hash="a6d1ee56f1192b2d817a74bd8471cf43"/></dir><file name="Template.php" hash="52e9a3e5ba6a48950bec070e7108de08"/></dir><dir name="Notification"><file name="Baseurl.php" hash="f465f0f939bacf140e17e2a73c68f648"/><file name="Curl.php" hash="5562dffe8f544de14477d633c58d11a5"/><dir name="Grid"><dir name="Renderer"><file name="Actions.php" hash="8a92a77ba89231ce3875212b265feb2f"/><file name="Notice.php" hash="d9d8f4a5657ac3ea69460beb094fab44"/><file name="Severity.php" hash="49a1c0f2b3e3dac83ea17bc415700737"/></dir></dir><file name="Grid.php" hash="b69968b2ffc329bd0d04e6e92cf3c389"/><file name="Inbox.php" hash="cf88df1189b59b5d80e3d80f5c5b5ee2"/><file name="Security.php" hash="a9bf2769b39a9fea4a4ee3ef3d1d9e30"/><file name="Survey.php" hash="1e212b6d13543cd10be01e2b15d60aa6"/><file name="Symlink.php" hash="9666c29f2f3fe03eaf4eaf9ffde45ef4"/><file name="Toolbar.php" hash="a32fa374fd13357033a99c4e41328ed7"/><file name="Window.php" hash="ae90e32783c39946ae4dc1bea9f8ca93"/></dir><dir name="Page"><file name="Footer.php" hash="d1a4e2acaf969095729041c182ca097e"/><file name="Head.php" hash="fe8b20f2fc855b15eab3ebae500b6c4d"/><file name="Header.php" hash="4043dddbd522d15fcbf30fa6b905941d"/><file name="Menu.php" hash="93fc054fa2e6052f07897cd941adb515"/><file name="Notices.php" hash="7298bcaba60c7a5433cccc0ef8fb4869"/></dir><file name="Page.php" hash="79ff758d432530488292c1d04d45be3f"/><dir name="Permissions"><dir name="Block"><dir name="Edit"><file name="Form.php" hash="250070fd2e5ff2b561696484204f1b26"/></dir><file name="Edit.php" hash="84137babee7bfaf5d74ec8d1abe7bc94"/><file name="Grid.php" hash="2af86b670dfa0daafa87c68549248c42"/></dir><file name="Block.php" hash="ba75e154ab0dacea1a496f5dddff3ee5"/><file name="Buttons.php" hash="cc95103c467e1690fa1a3af947d41934"/><file name="Editroles.php" hash="7000bd2a967324d4d8f59d9fba69e994"/><file name="Edituser.php" hash="37fd49b06155831e001aa72616c59334"/><dir name="Grid"><file name="Role.php" hash="e664e65f34a4a2388646dbc1593f2459"/><file name="User.php" hash="ff6e1722cf7d2dfabbc81714030e0900"/></dir><dir name="Role"><dir name="Grid"><file name="User.php" hash="e423bc61a4afa341ab8431ed444645fd"/></dir></dir><file name="Role.php" hash="af24afd4eb11f6285219e4b0f49ea70d"/><file name="Roles.php" hash="97918d7e78298f17f35d7443d5bd0397"/><dir name="Tab"><file name="Roleinfo.php" hash="d3d1b327c9ee471c97b8c811024df0f5"/><file name="Rolesedit.php" hash="94acaaef7675950120a511958a16e3fe"/><file name="Rolesusers.php" hash="1162dcc0461c5d27aa79632950888a48"/><file name="Useredit.php" hash="d299e6842fe7c46578c54e0987c79429"/><file name="Userroles.php" hash="99621d6b7b827435b75ebdd609b9b558"/></dir><dir name="User"><dir name="Edit"><file name="Form.php" hash="e56981d6fca4121ddc406e8c4888191d"/><dir name="Tab"><file name="Main.php" hash="14a3fc3b16f5834c34840ec6af6fe852"/><file name="Roles.php" hash="39263f8d830d709a68c1d3ddb3c5023c"/></dir><file name="Tabs.php" hash="dec4daa38e5951c969353b03f2d651e6"/></dir><file name="Edit.php" hash="bb570d5036d34531b46fd29c813f9234"/><file name="Grid.php" hash="66f37feace5315656052e355cf1030d7"/></dir><file name="User.php" hash="e566d45d3baba405d9c8d464c0face4c"/><file name="Usernroles.php" hash="5db4ffc12fef23f814dd5402e74e738f"/><file name="Users.php" hash="ee78f2adc119a2fc2ffe8a89ceebd57b"/><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="c386f51bfb9ce0bd67f6f85750bca473"/></dir><file name="Edit.php" hash="9cebf0be6ab18ef6682bae2c95ec316f"/><file name="Grid.php" hash="6768cd076848b08656653fac8c9304dc"/></dir><file name="Variable.php" hash="854436ed296fa61143eaad2012e00be2"/></dir><dir name="Poll"><dir name="Answer"><dir name="Edit"><file name="Form.php" hash="d1d567516ad5d195f58118d74a3c9485"/></dir><file name="Edit.php" hash="ea60da414febac398ad8a5f7e960a4d4"/></dir><dir name="Edit"><file name="Form.php" hash="f49681920874b6306db0b84bcddf29fb"/><dir name="Tab"><dir name="Answers"><file name="Form.php" hash="e4352cb54881242eeb76e16d3d0d57bf"/><file name="Grid.php" hash="72fe16bf15a5afba06165e359dafb80e"/><file name="List.php" hash="2689aa93a8757a2c622930cc30578fe6"/></dir><file name="Answers.php" hash="16b63468731527503a41202fa1210462"/><file name="Form.php" hash="fb78e237210fc3aaacafa7a260e08aaf"/></dir><file name="Tabs.php" hash="5d78bfe8c000e5dc45436bafa25d3006"/></dir><file name="Edit.php" hash="cf70265c9750388d2cdd235c5a92696a"/><file name="Grid.php" hash="37e4d5a930b9f642f3b5a98edcd667cd"/><file name="Poll.php" hash="438e44affda9859ccc07067d873e6640"/></dir><dir name="Promo"><dir name="Catalog"><dir name="Edit"><file name="Form.php" hash="8a71206ef66c7370119b4f2b348edabe"/><file name="Js.php" hash="0489e9289d574d351faf222342f3e5c2"/><dir name="Tab"><file name="Actions.php" hash="756556f16aae2e7d5099dd9ac0d6c3d9"/><file name="Conditions.php" hash="9fc57c4ed418a0cec1bd2006983d57bf"/><file name="Main.php" hash="068a51f801b94b4fdd7f2352f838c2ef"/></dir><file name="Tabs.php" hash="98c91073906792a0c6296fb83a7ab330"/></dir><file name="Edit.php" hash="99dbb202deb0b9f05801a63e42d31b0d"/><file name="Grid.php" hash="22be7c2ac5741cbe5d060c89cfd39f49"/></dir><file name="Catalog.php" hash="1ae39c43c5f75785edf1c5324a4290fc"/><dir name="Quote"><dir name="Edit"><file name="Form.php" hash="4a8463187cb19e25ea975cc2ed11d664"/><dir name="Tab"><file name="Actions.php" hash="ed58616f357944eb2f73a28f7efc1e39"/><file name="Conditions.php" hash="7febefb8d3f16e24e2bd3fa260135955"/><dir name="Coupons"><file name="Form.php" hash="d98e35ad0a8920bfbd3ef6c71978859f"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Used.php" hash="226bef3f5347cf5f87223f15602fcb58"/></dir></dir></dir><file name="Grid.php" hash="b8f3bb64730a0ad22621d4de28e4934a"/></dir><file name="Coupons.php" hash="6b15976a6d1f15012490237346d6057f"/><file name="Labels.php" hash="0374ba4e22cb6afe418cd0a2a85020cc"/><dir name="Main"><dir name="Renderer"><file name="Checkbox.php" hash="18855aea907c954a5475117a205635ea"/></dir></dir><file name="Main.php" hash="2bdacfbe90630bdd2ee8f23a66b64dd3"/></dir><file name="Tabs.php" hash="1bd68564db436b417f488bac6e097758"/></dir><file name="Edit.php" hash="8ce5af06e914dae03f0886ea05866af2"/><file name="Grid.php" hash="2a5f9302cce1fb40f796cc592299a524"/></dir><file name="Quote.php" hash="13e7c6d67080c994fb2a1cc59404406c"/><dir name="Widget"><dir name="Chooser"><file name="Daterange.php" hash="70bf48e3059b5118e63343e17948229d"/><file name="Sku.php" hash="2f0b0875caa8efd274aa26efa2334fe8"/></dir><file name="Chooser.php" hash="7db7b478b3c1b1595c483b4268aecdc4"/></dir></dir><dir name="Rating"><dir name="Edit"><file name="Form.php" hash="e21a9307f72c2026b066d7557ce9c57f"/><dir name="Tab"><file name="Form.php" hash="d7d970cc0d7d9dd10d7a03e808a8aed4"/><file name="Options.php" hash="106e1377ecef0876c9bd2542335c6435"/></dir><file name="Tabs.php" hash="f9210a4da76b60fc6446f5cb7addccad"/></dir><file name="Edit.php" hash="c72a2464231e82c381f94454562eebbc"/><file name="Grid.php" hash="eb80f7c545a4a0071addfe7f015da33c"/><file name="Rating.php" hash="39bb6e11d3bae43bfb4d35169ee4e41b"/></dir><dir name="Report"><dir name="Config"><dir name="Form"><dir name="Field"><file name="MtdStart.php" hash="a924ee763c18e3ed80b87d748f282cb2"/><file name="YtdStart.php" hash="cdb5ef1ce2da5813d13fe8f72a7079f7"/></dir></dir></dir><dir name="Customer"><dir name="Accounts"><file name="Grid.php" hash="125f58e5a98c21f5c7f41af2f18e1ba5"/></dir><file name="Accounts.php" hash="ba03c8be6d24be78a3348205d7b1c59b"/><dir name="Orders"><file name="Grid.php" hash="3b6c90bf0a2d500f55c37c463476e022"/></dir><file name="Orders.php" hash="b2bcb3c005b9d3b5e79640eb56b3085c"/><dir name="Totals"><file name="Grid.php" hash="53a10e918398bb631825e0834fffcfd8"/></dir><file name="Totals.php" hash="d6922f6143aeb8edc9b420afed078929"/></dir><dir name="Filter"><file name="Form.php" hash="d5b993228db6ed19ef0db663fe9e7815"/></dir><dir name="Grid"><file name="Abstract.php" hash="33f0615bff06d6080788293420ae1e03"/><dir name="Column"><dir name="Renderer"><file name="Blanknumber.php" hash="264f57bbe36d99209dbe4a459c860c9a"/><file name="Currency.php" hash="e6f4db3f02df326305086b0fb4a0af56"/><file name="Customer.php" hash="9347c243bfbe02bbf19b86e1eec157e6"/><file name="Product.php" hash="f9addb0013529e496f972c221f32ad40"/></dir></dir><file name="Shopcart.php" hash="897da04c70099203dc40de8f5c75706c"/></dir><file name="Grid.php" hash="7f61478562abc700c6e845e3a5f6dd63"/><dir name="Product"><dir name="Downloads"><file name="Grid.php" hash="09b580cf3a9b12333b637671c3d6a977"/><dir name="Renderer"><file name="Purchases.php" hash="31ebc48790ea8d1796aff7a0a26a98b0"/></dir></dir><file name="Downloads.php" hash="2601b484b6ec5f115f2c134b3ed56c6c"/><file name="Grid.php" hash="9739764d528da1173b74476aeaa90343"/><dir name="Lowstock"><file name="Grid.php" hash="d0cc3ec79ae288d3480dfeeb49396c0d"/></dir><file name="Lowstock.php" hash="606e6f1affec1d43c4a2d2169a0c2219"/><dir name="Ordered"><file name="Grid.php" hash="654181d62c7cc2623e3f97ab10e86d26"/></dir><file name="Ordered.php" hash="a16dad58467e0e2226a414dbfc4c00b0"/><dir name="Sold"><file name="Grid.php" hash="1966a5e024bca07b470fbd397c872be3"/></dir><file name="Sold.php" hash="7a6e7b04579774dadc2be4047b3ae258"/><dir name="Viewed"><file name="Grid.php" hash="b1d1e9daae03ff525976ef8bc1241688"/></dir><file name="Viewed.php" hash="44359a7eb23f239951867a192ffb73a6"/></dir><file name="Product.php" hash="b12b9b84f824c934beb2aa12f65047e3"/><dir name="Refresh"><dir name="Statistics"><file name="Grid.php" hash="464179727ceb08e438e264b02ab15883"/></dir><file name="Statistics.php" hash="c481a493b5a1bcacfc6667e1e3375ae5"/></dir><dir name="Review"><dir name="Customer"><file name="Grid.php" hash="eaeb6261c45a8a129afc019a40571971"/></dir><file name="Customer.php" hash="df0464f31e9650434fbe505d2b5d6fc6"/><dir name="Detail"><file name="Grid.php" hash="48a704b1a6307f9997d1c401e071a188"/></dir><file name="Detail.php" hash="e92d6d12ad04061df9a012d4d2427b6e"/><dir name="Product"><file name="Grid.php" hash="49466f8a9c3731ea13ae75b354da2388"/></dir><file name="Product.php" hash="36570e05c5e34a57de894ae2ce35157f"/></dir><dir name="Sales"><dir name="Bestsellers"><file name="Grid.php" hash="29dbb485598a8d96cbdfb9876d189443"/></dir><file name="Bestsellers.php" hash="dece62b23890be79025bce175a8873ad"/><dir name="Coupons"><file name="Grid.php" hash="2aa7f3681c09b4d48f3d9d17d71f5a99"/></dir><file name="Coupons.php" hash="231ae689b8b1369b863751203f5f6e56"/><dir name="Grid"><dir name="Column"><dir name="Renderer"><file name="Date.php" hash="57689030e9f44bd0253341acc821f4e4"/></dir></dir></dir><dir name="Invoiced"><file name="Grid.php" hash="490362b3d8b9474ded06a9af9176222c"/></dir><file name="Invoiced.php" hash="cad6ff9f84bd43374ca9b1f47fa5265c"/><dir name="Refunded"><file name="Grid.php" hash="104056775346b260c39b570e2c29c77b"/></dir><file name="Refunded.php" hash="53cf2c3212b5414a8448e53d327d739b"/><dir name="Sales"><file name="Grid.php" hash="1771f104565bc2a606cbcf662b5a6f95"/></dir><file name="Sales.php" hash="b564b60052182d9d7989c810250c1525"/><dir name="Shipping"><file name="Grid.php" hash="179ac71bc9e787df09c2d697d844fd50"/></dir><file name="Shipping.php" hash="c7650cc6c9ad2e168856e6bdbfd60d31"/><dir name="Tax"><file name="Grid.php" hash="13f4fce239c6834032118bbb95a85746"/></dir><file name="Tax.php" hash="03bb6ddb944a0f6cb818b8cb765ba928"/></dir><dir name="Search"><file name="Grid.php" hash="db8fb084a7392cffb50c8988b255048d"/></dir><file name="Search.php" hash="3d903ea0062a23a38afdb6257277ef69"/><dir name="Shopcart"><dir name="Abandoned"><file name="Grid.php" hash="11bfeff5565ac8391cbe21ad8dbc634e"/></dir><file name="Abandoned.php" hash="6c275144d3c233203b915836a99b9256"/><dir name="Customer"><file name="Grid.php" hash="33f38ff6795ca48a865be1ba8c1b626b"/></dir><file name="Customer.php" hash="46176721eeaf6b1d13cbd2ee4aac9c32"/><dir name="Product"><file name="Grid.php" hash="9863a30d2c53906b3a650bc4944fb60d"/></dir><file name="Product.php" hash="8db7478a73364dbe0f6b743eb796eeb4"/></dir><dir name="Tag"><dir name="Customer"><dir name="Detail"><file name="Grid.php" hash="e7ae098944aaede6d0e634ec58d7b1ba"/></dir><file name="Detail.php" hash="6c1d2a0744e3c1e47bd0d0b4e7f94896"/><file name="Grid.php" hash="38856f03efc67f4a26af2172a1af3a0a"/></dir><file name="Customer.php" hash="46ff79f5e4a9f582bce155b0f7b8ae1f"/><dir name="Popular"><dir name="Detail"><file name="Grid.php" hash="b03fc43b10d29d5a398b73cd1c2dbea3"/></dir><file name="Detail.php" hash="27d0cbb728aac205394a42c1ab85c5c4"/><file name="Grid.php" hash="d18cf3969a7adad625b60b28941a7270"/></dir><file name="Popular.php" hash="bb4e3f5e49419d3c8eda46df6aaa4f70"/><dir name="Product"><dir name="Detail"><file name="Grid.php" hash="b1450dab9226d4a9b2e84c1ce6cf6e5c"/></dir><file name="Detail.php" hash="5e836c4da0c50d12e616d5b6a129acea"/><file name="Grid.php" hash="ab880e5c3a6cc0b4e3efb3933e42b1c1"/></dir><file name="Product.php" hash="622c74aba260ccb80b7cd0466b254740"/></dir><dir name="Wishlist"><file name="Grid.php" hash="30c6507df24b9530e52d9abf2d72db92"/></dir><file name="Wishlist.php" hash="29c55462d5a7ba74bf944920ba32b88e"/></dir><dir name="Review"><dir name="Add"><file name="Form.php" hash="afaad3889588d19e78c5358ca31053bf"/></dir><file name="Add.php" hash="bed0d84fbce29827765e870bff16db74"/><dir name="Edit"><file name="Form.php" hash="d94544827780e99378670555538e6b12"/></dir><file name="Edit.php" hash="5131aae643eb8061ce598c127cff9fa4"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="7768070f8509625a9a2cc0178fbb42a2"/></dir><dir name="Renderer"><file name="Type.php" hash="a5871202c5a258f69c23fd938d840062"/></dir></dir><file name="Grid.php" hash="973b7c8444c20e7c6cd2fb3b5bee8320"/><file name="Main.php" hash="486e69de5935dc1233cb6272437d90cd"/><dir name="Product"><file name="Grid.php" hash="045dbe8bfe4482d83b8a1d41622908bd"/></dir><dir name="Rating"><file name="Detailed.php" hash="086e949db4cb03112b61ef64fa4f7c28"/><file name="Summary.php" hash="bed407f557d7f647e62f53a0afd67f0e"/></dir></dir><dir name="Sales"><dir name="Creditmemo"><file name="Grid.php" hash="88232609314c4d8b0badd1ea7abc18eb"/></dir><file name="Creditmemo.php" hash="7077674f1b98929a1746a2e0a2205c36"/><dir name="Invoice"><file name="Grid.php" hash="586cc0285856c88d0b0fe3f8d462fd96"/></dir><file name="Invoice.php" hash="6433788709a2896617beba8246c69024"/><dir name="Items"><file name="Abstract.php" hash="d250e9f03e6ba5df3f5575ac3d669c86"/><dir name="Column"><file name="Default.php" hash="e59a6699310b93569c5769e59c448e8d"/><dir name="Name"><file name="Grouped.php" hash="73fabc3f2ef4e076b7a44da3ec74232e"/></dir><file name="Name.php" hash="93365a10779ab90b16cb70aa7cb76f77"/><file name="Qty.php" hash="fd55983a3475987721b675907117e114"/></dir><dir name="Renderer"><file name="Configurable.php" hash="4f21e2b3302da7ae358538833d511241"/><file name="Default.php" hash="e2538c0044a3f905ecc11060a8e4c4d1"/></dir></dir><dir name="Order"><file name="Abstract.php" hash="45739bf1bea027fe45a88d5fb74bc1c4"/><dir name="Address"><file name="Form.php" hash="82c5e9cea0dc8b5c9f975751dba3202a"/></dir><file name="Address.php" hash="5223e26b8bf7b30acdaedddf211eea56"/><dir name="Comments"><file name="View.php" hash="039130ef6c6a23a631f4d96029671e90"/></dir><dir name="Create"><file name="Abstract.php" hash="ec59e0b6e9acd1a548555f9c6799ef6f"/><dir name="Billing"><file name="Address.php" hash="0df1e25bb08dad32e2bfb8a0f9a167ad"/><dir name="Method"><file name="Form.php" hash="a2bb4ecb917e3a761412193d5b742c6f"/></dir><file name="Method.php" hash="199760457b7473e0467d8c214ed11dae"/></dir><file name="Comment.php" hash="6e5f5722608c3338627724fdb4586632"/><dir name="Coupons"><file name="Form.php" hash="69d16bbe72563d8521e6e5c43abd3917"/></dir><file name="Coupons.php" hash="c01e37e722548e4a1a7ea157d71d48b8"/><dir name="Customer"><file name="Grid.php" hash="42df68f6d1fa8156711d8cf3b7cb2987"/></dir><file name="Customer.php" hash="b1cdeeee9cd91ac572963f0290230054"/><file name="Data.php" hash="a53aa485b2e4608e5523efbac2ba510e"/><dir name="Form"><file name="Abstract.php" hash="8342b7df4b622a5c5109ca720be19e76"/><file name="Account.php" hash="bf0f8022c18fec7c2ff2f0467cdbb2bd"/><file name="Address.php" hash="2652debcdd91d9a68eb12f3d14953146"/></dir><file name="Form.php" hash="37cce5735e6474c8f7a318cfea2bcb85"/><dir name="Giftmessage"><file name="Form.php" hash="e6ff0f1c7094056a3659b2fb34f2f6f4"/></dir><file name="Giftmessage.php" hash="5e4419f5ecb48733015043167176cccd"/><file name="Header.php" hash="5a0bd27a1abb28db3a1bd5b8290696c4"/><dir name="Items"><file name="Grid.php" hash="c59b6769d698d9dc758a1d3fbf8b1480"/></dir><file name="Items.php" hash="d70ba8b7eaa08b74fdf180a19066d542"/><file name="Load.php" hash="edeee2ea6deb6fc3751088d80e5dec6d"/><file name="Messages.php" hash="52bfb9f025f9d872f4eb33366957fc6d"/><dir name="Newsletter"><file name="Form.php" hash="c690ca5f1dd244de31d6b72232f9eea6"/></dir><file name="Newsletter.php" hash="8b2bee63e50417114d5dbce7fc71cd6c"/><dir name="Search"><dir name="Grid"><dir name="Renderer"><file name="Giftmessage.php" hash="04e63b8afe6cbd37db3129f4e8c699ab"/><file name="Price.php" hash="5281d1c8a312ca741d58d14fbe3deced"/><file name="Product.php" hash="0b76bf90a8f2d5cdbd4b18fb16b2eaeb"/><file name="Qty.php" hash="54cee680adfc48caf551e4a8cb2fdec0"/></dir></dir><file name="Grid.php" hash="fa13dba8c6b9700b46f29aede759923d"/></dir><file name="Search.php" hash="fa316633bbf0f02bb4d2baa6468b67c5"/><dir name="Shipping"><file name="Address.php" hash="644215db3b8a9085255f789305f5381a"/><dir name="Method"><file name="Form.php" hash="08be11adb3b48c77c52a4df4e5e66a26"/></dir><file name="Method.php" hash="61ea096b05b007410b26237b5dac302c"/></dir><dir name="Sidebar"><file name="Abstract.php" hash="f5b8c9e2b61f4f0efea22f739a196d88"/><file name="Cart.php" hash="c784182a9c3558519fd56a968a19deb6"/><file name="Compared.php" hash="b844720f38bb949d43a32dc773b15da7"/><file name="Pcompared.php" hash="8ebcbb054c9f682c0c2e10d206ad94bf"/><file name="Pviewed.php" hash="bbc071c18335ae066a5aefab212a07d4"/><file name="Reorder.php" hash="e09f2c7ee365800730e50e8d95cd6cb3"/><file name="Viewed.php" hash="8e2b366150e6802afdec9685d65ff409"/><file name="Wishlist.php" hash="daf7e737f3141d392d83e387a3ad6fd5"/></dir><file name="Sidebar.php" hash="5aadf67f34a30f866cc04cb8ef00f1ab"/><dir name="Store"><file name="Select.php" hash="58494c02e8b891e02250cebcdd60362c"/></dir><file name="Store.php" hash="52ed6a59d9094d816a28ab1e01352588"/><dir name="Totals"><file name="Default.php" hash="87c47abc5ae14e81b6e51726085b790c"/><file name="Discount.php" hash="333db7abe6b23ea11f6a4babad105817"/><file name="Grandtotal.php" hash="bf2e0c7eeecf93046d19881d27eb626d"/><file name="Shipping.php" hash="644e308ae7d0d73ab849225dfcdc2cd3"/><file name="Subtotal.php" hash="629e99987933be9751e043fc485a420e"/><file name="Table.php" hash="06c746d4bf94f0d9b2a102da6548b6ae"/><file name="Tax.php" hash="4e92963bcb4172c5877542c7e061da98"/></dir><file name="Totals.php" hash="95ef4744840cb78571bfe7e4f8dd397c"/></dir><file name="Create.php" hash="e8b2a62d41a7968f5b25ddce7d9b45cf"/><dir name="Creditmemo"><dir name="Create"><file name="Adjustments.php" hash="32d1fe6ba59c5490be8f8cf1a4292616"/><file name="Form.php" hash="761e40421c230555e96f10159985fb83"/><file name="Items.php" hash="71e02814cd463899e34002ca04774338"/></dir><file name="Create.php" hash="f7de01200705869cdcf95f9c7c86224e"/><file name="Totals.php" hash="88425527934940def2f62e07c8376174"/><dir name="View"><file name="Comments.php" hash="02a18178e6ce9a20b8220531b602fe86"/><file name="Form.php" hash="369deccfac5176136831e3a4c2c8f386"/><file name="Items.php" hash="ffe3820202c8615cc98e6b10f966d93d"/></dir><file name="View.php" hash="e7a412b2d713bf9da23f38c9eacdfd18"/></dir><file name="Grid.php" hash="a6b873cf99689a4e185e9cbf39cc461d"/><dir name="Invoice"><dir name="Create"><file name="Form.php" hash="0bb4ca3c8652753a67265fa508e024ae"/><file name="Items.php" hash="b331e20e32951de332b145322da16c6a"/><file name="Tracking.php" hash="176fce657283fe3ab46a978880f37e4e"/></dir><file name="Create.php" hash="fca078516396f61ed4a190e5cf0761a9"/><file name="Totals.php" hash="89ea1b4adccd1527742ef3a635f3e768"/><dir name="View"><file name="Comments.php" hash="231315629330662ac0d4ecfc4b94b956"/><file name="Form.php" hash="fae7a3587b2e65750b78453c202eba62"/><file name="Items.php" hash="e4b7bf50b026c03e5bc6077a41b73ec0"/></dir><file name="View.php" hash="e11d21463b5a54d766bd7156c4b77300"/></dir><file name="Payment.php" hash="bf73b8efb03db49e7981917f58e1999e"/><dir name="Shipment"><dir name="Create"><file name="Form.php" hash="19d7ab1eab9a39680ebb0babc4f889f1"/><file name="Items.php" hash="4d7604a86a11dc60212460a91860eb35"/><file name="Tracking.php" hash="e15d81cff93fad63f6fe9dc4b0936872"/></dir><file name="Create.php" hash="09c569b5a46cc5af4854ad8d6296a94c"/><dir name="Packaging"><file name="Grid.php" hash="708e82d58d7de322ab128c79d690810c"/></dir><file name="Packaging.php" hash="95b1a24a1177c96a0ba0a3994e07f7f4"/><dir name="Tracking"><file name="Info.php" hash="1e9e750fbc5b8dc0eda1300a4fb943ce"/></dir><dir name="View"><file name="Comments.php" hash="3ded55f91490c01aa222a64eb40a9515"/><file name="Form.php" hash="4434a74139f4cb9845feee89840c58f5"/><file name="Items.php" hash="ecff7af6d51846f9be730666df5144fb"/><file name="Tracking.php" hash="d7eb5eb9ccd5fa455e7e734a57956fcc"/></dir><file name="View.php" hash="ece7ff35488a5ef159d67579270f7ec2"/></dir><dir name="Status"><dir name="Assign"><file name="Form.php" hash="9b4e30d3fc1a42c7a6792f22a769852c"/></dir><file name="Assign.php" hash="348bf62626f5a27a803bcca48f20be2d"/><dir name="Edit"><file name="Form.php" hash="17fce0de94d4ad003b94e7c201b46427"/></dir><file name="Edit.php" hash="02492e82607134bf42f0e07a4ee4920d"/><file name="Grid.php" hash="52d5bfd055d4c8fefe78840014442d4a"/><dir name="New"><file name="Form.php" hash="aafe74d46855d19aec5938d4f1391a11"/></dir><file name="New.php" hash="f7256daa0364107d4fab1ac3608138c7"/></dir><file name="Status.php" hash="a9678b586a0e1c0ab78e8c253badf901"/><file name="Totalbar.php" hash="942e16a2630b93ae9d9bf4108896cb84"/><dir name="Totals"><file name="Item.php" hash="b96cedf974257076ea4de13f1ad555e3"/><file name="Tax.php" hash="45e0955cd679c47e17df955dbc9f3145"/></dir><file name="Totals.php" hash="3e21f4a401e6db9a90886f3198b33858"/><dir name="View"><file name="Form.php" hash="0de281fce53e6ce5b974c4750e487a06"/><file name="Giftmessage.php" hash="d72e07778f70449e525bc42cee5b5d1b"/><file name="History.php" hash="5a08d199d187a98156f1510c6a0fb209"/><file name="Info.php" hash="9211aaa0e8640093595a8df1ec7c6a9a"/><dir name="Items"><dir name="Renderer"><file name="Default.php" hash="e27e98952b037349c5ed44bb5d128cff"/></dir></dir><file name="Items.php" hash="b3956ac7700aa0db02a50506f944aabd"/><file name="Messages.php" hash="84d48df928eb3207d26d3d5b48ce4897"/><dir name="Tab"><file name="Creditmemos.php" hash="06b931ce1dfd688af78e108a890a51ef"/><file name="History.php" hash="9e94bfc713c545507825a9de373d367e"/><file name="Info.php" hash="10390772fe22959257922236601cb23d"/><file name="Invoices.php" hash="62d3958b62be9d3143d9955fca3775a7"/><file name="Shipments.php" hash="783fc711e7aa66954429dd618d893c8b"/><file name="Transactions.php" hash="24aec6ab4d074a51f832fe7c3306ceab"/></dir><file name="Tabs.php" hash="5a80c1873ef2d212436e79ba3365fcba"/></dir><file name="View.php" hash="afefa9c1fc0a3d0a509da69a8779b3b8"/></dir><file name="Order.php" hash="867a3d05a32de0ff1951a61495263663"/><dir name="Reorder"><dir name="Renderer"><file name="Action.php" hash="4ade6495da0d4c7861d76d0feebf0754"/></dir></dir><dir name="Shipment"><file name="Grid.php" hash="c73efc5a91cb630bdeb53a23e9d5c8a5"/></dir><file name="Shipment.php" hash="2e4802c132a7b74b7624b5d8eca65852"/><file name="Totals.php" hash="af26a6ae487a2c19212f27dcc203d754"/><dir name="Transactions"><dir name="Child"><file name="Grid.php" hash="422f95a665f1402a96df6dd41e48c625"/></dir><dir name="Detail"><file name="Grid.php" hash="ac07bd664ec30c7cd9cc776dd91df9a7"/></dir><file name="Detail.php" hash="466d909abf726e521ebf4a26ea30634d"/><file name="Grid.php" hash="613517e585a284162339c165ffa355b0"/></dir><file name="Transactions.php" hash="759dc094205d6f50e306ee8895a8e1c1"/></dir><file name="Sales.php" hash="85e41bd256030dc381bf41937229b2c8"/><dir name="Shipping"><dir name="Carrier"><dir name="Tablerate"><file name="Grid.php" hash="215ad38165d867ae249379a4aa14df0f"/></dir></dir></dir><dir name="Sitemap"><dir name="Edit"><file name="Form.php" hash="9298d64b4d901d31349e814185114c17"/></dir><file name="Edit.php" hash="f32576c26bbe22bcdcb0d0e906b501d2"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="049bafed18d2a6fc243f321e2e5f910b"/><file name="Link.php" hash="860fc688a2e32b4748995803ac626e2e"/><file name="Time.php" hash="8f7abc65d6b76ab7afe860ab973f0f1b"/></dir></dir><file name="Grid.php" hash="7fcaa769f080c3af1a7ac6ba05acf035"/></dir><file name="Sitemap.php" hash="0eb9104cbb4a1083a08c2f80e06a3655"/><dir name="Store"><dir name="Switcher"><dir name="Form"><dir name="Renderer"><dir name="Fieldset"><file name="Element.php" hash="178f45f348a82528daa1512ad6398914"/></dir><file name="Fieldset.php" hash="4da413d2e88f9e9327a8f9f3d49c5206"/></dir></dir></dir><file name="Switcher.php" hash="abdfb8b0b9d50e1d26bf670c7cc52d04"/></dir><dir name="System"><dir name="Account"><dir name="Edit"><file name="Form.php" hash="724d0ef86dc2c8c6162211a9ab014898"/></dir><file name="Edit.php" hash="1c0133fdd5deb83b037f59e5e81d147b"/></dir><dir name="Cache"><file name="Edit.php" hash="c460241a6e8b297afdd79869b00ff3ed"/><file name="Form.php" hash="9e04a6ffa820d5226c59fa5b18c20711"/></dir><dir name="Config"><file name="Dwstree.php" hash="9dc81b84d226f9488df3191857731a63"/><file name="Edit.php" hash="62a74fc635fbbc827eca2a4fea3f063b"/><dir name="Form"><dir name="Field"><dir name="Array"><file name="Abstract.php" hash="2d7e1f8baf6b40cf99eabee0bf6ee026"/></dir><file name="Datetime.php" hash="9dcfda6124cf0f25dba073b32826b610"/><file name="Export.php" hash="608bf1d1cfd31f10ebf78da291884ac5"/><file name="File.php" hash="3e31f49c77e40d674ca3f3db948c93c6"/><file name="Heading.php" hash="1cf79e6c2edd686b11be095bd5d4268f"/><file name="Image.php" hash="fe9ffa0ad2172d26a9684dcc7cb00a4a"/><file name="Import.php" hash="d291487bc5eb16f732f5e41884b498d4"/><file name="Notification.php" hash="062c73fd8066aff6b5f9650f97a71fa9"/><file name="Regexceptions.php" hash="4373b8ee96f0cc0d7a7dcfcf228b6b49"/><dir name="Select"><file name="Allowspecific.php" hash="0ef107ae4c63c0e016908359bf69a0f9"/><file name="Flatcatalog.php" hash="a246011eedf68f0cd42bbc73c71de0c2"/><file name="Flatproduct.php" hash="4f3784430bd835136e33988cc4bc3a84"/></dir></dir><file name="Field.php" hash="4f8d09202ed37588f4cf00923e14dfc2"/><dir name="Fieldset"><dir name="Modules"><file name="DisableOutput.php" hash="e302059fa3248cc48e520b4cc1554799"/></dir><dir name="Order"><file name="Statuses.php" hash="39de6497e1e23218883690ebc1c211d6"/></dir></dir><file name="Fieldset.php" hash="cc88cdd430c4a2d1036797f53d001adf"/></dir><file name="Form.php" hash="a4a4dfcbdf301c3c580e177713a7717e"/><file name="Switcher.php" hash="47be4380f93f25f25c08f7a9489c4a53"/><dir name="System"><dir name="Storage"><dir name="Media"><file name="Synchronize.php" hash="3ba97d2aeae4e2b987533a688769ba3f"/></dir></dir></dir><file name="Tabs.php" hash="7a76ed4c223c359a3a6a08c33d0d2650"/></dir><dir name="Convert"><dir name="Gui"><dir name="Edit"><file name="Form.php" hash="34a1d852071e8a668f9a918233934ef5"/><dir name="Tab"><file name="Upload.php" hash="066c77626c21cd66040bdbf6b7166f65"/><file name="View.php" hash="69b9e0b0604d36be0f2c5813252a3c58"/><file name="Wizard.php" hash="238c81cd7d8005aa5880d9a19d4e4db7"/></dir><file name="Tabs.php" hash="6522c80d035883c2281e1e909369f2c3"/></dir><file name="Edit.php" hash="d19f3f451824a9cc61ad4ce2f43e363f"/><file name="Grid.php" hash="d9b48baef0ed72de626ac7f436200047"/></dir><file name="Gui.php" hash="4350827a669efe856906d9ab68b6e385"/><dir name="Profile"><dir name="Edit"><dir name="Filter"><file name="Action.php" hash="bde22deee315064248611ed6b2ad16ab"/></dir><file name="Form.php" hash="4a2e8ed06a8d59c0c2100d0ed7c53a63"/><dir name="Renderer"><file name="Action.php" hash="8c9b0e1db555843b1c83a492c3abd778"/></dir><dir name="Tab"><file name="Edit.php" hash="69cd410e98c0786054a0b79e8b7ce271"/><file name="History.php" hash="2c5916e829b695ef6a70de18b00cbd4e"/><file name="Run.php" hash="931a4d60bf3a8617e7ffa6897ca4433e"/></dir><file name="Tabs.php" hash="73fd658cee413fc7188d164621bdd0a2"/></dir><file name="Edit.php" hash="b36ff98cebc8065a3adc2761061b47e2"/><file name="Grid.php" hash="9398722801c514cfc9dce17de92da075"/><file name="Run.php" hash="69c6338a4f4c3a0798c4c8aa4e3b579a"/></dir><file name="Profile.php" hash="3e3d88171cb6bd5f5e65de243f7ca0bc"/></dir><dir name="Currency"><dir name="Edit"><file name="Form.php" hash="2aa4d9904e2605aef4518e673543c2d5"/><dir name="Tab"><file name="Main.php" hash="25aaab5e589d6188c1b5c518e83a1e8e"/><file name="Rates.php" hash="a00b269f40e627cfce099601de20a91f"/></dir><file name="Tabs.php" hash="5e83f641504801a639f8328b03e13b3a"/></dir><dir name="Rate"><file name="Matrix.php" hash="57b842fd652808ba57af02beba73eed9"/><file name="Services.php" hash="d627271f20ed93d2b8e21ed3f92da34e"/></dir></dir><file name="Currency.php" hash="e8c5e50cfd955cae70566f634e73955f"/><dir name="Design"><dir name="Edit"><dir name="Tab"><file name="General.php" hash="d9401ff15ad83db694e9a675a8b79930"/></dir><file name="Tabs.php" hash="ca472f52eeed68ee4cfc7c2e11fe40ba"/></dir><file name="Edit.php" hash="cb2793aae1f1928305a810504025ac25"/><file name="Grid.php" hash="ecb9e5c60a2662eb67072da076b9f8e7"/></dir><file name="Design.php" hash="8d2e0a9860c04659ac9bb5b00a8d36e4"/><dir name="Email"><dir name="Template"><dir name="Edit"><file name="Form.php" hash="4047d7b28bb1012fe744352cff61e5f1"/></dir><file name="Edit.php" hash="d41764fc3f30dc19e94b3fac784ea5a5"/><dir name="Grid"><dir name="Filter"><file name="Type.php" hash="3a65e0cb2c719ce6cdcbffe7a8d39f0f"/></dir><dir name="Renderer"><file name="Action.php" hash="57385d1912ed259f426016c3c672efb2"/><file name="Sender.php" hash="a66f1b1e1640834752075fa9a25bfaa5"/><file name="Type.php" hash="149b001b475f99f68a8adb4121ad1a0f"/></dir></dir><file name="Grid.php" hash="299c926a54231aca1fda3218a57b98f1"/><file name="Preview.php" hash="ea13a3cca97ce05f7e26ae28547b336e"/></dir><file name="Template.php" hash="070f119a1cf4cec9086dbf3622884659"/></dir><dir name="Store"><dir name="Delete"><file name="Form.php" hash="1b12724f41ddc9804df3b1adc6aaf3b4"/><file name="Group.php" hash="a98de1773de879fe1802c191eb3dcb47"/><file name="Website.php" hash="712be69f55e4eb7497d00503f90dfa62"/></dir><file name="Delete.php" hash="950ce6a762483f6a9bc170ebe05c2cee"/><dir name="Edit"><file name="Form.php" hash="ff454cbc44bac6db7fe60cee729a65bb"/></dir><file name="Edit.php" hash="f934328a7507894c6ac16220e4fbaf21"/><dir name="Grid"><dir name="Render"><file name="Group.php" hash="a646b1e1c09442a6cd35b7ade3d1c58b"/><file name="Store.php" hash="af46fe92709138edaa34b7879f706b21"/><file name="Website.php" hash="2d9611dd6962917458dc27f1d0316547"/></dir></dir><file name="Grid.php" hash="aae919b8ddc65ed826860c12ee490818"/><file name="Store.php" hash="b9dce08fb5186579db7c0a2f141ebb0e"/><file name="Tree.php" hash="83f34a90883f0b5564542578827e9573"/></dir><dir name="Variable"><dir name="Edit"><file name="Form.php" hash="afe3ac35fcc2392f59bbf6149edeac43"/></dir><file name="Edit.php" hash="925d823e86aaf0e826634293d7215f00"/><file name="Grid.php" hash="4b7ea75f0c7c529adc1e46d1558bf99c"/></dir><file name="Variable.php" hash="8e26f5d1efad4bae053f03be0f610080"/></dir><dir name="Tag"><dir name="Assigned"><file name="Grid.php" hash="6fa9719638788074f2fe3e6c6f4ecdda"/></dir><dir name="Customer"><file name="Grid.php" hash="a69779f7f5b3fd4b5468a2987f4d5cb5"/></dir><file name="Customer.php" hash="fac677a42c59f5b7c0db6ae3e41a28a5"/><dir name="Edit"><file name="Accordion.php" hash="c09b6c3363882b5f4ca602206e20bdd4"/><file name="Assigned.php" hash="c581c8584f80bce4b4edf844f2d799de"/><file name="Form.php" hash="969c221079de8c9389d192015fc1b363"/></dir><file name="Edit.php" hash="c3c5820f753a002280969f08684adf2c"/><dir name="Grid"><file name="All.php" hash="244719441585726e8832ec01aa28489a"/><file name="Customers.php" hash="024dc8c415e729da49c4c6f7efea6224"/><file name="Pending.php" hash="b31394982859de98ff2286e92c55e5c8"/><file name="Products.php" hash="2bc99ba096bf8c4b2c86e950972a4982"/></dir><file name="Pending.php" hash="f34333f6bd655698aeb7300560c2dfbc"/><dir name="Product"><file name="Grid.php" hash="9f48afaacded433fc2ab57aa44a324ba"/></dir><file name="Product.php" hash="e6662e0fa5c8aef9d635e0bc0335e5ce"/><dir name="Store"><file name="Switcher.php" hash="7ba7c60103ea6392fc3e084bd7f0c356"/></dir><dir name="Tag"><dir name="Edit"><file name="Form.php" hash="c2fd548e26992867848bbeaa57fd025c"/></dir><file name="Edit.php" hash="26d55cbf55b3f3d277211dcfad794b06"/><file name="Grid.php" hash="98b5ca760618f3b79f6c8fdc88ae4e18"/></dir><file name="Tag.php" hash="3d27c57ce9b27289afed85ac471ab0ef"/></dir><file name="Tag.php" hash="5c2b86b81776c7ec3b2330855d2131cf"/><dir name="Tax"><dir name="Class"><dir name="Edit"><file name="Form.php" hash="c73474e1fc6a2fc4c0b9f711a7d184b5"/></dir><file name="Edit.php" hash="114a8bb193e2997625dce40dc511df51"/><file name="Grid.php" hash="4221025a57309a6a5d22fa8182339fc7"/></dir><file name="Class.php" hash="358ecb085cbf35c3bf9b86aab272e649"/><dir name="Rate"><file name="Form.php" hash="735b3fcccc099415edc49f14a9af7930"/><dir name="Grid"><dir name="Renderer"><file name="Country.php" hash="bd524126080e5ad5ed76d9248088bca1"/><file name="Data.php" hash="ffb41b73434fd919d306b80f7401314f"/></dir></dir><file name="Grid.php" hash="bf204ae63b3141dda2c7b94cb23a9671"/><file name="ImportExport.php" hash="a9cb8e94f63288d5a29c0c869d08147e"/><dir name="Title"><file name="Fieldset.php" hash="e72758c8f41e5194766181af24dcd262"/></dir><file name="Title.php" hash="a0cdd4e6d31a66bdabc019a226a20a2e"/><dir name="Toolbar"><file name="Add.php" hash="6aca1ecf71403052514123d02cd4f63c"/><file name="Save.php" hash="d30485a1be9d7a6b98470eac448a21d3"/></dir></dir><dir name="Rule"><dir name="Edit"><file name="Form.php" hash="05f178eb2ea1a3a9f43a16ae80f9055e"/></dir><file name="Edit.php" hash="470b4b4dfe09841c7a1fe4d892b17aa3"/><file name="Grid.php" hash="b30e13cbf1bb1c9fd92b7a285a6422a8"/></dir><file name="Rule.php" hash="28c4e8a83882aafe18d4343de91830be"/></dir><file name="Template.php" hash="36f5b292f4e2ae33b30fe3d73c86b5eb"/><dir name="Text"><file name="List.php" hash="5b923aafef84752e8274560dde17b89c"/></dir><dir name="Urlrewrite"><dir name="Category"><file name="Tree.php" hash="bce8f4744813be70932966b5948dd779"/></dir><dir name="Edit"><file name="Form.php" hash="f3c8420dce816fea6c2220933c2176fd"/></dir><file name="Edit.php" hash="0dc9b099d51583d6bb77931db9dee2a5"/><file name="Grid.php" hash="6e12625945f32cd3d3c4cfc34e5e3da0"/><file name="Link.php" hash="0311e1099bc46104d3af6b2ad234f257"/><dir name="Product"><file name="Grid.php" hash="b353f6dffd20c5255b7910e2e9860632"/></dir><file name="Selector.php" hash="abfe917849402fda943214cb238d9f7c"/></dir><file name="Urlrewrite.php" hash="96f5cc86bb6657cb7671fb8d40e8dda8"/><dir name="Widget"><dir name="Accordion"><file name="Item.php" hash="862b7ac1ae6da1ff3396d7eaa6476fc7"/></dir><file name="Accordion.php" hash="2bfd91842c44da9c2d928ee59d99d424"/><file name="Breadcrumbs.php" hash="f2e9c982e431beef24e9531ea282a65b"/><file name="Button.php" hash="e41efda16c0c57798b0c92329e8449bd"/><file name="Container.php" hash="519866b42615db90c75f953abface41d"/><dir name="Form"><file name="Container.php" hash="1e11d0757aa1b79dd549630a39b59196"/><dir name="Element"><file name="Dependence.php" hash="0bd48ed91f763b4cee92b7def6c1e0ec"/><file name="Gallery.php" hash="9bd81ae35f97f0c8865ba4065d727a99"/></dir><file name="Element.php" hash="2de7b0945e2fdab89265ffec97dac5ae"/><dir name="Renderer"><file name="Element.php" hash="1337caa569089562b6fc3fcb84fd30d4"/><dir name="Fieldset"><file name="Element.php" hash="1bdbf1b7b6f9b7f00e7954c5bf62380d"/></dir><file name="Fieldset.php" hash="3c5376aebd05abd599f989f02623203c"/></dir></dir><file name="Form.php" hash="f15c69923ae2f35b3bc98b0243c9cbc1"/><dir name="Grid"><file name="Block.php" hash="b1d3f1e3b1f35b26291a6986dc700756"/><dir name="Column"><dir name="Filter"><file name="Abstract.php" hash="9ec8d38af2e0a97aca97bd840338dbad"/><file name="Checkbox.php" hash="0c8d8bc032276d22d8a23b1cb5cb4ee3"/><file name="Country.php" hash="5c41e9bc49b829817fc6c6e0b3bb1301"/><file name="Date.php" hash="4d432d04c21e356ada833fedb11a8d32"/><file name="Datetime.php" hash="8b4e170ce510dff4672f566a0c6006d8"/><file name="Interface.php" hash="ecb2182f785bab42bce0aab1e9aeffb5"/><file name="Massaction.php" hash="be4a354269953c27b5651307a00b356e"/><file name="Price.php" hash="f7ef1bda31e33231ac8349172a22c885"/><file name="Radio.php" hash="5f60bbeba611df2280756e89e3edaf4d"/><file name="Range.php" hash="e3671131adcae3b8191b0ee12fc4479b"/><file name="Select.php" hash="bf0b958af6c17cf87acce2139594007e"/><file name="Store.php" hash="9e3391cef3d7e6b571ddb0ff1ce31e95"/><file name="Text.php" hash="decc14e17a7efe47df5627d6266d82eb"/><file name="Theme.php" hash="a2c1c6b7e7531ab123a59dbae9edfa82"/></dir><dir name="Renderer"><file name="Abstract.php" hash="704a010ad1e4b9d3de496ae6f2ad91e6"/><file name="Action.php" hash="9af11dec7785235d252a4ed4be6f615d"/><file name="Checkbox.php" hash="c75ff15abb158fc0739592af7ea7422c"/><file name="Concat.php" hash="0c98188f755ed33c3099b0e4a290a22e"/><file name="Country.php" hash="282ed653192f3e0967454a500b1d6c55"/><file name="Currency.php" hash="88f51735c3b03ed176d8f4e9f4fb68f3"/><file name="Date.php" hash="7b36c06c450f56de09a2a0e2e2003080"/><file name="Datetime.php" hash="1b0a1a0a77fe3503dec6bb89846e97fc"/><file name="Input.php" hash="54efcf346dcaefd0421d0fdfb3d35c31"/><file name="Interface.php" hash="064fb4d2541597d669b9d18f2f39cc1d"/><file name="Ip.php" hash="135fceb308bfae5a72e723efba31efdd"/><file name="Longtext.php" hash="512f23de2d3c820889b3d87afda9599f"/><file name="Massaction.php" hash="05fd267920703792920e5346e7ca0fb1"/><file name="Number.php" hash="1bcfc1fa0ce52b58757204c0d119f868"/><file name="Options.php" hash="66ed26d285706fe39a0022294972bf5e"/><file name="Price.php" hash="801e02cf3a66f89c02e9c90b925b81b5"/><file name="Radio.php" hash="762d232eda0a59fd4db6d570ae6a11cb"/><file name="Select.php" hash="3d0acd16d0323ef3d114a7aca647330c"/><file name="Store.php" hash="edada7e10d9635a8592dd76135f0f33c"/><file name="Text.php" hash="f08ff907545ff447f429214a5760ab8b"/><file name="Theme.php" hash="8e2ba7495c4161f44e1899d74b6f9f8a"/><file name="Wrapline.php" hash="3a7edf01eb91fd42305bf256d93531e7"/></dir></dir><file name="Column.php" hash="d04226c35fde4b31769656cdfff8cfe9"/><file name="Container.php" hash="7efc13b32c9d7c9f235c0194b9814f11"/><dir name="Massaction"><file name="Abstract.php" hash="04c79067f07388582101ce565644344b"/><dir name="Item"><dir name="Additional"><file name="Default.php" hash="53e9468b19a71f8e44920a0a0a39ea17"/><file name="Interface.php" hash="0b995f29e3c068cdffbdc93dc4d965e8"/></dir></dir><file name="Item.php" hash="f9da9045c7c77e625ba312d065dedb26"/></dir><file name="Massaction.php" hash="1e4b83485d7f0b556c88a5898c40e516"/><file name="Serializer.php" hash="7e2185abd12832c169fd42e89caade33"/></dir><file name="Grid.php" hash="6ac41f9c52e6fdc3fe7f01037f9aed2e"/><dir name="Tab"><file name="Interface.php" hash="094aaa32090cbcf7865c0641a1e2baa9"/></dir><file name="Tabs.php" hash="c09d2afbbcb4bfd78462723bb6972e6b"/><file name="Tree.php" hash="4ee77de449208f8bb2f1c4ee4656ab90"/><dir name="View"><file name="Container.php" hash="973b7b77e228a28bcff88520a3bbf43e"/></dir></dir><file name="Widget.php" hash="670978a7c059808e49191ad21d42cab6"/></dir><dir name="Controller"><file name="Action.php" hash="ea2630204852617ff41e4e1f948ede68"/><dir name="Report"><file name="Abstract.php" hash="c9dadae96c4f5bb9443167a5e4c0ac58"/></dir><dir name="Rss"><file name="Abstract.php" hash="5b04702be27869ce7af05581c6ac473a"/></dir><dir name="Sales"><file name="Creditmemo.php" hash="9baf9dd1d7003e5919acd7fd8be3c8de"/><file name="Invoice.php" hash="e18f2e1dbf17f766c3aa6a30d1b8b330"/><file name="Shipment.php" hash="4f115f033c90b1f0f05244c87892174d"/></dir></dir><file name="Exception.php" hash="1bf87284314f84a2e9dddbc6aa02d929"/><dir name="Helper"><file name="Addresses.php" hash="94dea4d61e921f74e574a13f35fa526f"/><dir name="Catalog"><dir name="Product"><file name="Composite.php" hash="5ebb5be492e23577a083518cdc4ebbb7"/><dir name="Edit"><dir name="Action"><file name="Attribute.php" hash="8fa9acfe18c721e80c067ff290fb4423"/></dir></dir></dir></dir><file name="Catalog.php" hash="7c43ea78a71e27be4c9e9275930d4c49"/><dir name="Dashboard"><file name="Abstract.php" hash="c2d2e0f8fe77177016afd7195e0c7bfb"/><file name="Data.php" hash="0cd9341123775b408eb2d870cbb6b152"/><file name="Order.php" hash="4ae6c3d63a209d9031aff5e3f69ff01c"/></dir><file name="Data.php" hash="abe5fffa5546a517c1ca60a201ace9c1"/><dir name="Help"><file name="Mapping.php" hash="4c5d3127d193a1f2c37e6d3af9eeb7e7"/></dir><file name="Js.php" hash="72316dae9a20494eb546340cbc838730"/><dir name="Media"><file name="Js.php" hash="94b127033b3975f6063cfb201aaa7210"/></dir><file name="Rss.php" hash="0ec2e6fc3c0f3a36207665a5440493b6"/><file name="Sales.php" hash="3c04f74983d4c7142c781cd89df71d12"/></dir><dir name="Model"><dir name="Config"><file name="Data.php" hash="d687ffbbc02a98cba695382e4894dedc"/></dir><file name="Config.php" hash="5830b87d46656f515b6d3fd6e1ac52c6"/><dir name="Customer"><dir name="Renderer"><file name="Region.php" hash="6b0653f92868441704b4dc8c990707de"/></dir></dir><dir name="Email"><file name="PathValidator.php" hash="28d73ea32531762160b56571a7946d98"/><file name="Template.php" hash="bcf8708d5b38c13fb750bb7f54d92258"/></dir><file name="Extension.php" hash="d38d90a931c22ad4210fc88f9007ea38"/><dir name="Giftmessage"><file name="Save.php" hash="f96d2f3f24b9509f6094417d66843c4f"/></dir><dir name="LayoutUpdate"><file name="Validator.php" hash="faf42b1ede2a9017c5342ce2138589ca"/></dir><dir name="Newsletter"><dir name="Renderer"><file name="Text.php" hash="5580b8c1af8552494f0a356c58bd38c1"/></dir></dir><file name="Observer.php" hash="2600edcd9b2ed84d8eef48bfe3137f77"/><dir name="Report"><file name="Item.php" hash="89d084e5c5bf665524c2605b6828f2d4"/></dir><dir name="Sales"><dir name="Order"><file name="Create.php" hash="f19d6d9aa7e79dfa8b3a2a8c95649cf4"/><file name="Random.php" hash="fe59bc31d04b4069dae013662a928355"/></dir><file name="Order.php" hash="be50cd145aa949efe0dbb8907ca2c66d"/></dir><dir name="Search"><file name="Catalog.php" hash="5d9a903fe56bca27c094929acc8807b9"/><file name="Customer.php" hash="c2b8935fcf7aef9bd4cc10be40e465a8"/><file name="Order.php" hash="958a0e0b7e7ebf02fe067fda4b8823a2"/></dir><dir name="Session"><file name="Quote.php" hash="41b0bd0c9fb61cc8130a413a09a2d79f"/></dir><file name="Session.php" hash="85361ee383f9c79986bbec474b8a1f3f"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Admin"><file name="Custom.php" hash="2e046894406289aa907ae0035e46b1c8"/><file name="Custompath.php" hash="ead8d3a1df593bd69890ea79bd9b3829"/><file name="Observer.php" hash="cf571f4c0de3b6360a0efb9515a0bfe2"/><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="a86613c9c07371cf3fac211fb19d6f24"/></dir></dir><file name="Usecustom.php" hash="fff1bebb0e91904cb26c63df391a1235"/><file name="Usecustompath.php" hash="fc23817391f632789cf63c822f57dd71"/><file name="Usesecretkey.php" hash="e21072aee647c809471f6e2893298cdb"/></dir><file name="Baseurl.php" hash="ab34a03baf0aba81c96b062f7be75568"/><file name="Cache.php" hash="f1936cb90a793bda1b6a35255edd96b3"/><dir name="Catalog"><dir name="Inventory"><file name="Managestock.php" hash="e5944356c0ff4dd9741690152719d3ea"/></dir><dir name="Search"><file name="Type.php" hash="7a6f20cd3be131670abf8b99566e60da"/></dir></dir><file name="Category.php" hash="fbda292baa5daaacb284a8fe715bfe9b"/><file name="Cookie.php" hash="81a5b71978c0ed23e1fa8b291c23306a"/><dir name="Currency"><file name="Abstract.php" hash="37d41ca094ad7a593ed70abe124d5ec6"/><file name="Allow.php" hash="68bd67c886ba2000f395c55c816a9b46"/><file name="Base.php" hash="af6b18eee844e76f329d4c51e933d4fa"/><file name="Cron.php" hash="17eb00bccbd61beca4581acf7416f022"/><file name="Default.php" hash="bee4b5c43f2f3e36db81043e1a4e38f0"/></dir><dir name="Customer"><dir name="Address"><file name="Street.php" hash="206e706118ee6655401b9b42c61f8506"/></dir><dir name="Password"><dir name="Link"><file name="Expirationperiod.php" hash="5abc0ac6ea5ea85848797706e06e99d9"/></dir></dir><dir name="Show"><file name="Address.php" hash="feeec998fd621ea03edf460fea1634bc"/><file name="Customer.php" hash="e61f0a53ee55ced4ac33c2ac0221370f"/></dir></dir><file name="Datashare.php" hash="25913fe52b59a4bd39e46c4428854c12"/><dir name="Design"><file name="Exception.php" hash="68565707472fe642dd4b7a40e2d0b925"/><file name="Package.php" hash="93e0526fcc2c9bad6826c18a36fb2ad5"/></dir><dir name="Email"><file name="Address.php" hash="421366b7e3a6b4c0244fbc6188d11f92"/><file name="Logo.php" hash="33b719f143c2903cee686388d3d060e7"/><file name="Sender.php" hash="79b079bd76cbea2d998738859784ab5e"/></dir><file name="Encrypted.php" hash="84b385dd684b85612707b4fa9db51ad0"/><file name="File.php" hash="f42cccdb5023090f46ae2607532e5368"/><file name="Filename.php" hash="96f867e0997f10d83febcfcba0004e52"/><file name="Gatewayurl.php" hash="dff96ccdae32aaff1d2535a1e7157a3e"/><dir name="Image"><file name="Favicon.php" hash="bcf45a7d93048d325b0f7f4ad1cf0eb2"/><file name="Pdf.php" hash="355ffa084fa7bac2f97436743f097f60"/></dir><file name="Image.php" hash="3ef32a5d2650336e8cbfc4093c54f221"/><dir name="Layer"><file name="Children.php" hash="7c2edbbd89dba4e5c46ca7332ac2ab2f"/></dir><dir name="Locale"><file name="Timezone.php" hash="4876cce3ad44db1787c159706166b597"/></dir><file name="Locale.php" hash="8181a84fc2f21a2d6e6df906b8b28ec8"/><dir name="Log"><file name="Cron.php" hash="0960c63fb46cdbc57554d68d01129032"/></dir><dir name="Price"><file name="Scope.php" hash="6e8849ccddcd5195481bb44ba194f543"/></dir><dir name="Product"><dir name="Alert"><file name="Cron.php" hash="536cae440b551a5c8b52988bd41dd679"/></dir></dir><file name="Protected.php" hash="824f1696606927d8b43da42477bad8a4"/><file name="Secure.php" hash="a036733f115c60ff74d92cf9e142ba60"/><dir name="Seo"><file name="Product.php" hash="28f4ed01035ff820777cc6ced55f3d87"/></dir><dir name="Serialized"><file name="Array.php" hash="baf23890355b037e76665e8db8bbfa69"/></dir><file name="Serialized.php" hash="df3b2f9a6d931bc5262960ad2c68b822"/><dir name="Shipping"><file name="Tablerate.php" hash="91656cfd86831cd8a26a5e57f3475edc"/></dir><dir name="Sitemap"><file name="Cron.php" hash="cb06d56d24023876fa771022d6ecbb2a"/></dir><file name="Sitemap.php" hash="c74a82773ad66c1495d24817a47c4c96"/><dir name="Storage"><dir name="Media"><file name="Database.php" hash="6923e70725113267e3deeba1cfb6da9c"/></dir></dir><file name="Store.php" hash="6e79f5835127803c134b82b3c4961d78"/><file name="Symlink.php" hash="95b9d98e178f4b8f927680b0791b631a"/><file name="Translate.php" hash="b6b6241975ad904fcb6dad072ba94ce5"/><dir name="Web"><dir name="Secure"><file name="Offloaderheader.php" hash="724df1bd4f97398e50223342ec786f4d"/></dir></dir></dir><dir name="Clone"><dir name="Media"><file name="Image.php" hash="5578699345bb7524f1fb182e442653d0"/></dir></dir><dir name="Source"><dir name="Admin"><file name="Page.php" hash="42d6d50d365de5f67652e34e9840b4a8"/></dir><file name="Allregion.php" hash="d797110c372e988ff1a6e49d08ce4b88"/><dir name="Catalog"><file name="GridPerPage.php" hash="34c1553061fc5ff78eebde96a405bfa5"/><file name="ListMode.php" hash="04af817c1308371fcff319df9d1657f2"/><file name="ListPerPage.php" hash="ecb52706a68b4f173d6841fd697aa27b"/><file name="ListSort.php" hash="b79668ebc442a45cbffd7b7d3bd5d596"/><dir name="Search"><file name="Type.php" hash="f1b3abe3363b407f0d227843f70e8e2f"/></dir><file name="TimeFormat.php" hash="52b6b587880e91136d62c9d00a0b9163"/></dir><file name="Category.php" hash="919d4a332eb1253e37eacd987a93dda6"/><file name="Checktype.php" hash="19755a1389a9f8cae1f4aa6461881f26"/><dir name="Cms"><file name="Page.php" hash="dff5ebe6df33c59bafbee5cf6743b244"/><dir name="Wysiwyg"><file name="Enabled.php" hash="7131f228f3b3d4200af27a9268a858c5"/></dir></dir><dir name="Country"><file name="Full.php" hash="fb170bf789af8e5473b8c8bc0815760d"/></dir><file name="Country.php" hash="03f0ce0aa5bcbbcf7f4166a5ef538ad6"/><dir name="Cron"><file name="Frequency.php" hash="f696f381b430183990d02c8842816373"/></dir><dir name="Currency"><file name="Service.php" hash="ba5b791f1f54723cd4f230e867b1fd83"/></dir><file name="Currency.php" hash="7a62eaf4aea976f5980ce25ff84966a4"/><dir name="Customer"><dir name="Address"><file name="Type.php" hash="50e978ba85a6b055bd286f1546bdc82e"/></dir><file name="Forgotpassword.php" hash="1173581eb58ff0233680da25f0dba5a0"/><dir name="Group"><file name="Multiselect.php" hash="262832009eab525d249b1549c8a2b966"/></dir><file name="Group.php" hash="516d462794a85a4f55a0b0b924f6a4a8"/></dir><dir name="Date"><file name="Short.php" hash="0ecb55ea74e7f0635cf9656bd4a79f56"/></dir><dir name="Design"><file name="Package.php" hash="92b1341793a9470fa4868f08ed054768"/><file name="Robots.php" hash="932beab930045a12398cec1af767edad"/></dir><dir name="Dev"><file name="Dbautoup.php" hash="b6466ce08c8de924d7d73302a1c4e395"/></dir><dir name="Email"><file name="Identity.php" hash="f7cf7b723bbc82a236adca740249e12b"/><file name="Method.php" hash="28d64e5cfed2865385d38c60a6d59c3f"/><file name="Smtpauth.php" hash="1379a68f7463a688da3559a56c0c62ef"/><file name="Template.php" hash="546603ce87c833f85c2886fa78c4da3f"/></dir><file name="Enabledisable.php" hash="e4ba4eefa3c92dcd4f6088df73e852b5"/><file name="Frequency.php" hash="b45cac5c61aa1c76f02354fa354c2e59"/><file name="Language.php" hash="cf4973e113cf46bf582ba866b0c84bd6"/><dir name="Locale"><file name="Country.php" hash="3f5882e3e02a1cfceb94e44dec5154a9"/><dir name="Currency"><file name="All.php" hash="f17029b7a993196608692c62074d357f"/></dir><file name="Currency.php" hash="e65f20d6b8dcc9b92eecc3773288b29a"/><file name="Timezone.php" hash="8a91c04de34b595b523b2744bafad7e8"/><file name="Weekdaycodes.php" hash="2dcb2f68f9676e7757511cfc52fae914"/><file name="Weekdays.php" hash="fd1c10e7451311bda4439bce1aaa4889"/></dir><file name="Locale.php" hash="7c1997cc0bd57c0e19a3049d2602ff16"/><file name="Nooptreq.php" hash="129aa8240d6dcf7610cf5aebce742014"/><dir name="Notification"><file name="Frequency.php" hash="992ad115d486c15b4e49d1c713c5fbe5"/></dir><dir name="Order"><dir name="Status"><file name="New.php" hash="b13e716a54aafb4debe2e39f862d1a6b"/><file name="Newprocessing.php" hash="98351a23d0cfc885f6ae955bc8497a79"/><file name="Processing.php" hash="463d61baa271f0be702d99496a9cc474"/></dir><file name="Status.php" hash="d51560e7f3996d42858d2234c71a46d3"/></dir><dir name="Payment"><file name="Allmethods.php" hash="bb56b4469058373f44333efbda871155"/><file name="Allowedmethods.php" hash="1c3df6f913320f5863c6ce5a895ab038"/><file name="Allspecificcountries.php" hash="e033d3d9881675523f824b520ed0c6e5"/><file name="Cctype.php" hash="bd508e1461321c62a8bc13d8009fcb40"/></dir><dir name="Price"><file name="Scope.php" hash="67a80549b00e35bb3cb2e1e1e5a19b82"/><file name="Step.php" hash="4f3c8edc0c9ffaaa2e1c876cdc4a1f12"/></dir><dir name="Product"><dir name="Options"><file name="Price.php" hash="675c24d90116fe01ca667b7c282ee480"/><file name="Type.php" hash="5e5b7e26c1582a5ec4414b9e8d234521"/></dir><file name="Thumbnail.php" hash="3055686e20099ff6e89291834a2adace"/></dir><dir name="Reports"><file name="Scope.php" hash="069a3499c4298db920ba405fa11c0ea4"/></dir><dir name="Security"><file name="Domainpolicy.php" hash="8077bae576aa62e2be69321140bb0177"/></dir><dir name="Shipping"><file name="Allmethods.php" hash="f1b6cc6e499d22ad0d09f12126a57ae7"/><file name="Allowedmethods.php" hash="cde3eb6702c5b55d004e6798294304dd"/><file name="Allspecificcountries.php" hash="b9ddf5a44b9f7b04295384365fe09103"/><file name="Flatrate.php" hash="c881e1fd1f4ae6c5d5e5195a7726fd4d"/><file name="Tablerate.php" hash="5b089f80b770d155ce1ce130904f6cd0"/><file name="Taxclass.php" hash="e3995dd47b8356e54438aa5172d4c53f"/></dir><dir name="Storage"><dir name="Media"><file name="Database.php" hash="168fa52133880bdd0a5b9940bd5eb419"/><file name="Storage.php" hash="0f9612972aad64996f79b073f6aa51ed"/></dir></dir><file name="Store.php" hash="58122ea3b33c37ec9ea19a7bcf52ec48"/><dir name="Tax"><dir name="Apply"><file name="On.php" hash="9895d966f0a3594f146e2143a75d9164"/></dir><file name="Basedon.php" hash="a439e01f07d6485c890e02630f98a758"/><file name="Catalog.php" hash="2fe2fdda4bcc8b445fe48c009342e642"/></dir><dir name="Watermark"><file name="Position.php" hash="2c04100eb63d9e8cbf3c88085fd2f996"/></dir><dir name="Web"><file name="Protocol.php" hash="df2fbf74d4e484c19a2813b3b9eb2b22"/><file name="Redirect.php" hash="182130c27530d8c8fd9f19a00cdc3b8a"/></dir><file name="Website.php" hash="29e00fba750aa9fed121702446994918"/><file name="Yesno.php" hash="3e3d9290c8a907608b9d5a58028b338d"/><file name="Yesnocustom.php" hash="8a5bc93d4c803e3fa20df139869096bc"/></dir></dir><file name="Store.php" hash="fd2a829b6c24413772706d9f74a227ca"/></dir><file name="Url.php" hash="9099e82b420afdd2b332029423541671"/></dir><dir name="controllers"><file name="AjaxController.php" hash="21aa2331850549a0d56a0f34e126672d"/><dir name="Api"><file name="RoleController.php" hash="dd71ee700489808549abbda71255d9b4"/><file name="UserController.php" hash="ada4455c4277dd842949e1d8393a945d"/></dir><file name="CacheController.php" hash="82ffba0759bca1498d810db6cbdbae9f"/><dir name="Catalog"><dir name="Category"><file name="WidgetController.php" hash="d7274f61d984ca38d10f3f89abdaa38b"/></dir><file name="CategoryController.php" hash="c52faa77117d63bad16a2fcf08203cd8"/><dir name="Product"><dir name="Action"><file name="AttributeController.php" hash="f85caaa4837b6e123d3f595cb7ff0cea"/></dir><file name="AttributeController.php" hash="b8eed27c6fe0ae198f9c2be26988b356"/><file name="DatafeedsController.php" hash="b6f1fb27951ccc158ebf1e27b0be9f65"/><file name="GalleryController.php" hash="2bf4baf9369aadbc9357117b48d08a11"/><file name="GroupController.php" hash="08c4d556258752769c14a8da3e8360a6"/><file name="ReviewController.php" hash="8489dfc3a9de1a9fe6a9d1994b4486b1"/><file name="SetController.php" hash="052505c1fac2a67a21f04451bfaf212b"/><file name="WidgetController.php" hash="ab47a3fd2d409fa3590aa1ff866e0515"/></dir><file name="ProductController.php" hash="6e73408d2e11a5798774647108b32e23"/><file name="SearchController.php" hash="8f0be8ea2dda17161f44a244e7721b65"/></dir><file name="CatalogController.php" hash="247369a9fa2674f1660c92f630b7343a"/><dir name="Checkout"><file name="AgreementController.php" hash="a11d48d0dc311c1107db2d7f3ed54a11"/></dir><dir name="Cms"><dir name="Block"><file name="WidgetController.php" hash="45aad6354caa2b7a5608a14d8b86a6ce"/></dir><file name="BlockController.php" hash="117f2f823bd437abf534f2fc4200c50f"/><dir name="Page"><file name="WidgetController.php" hash="27e2d88da95bf627dc94e2eb4c62f7bb"/></dir><file name="PageController.php" hash="f68ee1a38644bceec232f23c961aa9cc"/><dir name="Wysiwyg"><file name="ImagesController.php" hash="0002d34d5a20602f947029710c003e94"/></dir><file name="WysiwygController.php" hash="52937e9d1c6c2e60abf4f6f4e506ea3e"/></dir><dir name="Customer"><dir name="Cart"><dir name="Product"><dir name="Composite"><file name="CartController.php" hash="00aec88f5179e17aaa2cb32410d4e627"/></dir></dir></dir><file name="ConfigController.php" hash="75fc248de6217cec3dc7115a6d3c7871"/><file name="GroupController.php" hash="300e16d47af15dfdc72d3a72d6a8b425"/><file name="OnlineController.php" hash="c582c470171c6f22930874ace2212fbb"/><dir name="System"><dir name="Config"><file name="ValidatevatController.php" hash="9ec588e2864cf7584f86e7ea03ef859b"/></dir></dir><dir name="Wishlist"><dir name="Product"><dir name="Composite"><file name="WishlistController.php" hash="312e61c120d15fa6b9beff8d013669a5"/></dir></dir></dir></dir><file name="CustomerController.php" hash="840b12a524c3c4ddcbb33a84eec8e5c0"/><file name="DashboardController.php" hash="cccdc39d1b4256bc6d3fdc3f312b469c"/><file name="IndexController.php" hash="93d25be27f7172e4b91be4e29b1667d5"/><file name="JsonController.php" hash="2a0884d78d11507f5ca8617ab60a65fb"/><dir name="Media"><file name="EditorController.php" hash="08217fbb9baea7eadf7e1c2fa9d37ed0"/><file name="UploaderController.php" hash="5a3f8a7627dce0832bf279ee0bb29aec"/></dir><dir name="Newsletter"><file name="ProblemController.php" hash="666980a1414023c417422a9354854ca7"/><file name="QueueController.php" hash="84615826588fd8d919efce2d5f261953"/><file name="SubscriberController.php" hash="012dfabbe5188395de3d4934db9d8f1f"/><file name="TemplateController.php" hash="026a29a362a1d886341cdc6fa16b402e"/></dir><file name="NotificationController.php" hash="d7a410e9d20a264e4d9515b1a86f7d30"/><dir name="Permissions"><file name="BlockController.php" hash="185535dffd66b8d8ef1068019eb3eff8"/><file name="RoleController.php" hash="9606953d4410722d615ac816820fa340"/><file name="UserController.php" hash="50f7bdedd11f5682e275bc2139461ca6"/><file name="VariableController.php" hash="c92ad3f6d684b0766cd43d3a31f4c1fa"/></dir><dir name="Poll"><file name="AnswerController.php" hash="9287852777f2b860e531374d94e45157"/></dir><file name="PollController.php" hash="b430f477bc4bfb01ccaf060ea4ffdf99"/><dir name="Promo"><file name="CatalogController.php" hash="0f2bd8b16387cc6406e8ab36b968a2e0"/><file name="QuoteController.php" hash="48cd57aea41091c9549676a30d9fe274"/><file name="WidgetController.php" hash="d91c5d5958237820bcfa78c89cac16c2"/></dir><file name="PromoController.php" hash="ed7e53ece75726b7a31e675748540a84"/><file name="RatingController.php" hash="315660eb3bda08558a3f609a5596d7c2"/><dir name="Report"><file name="CustomerController.php" hash="9f5dfc9f1f6ed652d59c420b5c069502"/><file name="ProductController.php" hash="0c615feb915eb56af10fc75c00feb0c3"/><file name="ReviewController.php" hash="7da2ab6db4eae2bfdf9ecccd3c87e7f5"/><file name="SalesController.php" hash="d1c582fa4d0df0af89b528012fee1c2b"/><file name="ShopcartController.php" hash="525c2321b21e62a3c1f686d62559c01b"/><file name="StatisticsController.php" hash="91a77e722297e68b0ad1ba54ad359b2a"/><file name="TagController.php" hash="3c1aec074c4eb53d14f77f549339dbfd"/></dir><file name="ReportController.php" hash="63feec302514efa918d1a80f8f7e9cca"/><dir name="Rss"><file name="CatalogController.php" hash="c007de3af2772afd0af741b3be6c8a79"/><file name="OrderController.php" hash="608bc4c2de1d4785ffec32805c10368c"/></dir><dir name="Sales"><dir name="Billing"><file name="AgreementController.php" hash="2da3d500f2049c5ece840fbbfca9647d"/></dir><file name="CreditmemoController.php" hash="2d688eee9da7ccfcefaf9788def48b1a"/><file name="InvoiceController.php" hash="19a9445cabc5f9059d6e550b8f58b873"/><dir name="Order"><file name="CreateController.php" hash="1dab538d3c4b2f4c618d5d99a6745b5a"/><file name="CreditmemoController.php" hash="4445b5dc62da541f2f847beb0d1bbaec"/><file name="EditController.php" hash="0b7c20984714ac732162c98bf89850fc"/><file name="InvoiceController.php" hash="1f1a90c7f42c23debcf804b1be6defff"/><file name="ShipmentController.php" hash="fbf45e3a33640447a07b66744f9c1346"/><file name="StatusController.php" hash="39ea9de1b69ab854ddc481948281d94a"/><dir name="View"><file name="GiftmessageController.php" hash="99aa2e8b8abc4e517817d4a206f66994"/></dir></dir><file name="OrderController.php" hash="6d237944b46c4cda0a259371732ef925"/><dir name="Recurring"><file name="ProfileController.php" hash="9cb710bd52e9a0ffe2e3f7471a7344f0"/></dir><file name="ShipmentController.php" hash="fd91d81711fc1dff84ab77ead90cbe42"/><file name="TransactionsController.php" hash="2804baa76fb26d4ef1bb52b4657623a2"/></dir><file name="SalesController.php" hash="0af897e1b6c86b1a333ade2d42c7132f"/><file name="SitemapController.php" hash="7052d7d9dafbdc002aae0600daf7e15c"/><file name="SurveyController.php" hash="1f472bbf45c9b2c5b0871da68a64747d"/><dir name="System"><file name="AccountController.php" hash="065a0d935e4eb62882fb1c0e581509b0"/><file name="BackupController.php" hash="a978f19979f623f2db52a4cd2521461b"/><file name="CacheController.php" hash="75ddb06e7d3aa12d387bad621b5a69f8"/><dir name="Config"><dir name="System"><file name="StorageController.php" hash="07f6a5f5ad1ace3aa724902656de99cf"/></dir></dir><file name="ConfigController.php" hash="35ff2d7f2282dd7983f832d215dc4257"/><dir name="Convert"><file name="GuiController.php" hash="9c3a90e18ad3b405779df0dc3b32f3a0"/><file name="ProfileController.php" hash="535281019f5bb6e456f7dee19952ff29"/></dir><file name="CurrencyController.php" hash="51394cd2c6721baa9f9a88c6a5d10377"/><file name="DesignController.php" hash="47108670fb51eb5a66d626e9a48a816c"/><dir name="Email"><file name="TemplateController.php" hash="9bfa5606da8f2b90a02c204f2f9044d8"/></dir><file name="StoreController.php" hash="2b0bb94e5c7a359e9109bc5e038ef621"/><file name="VariableController.php" hash="4399817273fe7e92bd3e7aebcd3c23ad"/></dir><file name="SystemController.php" hash="968204b11a8efb93c13ff3a36ea3aa0a"/><file name="TagController.php" hash="b427319c9cc848023e2894ff98cf6e77"/><dir name="Tax"><dir name="Class"><file name="CustomerController.php" hash="e11693950ace13f570c97f46110d671b"/><file name="ProductController.php" hash="ff329c1879ae3ba19b3cbc2d20f4d93e"/></dir><file name="ClassController.php" hash="f30d45900d180019a6e2f2d9d5edad9e"/><file name="RateController.php" hash="bba20ae7c52d95d3f6add60eb7785388"/><file name="RuleController.php" hash="6a24cb90bec2d0878c23530593ff50e5"/></dir><file name="TaxController.php" hash="2bcb2c6c6164bc91a14711f13808ceda"/><file name="UrlrewriteController.php" hash="8728bfac026517f44f522deafc102c78"/></dir><dir name="etc"><file name="adminhtml.xml" hash="eacc179395f301ba856c22b7ae75d4b1"/><file name="config.xml" hash="cee3689bb30fbde7f0b28a519cb004a6"/><file name="jstranslator.xml" hash="bc2b74495321e4a736d063e9ddc71693"/></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_Adminhtml.csv" hash="0c414a77e3bf1d5e75ae4f717953c207"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.19</min><max>1.51.1.19</max></package><package><name>Lib_Js_Ext</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_LinLibertineFont</name><channel>community</channel><min>2.8.14.19</min><max>2.8.14.19</max></package><package><name>Lib_Js_TinyMCE</name><channel>community</channel><min>3.5.11.18</min><max>3.5.11.18</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Core_Modules-1.9.4.1.xml b/var/package/Mage_Core_Modules-1.9.4.1.xml
deleted file mode 100644
index 21ed885..0000000
--- a/var/package/Mage_Core_Modules-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Core_Modules</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Collection of Magento Core Modules</summary>
-    <description>Collection of Magento Core Modules</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:53</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="Admin"><dir name="Helper"><file name="Block.php" hash="458b8f115baadb9bb2a64772ecf6faaf"/><file name="Data.php" hash="ee37966b67fede75d28e2bd4b642a206"/><dir name="Rules"><file name="Fallback.php" hash="63a2a06fcc65d1365fe14389b0cc8590"/></dir><file name="Variable.php" hash="e6a48f57af455ab3f3610a7094680bf0"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="df761d8226d98aebd5047558c90dddc5"/><file name="Time.php" hash="8581922d946be6f1e6496228f250d63f"/></dir><file name="Resource.php" hash="c78602679aa503a4641100a70d87dd21"/><dir name="Role"><file name="Generic.php" hash="8e268c160dc69b1f052e1948b3772cf4"/><file name="Group.php" hash="85cbd9ce11fa91cd866387e7f2241cf3"/><file name="Registry.php" hash="10ae5d0ae8eb22282213406a3b1c6b57"/><file name="User.php" hash="45dfe3b059b4d76232dd0f4266d27de4"/></dir><file name="Role.php" hash="8319d780dd06ac1ee61b34b9bd9b1cf5"/></dir><file name="Acl.php" hash="f1a340153512be4e5809f5dac8369d90"/><file name="Block.php" hash="2c43da933450e800f6dfe9b44342153b"/><file name="Config.php" hash="5a9ff605e890d318845b08fce172cd87"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="1d6d5abcdf73801aa101061e1aa65f06"/></dir><file name="Role.php" hash="86f57a0a161f1c2f83f6d024f4c2912c"/></dir><file name="Acl.php" hash="4d305204a82da4aac2da4610b1e0124d"/><dir name="Permissions"><file name="Collection.php" hash="18351c0c29cfc2b5aeda23676981ee6b"/></dir><dir name="Role"><file name="Collection.php" hash="81c32bf683040142c56c4d7908eea7b2"/></dir><file name="Role.php" hash="c273803640f531fe3a70789c138bb2d5"/><dir name="Roles"><file name="Collection.php" hash="c49a4a37edecd189de05abd22317afb9"/><dir name="User"><file name="Collection.php" hash="d2a2541d7b716cb149e8bf85892de2e5"/></dir></dir><file name="Roles.php" hash="7ce5c01f31ab0a0a17733dd5d287d971"/><dir name="Rules"><file name="Collection.php" hash="d899f64d25b4b94c8af851758d7aae23"/></dir><file name="Rules.php" hash="bb1854a73b92b474a8b08e1cc3744a55"/><dir name="User"><file name="Collection.php" hash="4c660da859de8fc555ec5762ddcb36e0"/></dir><file name="User.php" hash="2476a65f5413ca88bc472e667d1e2fae"/></dir><file name="Observer.php" hash="fa5800ac1cf353a58ac6c54302b00092"/><file name="Redirectpolicy.php" hash="63c1657f8bc4057fbff402a787f5b4b3"/><dir name="Resource"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="f303429166be37291210a09bf5a5b7b0"/></dir><file name="Role.php" hash="024d8fd83ad0202cabd4681ad49d5353"/></dir><file name="Acl.php" hash="4fcc23cfdb5640f0d7a586106b11b1a4"/><dir name="Block"><file name="Collection.php" hash="47c9c77cf4fbcf4e23e92177883e61c4"/></dir><file name="Block.php" hash="6da7836e73f2b7bcd6ffe441dcb2d8b5"/><dir name="Permissions"><file name="Collection.php" hash="f189808b46860de0a1371b6e4c4893cc"/></dir><dir name="Role"><file name="Collection.php" hash="a08a34456c4d21b735949239d8c88158"/></dir><file name="Role.php" hash="9f10fd18cb941f3282ab0b6612fdc2eb"/><dir name="Roles"><file name="Collection.php" hash="9bee6ac75a949e5b403cfd19d259fd06"/><dir name="User"><file name="Collection.php" hash="e7e9996a1128f35cb87b9aa75fdbe2a5"/></dir></dir><file name="Roles.php" hash="6d9d4a4704bd62b7c2af7f7c1f0e244e"/><dir name="Rules"><file name="Collection.php" hash="9aa586accf6b402ca57b5930dbdbc21d"/></dir><file name="Rules.php" hash="9b48b047903611a52d91dda257048da9"/><dir name="User"><file name="Collection.php" hash="d68fbdc9b6e0b59ece07b8a9e6786735"/></dir><file name="User.php" hash="19f9662e179ae93b95a7414197e1e97b"/><dir name="Variable"><file name="Collection.php" hash="bf75d58b6748a9061cf9f0d894444d6f"/></dir><file name="Variable.php" hash="381276f5ab482fac9f276a7bf09edb1c"/></dir><file name="Role.php" hash="0c579d2eb5a9f993e5e3329286ba02e7"/><file name="Roles.php" hash="be8be3c2225ad59cec09aad3696cd154"/><file name="Rules.php" hash="9aec2dcc8843a9b2aa7c2f169b27967d"/><file name="Session.php" hash="6fb43a7459f0af522f74b9044f41ed66"/><file name="User.php" hash="ef71c71301203ba99064fc7473ad9f30"/><file name="Variable.php" hash="aec37b73e2b07b24642873047404f20c"/></dir><dir name="data"><dir name="admin_setup"><file name="data-install-1.6.0.0.php" hash="7113336c6b7992a5336c8ca3d38a2c52"/></dir></dir><dir name="etc"><file name="config.xml" hash="fa53dadd6e1989703d157a53dfc29920"/></dir><dir name="sql"><dir name="admin_setup"><file name="install-1.6.0.0.php" hash="1c84ae65e4147d21198b1f6ff96a8090"/><file name="mysql4-install-0.7.0.php" hash="dc2ec63c66efe0667052f5695093efe2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="893eba8a43a2437db98f8f089deba809"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c256c803009aaa3b08c09811fe01ce64"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="3c493153e71d4fa917b648c4b3ab0399"/><file name="upgrade-1.6.0.0-1.6.1.0.php" hash="1558790a6f8e8cf5c778a242fbe756ee"/><file name="upgrade-1.6.1.0-1.6.1.1.php" hash="4d46adc07a9f68c089c6ee25ebb54064"/><file name="upgrade-1.6.1.1-1.6.1.2.php" hash="9025a95c29a05a354458e97a9d7444b9"/></dir></dir></dir><dir name="AdminNotification"><dir name="Helper"><file name="Data.php" hash="bdf63a1450e6a0d77647163e535a1a7d"/></dir><dir name="Model"><file name="Feed.php" hash="1cbe43f8f0f79d4ba4d104d022485e40"/><file name="Inbox.php" hash="822e30a30c67ebc5651a059370edc50e"/><dir name="Mysql4"><dir name="Inbox"><file name="Collection.php" hash="0c711250151fb41968688e8a7baaa8f5"/></dir><file name="Inbox.php" hash="c8767a365e9f9b0302aebc42e72d8761"/></dir><file name="Observer.php" hash="a85254ea61683a6146e266c46e4cfa91"/><dir name="Resource"><dir name="Inbox"><file name="Collection.php" hash="8a1c2a44972cfbf2a0b5c24da5133318"/></dir><file name="Inbox.php" hash="95e2ddc1912bd2efa08a618bdc542721"/></dir><file name="Survey.php" hash="c71fe449197c0a95484361b06e1acc9c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9184c5e0cd123342fef181533713a39a"/><file name="config.xml" hash="4bf128768d14ef45927ca932d8423d58"/><file name="system.xml" hash="627114a3b4fd2cdebe5fb76a6cfb41ca"/></dir><dir name="sql"><dir name="adminnotification_setup"><file name="install-1.6.0.0.php" hash="fabadefeaa0cbadc7d765e49b00c03e2"/><file name="mysql4-install-1.0.0.php" hash="7be8540787e2171bca831efa9692cdc2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f1039f623c2ce22aaa01d97277e0523e"/></dir></dir></dir><dir name="Api"><dir name="Controller"><file name="Action.php" hash="bd77a9bdaf5850d9bfad340174c12d17"/></dir><file name="Exception.php" hash="d1e38258a214dc8db2751c8e67058737"/><dir name="Helper"><file name="Data.php" hash="0235c25d21316a6b1bf71e5f06602892"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="4c325d339c19b0bbb8a14b180556920a"/><file name="Time.php" hash="06cc212749e4d7e2a8f5afd03705414d"/></dir><file name="Resource.php" hash="aac365b2c3ee9b552e7fc375a609187b"/><dir name="Role"><file name="Generic.php" hash="1a92e79f592330147dfc5812c749b7fc"/><file name="Group.php" hash="7524be45a0860a7ade02a8d94037464f"/><file name="Registry.php" hash="c728275604c9e3710b3001973d10fd00"/><file name="User.php" hash="653adf396b08780f2175f7c96548aecc"/></dir><file name="Role.php" hash="bc68c60309dacff590e7ca5687b0618e"/></dir><file name="Acl.php" hash="6d3a947164d97c653d7408b28965ebee"/><file name="Config.php" hash="0d7cbdc5a29b2ea9e0018b9ec3084bcc"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="0021a4898d1b458957eb82bc056f468e"/></dir><file name="Role.php" hash="9dba1e6bb824820fce1b2e3cb878bebd"/></dir><file name="Acl.php" hash="f9a5a4868835e3fb9ef2befc2e2fca97"/><dir name="Permissions"><file name="Collection.php" hash="93e7ed97d480968828126f8cbac2b664"/></dir><dir name="Role"><file name="Collection.php" hash="e564b8136d2beebd7dfd3c8795a6e7fb"/></dir><file name="Role.php" hash="d2303886929c5a2d9484ab6dc9fc648e"/><dir name="Roles"><file name="Collection.php" hash="39f697e304e7a4a2978c35a4d89cf0fe"/><dir name="User"><file name="Collection.php" hash="d51c2908f06e072ed90c8fd252383549"/></dir></dir><file name="Roles.php" hash="6305b9320e2bd030fb2081df86e91004"/><dir name="Rules"><file name="Collection.php" hash="e3edf62d099fab993099fe7978f509e1"/></dir><file name="Rules.php" hash="e6b2ebb7b9f814d6707a299b239dd5e5"/><dir name="User"><file name="Collection.php" hash="b0f3a87ba9cc21ec9cad2c3f70c8006a"/></dir><file name="User.php" hash="2a6f6b9b53cdf0a51ad2c9e253c483a9"/></dir><dir name="Resource"><file name="Abstract.php" hash="b40505a25b52fec30b0301500a4c496e"/><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="c39386eacf0f62cb47f5f5e0d7014901"/></dir><file name="Role.php" hash="2928e279cac38426a7412c14807c2213"/></dir><file name="Acl.php" hash="b4d9d34d5da6ed935cc21116435dc471"/><dir name="Permissions"><file name="Collection.php" hash="1ed55c2383301800a07667bc81cc64b3"/></dir><dir name="Role"><file name="Collection.php" hash="389bc113941dbc97b9d66f1f466bc517"/></dir><file name="Role.php" hash="d7024cb60533f6f695d7b2640cdb3b29"/><dir name="Roles"><file name="Collection.php" hash="2ecc66e5450ce840ba0815baae50b628"/><dir name="User"><file name="Collection.php" hash="843c0817b32d47a643fe228d8da97658"/></dir></dir><file name="Roles.php" hash="7ec43dce63b207595cdf18d11f3678de"/><dir name="Rules"><file name="Collection.php" hash="bce86b29edc97fcc30288a6c17087cb9"/></dir><file name="Rules.php" hash="5c5e0f6b3f7ebfcf40b262897eb3136b"/><dir name="User"><file name="Collection.php" hash="74e42dad01f99a8d90ecc0ee9bc434f9"/></dir><file name="User.php" hash="940e1623c70b37ba21d9f379298d068b"/></dir><file name="Role.php" hash="1a34866ab10a5126f886b37ad9393026"/><file name="Roles.php" hash="b69872a87d5080c393bbee4946347e41"/><file name="Rules.php" hash="bfad6890c425f6ef2867454dc7a09257"/><dir name="Server"><dir name="Adapter"><file name="Interface.php" hash="49d97f0fdf244cba251f2e71df4532d6"/><file name="Soap.php" hash="aea4f7712b8e053cfb3ad0b2aa579a58"/><file name="Xmlrpc.php" hash="f4d77d694c5c55097cb816f94217f438"/></dir><dir name="Handler"><file name="Abstract.php" hash="cf7483db39b44c1234fb852592770d05"/></dir><file name="Handler.php" hash="402d95a6f76155ddfc676b6a71baa259"/><dir name="V2"><dir name="Adapter"><file name="Soap.php" hash="3a179c5fb3150c3d8aba66e8999866e2"/></dir><file name="Handler.php" hash="6a939cce44aa9cde7be5b5954c5d753a"/></dir><dir name="Wsi"><dir name="Adapter"><file name="Soap.php" hash="9b2e5affb656129f9e71a0c64853eb84"/></dir><file name="Handler.php" hash="edc38c50fd82505aec0352afc03e691a"/></dir></dir><file name="Server.php" hash="b18193c91fb496f53ad7b089a4dc354d"/><file name="Session.php" hash="11b03d4e7981b9cfb1084591a0aea701"/><file name="User.php" hash="96d22cd787a295bb80a5260d134b372b"/><dir name="Wsdl"><dir name="Config"><file name="Base.php" hash="29d45f55afd1d66cf64af7444e18c559"/><file name="Element.php" hash="93d907a44ab1bc5f7d0424b83c1c501f"/></dir><file name="Config.php" hash="c5a618233b98eb5b0e37d67b65a18597"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="568e76f1884f10d0f5bf8e645ea875bd"/><file name="SoapController.php" hash="a94f525c875292024c976a3274954024"/><dir name="V2"><file name="SoapController.php" hash="7a128ce7e5dc7ba6807e059e45c346fe"/></dir><file name="XmlrpcController.php" hash="7368bbf60c4f6ea50c07b8b555ddc0ed"/></dir><dir name="etc"><file name="adminhtml.xml" hash="b4264dc427c433e5e98207dd637e5e57"/><file name="api.xml" hash="01302962e36ba24259cb3c19a035e856"/><file name="config.xml" hash="26783afff003adf6af459ea1679581ae"/><file name="system.xml" hash="b6a534e8fa06ee34c7befd27b4e44339"/><file name="wsdl.xml" hash="f0db676b04733b38f310355bb44bc3cb"/><file name="wsdl2.xml" hash="7d527421ba4b63a8a812ab6b1095891d"/><file name="wsi.xml" hash="9fb1700cf935a26e7fada90a07fae7fe"/></dir><dir name="sql"><dir name="api_setup"><file name="install-1.6.0.0.php" hash="066ad21052c5b083ab2778e26bbe4db4"/><file name="mysql4-install-0.7.0.php" hash="5d039bc1aeb7f803ab216a1139919bb1"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="4cdf27ca6d95a560f40cbc7eb2665094"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="25e09696a22644ac6aa111ed73b5655b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="15efffec7b0ef3361156df41d15946de"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="1e64826e6d3ca3d0846017cf8acaa4b0"/></dir></dir></dir><dir name="Api2"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><file name="Buttons.php" hash="4376dded28b4aa5586685e2f732ad2ab"/><dir name="Edit"><file name="Form.php" hash="0af6dc58ce485e2f59bac5a46c0d7163"/></dir><file name="Edit.php" hash="1f99242190399def7e2ca9283fe5c410"/><file name="Grid.php" hash="30bd3ba3317f12cc7c52844cf150b994"/><dir name="Tab"><file name="Resource.php" hash="7856f0dbbcc9be2dbf353d58ce480b2f"/></dir><file name="Tabs.php" hash="f54db50cb4a392c688ae6d1be77c58e2"/></dir><file name="Attribute.php" hash="d2dcf496bc82ffdf9a705a3877bb8b2d"/><dir name="Permissions"><dir name="User"><dir name="Edit"><dir name="Tab"><file name="Roles.php" hash="72a6b7a56e4274b02a365ad0f30c8165"/></dir></dir></dir></dir><dir name="Roles"><file name="Buttons.php" hash="4c579d0bc782554233f06cac17412895"/><file name="Grid.php" hash="cdbb76a0a3d30ef0daf01283767fb85a"/><dir name="Tab"><file name="Info.php" hash="e43741793c49f3777e6b392c842c1fd9"/><file name="Resources.php" hash="7054ebad58581afc4407ad8da7c079b0"/><file name="Users.php" hash="f993e6653358f42ff71db5cf9286a429"/></dir><file name="Tabs.php" hash="9d35522fc2a4c3b02255f3d60e9331d1"/></dir><file name="Roles.php" hash="af1a304185f658eb382267e449f7ee47"/></dir></dir><file name="Exception.php" hash="c21f7e48d91909cdd8ff34c7b5f5996c"/><dir name="Helper"><file name="Data.php" hash="3b3b8c14d3e0062cc169f5170e865860"/></dir><dir name="Model"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Operation.php" hash="09038220fb9d14e00b7fb1161f443e40"/><file name="ResourcePermission.php" hash="0afbf662990f30b973a7000f90e130f4"/></dir><file name="Attribute.php" hash="0a5693b841c58a4cf2b11a586ab015b6"/></dir><file name="Filter.php" hash="3c35c99209e0e44972db68289427d0c5"/><dir name="Global"><file name="Role.php" hash="fbcf77d11b3ad6b3d76f62de2631cfd9"/><dir name="Rule"><file name="Permission.php" hash="b562dc5aface03f159f364dfb221046e"/><file name="Privilege.php" hash="0e758f46f64b58efed6ef6330417bb8a"/><file name="ResourcePermission.php" hash="7c7d8f9f33daeec606c5dc68d72aa6a0"/><file name="Tree.php" hash="7b5a5f72cc5f5bcb4c880e5c1b3e0533"/></dir><file name="Rule.php" hash="b4c30ae4bf8ad5111f56d5cc5c1f4c22"/></dir><file name="Global.php" hash="b8740f8a74f44181cfe72594c9962156"/><file name="PermissionInterface.php" hash="a2da51f36241c2f2cdadb52227ebc6cb"/></dir><file name="Acl.php" hash="1573afb52fc330438eac73bfc6d11763"/><dir name="Auth"><dir name="Adapter"><file name="Abstract.php" hash="3720722eff5b1948e4b8e8283cfc991b"/><file name="Oauth.php" hash="6cb6dc6f5e261710a5a217262e300725"/></dir><file name="Adapter.php" hash="b5759916b5235990ebaf3509b3d02790"/><dir name="User"><file name="Abstract.php" hash="ba1a6bba6d01055fda5fb3efc9e5342a"/><file name="Admin.php" hash="9fb3184fd96676702c15184ea14eae12"/><file name="Customer.php" hash="4c14d7df43453f52af73fa10e773e015"/><file name="Guest.php" hash="6402fa2d5ef1b6b688ca15057675ee59"/></dir><file name="User.php" hash="53283f1d82f3f704c4dbec8808ba22f9"/></dir><file name="Auth.php" hash="d2b4b8b817d6618ff2310e7d66f82be9"/><file name="Config.php" hash="65eee46fe1d1099fb3b0516e9279ee61"/><file name="Dispatcher.php" hash="bffc0249f6f9dbb2e8f52e8558b9baff"/><file name="Multicall.php" hash="f303ee72911f0628a181b206f5727c09"/><file name="Observer.php" hash="acf8944643c694c1e0b555d12c33cdae"/><dir name="Renderer"><file name="Interface.php" hash="d580bba55508a29b09eddb0e0f753eac"/><file name="Json.php" hash="038ae9d48ddd2d00fb3a73c0dcfc90bc"/><file name="Query.php" hash="5a3fc89d32a6e4540039fd7ae36feefc"/><dir name="Xml"><file name="Writer.php" hash="b5f2fb511668c0e713b7d569460dace8"/></dir><file name="Xml.php" hash="05844d8a79ef772e98eb1516fca69c75"/></dir><file name="Renderer.php" hash="a6dd26eadb27238cc5a39fc970ce60e9"/><dir name="Request"><file name="Internal.php" hash="85db2090307e0b32c11662dc274bd260"/><dir name="Interpreter"><file name="Interface.php" hash="7adc09d4d35ea0693d440e951b02d422"/><file name="Json.php" hash="c155284d01ba4967c03bcaf2ae6f2d04"/><file name="Query.php" hash="f1a500e1b52d781ffd85214111ec46fd"/><file name="Xml.php" hash="1474e9963e826ee65adf3d83d82d5b3a"/></dir><file name="Interpreter.php" hash="55520f65c5f50dc164784d328b7cc391"/></dir><file name="Request.php" hash="dbd1366ad80c96f28e9c6df621d1ee84"/><dir name="Resource"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Collection.php" hash="e5a758eb30a4ee0b406e14d90fed3f7d"/></dir><file name="Attribute.php" hash="bff17f4c6dae72f866075aed2143a7ea"/></dir><dir name="Global"><dir name="Role"><file name="Collection.php" hash="27100e15437eaf77ad1442c57512efd6"/></dir><file name="Role.php" hash="0573edd7fbdaec6c60677bf9524081b8"/><dir name="Rule"><file name="Collection.php" hash="f0e7595e6a38d6908f02a80f51d69a77"/></dir><file name="Rule.php" hash="bf31ec43122c7148631e8353ce072ee6"/></dir></dir><file name="Setup.php" hash="39bae99a03d25ec831edfe03dae94c6e"/><dir name="Validator"><file name="Eav.php" hash="7d5b412a1011ae3ebe26f5bedcd53b55"/><file name="Fields.php" hash="e49f90a6054e9668ece648c8af135400"/></dir><file name="Validator.php" hash="0f31952b0282cb8ce0c6de1a61e6faed"/></dir><file name="Resource.php" hash="f626093895fb369a857b3d93e895f595"/><file name="Response.php" hash="cf5bafdb46c7c5cd6954b2e64f3a581b"/><dir name="Route"><file name="Abstract.php" hash="b63d027e93acd4fac077146537be06c9"/><file name="ApiType.php" hash="4e239e1601c6604a185e267f8ae126d0"/><file name="Interface.php" hash="3191c533ce588c2df505c1504c66f5ad"/><file name="Rest.php" hash="e49d49128fb02808fe5c72d4a4b06f52"/></dir><file name="Router.php" hash="ac09ccb08d4a7da221e078d8c0faafb0"/><file name="Server.php" hash="97ce9fe49ceab3e8f87fab8cef1840d1"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Api2"><file name="AttributeController.php" hash="0780ce523414d956dc51b46867b51f15"/><file name="RoleController.php" hash="0f3e02c6804c03e4c76ca8458d9aa6da"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="9b99c5a3de756424196e58a98487e4e5"/><file name="config.xml" hash="c2c3d2f8ee69cce25c6cd662391b77f8"/></dir><dir name="sql"><dir name="api2_setup"><file name="install-1.0.0.0.php" hash="790f059183189cfa3fbb348c362403eb"/></dir></dir></dir><dir name="Authorizenet"><dir name="Block"><dir name="Directpost"><file name="Form.php" hash="951236a941f006e8d3067949dbb93eb0"/><file name="Iframe.php" hash="4ee9b7b6b588d7a36108af6b36d807f3"/></dir></dir><dir name="Helper"><file name="Admin.php" hash="242ce0696a5ea9123097869120543fb2"/><file name="Data.php" hash="745bce8bee42112c10d9e52705b96e67"/></dir><dir name="Model"><dir name="Directpost"><file name="Observer.php" hash="bc0cb094c3f4393861b2f5d3c45ac219"/><file name="Request.php" hash="3042662702dc0e2a8b5fe14e6bfe36c2"/><file name="Response.php" hash="3897d872b0f7a3edc3cbbcb02985c712"/><file name="Session.php" hash="94b77b8be59e39571d4e0d399a330e4b"/></dir><file name="Directpost.php" hash="c936c0798b8e329270273c43077c48e1"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Authorizenet"><dir name="Directpost"><file name="PaymentController.php" hash="2fe86219e1e9eec3b40eed97e5ca31ce"/></dir></dir></dir><dir name="Directpost"><file name="PaymentController.php" hash="5fad7bd1934637ff441eed6ed08358f0"/></dir></dir><dir name="etc"><file name="config.xml" hash="f91ed533702d8b51aee6ed41fe8d670d"/><file name="system.xml" hash="23b31628a9b437a899924c456cf23b71"/></dir></dir><dir name="Backup"><file name="Exception.php" hash="baa8812918560125167c4b3dff59fd4b"/><dir name="Helper"><file name="Data.php" hash="a74e2b999e106365de6d702acef15621"/></dir><dir name="Model"><file name="Backup.php" hash="2f0baa336548120691c2f86c5d7d6158"/><dir name="Config"><dir name="Backend"><file name="Cron.php" hash="e3afe2dac55f4c0c21035509a7ad03ff"/></dir><dir name="Source"><file name="Type.php" hash="80d255889f3ab648ecd2b96789cd5b8f"/></dir></dir><file name="Db.php" hash="20de8464af9b44585d86542770d84424"/><dir name="Fs"><file name="Collection.php" hash="bda11a66e9485d39bbd65ef106a5827a"/></dir><dir name="Mysql4"><file name="Db.php" hash="c709100f98d4c0e594ac781818ae91c4"/></dir><file name="Observer.php" hash="e15b50bd82367ba32a07ff7e920448f9"/><dir name="Resource"><file name="Db.php" hash="126e3ee2b9bd03fb2008f958852a9931"/><dir name="Helper"><file name="Mysql4.php" hash="433085a484930534865c7096108e5b18"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1bdf439e0dd516b2793aed5b29292595"/><file name="config.xml" hash="c116519a1ac0e6b14344a154addb3bd8"/><file name="system.xml" hash="c561811e44bbf97968fbde0d3f93cabc"/></dir></dir><dir name="Bundle"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Bundle.php" hash="7ba4af5e0cc19fd57543a1e8a435e463"/><dir name="Options"><dir name="Type"><file name="Checkbox.php" hash="b4802f23317cec64155a0a854fd05f38"/><file name="Multi.php" hash="666954cfc526ff66a93794c3a4a4329d"/><file name="Radio.php" hash="3e16ee3943c4dd6db44e6aaf43669534"/><file name="Select.php" hash="bf93776f105756314e810a20aaedfbcf"/></dir></dir></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Attributes"><file name="Extend.php" hash="6b15e48fbb1d64f91c9b33bf48117d0d"/><file name="Special.php" hash="ba9c7de799a80bad0f37c88a92bbc0ad"/></dir><file name="Attributes.php" hash="282fe2257c01625167d2499502b8f28d"/><dir name="Bundle"><dir name="Option"><dir name="Search"><file name="Grid.php" hash="0a157c18808c8e97a7090ca4014f88b3"/></dir><file name="Search.php" hash="ed0a329442cf1207bd9f7e2c91e9dcc0"/><file name="Selection.php" hash="2a3d2c794fbf9754978a8e751b935821"/></dir><file name="Option.php" hash="66bb0e76f1810c7f4908f2a8b531418e"/></dir><file name="Bundle.php" hash="4076b8967fe5d7507058338ba36c473a"/></dir><file name="Tabs.php" hash="e31c5a810990ab5c089df54761082bc7"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="c0afda9392dde9b38bc71eb09151a1fe"/></dir><dir name="View"><dir name="Items"><file name="Renderer.php" hash="9a5c04f6975466b25c3baf9436bbade7"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><dir name="List"><file name="Partof.php" hash="f14e5c86ee5482519933627ec0ac3da8"/></dir><file name="Price.php" hash="cf6e7d8dfdeb7c20102d78d955c3a08f"/><dir name="View"><dir name="Type"><dir name="Bundle"><dir name="Option"><file name="Checkbox.php" hash="234a0dde586568d352a2d63bdbc1a203"/><file name="Multi.php" hash="247fb02f6773737d566cd4f30dd42585"/><file name="Radio.php" hash="e69225f7462c36f62092b9264dc3ccad"/><file name="Select.php" hash="aa02b9e489a4b817875cf8352c5cca71"/></dir><file name="Option.php" hash="4a4049d3d4528214818366dd4238a73c"/></dir><file name="Bundle.php" hash="78e470548ba63160e4c3fb5eefe3c5e0"/></dir></dir><file name="View.php" hash="adf9d177b5f714144f732974a75f693c"/></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="b4846bf466d14816fdc960bad99253bf"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="8328adc7ab06c404b5f678f52c4b36ba"/></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="c3b92627d497d6af3420a70884a9900a"/></dir></dir><file name="Data.php" hash="1df35d7602d491b3a3a5896dbe1c4439"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Bundle.php" hash="07e8532dfdf36af78680fe629726df65"/></dir></dir><dir name="Mysql4"><file name="Bundle.php" hash="a42904a5602a94bd4bc682866b4db372"/><dir name="Indexer"><file name="Price.php" hash="2d31c9d360c0c3483157283f9675399f"/><file name="Stock.php" hash="178db785d8bd219a0cd789bf1c998259"/></dir><dir name="Option"><file name="Collection.php" hash="094532247ebc66e7531f8b4d37448a6b"/></dir><file name="Option.php" hash="757bbf29c2788e7ad3c46a1abe6e8c6f"/><dir name="Price"><file name="Index.php" hash="188f493c00e63966bf9bcc817e99c578"/></dir><dir name="Selection"><file name="Collection.php" hash="450f5c62e214a2739bbd65a8bf37cafb"/></dir><file name="Selection.php" hash="94b63b71c7d37885385223f7ff0d1f4a"/></dir><file name="Observer.php" hash="086ce0bea7d0b7e9c2c6862a0445cf6f"/><file name="Option.php" hash="c3286cf424d27fa9474691f44a8fe0aa"/><dir name="Price"><file name="Index.php" hash="b6ad3d5912b14b50e83105a5cb89171b"/></dir><dir name="Product"><dir name="Attribute"><dir name="Source"><dir name="Price"><file name="View.php" hash="999c58650a57146f6115b6152c931d12"/></dir></dir></dir><file name="Price.php" hash="5714d620d44a3b78e1824fb5ed3ae01c"/><file name="Type.php" hash="940953a610d3ddf54452750d4eb09ba6"/></dir><dir name="Resource"><file name="Bundle.php" hash="dff534e1e5b1bdd46d381e534163787d"/><dir name="Indexer"><file name="Price.php" hash="87e595b484a5e306e8a9111cdc41b770"/><file name="Stock.php" hash="467fd84b1330cc43410f9a11c9a7569f"/></dir><dir name="Option"><file name="Collection.php" hash="f933036863523dac13f6d4e0c5192de9"/></dir><file name="Option.php" hash="40c76760181b30092e745caf7e71a825"/><dir name="Price"><file name="Index.php" hash="156ea664373d1e7074f604e150b47416"/></dir><dir name="Selection"><file name="Collection.php" hash="5e637bea02628db76299f9141cd69280"/></dir><file name="Selection.php" hash="b92a36a662d7c15da0b6be34a72abd28"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="03572513aa7302634912cdb25682700d"/><file name="Creditmemo.php" hash="72830f7b86d48f04fabe7dc149d0c8a8"/><file name="Invoice.php" hash="4eb93c31fddd2743e9fad84f82468403"/><file name="Shipment.php" hash="ff978de79d7517c9665d43519f2ce386"/></dir></dir></dir></dir><file name="Selection.php" hash="69baeefb547cd3e266695ba07fe05428"/><dir name="Source"><dir name="Option"><dir name="Selection"><dir name="Price"><file name="Type.php" hash="0125cebe6acd7c5d8d5ba5471c560cc5"/></dir></dir><file name="Type.php" hash="b132757f9677ca55c605266de6357df8"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Bundle"><dir name="Product"><file name="EditController.php" hash="590760cfa7cba02f55192b805db49bb7"/></dir><file name="SelectionController.php" hash="c67d92020a00d1e92fb6d1ce2d143478"/></dir></dir><dir name="Product"><file name="EditController.php" hash="c707c3f48f3513035a2e0370fb5aade8"/></dir><file name="SelectionController.php" hash="c9865d2186f986d57d2024076914b381"/></dir><dir name="data"><dir name="bundle_setup"><file name="data-install-1.6.0.0.php" hash="834e88f6e39a4494fcd6e38c054c6928"/></dir></dir><dir name="etc"><file name="config.xml" hash="6b7ab06798a4fa4854b29ea2055d1d5a"/></dir><dir name="sql"><dir name="bundle_setup"><file name="install-1.6.0.0.php" hash="262c230428893cb4bdd1a4302009b98a"/><file name="mysql4-data-upgrade-0.1.13-0.1.14.php" hash="4998433373fab9c5c49160a29a0506b5"/><file name="mysql4-install-0.1.0.php" hash="6fa016bc3431841ce3207fec2d523b54"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="effab7ebe8c2e84c0f22657191758711"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="6e550a3d455cef957ecca7ead0d280e1"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="76ef43ee7da599cd9373ef468bf005c2"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="d1ba25ae101d380cb8d68335f2ab06b4"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="124054e21b0980238b0366f0a62bb42d"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="6f5ae289258acc4522d12ac5abf4ef3a"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="ebca03c63ca3d4cb2e99f0b35e994b3f"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="3773f524d98c2e47bf89d251f80fb2b3"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="f30a13c3101129c7235e51e5354dd6eb"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="68e4f5cafb451800272abc27d177ca99"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="6eecd8118f59a2207d79b30ba264f2b0"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="ad618762396db26f49047f72c70c1c8d"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="c118caf7158504dd027d7281e447d263"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="78643674b5e2a23ee8a7fde720863e25"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="caadeb7ff995da1e38205162eba466c4"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="58c22c0e8cd208b2d835653a3dde61aa"/></dir></dir></dir><dir name="Captcha"><dir name="Block"><dir name="Captcha"><file name="Zend.php" hash="3977d0d2bf3559ea2d1a8b61e34117f2"/></dir><file name="Captcha.php" hash="43bfc5969f3760b7722881264b40e0f7"/></dir><dir name="Helper"><file name="Data.php" hash="4c2c154247df498f877b454c1502d9be"/></dir><dir name="Model"><dir name="Config"><file name="Font.php" hash="16fe5a425b5904f4f0b00812cad7942b"/><dir name="Form"><file name="Abstract.php" hash="0597e90c9258fc7e9de472b9b25953bf"/><file name="Backend.php" hash="644d7f0c08686657a8ce89e644a86ca9"/><file name="Frontend.php" hash="6653882a570c41743beaa0067a8e2cf5"/></dir><file name="Mode.php" hash="0fcefa5ea27784bdd4b6e125ef68fff3"/></dir><file name="Interface.php" hash="fb4478e8efbcf6e5da049262cf66d888"/><file name="Observer.php" hash="b092094a1eddec47b3154d929d77bae6"/><dir name="Resource"><file name="Log.php" hash="5a0fcf217682a204b35e418f9651fcad"/></dir><file name="Zend.php" hash="0cad6772c236172521bd055e52f4b0ef"/></dir><dir name="controllers"><dir name="Adminhtml"><file name="RefreshController.php" hash="0a547debcf1ecf94f5cbf45af9df3ae1"/></dir><file name="RefreshController.php" hash="82f8029551cfd90cd49f2564b1d326ba"/></dir><dir name="etc"><file name="config.xml" hash="c61bc3cbc21b8f5962ad064b6360227c"/><file name="system.xml" hash="6b7e2abc886b31929e708032016d596c"/></dir><dir name="sql"><dir name="captcha_setup"><file name="install-1.7.0.0.0.php" hash="f55e8b44e85eb45a1c269ca812673ab9"/></dir></dir></dir><dir name="Catalog"><dir name="Block"><file name="Breadcrumbs.php" hash="fddd5639798e608beab3083ba2c8cbd7"/><dir name="Category"><file name="View.php" hash="20e9ffebff3b3b815744a1004c1ace17"/><dir name="Widget"><file name="Link.php" hash="958b7b4d4451c45c87eeec162fb036a0"/></dir></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="233349b4ed30754552beebf2017befaf"/><file name="Attribute.php" hash="89f25995def2df558d16cd5a789a62c0"/><file name="Category.php" hash="ea73ccf086dae6e75ab42f12a1e0fd4c"/><file name="Decimal.php" hash="a234d3e3d8ce706a6dc2d767dd3c1d2c"/><file name="Price.php" hash="8534996d8cef258d71058e8f7bd2a39a"/></dir><file name="State.php" hash="13dcb224587b9aa0713b328036823842"/><file name="View.php" hash="5704d8dc8c9eb75eefb2c0ab944ac23a"/></dir><file name="Navigation.php" hash="7b1ac252eb61561c2d5469f3334a4999"/><dir name="Product"><file name="Abstract.php" hash="7251ca5141601e62788d7ec8e45a90e1"/><dir name="Compare"><file name="Abstract.php" hash="4c5b544b7f377b24e37b00932c0a0cea"/><file name="List.php" hash="e955111eebdc60c2a544ad66ab97c676"/><file name="Sidebar.php" hash="e75063e747180ee5770d5ddf94acb21e"/></dir><file name="Gallery.php" hash="889da5cbd69b57dc962cab3b06005779"/><dir name="List"><file name="Crosssell.php" hash="16207ddc8747afd0e69498864dc3a709"/><file name="Promotion.php" hash="089d616d1256ba1c07ce77636ea7a8a7"/><file name="Random.php" hash="57fc65f888bf1dd0dfd9d42a21998e2e"/><file name="Related.php" hash="d247df0901913879c9c1087b72a21d9f"/><file name="Toolbar.php" hash="966dcf34a0eafd655d3a4ea7eaddb3a5"/><file name="Upsell.php" hash="c92ae83f08e6c4c45760728b3f40891d"/></dir><file name="List.php" hash="a9f4e8afa57585edb4a258c76f319898"/><file name="New.php" hash="999949bf0fcdb227134c8e961868586e"/><dir name="Price"><file name="Template.php" hash="8f0bc8a4e7c7461d36bc7a33a78ca1d2"/></dir><file name="Price.php" hash="9acaf5c95cb91048fabe750592f6db2b"/><file name="Send.php" hash="75f97faddb731f029cf699e65e2b8b3c"/><dir name="View"><file name="Abstract.php" hash="6e63017428696209c585e9bfd1385d28"/><file name="Additional.php" hash="802f73ac1e8a66549e5b5b40ffee88e5"/><file name="Attributes.php" hash="4d82fbb43a89e9dfcaae01d1a5b4436e"/><file name="Description.php" hash="f9fbc548fe417a1f1b633415d9f0a63d"/><file name="Media.php" hash="e2bb92043c1cbb187de2956dfa6876b9"/><dir name="Options"><file name="Abstract.php" hash="725b81be39c3848fcbc3fb70721db151"/><dir name="Type"><file name="Date.php" hash="f3678e2b3c39fa5d715cc05785312cb2"/><file name="Default.php" hash="72366888ca379300c605f731eccde59b"/><file name="File.php" hash="8686ba6fdd775c2ab0d4af2c60543eef"/><file name="Select.php" hash="1b8b22cfe146d294cd104ad63c2ef4ee"/><file name="Text.php" hash="7373b44ae870027f493e095720b84b0e"/></dir></dir><file name="Options.php" hash="946b45b2199ba1ec1e10896adbf43682"/><file name="Price.php" hash="6dbe44af12aa2cd9b2a7651f67edea8e"/><file name="Tabs.php" hash="e175ecbef45eea4c478d31c9d31fa31e"/><dir name="Type"><file name="Configurable.php" hash="99b1835743bd3aa1b53e80e5795ff037"/><file name="Grouped.php" hash="1352247682029865c76f704eb233c124"/><file name="Simple.php" hash="d7aaf15d55146d78d812d38b7fa6368f"/><file name="Virtual.php" hash="e64c5c2a8b71912d27657a44426727c5"/></dir></dir><file name="View.php" hash="621ca1ecc0cb4f21bb91ea26a0cfe29c"/><dir name="Widget"><dir name="Html"><file name="Pager.php" hash="d23f158ebb2383b7ff7a299915becc49"/></dir><file name="Link.php" hash="511a83b5c1328cd36f134d8f0814aab3"/><file name="New.php" hash="cb6dc0d7bd0c57d6a7c24e49fb279687"/></dir></dir><file name="Product.php" hash="5c2ad3dd5f5397c65efbf724f53f7d1b"/><dir name="Seo"><dir name="Sitemap"><file name="Abstract.php" hash="40505e53a280121520a9ab520c663a83"/><file name="Category.php" hash="620007da4f8211cdfb98fe9869f076ab"/><file name="Product.php" hash="4ef93e4a8947ff83f217e4af62c30037"/><dir name="Tree"><file name="Category.php" hash="931c98b2d937398ff7d4c1d8c3bb3965"/><file name="Pager.php" hash="0c7e6eb90729ea43712e6aef24e5b1ce"/></dir></dir></dir><dir name="Widget"><file name="Link.php" hash="e342be9976dbaffc9dcda7114f4ff07e"/></dir></dir><file name="Exception.php" hash="f12a83054d1a20c8e3aa4cd1d7aeed1d"/><dir name="Helper"><dir name="Category"><file name="Flat.php" hash="b25f4a4413c48058f1ad39cc58fc9d7c"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="14862f6ce3841239fb8e716978c1a311"/></dir><file name="Rewrite.php" hash="f6d564c29c38d9a0ef4aae9b80b91d64"/></dir></dir><file name="Category.php" hash="a3b276b2a88e1f97d986ed410fc89ea5"/><file name="Data.php" hash="f059c4211b1e40dc7c6bcb36b3b92d74"/><dir name="Flat"><file name="Abstract.php" hash="734af81e26cd91683decfd37c6fdb3bc"/></dir><file name="Image.php" hash="caccf877e69bcd2d1ddf44d4bdff0732"/><file name="Map.php" hash="8b29bb2b08a1db72f9e503a1e0e6b6c7"/><file name="Output.php" hash="3f66589fc28f12e2ae0ee9e64b42c17b"/><dir name="Product"><file name="Compare.php" hash="2f123719fa790283470f7014b3438d19"/><dir name="Configuration"><file name="Interface.php" hash="1f160deb5cc07c0b0cdc7f76939e4caa"/></dir><file name="Configuration.php" hash="834c453253c40cb83b407221589890e9"/><file name="Flat.php" hash="c3e13a893302fe1bc6a0cf7fb578d093"/><file name="Options.php" hash="69f21b6b8265daa0e9d05b9d92cb468d"/><dir name="Type"><file name="Composite.php" hash="d7a74a64416804402b0d285bbcabf41d"/></dir><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="031aa4fca8c3e0b1f55ddf8eadae6a8d"/></dir><file name="Rewrite.php" hash="edcb3ca25714d5898bedcc551022bc65"/></dir><file name="Url.php" hash="2f859186a0b33b2ffd81ce381515c003"/><file name="View.php" hash="2ebc969f69e0d229b68b6462a52cbfcb"/></dir><file name="Product.php" hash="2262cd6fdba539bf437c517ec9d83ca2"/></dir><dir name="Model"><file name="Abstract.php" hash="a8752cda0d7483ff1f2abe8c6d8667ac"/><dir name="Api"><file name="Resource.php" hash="c864b1f333f93a7e7f4e9dae32cf514b"/></dir><dir name="Api2"><dir name="Product"><dir name="Category"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7d7df63a06284862387fd3e183c10ff6"/></dir><dir name="Customer"><file name="V1.php" hash="8f4f1df79cd262f164d4830de2457792"/></dir><dir name="Guest"><file name="V1.php" hash="985d982fe174e9c574f79ecf71fdc79b"/></dir></dir><file name="Rest.php" hash="3e6a87ed62de65906241b2fd744d2d1e"/></dir><file name="Category.php" hash="8ee8aff92291ff265125a2a09c89cd60"/><dir name="Image"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="b99a15e80fcba83b69da3f0577732055"/></dir><dir name="Customer"><file name="V1.php" hash="b77c0d708c7341a755e7019cda0d638f"/></dir><dir name="Guest"><file name="V1.php" hash="1b25d97bb413a07e3cdedc4315d80552"/></dir></dir><file name="Rest.php" hash="3bedc3fdcb449e4fc552d51b4db3befe"/><dir name="Validator"><file name="Image.php" hash="8f563a0dd5eae33f59bb02d2350c8362"/></dir></dir><file name="Image.php" hash="4a435d724c9449619b9dfeada3c7f349"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="783b786dba0cfc0d7ac426f21985d332"/></dir><dir name="Customer"><file name="V1.php" hash="93bbb0c279c14210ccf40efda631ce66"/></dir><dir name="Guest"><file name="V1.php" hash="a6c70a60cb465ea65ae9d6dc5bd4a77d"/></dir></dir><file name="Rest.php" hash="168cc5bd719b85c205ec26742231701e"/><dir name="Validator"><file name="Product.php" hash="b1aeba72fd9478aa254e00befe7749d2"/></dir><dir name="Website"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8af3b32ea6a088a5eba8897a27b0fc0f"/></dir></dir><file name="Rest.php" hash="bce18e8c16db4be5067cf2e6ba364196"/><dir name="Validator"><dir name="Admin"><file name="Website.php" hash="8d22190d53b13b51a94eff9fd04f0aeb"/></dir></dir></dir><file name="Website.php" hash="6719ea0d36732907b897e377613d475c"/></dir><file name="Product.php" hash="11f9ccd6151a00d1cc19458ac5d05ee0"/></dir><dir name="Attribute"><dir name="Backend"><file name="Customlayoutupdate.php" hash="8a21fffdaf1cc4ffdf99f8ea7aa6d597"/><dir name="Urlkey"><file name="Abstract.php" hash="601a5cb04d820a1d28303e419708076b"/></dir></dir></dir><dir name="Category"><dir name="Api"><file name="V2.php" hash="5f0d39fc8300b9c4cdf080930ec27000"/></dir><file name="Api.php" hash="06db8ae01d1d3dcc9aca5a6ad4a8682f"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="c523122e1a5372678021801313f5fc49"/></dir><file name="Api.php" hash="b903a006267395b79ed6597c1f4743c6"/><dir name="Backend"><file name="Image.php" hash="8fd6fde98705cddced3ecf8253d5e9d4"/><file name="Sortby.php" hash="691af9d6173479fe7de0e82a3041ccfa"/><file name="Urlkey.php" hash="aeaa47c7a3aa478890f34d813456a40d"/></dir><dir name="Source"><file name="Layout.php" hash="ed247fde90f503a0ff797d9c019a3261"/><file name="Mode.php" hash="73e70a70a5aefbde6deb297882682fce"/><file name="Page.php" hash="9ab54c333bdb3458cc4ed5772cbda275"/><file name="Sortby.php" hash="8e19aea914848a0cbb31f3052677c255"/></dir></dir><dir name="Indexer"><file name="Flat.php" hash="604655e7cb987b716c2cf5b53f67d7f3"/><file name="Product.php" hash="9292cdefc56b9a80d68bb89a50b2b8db"/></dir><file name="Url.php" hash="937cbb08cf0df2a7f0c5ad78fcab17a7"/></dir><file name="Category.php" hash="fa9eab482b2dc9c89d9872963ddda499"/><file name="Config.php" hash="bfd4ebc72a0af7794c5866dea818db39"/><dir name="Convert"><dir name="Adapter"><file name="Catalog.php" hash="4a5dc0d4e4d513722ecb1e65507b9cac"/><file name="Product.php" hash="480c3893ac68ba8d5543e807cc8baa3c"/></dir><dir name="Parser"><file name="Product.php" hash="93fe85cc3b5d9c30adef55c6d17a9a99"/></dir></dir><file name="Convert.php" hash="d30056fc529cbc17b30ab1e9eade55d0"/><file name="Design.php" hash="015dc04db309159146bac792dc095356"/><dir name="Entity"><file name="Attribute.php" hash="17a40b3517dbe7ffe701f1da46970638"/><dir name="Product"><dir name="Attribute"><dir name="Design"><dir name="Options"><file name="Container.php" hash="7455da8147f8507b60bb0ba1418bbb4d"/></dir></dir><dir name="Frontend"><file name="Image.php" hash="f732289725a78b3c6632fa7990751899"/></dir></dir></dir></dir><file name="Factory.php" hash="12e1d2c3eda1542ea68d815255811d89"/><file name="Index.php" hash="d0b063d15d53b5cce0c43a04c98bbd68"/><dir name="Indexer"><file name="Url.php" hash="38765eba8afe37e6b2684e5ac29f8dc3"/></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="dd2cc2f440246631303bced9048750a4"/><file name="Attribute.php" hash="6a2c1c5cbe65138ef8bf33e274b61fe0"/><file name="Category.php" hash="98fa713a3a3bb451be05dd417be1c655"/><file name="Decimal.php" hash="e90016c6d18a189530fe888920dba47c"/><file name="Item.php" hash="201f811b88c46bf8a69db078eff5a3c5"/><dir name="Price"><file name="Algorithm.php" hash="544a88b82e4d3c494a479e8ea73e0b92"/></dir><file name="Price.php" hash="7cd7c428a372882153a61a032df62de9"/></dir><file name="State.php" hash="76bc7ddbb78683b65e71e905b575a5eb"/></dir><file name="Layer.php" hash="9a9b65ebd5a1c36011aaea477e198563"/><file name="Observer.php" hash="4bfd941d75131dd2232f888985849389"/><dir name="Product"><file name="Action.php" hash="decd0145a0f07fe7cbd7393fa118c9ec"/><dir name="Api"><file name="V2.php" hash="793a4b99d025fc6dfabd2da709cbdcd7"/></dir><file name="Api.php" hash="4501c79b530a237fce07c6a60d9ecbf3"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="3685f98a45122c256ede43ece696d5c5"/></dir><file name="Api.php" hash="bd1e32f897684f8dbd33bf8a05bbf072"/><dir name="Backend"><file name="Boolean.php" hash="2a5a0456c6620dea4221748911124d3e"/><dir name="Groupprice"><file name="Abstract.php" hash="b5900fc2c486a70e526baeda26cb0c3e"/></dir><file name="Groupprice.php" hash="3786eb7d502bd0b3a17f0f6f80e82dce"/><file name="Media.php" hash="65e6c1cbaa29a18f6aefa3fffdca8a75"/><file name="Msrp.php" hash="c7d44ca4f1ea3794cb19154bc2bc9e9a"/><file name="Price.php" hash="141048adfd0a2e00c4df780bec708c5b"/><file name="Recurring.php" hash="097c0474a762c4cf7cb87b5b0e4d048e"/><file name="Sku.php" hash="54a49ebfe99905992c11d6e193cbfcb8"/><dir name="Startdate"><file name="Specialprice.php" hash="0bb04fa551a461658cdfeea5c783be81"/></dir><file name="Startdate.php" hash="0ad91d8bccbe9dc867ccea9f99d0fd2e"/><file name="Tierprice.php" hash="3681dc3533c8604368a349c68ac68f1b"/><file name="Urlkey.php" hash="2e29bcde62d97ad85f8be84361b3e343"/></dir><dir name="Frontend"><file name="Image.php" hash="290245ae6814aebe9e6ef535973841f5"/></dir><file name="Group.php" hash="0d5a1d1d89c2d6a1055d77db9872ea6b"/><dir name="Media"><dir name="Api"><file name="V2.php" hash="133a39fb7e1107ef9fa81a0543a3e8dd"/></dir><file name="Api.php" hash="49913c934aa085481b744d7333fe343b"/></dir><dir name="Set"><dir name="Api"><file name="V2.php" hash="15517f2009ed3c7d72af842619926088"/></dir><file name="Api.php" hash="28959aef8dffec2ccc252a0f39660e38"/></dir><dir name="Source"><file name="Boolean.php" hash="72523d6f15bb4b7a5ddd8fb235f046bd"/><file name="Countryofmanufacture.php" hash="aadda3679470302577acd9f724d08ad0"/><file name="Inputtype.php" hash="15f7e59849a0ac4977e939caa3c4465a"/><file name="Layout.php" hash="c559a06df151d3d9c452a228f29876fc"/><dir name="Msrp"><dir name="Type"><file name="Enabled.php" hash="de117cb62373580b321199a446b804b6"/><file name="Price.php" hash="c8ee83148e929926333e11d838482b5e"/></dir><file name="Type.php" hash="5d6016b1c16da153676b7c0e4a081464"/></dir></dir><dir name="Tierprice"><dir name="Api"><file name="V2.php" hash="11ad5b869f9cb14fb0686f47b1680f08"/></dir><file name="Api.php" hash="94a5c06286100b29190c34655178bd33"/></dir></dir><dir name="Compare"><file name="Item.php" hash="1770a04bfd6b7663bb99e37904a91c13"/><file name="List.php" hash="72668aa9d697d58b18fb18191effd38f"/></dir><dir name="Condition"><file name="Interface.php" hash="f2cf66045ea9dd61986b758342556233"/></dir><file name="Condition.php" hash="19cd56bf3f2550ed01292cc341c7d6d0"/><dir name="Configuration"><dir name="Item"><file name="Interface.php" hash="0f23070446e06334285c197372c35b7d"/><dir name="Option"><file name="Interface.php" hash="c66bdfbe8f13e7a5edad0672275bee2c"/></dir><file name="Option.php" hash="ee7272d03f6afc6e9449d6e474f37b11"/></dir></dir><dir name="Flat"><file name="Flag.php" hash="363aded09ba741942b0aacb3d3a07c27"/><file name="Indexer.php" hash="0b3c9e5fed4229a33b5641075e637517"/><file name="Observer.php" hash="d5662401baa5cde6c28f01d141294bc7"/></dir><file name="Image.php" hash="baec4a63b96bbbf5e14e455dc2e2d015"/><dir name="Indexer"><file name="Eav.php" hash="e47e464e1023c564e911ab1961a0b11f"/><file name="Flat.php" hash="e88b212e14303f5869321e95dda2999e"/><file name="Price.php" hash="eebb7689c64c15b55a0cd5dc37a5d276"/></dir><dir name="Link"><dir name="Api"><file name="V2.php" hash="477152eaccdc7de5a464e56dabbb3612"/></dir><file name="Api.php" hash="0908690809e366ca32a85eccc39424ba"/></dir><file name="Link.php" hash="aeb02bfb03bb74c369e081e3ee0d8af2"/><dir name="Media"><file name="Config.php" hash="099a406b5674248b233f09f243a2920a"/></dir><dir name="Option"><dir name="Api"><file name="V2.php" hash="14bb5161d6a2a298d435f516798ede69"/></dir><file name="Api.php" hash="befcfd818c890847fd991db908f337bc"/><file name="Observer.php" hash="4356352cea7f0cf6aa42df08ae2f90ab"/><dir name="Type"><file name="Date.php" hash="f58c2ebf294cab03940eca55c4e84490"/><file name="Default.php" hash="d30754bfd2505dc7b7c2fa088dc4115c"/><file name="File.php" hash="6352b854844cdcfa25cf6f43dff7d54c"/><file name="Select.php" hash="9555af869c9cda85d96be06ce4ea8c88"/><file name="Text.php" hash="3343457af57c576140ab52c759de1d57"/></dir><dir name="Value"><dir name="Api"><file name="V2.php" hash="3939065d0e21ab3d7f91673be42280b7"/></dir><file name="Api.php" hash="0b85d0ce714b5acffa1e428c2d8aed58"/></dir><file name="Value.php" hash="4e14b90cc585e7a5b691625135dbd028"/></dir><file name="Option.php" hash="eb7598408500873cb7e55c9eca535b38"/><file name="Status.php" hash="e848573b6f8f57f01053330d20b2bcdb"/><dir name="Type"><file name="Abstract.php" hash="456ddf2b2a03e14e81e3e0a683119e4c"/><dir name="Api"><file name="V2.php" hash="b6707f76e85bc688dc5ba8f60dc10d3b"/></dir><file name="Api.php" hash="e42bfe85d504d4b9dd00b4b64b8fecb0"/><dir name="Configurable"><file name="Attribute.php" hash="b8ed3e9057b253b0f344846b188509d2"/><file name="Price.php" hash="1802e8c7a74d5795d125a27d1e3a53a4"/></dir><file name="Configurable.php" hash="0ba0e65168d5af4647b9fe6da254e39e"/><dir name="Grouped"><file name="Price.php" hash="d1afc84f82d025db921f5d4ce1b7e32b"/></dir><file name="Grouped.php" hash="9d5c08c0e094dcacedc542afa334d98b"/><file name="Price.php" hash="85eddbc0df0b45a54e5cfbb801b9a010"/><file name="Simple.php" hash="e4a0cefc389b7da8509a9b17b4c2ba09"/><file name="Virtual.php" hash="89d8e7e2b763427055e3da933a172e88"/></dir><file name="Type.php" hash="54d62b5d5c8d98f279443906360247ba"/><file name="Url.php" hash="9430be8c25239582d3aea22711db6720"/><file name="Visibility.php" hash="3d4d497257c9f3335dac07b41cb4c69d"/><file name="Website.php" hash="b65aaa5099f357f5aa688efb8a0823b4"/></dir><file name="Product.php" hash="8c1eca1931764491e74f1d15c735df1f"/><dir name="Resource"><file name="Abstract.php" hash="c14958ef6804679c24703aba82434753"/><file name="Attribute.php" hash="4b8177eb1f1e7241eba5e70806beddc7"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="3ffbcb599ae748665619ecb1bd4e32de"/><dir name="Frontend"><file name="Image.php" hash="265bcb0baebcc805a992d9e92a105c98"/></dir><dir name="Source"><file name="Layout.php" hash="8a605bb387b98c83eb8370714bc536de"/><file name="Mode.php" hash="2f54f5b1302a21f362e7f3776c1ab10b"/><file name="Page.php" hash="3f583421a6c6a90fcfded71ac86b1711"/></dir></dir><file name="Collection.php" hash="60ee6565b57ce712723d4e41a827dede"/><dir name="Flat"><file name="Collection.php" hash="c8dd70661951f7fd60a61fd08b1247fc"/></dir><file name="Flat.php" hash="5b2c10a35f424b8168dd1b2794f1dfff"/><dir name="Indexer"><file name="Product.php" hash="fb9f9cf67f670d287ff49a762b91fa3e"/></dir><file name="Tree.php" hash="76ddcd3417b6ec0b62e0b175933217e0"/></dir><file name="Category.php" hash="d5be53b29b16c8ae073b482daa66ef4d"/><dir name="Collection"><file name="Abstract.php" hash="f871c02ea4d88638f637eb24b790b3d5"/></dir><file name="Config.php" hash="3b6571774cadf96433902cd54297a9d6"/><dir name="Eav"><file name="Attribute.php" hash="e92cbf5f90282670c86bcedd005846ea"/><dir name="Mysql4"><file name="Abstract.php" hash="2a367c043fbc2858adb01c6c4ea2ff9e"/><file name="Attribute.php" hash="b2344f0813ac67e3d4550087a20ad2ae"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="bd7da78fe2526ae9ecf57eec773092f0"/><dir name="Frontend"><file name="Image.php" hash="592591274fd4dd36f1c101a40d4b2951"/></dir><dir name="Source"><file name="Layout.php" hash="645778015cea4f06dff49c5726502f4b"/><file name="Mode.php" hash="96bcbb702e35ecf20f03b12ebf8042d5"/><file name="Page.php" hash="5e5193c362e2fb605d7128c3f2894ac2"/></dir></dir><file name="Collection.php" hash="e3fe15e20c006b16c9aa38caa17caa95"/><dir name="Flat"><file name="Collection.php" hash="847dff2c53f375efc6107a5044afbd1e"/></dir><file name="Flat.php" hash="040ba88e64f19013f85b66834cf0f5f8"/><dir name="Indexer"><file name="Product.php" hash="33642d91c512107fb37252f6e97408df"/></dir><file name="Tree.php" hash="6115a020dc6913f3dfaf226601247c80"/></dir><file name="Category.php" hash="79029baf7c325430171bf30886a5caa5"/><dir name="Collection"><file name="Abstract.php" hash="124dfabd4981973f07975154bafea8d0"/></dir><file name="Config.php" hash="9fe560aa88aabe6f9fbe03b68b4085ea"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="ccbf9d48d22c7f077054e95b3d2042cf"/><file name="Decimal.php" hash="0d9a04b5a445d15d6b7b03a7febcb4be"/><file name="Price.php" hash="59d45ca47c02f4d1ee5860923d5c96d1"/></dir></dir><dir name="Product"><file name="Action.php" hash="0bb6f6cd561b111392302f58de49b7b0"/><dir name="Attribute"><dir name="Backend"><file name="Image.php" hash="b2ff2e77ca0a5c1b96e2b0ea7913195d"/><file name="Media.php" hash="08eab44f2071f37ed4a17771014d18a7"/><file name="Tierprice.php" hash="d8e1f29c9aded8a2f503e1e05f0f3508"/><file name="Urlkey.php" hash="f4a2a06d66828a9425032ff779971546"/></dir><file name="Collection.php" hash="42d92267179369ca1b53a04769202de5"/><dir name="Frontend"><file name="Image.php" hash="9ff5fc06d6bb7367283c7d4254d792f6"/><file name="Tierprice.php" hash="15c00b90689a29f9a011c9f485e49ddd"/></dir></dir><file name="Collection.php" hash="b79fc090c34b6fd44c9cf6ea9cbd4883"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="8ef3865a4184e44a79ae2e266135a6ab"/></dir><file name="Item.php" hash="3a11128e27a6e042c859fd9870b12138"/></dir><dir name="Flat"><file name="Indexer.php" hash="de2ed76c939ee2bdb9eb184176a8e604"/></dir><file name="Flat.php" hash="699390b439b8db9bde5104d2a59009da"/><dir name="Indexer"><file name="Abstract.php" hash="bc190cb0183bd1f7db0ac4c2e3cd182d"/><dir name="Eav"><file name="Abstract.php" hash="1f3bdac32c138ad8c5a71fad5f655eba"/><file name="Decimal.php" hash="8418e2274ff77522e8caa393339acf61"/><file name="Source.php" hash="956a03b9a4cb0602f28cb06373d41e82"/></dir><file name="Eav.php" hash="9dbfa6685d22718fd6dd81ac9112dd34"/><dir name="Price"><file name="Configurable.php" hash="460c5542704c3b11741821ff704d4fcc"/><file name="Default.php" hash="c5edd3e077b00463b3cbbaefad1ba6a8"/><file name="Grouped.php" hash="077cb723a265b1a5c43eeaa1b601e1a6"/><file name="Interface.php" hash="3f4c53d917ec9381894358b8822d806d"/></dir><file name="Price.php" hash="3fc351998bdaba729be4678a78a0da85"/></dir><dir name="Link"><file name="Collection.php" hash="34fe71afca447379ed7513536fecd642"/><dir name="Product"><file name="Collection.php" hash="853c7788c08dcf878e2607a555685122"/></dir></dir><file name="Link.php" hash="14758eb79f27b954abb80ed90a101a3e"/><dir name="Option"><file name="Collection.php" hash="0a201c7e6fb601f98e9f9cca226358e9"/><dir name="Value"><file name="Collection.php" hash="86aa68a240301b088861ed13dc8381f0"/></dir><file name="Value.php" hash="82d41979c3abf45111e1dd2c56a4b001"/></dir><file name="Option.php" hash="b3bc9c0b3ab001abf97628fb2d5dbf96"/><file name="Relation.php" hash="34958c4dacac719d88f9e2cdfdb8b136"/><file name="Status.php" hash="1ee8129ba6198845a4022cb0a23e1b60"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="9b7f72984109f13c28cf85a68b319bd9"/></dir><file name="Attribute.php" hash="e2caafaf5f244802e171ee2ed1ff7bbf"/><dir name="Product"><file name="Collection.php" hash="db3d68e3ebf537cd23158e9292d3d575"/></dir></dir><file name="Configurable.php" hash="6dde68202d2dfd1cd0cc00548b7a1985"/></dir><file name="Website.php" hash="cc737b50d6e2e43e14b81ed1746e9b3a"/></dir><file name="Product.php" hash="4151845a9d0686def340b920e098f741"/><dir name="Sendfriend"><file name="Collection.php" hash="db2654b8b3538dc570f4411d4735131e"/></dir><file name="Sendfriend.php" hash="0525ce13a3a3a10d7171fb8622dfd48d"/><file name="Setup.php" hash="3e1d02f8e0c571a19598f9d98ad84bba"/><file name="Url.php" hash="56970705a722b52eca45df8ae3a066d6"/></dir></dir><dir name="Helper"><file name="Mysql4.php" hash="346aed24f42fc8cb87edb7140638663f"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="9dad377ec4098111bc3db812204ff080"/><file name="Decimal.php" hash="749ff82a37683e09b24c65dcf701402b"/><file name="Price.php" hash="310aab644b6600746d0c27c6a01403ac"/></dir></dir><dir name="Product"><file name="Action.php" hash="298bd0d4c878a4c20ef1e38055302b53"/><dir name="Attribute"><dir name="Backend"><dir name="Groupprice"><file name="Abstract.php" hash="e14702c7892e3bafd6a7d8b1ba361b51"/></dir><file name="Groupprice.php" hash="646caeb2f18916e63c1432f1af1708e0"/><file name="Image.php" hash="ff506a149dd3f4e6bf3ea120d3473170"/><file name="Media.php" hash="01fafee272101d93242d0e574a32481a"/><file name="Tierprice.php" hash="b328e4cde490e74a3296882570c0ed6b"/><file name="Urlkey.php" hash="3fbc5b079cfc88a46e2e45a589182041"/></dir><file name="Collection.php" hash="63fdcf9337942f1dca816ea76dc35fe5"/><dir name="Frontend"><file name="Image.php" hash="22810c5cad61e224f0fc6881bc88fae3"/><file name="Tierprice.php" hash="04ea1ae5b17fc1a388859a0c4b9cbdaf"/></dir></dir><file name="Collection.php" hash="f1cd791dd63e491fce2dfdd13b64b82a"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="4fb51b54810df997353844058e8741b9"/></dir><file name="Item.php" hash="b744e1f4b3ad4b448e41162746c3dfe3"/></dir><dir name="Flat"><file name="Indexer.php" hash="d23c69dd71584b02c83cd997b390dfb3"/></dir><file name="Flat.php" hash="26e93d868615c55fb33db2213db4286a"/><dir name="Indexer"><file name="Abstract.php" hash="b51e95b7b0f89be7859b20e0c439d6c1"/><dir name="Eav"><file name="Abstract.php" hash="a7de365b3c24f7925d0aff2ded37f403"/><file name="Decimal.php" hash="8bca02dc0329c702b965f05f5a9949cb"/><file name="Source.php" hash="b207472624ad4d67f9f2a88e6e2ad2e6"/></dir><file name="Eav.php" hash="f5e66db5984ed89d7ff6531dd30633f3"/><dir name="Price"><file name="Configurable.php" hash="c0a92825df74de40aadab166763d6fc8"/><file name="Default.php" hash="3df089b3b5116fb4db829dc94ac66fd4"/><file name="Grouped.php" hash="ff69c8dc1428f1ed620843acfaaa5121"/><file name="Interface.php" hash="ec19f8d573eca3c7dcd43a5c33f98f4e"/></dir><file name="Price.php" hash="2c4385289d5a45a8a66ab41472b64754"/></dir><dir name="Link"><file name="Collection.php" hash="c0983cdfd3183129078b302021e57587"/><dir name="Product"><file name="Collection.php" hash="ea9ec18e1ba474635dde20f245f90430"/></dir></dir><file name="Link.php" hash="7dbac8c8fa2cc623f4d50aceb27e0e00"/><dir name="Option"><file name="Collection.php" hash="de9703a538cfe61ec3b5bfe0ddef228a"/><dir name="Value"><file name="Collection.php" hash="cf7203a390fe7bcdd2d80658ea638f8b"/></dir><file name="Value.php" hash="6e12f40c2708897a49aae723a2ff19d9"/></dir><file name="Option.php" hash="75fd5d228bbc80fd97e12c4d0d9622b3"/><file name="Relation.php" hash="46966dfd38f5d80d22ffe0ff9e43c967"/><file name="Status.php" hash="e77d71b99b3e29da963a7f76600f10ea"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="bd087f24c45cb093d8d536ea05c6e92c"/></dir><file name="Attribute.php" hash="2f2399997b9b922c2ea9f5ada87ff958"/><dir name="Product"><file name="Collection.php" hash="d24bba40636bf969f73e20b407dab32c"/></dir></dir><file name="Configurable.php" hash="a0ab436c28d58783caa04224c1f5d3bf"/></dir><file name="Website.php" hash="ae55f3449cfef9a583d3a0e2d43f2cb5"/></dir><file name="Product.php" hash="d8d540dbeca26d6dd3acdfc26302ac41"/><file name="Setup.php" hash="a9aceb3a22800559189a82f3d644d6e1"/><file name="Url.php" hash="fee84f8fd827c4b523c8bc72f1de704b"/></dir><file name="Session.php" hash="d215af2e51c77cd0eb48d01886d97c67"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Catalog"><dir name="Category"><file name="Flat.php" hash="5e7c93fe883ca86ae471ec9533b92488"/></dir><dir name="Product"><file name="Flat.php" hash="be6906d997d57412dc0f0678fed1fcda"/></dir><dir name="Url"><dir name="Rewrite"><file name="Suffix.php" hash="dc19187f7b9027e075e69ad5828bca08"/></dir></dir></dir></dir></dir></dir><dir name="Template"><file name="Filter.php" hash="be97244f623000eba021d31da010f457"/></dir><file name="Url.php" hash="b9cc8fa3476c3028ee3fd90852aa3050"/></dir><dir name="controllers"><file name="CategoryController.php" hash="0b623f4ee9d8e885aad13d0f23f13a30"/><file name="IndexController.php" hash="805f36221033bcbd93eb3121d0d0948e"/><dir name="Product"><file name="CompareController.php" hash="85c7287cb28dedb46402aa92fd594959"/></dir><file name="ProductController.php" hash="e14a5e084e5e2f024c5fd3b5477c906c"/><dir name="Seo"><file name="SitemapController.php" hash="34d2c078cdb514e676a60691d607e15d"/></dir></dir><dir name="data"><dir name="catalog_setup"><file name="data-install-1.6.0.0.php" hash="ef9ebc687f8cc23de608e3eec94232cc"/><file name="data-upgrade-1.6.0.0.12-1.6.0.0.13.php" hash="d472917c63d90778ca89350d7232ee13"/><file name="data-upgrade-1.6.0.0.13-1.6.0.0.14.php" hash="8212a73ea36cb390312bdb382ec6f408"/><file name="data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php" hash="5f60b06746ecaaa74f24ebc376fc0f38"/><file name="data-upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="d369491d2e0204a1708d8a8e0212be93"/><file name="data-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="8717445601b14a3f806bb161fb596a4f"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fd5a88df31874c873ddc47fd12128483"/><file name="api.xml" hash="61f1a48867bbfafb52e53a29b5c3d694"/><file name="api2.xml" hash="013a076022ddbf3fea4a0742d5b8bc8c"/><file name="config.xml" hash="0f41603c3f745b50d2a0fb4de8d0a546"/><file name="convert.xml" hash="8d8f7eba4c23dc6873132c771d46af97"/><file name="system.xml" hash="c68005c02276e6b02fcee376373c9248"/><file name="widget.xml" hash="772ee5617954b3a85519bd64bd25abdc"/><file name="wsdl.xml" hash="fa198392d766134085b3c2ec1be4a0e9"/><file name="wsi.xml" hash="0acfd65c613ccb83404317500078a85d"/></dir><dir name="sql"><dir name="catalog_setup"><file name="install-1.6.0.0.php" hash="c29963f106b44ac2bedf0ef43b16caab"/><file name="mysql4-data-upgrade-0.7.57-0.7.58.php" hash="9c5663631e26bc0dbae1ea7f31d2ee86"/><file name="mysql4-data-upgrade-0.7.63-0.7.64.php" hash="6073444dda366a4cb50d3b4704bbb1d5"/><file name="mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="fdf01e58ffaf834d4761675e99ba5b88"/><file name="mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php" hash="466304c2f961b3dbcd2606fc02cc8087"/><file name="mysql4-install-0.7.0.php" hash="a6b88eeac8ea791e1c6b50be6a2bdcff"/><file name="mysql4-install-1.4.0.0.0.php" hash="d4e60629ae2494d3d7d8db7424e4f463"/><file name="mysql4-upgrade-0.6.40-0.7.0.php" hash="507edb127b940c5b9c85dc5bfdd9ee30"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2f6b873ea84bac96da7be4905fe9c17f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f43a60fb17d36c541e08b0ad92d146da"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dfc471e252d3995a7ef491d1399d9ffc"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="bc84e63dd439f8a424ef9e6d8ca29adb"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="ea6b851a464cb7005f0798c17448a5e7"/><file name="mysql4-upgrade-0.7.16-0.7.17.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.17-0.7.18.php" hash="5677f19bba0d4e8cfa1f88363081e7af"/><file name="mysql4-upgrade-0.7.18-0.7.19.php" hash="7d624e6c993855ad8fba5f3898429401"/><file name="mysql4-upgrade-0.7.19-0.7.20.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="f9d888899433993fedac11a5ae62a2bb"/><file name="mysql4-upgrade-0.7.20-0.7.21.php" hash="5d8ff6a9614259de0da5aa89ab3f0c06"/><file name="mysql4-upgrade-0.7.21-0.7.22.php" hash="a8063991dd0567f63c169893210d04ec"/><file name="mysql4-upgrade-0.7.22-0.7.23.php" hash="d89516b96caced26119cf3a3f14442b7"/><file name="mysql4-upgrade-0.7.23-0.7.24.php" hash="8b96b8f483d5c21b42dbdf68ecf6c2f2"/><file name="mysql4-upgrade-0.7.24-0.7.25.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.25-0.7.26.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.26-0.7.27.php" hash="083503e821d19cfab3ca9d97bbbbaa72"/><file name="mysql4-upgrade-0.7.27-0.7.28.php" hash="64cb2325781d72a135aa2e5744e012e5"/><file name="mysql4-upgrade-0.7.28-0.7.29.php" hash="460f9b2de5477af5ec4c36ca2791d530"/><file name="mysql4-upgrade-0.7.29-0.7.30.php" hash="908ca45d436735f8d498de0d28c5a092"/><file name="mysql4-upgrade-0.7.30-0.7.31.php" hash="085e3ad264455870e6b57b135b10860c"/><file name="mysql4-upgrade-0.7.31-0.7.32.php" hash="25dbc8dc2e32d91e394ed76f2e68b94c"/><file name="mysql4-upgrade-0.7.32-0.7.33.php" hash="6c050648205a2971087c3822fa10f99a"/><file name="mysql4-upgrade-0.7.33-0.7.34.php" hash="53bfad70ff24d6227c2a3e4f831513e3"/><file name="mysql4-upgrade-0.7.34-0.7.35.php" hash="0bf51a7f95d6e11f5244bac7b4b7ce9c"/><file name="mysql4-upgrade-0.7.35-0.7.36.php" hash="8b01c971f3a27f7b49576aa8b7d4ddcb"/><file name="mysql4-upgrade-0.7.36-0.7.37.php" hash="09c848c52e1e27cd105e3cfb107a24b2"/><file name="mysql4-upgrade-0.7.37-0.7.38.php" hash="1c27b73c04e636200f7c8e388fec68c8"/><file name="mysql4-upgrade-0.7.38-0.7.39.php" hash="6c573296430a1e2ccdfe596ced83b201"/><file name="mysql4-upgrade-0.7.39-0.7.40.php" hash="c337c33147016060b3ff88c8dc415da4"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="e236771503e6d160a30a216bf7e77b43"/><file name="mysql4-upgrade-0.7.40-0.7.41.php" hash="8e594a691237dd91fc12635476d38fee"/><file name="mysql4-upgrade-0.7.41-0.7.42.php" hash="1b8378086638dba3520f1044d8352485"/><file name="mysql4-upgrade-0.7.43-0.7.44.php" hash="f824722e979b87d55941ad6d6d828452"/><file name="mysql4-upgrade-0.7.44-0.7.45.php" hash="a03e8d35ed5bb34226075266b395dbe5"/><file name="mysql4-upgrade-0.7.45-0.7.46.php" hash="fb4ebc451e162848f9897f94772862b4"/><file name="mysql4-upgrade-0.7.46-0.7.47.php" hash="b0ee6aa0fe5a6b836e91e2c4d03f4f2b"/><file name="mysql4-upgrade-0.7.47-0.7.48.php" hash="87aa57f14078c57fc1a8da34e314e347"/><file name="mysql4-upgrade-0.7.48-0.7.49.php" hash="6d76557d041bf75e5bfc306a2bb9f3ed"/><file name="mysql4-upgrade-0.7.49-0.7.50.php" hash="07d744ff031c377e2728ecaba6009629"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="9d946faeab0c58e3f085609032515478"/><file name="mysql4-upgrade-0.7.50-0.7.51.php" hash="7f9260d51a63a0a8f3c5192f1db14d0b"/><file name="mysql4-upgrade-0.7.51-0.7.52.php" hash="2c18d6c66df05f3b4207f7c00854cf66"/><file name="mysql4-upgrade-0.7.52-0.7.53.php" hash="5a1008b25157ec584c5c881c3c7e154d"/><file name="mysql4-upgrade-0.7.53-0.7.54.php" hash="15ff250c95b87120a83d90a062f73a5a"/><file name="mysql4-upgrade-0.7.54-0.7.55.php" hash="719516da1f701c670f856f60f98860cf"/><file name="mysql4-upgrade-0.7.55-0.7.56.php" hash="c771a19fff3b61373ce76646a701bc47"/><file name="mysql4-upgrade-0.7.56-0.7.57.php" hash="490d8c1cb40c3045dbe7484bafa2b1ba"/><file name="mysql4-upgrade-0.7.57-0.7.58.php" hash="9a0d6890063532aad3a0eb27e32fc622"/><file name="mysql4-upgrade-0.7.58-0.7.59.php" hash="76025781953b54f5316084857594254c"/><file name="mysql4-upgrade-0.7.59-0.7.60.php" hash="d74eeb502951b3f401813795be8c7a60"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.60-0.7.61.php" hash="88de24828d60913d63ce0c2f76315a3d"/><file name="mysql4-upgrade-0.7.61-0.7.62.php" hash="06aae2ea1d872fa83f0121324aa02400"/><file name="mysql4-upgrade-0.7.62-0.7.63.php" hash="f7ca5162b321dd64887c9d245eeed643"/><file name="mysql4-upgrade-0.7.63-0.7.64.php" hash="9e19c27309b19b275ca0bee0a4790476"/><file name="mysql4-upgrade-0.7.64-0.7.65.php" hash="979fb613a8ec5695ed2e6f615616d169"/><file name="mysql4-upgrade-0.7.65-0.7.66.php" hash="dc64aa0fa4c4198100948dceee48f96d"/><file name="mysql4-upgrade-0.7.66-0.7.67.php" hash="86a3c5fd7a06048cda04cdad7a6e801d"/><file name="mysql4-upgrade-0.7.67-0.7.68.php" hash="f2afb3c2630946476346958e29d9e70e"/><file name="mysql4-upgrade-0.7.68-0.7.69.php" hash="89b9d73c5b6c625ece67693ccd498ce7"/><file name="mysql4-upgrade-0.7.69-0.7.70.php" hash="a0548013b1718f68e9ce15fcf5d38408"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="79e710442cb653908c95b585829abfaf"/><file name="mysql4-upgrade-0.7.70-0.7.71.php" hash="e767f97578e42fc4a32162f58d9b2e4f"/><file name="mysql4-upgrade-0.7.71-0.7.72.php" hash="eeff783e2e2000befd14b9340ba28a32"/><file name="mysql4-upgrade-0.7.72-0.7.73.php" hash="419232e5dce501a80c5dc2a66a42577b"/><file name="mysql4-upgrade-0.7.73-1.4.0.0.0.php" hash="8b6172c12f58ce3ef1a16bf35ee31cdc"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="623853171877cf7085d6f3abcc49673f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="20555dcf3e6a01e408b1cb1c56957f23"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="5aa11d1c55bc3cd63db6c2cd157cd71d"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="87eb69de3122c4d90935518fe8868749"/><file name="mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="a3f9c9b41fb20c258248f98bb9e1ec2f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="f18e34961d0277f9ae9875075c2e4514"/><file name="mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="9a2dc72bb5b00912af39399d53021d21"/><file name="mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php" hash="de27b4f0ddc37e5cd856c66f041479e6"/><file name="mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php" hash="b1eb1bc037284300f4b7280c03eb241c"/><file name="mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php" hash="5651974d4eb2bae3c27be5cd312cfbbe"/><file name="mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php" hash="660ec00a2013d97bc10851ef4b27e940"/><file name="mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php" hash="dae45d8263ea6f26b98d6ac49a08e19e"/><file name="mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php" hash="79c4658fa552dfaeda70ba030a3642b2"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="593097cd07e2a4806d832c85fc735706"/><file name="mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php" hash="235e9a7c3ebe5ea369584b49e86276ef"/><file name="mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php" hash="677245c0b3379140dffede0d209deee5"/><file name="mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php" hash="841015edcc5f636391541fd252463c50"/><file name="mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php" hash="6504d290e95977304959211ac7bfc0c4"/><file name="mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php" hash="e83e00bed962a768af6ffc6906bf6c0e"/><file name="mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php" hash="e0e38aa2816abd6159b33717dc246e97"/><file name="mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php" hash="f7d17fca52fb06de66f430900fee2c13"/><file name="mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php" hash="6084b618f9a2d7d69e2e2e91f2e1f55d"/><file name="mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="a69471d54bede4e5afed8ccae51b8a9c"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="a7c535e680a7c9c623094e54f514b58f"/><file name="mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php" hash="2f221443dffe6cfd32ea64ecda52ce2f"/><file name="mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php" hash="d64fc6dd5225c10dd4e36bf298aa4d7a"/><file name="mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php" hash="d1fe2d8afb82cf468657ddda5389aa88"/><file name="mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php" hash="cf0e6b3578ad191f76157c0132d03230"/><file name="mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php" hash="9717a718577395f0e0646fcffeb7f6da"/><file name="mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php" hash="551b8c6cdd768e72050f686f267c9ebc"/><file name="mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php" hash="39a95ef491d0af85fa873fc53bc0a591"/><file name="mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php" hash="d8f9fa201cb8bee1872c01c5364710e7"/><file name="mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php" hash="3da4c8953eebd0faa442fe07ea3f94f6"/><file name="mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php" hash="8269869aaf91ae34cfdb2b6f2f6f4545"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="033cc6f1eb844eb2aca8bdb4ac2d7901"/><file name="mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php" hash="c123b4fd1db3e8638d748613d0af8138"/><file name="mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php" hash="fba18ca14ea477338ed50c1beec34bcd"/><file name="mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php" hash="e8fc42ea638f58c7221a19b49c9cf9ab"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="b80203909773a1f38c35383a983b3273"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="b41a118ff245764def690665767cca24"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="2ece267357c4d9440e3402c3f0c8b19b"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="e6580f466b4567f9db9c69ce4d19be6a"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="b65d059cd51c7d188ffa9bacff3d978a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="375eecb3c1d1378633edf5b674e14da6"/><file name="mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="7c81d529fdcbfeb15e293ce059c0cbca"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="077527314f082634ae92550d915e543f"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="9f2bacade9c4d2ad1a8542cac36097c4"/><file name="upgrade-1.6.0.0.10-1.6.0.0.11.php" hash="e7529d1f8a30b456f6577ff8b3b46245"/><file name="upgrade-1.6.0.0.11-1.6.0.0.12.php" hash="8814c53ea7fc2e5a15b96a4f2c15a391"/><file name="upgrade-1.6.0.0.14-1.6.0.0.15.php" hash="dc9ac4700806bdc55bd4ffcd5c22a49a"/><file name="upgrade-1.6.0.0.15-1.6.0.0.18.php" hash="d39d85f7ea7f2975dad11e467b8bba7a"/><file name="upgrade-1.6.0.0.18-1.6.0.0.19.php" hash="5e06c46ebebd369a3178b00603f0bc18"/><file name="upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php" hash="7d10833e5b4f9b540ddf4df06dbf63fb"/><file name="upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php" hash="ce8eb57226d3b66fda8ff9cace5fb8c9"/><file name="upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php" hash="ad98088ce7ecb304e78e7e4c2163fe33"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="a4f70ae360f99126e6b25e166431e337"/><file name="upgrade-1.6.0.0.3-1.6.0.0.4.php" hash="e0ad21122b4cee55e0f4c8b5c44d737b"/><file name="upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="1cbb44723229355c50f2202fab455931"/><file name="upgrade-1.6.0.0.5-1.6.0.0.6.php" hash="e78ecce5cfd76b13dbd7ef5d9f9735e3"/><file name="upgrade-1.6.0.0.6-1.6.0.0.7.php" hash="5f4e31a57366b12432190b0dbdc0a68c"/><file name="upgrade-1.6.0.0.7-1.6.0.0.8.php" hash="e79d5e53a7a4c25497eb3bfdda46eb97"/><file name="upgrade-1.6.0.0.9-1.6.0.0.10.php" hash="ce5b3dbc98219a2c0da94040da590f51"/></dir></dir></dir><dir name="CatalogIndex"><dir name="Model"><file name="Aggregation.php" hash="9c6f7998d76d1bca362e089175a93ae2"/><file name="Attribute.php" hash="78d663d4ea9f77754c2c3560d0b020e1"/><dir name="Catalog"><dir name="Index"><file name="Flag.php" hash="9524e2814fdeca550e656b6733338f65"/><dir name="Kill"><file name="Flag.php" hash="5a9339464929555f00c31e9ecaf098aa"/></dir></dir></dir><dir name="Data"><file name="Abstract.php" hash="b9ce96f710806d292935a8db74af86ff"/><file name="Configurable.php" hash="eee28753c670a9c2379b39f0234d427e"/><file name="Grouped.php" hash="bb07795d092a9ac2c63ff0c29e76b729"/><file name="Simple.php" hash="f007617c31143387958a8604e3f0870e"/><file name="Virtual.php" hash="4aca3ebe694553e66aa6e3ea0682cda9"/></dir><dir name="Indexer"><file name="Abstract.php" hash="61295f02872b473935c13c0aca969d47"/><file name="Eav.php" hash="9085f089b3882a86f4f847f2abb5caad"/><file name="Interface.php" hash="6c71d4648ba7201f7987022cdfce3685"/><file name="Minimalprice.php" hash="6decf39ab3208edce2543e75892ac265"/><file name="Price.php" hash="95c1e4e340c4caa61dd8d2468c082080"/><file name="Tierprice.php" hash="47dcfa2ab722cbe136b770f70d6edef6"/></dir><file name="Indexer.php" hash="56c31bb712bbe66591c98161de5e38e7"/><dir name="Mysql4"><file name="Abstract.php" hash="6e0f0fe11a1ce650c3e10a23a0d945e4"/><file name="Aggregation.php" hash="76f46435204ca54d4591ab2a0c616cbb"/><file name="Attribute.php" hash="a58cd34ef532d852bed7b9d4ad1b9771"/><dir name="Data"><file name="Abstract.php" hash="41bc6267ada02fa6fe8ec615ec3ebb3f"/><file name="Configurable.php" hash="4577c89b879e8f99bedc4465fb9661f3"/><file name="Grouped.php" hash="a6884d4b81b61a067b1e505dbfc93a19"/></dir><dir name="Indexer"><file name="Abstract.php" hash="d3a9da75a16656171c18bb86fa33fab5"/><file name="Eav.php" hash="1d0f16eebd4ce5b824e1ae1eda2cfc15"/><file name="Minimalprice.php" hash="064cc6452df17680b1512dbfc226c141"/><file name="Price.php" hash="3c6e97db8d77933ca4defea0b51d6e91"/></dir><file name="Indexer.php" hash="5898b1893183208da157dc36abf37cba"/><file name="Price.php" hash="74b8fa8fba67d2def8524a1dd460e1c1"/><file name="Retreiver.php" hash="df8626625cbcbd70a168d8d0176fa097"/><file name="Setup.php" hash="06f2b09a62a2ede2972d82217c12fa36"/></dir><file name="Observer.php" hash="323541f9c7627005c1097bae4745eaaa"/><file name="Price.php" hash="59d2c099a753e4bfc63a3dbc38182a4e"/><dir name="Resource"><file name="Abstract.php" hash="841e8054f863bb931a77ee7566252c2e"/><file name="Aggregation.php" hash="3ffea2e0c7fde3c001db5b39ebfa9f0b"/><file name="Attribute.php" hash="7dfb03a93545bbc0f3dfc764be9d7f8d"/><dir name="Data"><file name="Abstract.php" hash="835008239d9b91c16a2d972aa0f59568"/><file name="Configurable.php" hash="7ab1340e4d655b92110de56727b3baa1"/><file name="Grouped.php" hash="94e47080c8f6d107791271c21c88710b"/></dir><dir name="Indexer"><file name="Abstract.php" hash="ed70e8d2d098dab0aa3e69987a6eb43a"/><file name="Eav.php" hash="31a975aef9ba4b6342eaee5c807f3e65"/><file name="Minimalprice.php" hash="6eb6e4b3fb2fa545f2d038ccf0cadc0a"/><file name="Price.php" hash="064d4f9ae150af92c167e2f87bacac54"/></dir><file name="Indexer.php" hash="2cc939178ff4282eec7626cdba5f1c04"/><file name="Price.php" hash="92c794f7efea76b7743824653c1af1be"/><file name="Retreiver.php" hash="2c957b00ad7ce5a6b95edd019edb6d66"/><file name="Setup.php" hash="5554288996af6894c7775b145ffc5bf6"/></dir><file name="Retreiver.php" hash="1df136bf73b17d8359282db267f82c4f"/></dir><dir name="etc"><file name="config.xml" hash="c656807d07ca63f6559c2c16433a30e4"/></dir><dir name="sql"><dir name="catalogindex_setup"><file name="install-1.6.0.0.php" hash="97c3e10d65e4659926d6b421c1176ffc"/><file name="mysql4-install-0.7.0.php" hash="abc5d0a60e6aab9d45381283f81135fa"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2fe9002754d7040b3d81232775aeaaf3"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="3eea917118c05a18058a1cd8a4ba4bf1"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b6d8864d8dfd8c7ee3a02b8aa302e871"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="44255be8ed6d405d4fb46437834fd5bd"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="84481ab5908352b47ee67f8e567fdd51"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="31cb140799cbfdea28fd5664dbd20ebb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="4d6dacf7add59599453c62b2030f8a19"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="941ce43d345e02a8e2063372f668aee4"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="af882140c001d15fd714561a4edeba4a"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="ca365f245bb6431d707cb6b4191875ce"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="713fb9108b9cc1a693beb46c4bc0f70d"/></dir></dir></dir><dir name="CatalogInventory"><dir name="Block"><dir name="Adminhtml"><dir name="Form"><dir name="Field"><file name="Customergroup.php" hash="2e9c0b96002b64f4f7162bd226d8f272"/><file name="Minsaleqty.php" hash="f8e25f0b5e7963d56340bfedfe36568a"/></dir></dir></dir><file name="Qtyincrements.php" hash="2e8244667132250bac8df2261776922d"/><dir name="Stockqty"><file name="Abstract.php" hash="8e2e0ade0a0da53c6b35222dc09c071a"/><file name="Composite.php" hash="abf260fa1ed8bc927c5d8c3cc96ddc6c"/><file name="Default.php" hash="a9faf85cce3e6e55e3f6e4c6238cd500"/><dir name="Type"><file name="Configurable.php" hash="9e70eb26e469c140f8284f1e5ba40567"/><file name="Grouped.php" hash="e417d1c1e33593a0716fa13c08532b47"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="e0445a47c24084f278d63fd06637cd64"/><file name="Minsaleqty.php" hash="1d5f6decd8444784b18259933d81bb70"/></dir><dir name="Model"><dir name="Api2"><dir name="Stock"><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7a23ef28d5a0af8bfc560a0676b2a085"/></dir></dir><file name="Rest.php" hash="ba30f908399b6f74e8b0a7002d7a58ee"/><dir name="Validator"><file name="Item.php" hash="b4c1717c1e68a85e311b5824785578b2"/></dir></dir><file name="Item.php" hash="aa104a6ad7fcd8bbb5525d2b06da44b9"/></dir></dir><dir name="Indexer"><file name="Stock.php" hash="335ec51bc643daed577dfb2ba8bf6b46"/></dir><dir name="Mysql4"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="4473b479ce9ba081ed544e1b8f0b7309"/><file name="Default.php" hash="9ca91a40962bd6c477c078a630e13ab9"/><file name="Grouped.php" hash="8b101ec046557860d6f105ae41e1522e"/><file name="Interface.php" hash="326e696ddeacaf4276cbaab8a4182dec"/></dir><file name="Stock.php" hash="71d81a2696bacfc9c0dd6424ab85ab16"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="a38578f9783e2a4ac28c4e805abe2636"/></dir><file name="Item.php" hash="2cfd2de320892d92e7c8a292b56d78bb"/><file name="Status.php" hash="e08210b68acf2bffd5f42f13fc3e5664"/></dir><file name="Stock.php" hash="182adcece403f3ef3bd7dce42eac8d87"/></dir><file name="Observer.php" hash="020a068947260bb45ec1d78060aa5fef"/><dir name="Resource"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="ccea699212cff2126272bb083c5d263d"/><file name="Default.php" hash="8149b5c0bf67e786f7578dbb9deab3e6"/><file name="Grouped.php" hash="536e6f1a82a87fc585c12ef19dea0cf8"/><file name="Interface.php" hash="8618058d3e32ebd241f70cc2d2e2b724"/></dir><file name="Stock.php" hash="61375ad597c7aba54135ec211b1a82f0"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="869c034146c234b9903de6a77daad195"/></dir><file name="Item.php" hash="cd33d89bd9b106404390c13e45e59e1c"/><file name="Status.php" hash="3779311bafda42361e4914457843fe0d"/></dir><file name="Stock.php" hash="6b27005eed460abb8024062ab5689627"/></dir><dir name="Source"><file name="Backorders.php" hash="52bfd816b598f674af9246a386e853d0"/><file name="Stock.php" hash="8f989c3a9c2bfad7024c2972660b6230"/></dir><dir name="Stock"><dir name="Item"><dir name="Api"><file name="V2.php" hash="11906267f8825815d908e8dc4da2d5f7"/></dir><file name="Api.php" hash="ee5f50879277fbfb25fef1cd765fbec4"/></dir><file name="Item.php" hash="b1cd47179773a36d88e1cbbddcf35f08"/><file name="Status.php" hash="7bbd47e4e0f67216aa713490ba8f1325"/></dir><file name="Stock.php" hash="d855ca5b36d285f8a17ea50a6505b3ef"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Minqty.php" hash="4014d544cb255499a02e567d4996903d"/><file name="Minsaleqty.php" hash="fdece014d82645ec760f206ff7df57d7"/><file name="Qtyincrements.php" hash="285280b282792966c9a0f6ff1021a4a0"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1df150f6a6a441a5e7cbda8e585700f6"/><file name="api.xml" hash="e7091001f41aad0123d9b497de699ad9"/><file name="api2.xml" hash="cb0a1352c87cfc41d300433cdc751543"/><file name="config.xml" hash="bb99649315278ff3c9ab14c42e4da6b3"/><file name="system.xml" hash="e82c936b49b723bfaf7708955302f31e"/><file name="wsdl.xml" hash="cfad5924eb32b8fb7ccf79309e5966df"/><file name="wsi.xml" hash="ec7bdd8cb2bc5dd12c0a4d865fe3d313"/></dir><dir name="sql"><dir name="cataloginventory_setup"><file name="install-1.6.0.0.php" hash="c58fbf677912982192f8ba6f92da98a8"/><file name="mysql4-install-0.7.0.php" hash="c14adc7fd17314f606dd025e5a3596ab"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8bc1263072589be9aad31acec946d7d2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9ccd6c185ac8c4711b0dd2f23b41ee27"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a9b3620418d2989d776b7331c57f2662"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="b4ce29815129ac4a20e3c90c2e79c21a"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b6d74e91f068732e6d22ab91676c1f4a"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="643fe882b5ab42a56116119e424d0c63"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="e7b0e938da066210c9ebf4245ab58490"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="aa4b8366d8fa8eea648a025e99a8ad7a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="80990b2e6d3614b02bfbd1d937d34d5a"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="9658089831fd4d840ce4db56aed83b23"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="89d03a9fa5a570b3313142496c6aa615"/></dir></dir></dir><dir name="CatalogRule"><dir name="Helper"><file name="Data.php" hash="02fd668b6fac397272a825c3541da418"/></dir><dir name="Model"><dir name="Action"><dir name="Index"><dir name="Refresh"><file name="Row.php" hash="93b092e341b065a9bb317e12444c5bb2"/></dir><file name="Refresh.php" hash="0e568cce6cda87c03d340c870d0b1785"/></dir></dir><file name="Flag.php" hash="06cd7f3695868ca1179c714c21cf5940"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="386d62b6e7b73f4b6b9c3b02cf74d88c"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="129382f3131c13a18283adbfeb62c2a8"/></dir><file name="Price.php" hash="429bbac7f001786a730fcb4952cd08ed"/></dir></dir><file name="Rule.php" hash="f5d715c0ef2b3131f17f0b3b58b57c9b"/></dir><file name="Observer.php" hash="a4f5c653cf6ea08d438ed6cb7ab01815"/><dir name="Resource"><dir name="Rule"><file name="Collection.php" hash="e68a7c7f5f2c30135292dfec6a9ba1c7"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="24b6c52ec0ae8e4a77aa026afeba33eb"/></dir><file name="Price.php" hash="dbb69f5dc27ba7ac2906dfeef83058bc"/></dir></dir><file name="Rule.php" hash="333901cbed42699ed619591aefa54d3a"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="9f1535a506b3572ef624fb1fb6728420"/><file name="Product.php" hash="5ec3f6ce240e4a566df9c8f986952482"/></dir><dir name="Condition"><file name="Combine.php" hash="e5ee0060b291073742ccd8117e063dfa"/><file name="Product.php" hash="ad29e318311505376d6107505ce3ddf1"/></dir><dir name="Product"><file name="Price.php" hash="2c10f93fffed8412ee293593ee921f51"/></dir></dir><file name="Rule.php" hash="bb269632d99431ba30af6495afcf0a83"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c6b223bf5a5652ab22611116c8c657e2"/><file name="config.xml" hash="9d73f646bfdbb6cc8c5bd138193d7f5a"/></dir><dir name="sql"><dir name="catalogrule_setup"><file name="install-1.6.0.0.php" hash="f332d718d7bd99d71d0f082665693ecc"/><file name="mysql4-install-0.7.0.php" hash="76d2ed479091e930a6d38ee4352bd7f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="52b4d6b4f74ad67eb2bd2f55dd01d687"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="881908a6f1cb2168d75faec9c12386a4"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="7b46efbd5570db930a2c48c48d6e1d42"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="66928483f1f7b1998478515ccc51c5e8"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="de0d78cebca0488b813b3a2cd87446ff"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="e0a6bffa1b75781d635af98ab71d55ff"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b9dd39d53f3640cc1a3353db14b55184"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="c1a0379e645058c2ce17e82d085bd8dd"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2d8f52da58d3aa7c880c973253d79910"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="31c2d3d59471a95b3e76c7565badd1c8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="2a4f997d4154ba7eea0bd70341361870"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="b960a4dd01fa9fd52b6cc7a69182cf84"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="aa53e808b061f65ee9e96ab5dd4669d1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c12a6c50ab346177340f211130e35c5e"/></dir></dir></dir><dir name="CatalogSearch"><dir name="Block"><dir name="Advanced"><file name="Form.php" hash="e09857306805f17d7eab766db1a311b3"/><file name="Result.php" hash="3b276615955ba0b3f0e7aac91000be10"/></dir><file name="Autocomplete.php" hash="47bb6c0ee66fe844396761c32b7e0fd2"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="d61b49dfd69ac4911df3164b28c253c9"/></dir></dir><file name="Layer.php" hash="c184ba0c66101349863cf4ece22fecaa"/><file name="Result.php" hash="744bd500ea0a539689dfdc90a010928c"/><file name="Term.php" hash="dcaed98a36ce41a8aa772aaa2fe579a7"/></dir><dir name="Helper"><file name="Data.php" hash="21e8df110a7815488a32d826288a1779"/></dir><dir name="Model"><file name="Advanced.php" hash="68f1e6b7ae6d58b7c7dfffe451c12468"/><dir name="Fulltext"><file name="Observer.php" hash="55bb856408b532a5a2fcbe5d72ec7e5b"/></dir><file name="Fulltext.php" hash="7f979ca22146216bc5e79f54146c6307"/><dir name="Indexer"><file name="Fulltext.php" hash="37a36fa4fc2c5644590984c97b292c48"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="51fdc45bc9d7b73240e5912c96318e53"/></dir></dir><file name="Layer.php" hash="dc75dfbfb1d4500419fe2e920a9a197d"/><dir name="Mysql4"><dir name="Advanced"><file name="Collection.php" hash="93472c5b0519e8a32716607f44e2e931"/></dir><file name="Advanced.php" hash="91b392b7e91171e513edaaa7bf9daaa6"/><dir name="Fulltext"><file name="Collection.php" hash="64a3d6b2222856b359fc590e0f9123f7"/><file name="Engine.php" hash="02c44612ab356054281fdc57c8bf4f43"/></dir><file name="Fulltext.php" hash="5306ad7e0a51b62b4a196d12567a85fb"/><dir name="Indexer"><file name="Fulltext.php" hash="17ca5374bbfdc866c2042539413fd1a1"/></dir><dir name="Query"><file name="Collection.php" hash="2d199f6a7a59dd72431361882e2e3bdb"/></dir><file name="Query.php" hash="c50ba30123a9097da433d6477734aefa"/><dir name="Search"><file name="Collection.php" hash="3082b50e38e1316290f02d44cb7bea09"/></dir></dir><file name="Query.php" hash="3c554833d0d6d9ff28249413ec69c95a"/><dir name="Resource"><dir name="Advanced"><file name="Collection.php" hash="367e28f0b01e481639f9080af2103273"/></dir><file name="Advanced.php" hash="499d0194d4398b6112fe4728b4574d08"/><dir name="Fulltext"><file name="Collection.php" hash="c1aa738ba2762c740bafd30b91541811"/><file name="Engine.php" hash="f4ff7fb0fef054d0b9e07fc8d6a7a4f1"/></dir><file name="Fulltext.php" hash="49e4c0eaeec47644808638c06acfc79e"/><dir name="Helper"><file name="Mysql4.php" hash="d842b9fb5472821c9ab907e59d91aebf"/></dir><dir name="Indexer"><file name="Fulltext.php" hash="4904abfa5a1b521ac3cf6dba2e634de6"/></dir><dir name="Query"><file name="Collection.php" hash="423c3688bdd152ee2a3fd3b4edecfaa8"/></dir><file name="Query.php" hash="72c2d37cddee2a7324d11aefd52f14be"/><dir name="Search"><file name="Collection.php" hash="66208450247763e5966249f23686703d"/></dir></dir><file name="Session.php" hash="3745505f98b1a5048a6b7a9d8b6c4f6d"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Sitemap.php" hash="fa4e835f1e0cf01dbf1ac83f55b37b7f"/></dir></dir></dir></dir><dir name="controllers"><file name="AdvancedController.php" hash="23d18bbefe8d5adfdc9b9b55e733b273"/><file name="AjaxController.php" hash="2fdba8218e3c8a6459be9811df8ddc9a"/><file name="ResultController.php" hash="f426aec253d9637a23166d8b68ea7476"/><file name="TermController.php" hash="8e7c5c0c561a20e576a9bf92609f51b3"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c4ec08c32f76b59392eb05422a7aea0a"/><file name="config.xml" hash="a8ea307b4b0a8d243a562b722d5f6cc8"/><file name="system.xml" hash="11d073698075bd1d34bcad7b97ece881"/></dir><dir name="sql"><dir name="catalogsearch_setup"><file name="install-1.6.0.0.php" hash="5167ffecb4d0816729fa55ecfb031f6e"/><file name="mysql4-install-0.7.0.php" hash="60a67b21cf81c144a73b675c38b448dd"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f60f5ca4dfe09e5cb4542661ca100f58"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="933ff654bec558c06154bf4a94361e50"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ef06fdabc135f31e09f5d9d352afdb4b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b3d2a1b9f232e07ec18eef4eb73663ce"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="86d5358977b644d0cfcbffe3a2af2b5f"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="a69f6e028a210cacd6c25cb9da90f40a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="9558e9c0922c08180ca20bdc32bbb002"/><file name="upgrade-1.6.0.0-1.8.2.0.php" hash="8f960ea56b711026613027837ca2fe44"/></dir></dir></dir><dir name="Checkout"><dir name="Block"><file name="Agreements.php" hash="6c419b6e50cadacc1e3683175f78a52e"/><dir name="Cart"><file name="Abstract.php" hash="79ea3265df399c9d5aa26205b25029a8"/><file name="Coupon.php" hash="5ff10b062d60e48654a97a764cf9eebe"/><file name="Crosssell.php" hash="72f9367a7ca7afebcef1717958b3e2f8"/><dir name="Item"><file name="Configure.php" hash="122317fd9233a58f8431f5aa8fe6c6b3"/><dir name="Renderer"><file name="Configurable.php" hash="0499106074c07c07911e02bdabc28562"/><file name="Grouped.php" hash="7dc9b801b73e502eed94f688e56aa8f6"/></dir><file name="Renderer.php" hash="b115b174d92e3b9c89712be5fb1ddd25"/></dir><file name="Minicart.php" hash="baa802262a3d62eb9f5e9b9a6b575666"/><file name="Shipping.php" hash="98375067aecfbbd314a49b01703f35fc"/><file name="Sidebar.php" hash="eae9e0946e0ed91cb983d2cf3d8ff413"/><file name="Totals.php" hash="278079d9f15c7fb26a96d4eafbc2457d"/></dir><file name="Cart.php" hash="8927a89d17a7c5450a297f2fcd2f4d63"/><file name="Links.php" hash="5af955b92e6909a8037d3b2bfe3299d0"/><dir name="Multishipping"><file name="Abstract.php" hash="13eed75a648bc53d3f9cab30fa886d1a"/><dir name="Address"><file name="Select.php" hash="c1d42e9a074f1aae15e7cc8d2438958c"/></dir><file name="Addresses.php" hash="01bd295d52c0efd3d25c85eb70224b64"/><dir name="Billing"><file name="Items.php" hash="439e1c39eb8f0ff590855619ee0b487c"/></dir><file name="Billing.php" hash="cd0ce4f01da14b9db765b0e1a8b73939"/><file name="Link.php" hash="fd48a3860b89af8fa1fff0b6e8ee635d"/><file name="Overview.php" hash="c466ea1a4704fd3eb239d29bc18426c6"/><dir name="Payment"><file name="Info.php" hash="f3c621bf82891c1526e033658861985c"/></dir><file name="Shipping.php" hash="ed6224c3de5545061118a46eb26f323d"/><file name="State.php" hash="2d44a4589b51b51717d7388c1f089060"/><file name="Success.php" hash="fbfacb807fdcafd4303c876e95cf44c5"/></dir><dir name="Onepage"><file name="Abstract.php" hash="6636e2a60c4333b67476c1ab73470e42"/><file name="Billing.php" hash="6895de8b90b2ebfa0fd45c36b9d62a60"/><file name="Failure.php" hash="fd9d92089ff78b9c1bdd9c550b1b0beb"/><file name="Link.php" hash="244a96a744397a83e0adc48755462ec5"/><file name="Login.php" hash="acfdf55652b1b6216f948f9264107721"/><dir name="Payment"><file name="Info.php" hash="4c949f134995bfc85af1aaa1408d30af"/><file name="Methods.php" hash="e7e382062e415ee142eb874f3d7982de"/></dir><file name="Payment.php" hash="33174e1083b18f0ffd8b01193e346479"/><file name="Progress.php" hash="e3fd23946ed8dea075237cedad3504b9"/><dir name="Review"><file name="Info.php" hash="cbe8a8c5c7dda76be20018f22ddea285"/></dir><file name="Review.php" hash="01938f8f5d45925b4b6deafc95ef81ea"/><dir name="Shipping"><dir name="Method"><file name="Additional.php" hash="2e827ccaa46ad3f571dbe055da2d9d4a"/><file name="Available.php" hash="3b091336ac70c22a1f5c4254468e838f"/></dir><file name="Method.php" hash="fc1c37cd94b51f12a05ea5b34a505cd1"/></dir><file name="Shipping.php" hash="8bce6afd8592e02fa26e7838653fd2e5"/><file name="Success.php" hash="15215ffcbb27b211983f6729f16808e9"/></dir><file name="Onepage.php" hash="9c055da8dac9e6768e11410a5af1b111"/><file name="Success.php" hash="934b486b48e29808a83ce46548085f9f"/><dir name="Total"><file name="Default.php" hash="ac18f91a451a3b0e5f3534b8d331d801"/><file name="Nominal.php" hash="c680791504238741fbfda82bd3e529ae"/><file name="Tax.php" hash="c167aba9ce6886e0e039b299f02e266d"/></dir></dir><dir name="Controller"><file name="Action.php" hash="0b6b8223ff9fa50cce71a981b81a1e69"/></dir><file name="Exception.php" hash="8843b4d4cb6c2300c7eb41f25c36fbf4"/><dir name="Helper"><file name="Cart.php" hash="88c7a664f4b6235169238a1449a7cb37"/><file name="Data.php" hash="6dff22121e836f64f4495df89178514e"/><file name="Url.php" hash="aa56ee90a07fbe7011a7c0108ea8757f"/></dir><dir name="Model"><file name="Agreement.php" hash="3f041873a16711d3187093f99c0157de"/><dir name="Api"><dir name="Resource"><file name="Customer.php" hash="01695dd8fbf9dcb04e58452b7cb8dc4e"/><file name="Product.php" hash="60c82ea66b3307ada9629cfeb3085a70"/></dir><file name="Resource.php" hash="e9318ac0ccea53931bf3e1820440ad82"/></dir><dir name="Cart"><dir name="Api"><file name="V2.php" hash="8ed31090d4343e10f32096dfa8be5921"/></dir><file name="Api.php" hash="10c6022b2e4d543eeb176280d2fe9adf"/><dir name="Coupon"><dir name="Api"><file name="V2.php" hash="37e5b83cc1885403394b925d2f1811a8"/></dir><file name="Api.php" hash="248dab0865f6f11b33675ecf4d49aca0"/></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="437058c8e011f4451cd24092a687e1e3"/></dir><file name="Api.php" hash="4ab20a22e0e0cae84a8bbf7504230e3d"/></dir><file name="Interface.php" hash="90a82b74a7125491fbcf209f7253ee33"/><dir name="Payment"><dir name="Api"><file name="V2.php" hash="dfdd088a3c9cd8e0eadffe3478169bba"/></dir><file name="Api.php" hash="e061f0a8eafb776dfc9278c4e1bf194b"/></dir><dir name="Product"><dir name="Api"><file name="V2.php" hash="69b1b20f8507a6e1d49e60a6d6624552"/></dir><file name="Api.php" hash="4cd63af3cf6aebc8ab92a9870e256fa0"/></dir><dir name="Shipping"><dir name="Api"><file name="V2.php" hash="9745eccad000d73a39bdc942b078db6f"/></dir><file name="Api.php" hash="3beb01b7eb467504151f4930e3786f1a"/></dir></dir><file name="Cart.php" hash="39d64fd85416c389b8898fce0aa122fa"/><dir name="Config"><dir name="Source"><dir name="Cart"><file name="Summary.php" hash="a7de12a6e7bada6ee07ca7b420dfcc93"/></dir></dir></dir><dir name="Mysql4"><dir name="Agreement"><file name="Collection.php" hash="630bc38c5b7dd4282a8e5fc40b8dd82b"/></dir><file name="Agreement.php" hash="8b84786b700b9a3b1571ed60d200c1fc"/><file name="Cart.php" hash="a9c3c664819226cc6b991396dfe9da61"/><file name="Setup.php" hash="853da7adb3c0f2601cea42422b3c8615"/></dir><file name="Observer.php" hash="23f1b13f2ff512aa176127da47bc59ca"/><dir name="Resource"><dir name="Agreement"><file name="Collection.php" hash="d382c3cb681caf3595e8f1e74333afcc"/></dir><file name="Agreement.php" hash="76b6db40df8585da3f36316d560f52e9"/><file name="Cart.php" hash="b9bcb03fa78ac8e853c4e7a2f25bc8dc"/><file name="Setup.php" hash="d52f8c44ff0a18ce90186d998b5a1299"/></dir><file name="Session.php" hash="61d6212fcc8df3b07ebb3a7b561fe447"/><dir name="Type"><file name="Abstract.php" hash="876431c28c3e06020a1b0fc87e5280fa"/><dir name="Multishipping"><file name="State.php" hash="f22eb108e021c5654d6c956441c67836"/></dir><file name="Multishipping.php" hash="d7df9388663a58ed18d14eab796b5a77"/><file name="Onepage.php" hash="7623296ec5eca56b6b5ce5eedf96a9a2"/></dir></dir><dir name="controllers"><file name="CartController.php" hash="d8d9bba5baadb115ad53523d945b4306"/><file name="IndexController.php" hash="c27bcd873c8bd5608ab90ae78d200f96"/><dir name="Multishipping"><file name="AddressController.php" hash="c961a9cd3de294783ed7d41726430465"/></dir><file name="MultishippingController.php" hash="291fe953a99e782bd123ce1b3e88fa0e"/><file name="OnepageController.php" hash="256594edeec31e54e583883b075e8e1e"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3bd25edd429a1761399ce2f33926dbe0"/><file name="api.xml" hash="56f66248a45024499270e622af0b101d"/><file name="config.xml" hash="9d6e4eb2e746a7341535136d3891b01a"/><file name="jstranslator.xml" hash="c70d5f292b4e369d7c378346dbc05416"/><file name="system.xml" hash="f6f67fbccdc6a8223f22d0f2d94a1d91"/><file name="wsdl.xml" hash="9a10e25803e84713f5031a168dd0c624"/><file name="wsi.xml" hash="2567bee4ef18e1b426c700ce66c3bcb1"/></dir><dir name="sql"><dir name="checkout_setup"><file name="install-1.6.0.0.php" hash="bacfdd2c8ccb82057efca72250758a93"/><file name="mysql4-install-0.9.1.php" hash="7f40a79587cd339e871165bb4e8b38bc"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="0fae593af23654670a9a60e1ec93d7df"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="4f9a3d70f56c78478f5d1cc73b3ac918"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="96777089267f69ce0ece1f0b85b79a84"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="ad23b08fb3a6253b679846d7e2d9a877"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="4689dea6d535aca2681d91050aaf700c"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="feadb7e5160ff33b7d4b595c5594039f"/></dir></dir></dir><dir name="Cms"><dir name="Block"><file name="Block.php" hash="08baae8f852b0eb7ceb7f00703f90349"/><file name="Page.php" hash="d3893bc1dc3df63c65c3d8e3eee596d7"/><dir name="Widget"><file name="Block.php" hash="2d29800146e6e32e75a00ea9d8663bc8"/><dir name="Page"><file name="Link.php" hash="c8d6ab51cd313b3b2bbade08f8981727"/></dir></dir></dir><dir name="Controller"><file name="Router.php" hash="6a8e1f13e9da08ef8fd7364712a5dc8c"/></dir><dir name="Helper"><file name="Data.php" hash="63cb5d78811cde0406c55ac2706bef67"/><file name="Page.php" hash="e514993ac654fb8ac5bdd16f5476dab4"/><dir name="Wysiwyg"><file name="Images.php" hash="d38e6d1abbc0c30c7b9d556508aa68cc"/></dir></dir><dir name="Model"><dir name="Adminhtml"><dir name="Template"><file name="Filter.php" hash="23efebd6cd5e478ae573167f90f7e45d"/></dir></dir><file name="Block.php" hash="2510ee77473f2dfe1b70dffdb6c71ea5"/><dir name="Mysql4"><dir name="Block"><file name="Collection.php" hash="56f951c0fccd6f8f4217e48a0dc34e1e"/></dir><file name="Block.php" hash="c8e3e5c7817f2d9580092197b222e795"/><dir name="Page"><file name="Collection.php" hash="f8455b1b345414ae2233229e6e89ba21"/><file name="Service.php" hash="52cda9bdbc67bed0ad890ebc4253e044"/></dir><file name="Page.php" hash="57bbae6d1da3f3fbcae2e974dd24870e"/></dir><file name="Observer.php" hash="7c0841e97b147871d78ae5d4eacbf365"/><file name="Page.php" hash="cd5813f33a28df24d2a871176ef6a872"/><dir name="Resource"><dir name="Block"><file name="Collection.php" hash="6ceb057a593d25ff06064a6649039b32"/></dir><file name="Block.php" hash="40f9938bd66ad36f46899c78ef6a8b95"/><dir name="Page"><file name="Collection.php" hash="ef32535a56be83dfadbbd6d31b438353"/><file name="Service.php" hash="7cf9b5d216081a22cedfd6e203c5ec6e"/></dir><file name="Page.php" hash="3991ad97fd44ec669410b11d392eece0"/></dir><dir name="Template"><file name="Filter.php" hash="5d27b599aca8a35f85ec6d19f338bbe6"/></dir><dir name="Wysiwyg"><file name="Config.php" hash="464b3d700f42a84ef0c609f07f84e8e4"/><dir name="Images"><dir name="Storage"><file name="Collection.php" hash="b6e877870e17351df738be1dff5cd856"/></dir><file name="Storage.php" hash="0c179d8ef5099f7bbd66ae62175efccb"/></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="f872d2a6efeee3d405e5cc633481a6d3"/><file name="PageController.php" hash="0e0257f9133bbf7773508f0c5eba6e93"/></dir><dir name="data"><dir name="cms_setup"><file name="data-install-1.6.0.0.php" hash="a2524a24696ccc0c0051abc687b3b63d"/><file name="data-upgrade-1.6.0.0.0-1.6.0.0.1.php" hash="aa16ad74a468113741303f3a9b992efb"/><file name="data-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="364a7d774dc5f46ff84716a32374ae94"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5fdb8a794aa9c661491b77ba99c62eb5"/><file name="config.xml" hash="9fa2613be0401a9f07dba4f8021ba8e0"/><file name="system.xml" hash="568f4eb1982d6c4dd32b25dfd3083ed8"/><file name="widget.xml" hash="fb79ba2126ba0c725eb1813dff174fb7"/></dir><dir name="sql"><dir name="cms_setup"><file name="install-1.6.0.0.php" hash="11ceea6c6c0d695d822096571fab4b9f"/><file name="mysql4-install-0.7.0.php" hash="5ebbb4e38de419a58f3d1a06d6381f93"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="76beaae155c65796e580e922fc10cdb2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="5c7e65d4b2faac184097691e77e46b57"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="9df2ea203d9aeea43a6d450a1b403780"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="6aed180669f3c7751b58b6c6aac430b1"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="9e55629d9f9b47d682a17058997246e2"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="775f2b5b185dea356844293e9f732e97"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d6fcd1a5949c041035954a1604828f50"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="408cb50d7a9878fb017069d30a65170b"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="e91389aa6444e2d56be0925897709f6c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="14a5a61c8214ce5dd7d47f8cf3744edb"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="929a4d0435d84c06fd662ae80bf09b52"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="eb09203a1d3c74197beb5d52cf1eb794"/></dir></dir></dir><dir name="ConfigurableSwatches"><dir name="Block"><dir name="Catalog"><dir name="Layer"><dir name="State"><file name="Swatch.php" hash="6887e2af0be94e3cd1a7ae5ed7cf136a"/></dir></dir><dir name="Media"><dir name="Js"><file name="Abstract.php" hash="0efe6efa7f3b10f969d394786ec07ae0"/><file name="List.php" hash="610da3f155d02eefcb92a0a5148b62f8"/><file name="Product.php" hash="a21153887e119a79084a16ba05685ba0"/></dir></dir><dir name="Product"><dir name="List"><file name="Price.php" hash="9f444e14b4d91046919ba561aea953a7"/></dir><dir name="View"><dir name="Type"><dir name="Configurable"><file name="Swatches.php" hash="f2f57c18a3a8e3e28fe113ef4a040440"/></dir></dir></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="6e2e74df24270f8d2439248af8e1f6f2"/><dir name="List"><file name="Price.php" hash="07f06e13d39df55fb6ea4b4061b51530"/></dir><file name="Mediafallback.php" hash="49a9b43961336e4a559824d03ec80f2c"/><file name="Productimg.php" hash="2f54dbbd264875d55145002411a124a2"/><file name="Productlist.php" hash="b0a644f9a7696db14c44efcbaff2d325"/><file name="Swatchdimensions.php" hash="05e4dcd9530b050cd7b58496141bfef9"/></dir><dir name="Model"><file name="Observer.php" hash="8a14785bd5cd4a97238dd4eec5a70841"/><dir name="Resource"><dir name="Catalog"><dir name="Product"><dir name="Attribute"><dir name="Super"><file name="Collection.php" hash="cc8383320165c4b86b4d69dbb9dd9c80"/></dir></dir><dir name="Type"><dir name="Configurable"><dir name="Product"><file name="Collection.php" hash="a57bde9ef68e3e132bee8277ea2a1350"/></dir></dir><file name="Configurable.php" hash="9e962b8ce86d7759a98dee78ad695d21"/></dir></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><dir name="Catalog"><dir name="Product"><dir name="Configattribute"><file name="Select.php" hash="e62adfcf184e9a2122f1a19040dc21c3"/></dir><file name="Configattribute.php" hash="16aac641aaac0d4414bc6c184b39c9b4"/></dir></dir></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="89988fe030e4c09d2026f1bbf7660af9"/><file name="config.xml" hash="cfa742589e8e8ed4bd58fc3f79ead76e"/><file name="jstranslator.xml" hash="969a61359c6f119aad145803bd2a8c8b"/><file name="system.xml" hash="45153613a10f66eb03200863329f2a66"/></dir></dir><dir name="Connect"><dir name="Block"><dir name="Adminhtml"><dir name="Extension"><dir name="Custom"><dir name="Edit"><file name="Form.php" hash="76b93302a318c93964500d94b58ea4b9"/><dir name="Tab"><file name="Abstract.php" hash="17596eeb6b89b1224c4e231db7bf1d99"/><file name="Authors.php" hash="04a6a4f80bf35b812b94c2e1e968f447"/><file name="Contents.php" hash="e413c95985acb90a4b95fc9a07daa4e2"/><file name="Depends.php" hash="0d76887da37383555abed6e1864c29f5"/><file name="Grid.php" hash="e697766b63ee61b93a43cef718b4983b"/><file name="Load.php" hash="ebc124649980545035a84844a2ec26cb"/><file name="Local.php" hash="811fc83e338d7253c9b01cf0b42ddc68"/><file name="Package.php" hash="c104894bd8051f2bb116226cd13eb8d7"/><file name="Release.php" hash="72da8682ba77a0390283af960e0f6382"/></dir><file name="Tabs.php" hash="dc98a95db0627f6ea68098951ac62a0a"/></dir><file name="Edit.php" hash="065ab68977dea45f03106f9888b3163b"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="775c24dc230dd16d7c45d5aab8f8bc5f"/></dir><dir name="Model"><dir name="Extension"><file name="Collection.php" hash="7ba1af3c40d1c9178a2441087b552c9a"/></dir><file name="Extension.php" hash="4ec228deb98a7c0f73a053785b2e7baa"/><file name="Session.php" hash="83b7c65b6e95aa98be31fcf73c59c11b"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Extension"><file name="CustomController.php" hash="25b2c303170316f51ade98f9ed296771"/><file name="LocalController.php" hash="45c2e963cbf6971e79f7236f37b465e8"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="65d57a497ee09c0f55889a464e9e8ae2"/><file name="config.xml" hash="ea7d1fb7798ba51608b4b423baa769ec"/></dir></dir><dir name="Contacts"><dir name="Helper"><file name="Data.php" hash="01fd76d3de097833859238af70268c7f"/></dir><dir name="Model"><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="972d0ea115f2e748ff5ed306d2f86d93"/></dir></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="ad53ddc28af4e5f60402bde2187d14cc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="5a5412d8cd4ba0577b53483384304464"/><file name="config.xml" hash="d73ab097d6502eccb1d5b2d177a75ca6"/><file name="system.xml" hash="e675da38d1a140774e10e5eefcfce547"/></dir><dir name="sql"><dir name="contacts_setup"><file name="install-1.6.0.0.php" hash="89d25bebd151554fe3bbe3aa7c0dc919"/><file name="mysql4-install-0.7.1.php" hash="da95f978021d0b072b68dcd96b48e56e"/><file name="mysql4-install-0.8.0.php" hash="5cd7480fc89bd86f98ccaee703046616"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f65d6c63a1f7d8304809352e6b283c10"/></dir></dir></dir><dir name="Core"><dir name="Block"><file name="Abstract.php" hash="181c69bec880b301cf2a8f420bb29351"/><file name="Flush.php" hash="fd9dfb94528913c62cc7a4d7e5a1a517"/><dir name="Html"><file name="Calendar.php" hash="b101ca0e43d1dbc4e6880337bf01f083"/><file name="Date.php" hash="55f39c51369070b92407c353b450dd83"/><file name="Link.php" hash="52008b8eee4025fa3ce89afff820dab4"/><file name="Select.php" hash="94d45ec931414b391f8627fa79105a68"/></dir><file name="Messages.php" hash="b99feba6519e2e9a7f1392b19a852f05"/><file name="Profiler.php" hash="be9cad609a54f5a54858238aae217a92"/><dir name="Store"><file name="Switcher.php" hash="19f7c757077689e92c5072a24f843bee"/></dir><dir name="Template"><file name="Facade.php" hash="3b0217c0329aa8ce65805d794f97f0db"/><file name="Smarty.php" hash="3952590ec21561a967bc7ae4093e41a4"/><file name="Zend.php" hash="df09e4fa347b60978eea94bbf85070c4"/></dir><file name="Template.php" hash="6000e614c2e4f2dfa51c56feba11737a"/><dir name="Text"><dir name="List"><file name="Item.php" hash="1217b54e7a673f5362b93b801e8e47ec"/><file name="Link.php" hash="d2c7b7093cd7e73d1477ac9586ad630c"/></dir><file name="List.php" hash="4fd2bc96e9c37feb598eac4c4588eb8a"/><dir name="Tag"><dir name="Css"><file name="Admin.php" hash="f489191668ee974a3cd58249114c23a8"/></dir><file name="Css.php" hash="2df8967b6fb12467d2089156838d5744"/><file name="Debug.php" hash="45464fa97f1073305a54091c888c6595"/><file name="Js.php" hash="c2c209a6fe743d0a1e23c064b0da7f74"/><file name="Meta.php" hash="4be5ce7d98b752f78ce557e4615e09a4"/></dir><file name="Tag.php" hash="91fb5ed6bc5c86d81a164222dbe252a3"/></dir><file name="Text.php" hash="107c848b8a1445b448b0fb700b1f9a48"/></dir><dir name="Controller"><dir name="Front"><file name="Action.php" hash="68f128fb1eeac96a88ccadc9e6266031"/><file name="Router.php" hash="c2a39b4e6b0522a85e1e3c933379da10"/></dir><dir name="Request"><file name="Http.php" hash="9630c120fa5e6c9bb40dd834510e7394"/></dir><dir name="Response"><file name="Http.php" hash="611b9c20b0db52fafe10d982d1190729"/></dir><dir name="Varien"><file name="Action.php" hash="60099b82349b2d1a4f6b9c3e5b45164d"/><file name="Exception.php" hash="d61c714f6177c3113637e37492ae861f"/><file name="Front.php" hash="93246cc98978f42489f3b54085d3b6cd"/><dir name="Router"><file name="Abstract.php" hash="4e55cf4f93c0bf9511b39b5a58bfc125"/><file name="Admin.php" hash="77c9d603cd241af6979d42bf18aa569d"/><file name="Default.php" hash="3efe36835a5671227ede3b2995b3ee27"/><file name="Standard.php" hash="abf493b56ab8ecb0cdd377e282481e5d"/></dir></dir></dir><file name="Exception.php" hash="31ca7f9b564737aa0d9e44c40f8ae884"/><dir name="Helper"><file name="Abstract.php" hash="2fced038e5f6797b6b9c0871fa305fe8"/><file name="Array.php" hash="9f4a32af761a5183a2382967143bdb73"/><file name="Cookie.php" hash="1a7137d6315a204839964ca6ad14444d"/><file name="Data.php" hash="85874417ce74d48637b037793fbe8dde"/><dir name="File"><dir name="Storage"><file name="Database.php" hash="ed127be92b1accf150d16fccd36ef1c4"/></dir><file name="Storage.php" hash="03de906d7c74b5fbda3fba390e3d4466"/></dir><file name="Hint.php" hash="0a54b2a389f46b52e0e2ced66baa6583"/><file name="Http.php" hash="989506e44c5de4c5c38a5383989d59cd"/><file name="Js.php" hash="2a387f8aeeac68c505f7843151987dce"/><file name="String.php" hash="07ac63bfbea05a210fcf632d999adeaa"/><file name="Translate.php" hash="c96c535de4a30db514a0a611af6ef9d8"/><file name="UnserializeArray.php" hash="b14f0cf9a2676961650828bfbd52992c"/><dir name="Url"><file name="Rewrite.php" hash="1bef9c0835550ea3839306a23412b1ad"/></dir><file name="Url.php" hash="d0c40c0c2d5604d182c854c9adc32f4b"/></dir><dir name="Model"><file name="Abstract.php" hash="d1d1d3a5d98f1d740c11c28a504c42fd"/><dir name="App"><file name="Area.php" hash="ebc16a577260811a2a6a18af0076d974"/><file name="Emulation.php" hash="02c3d17d61e3cb4226b8529ca509328e"/></dir><file name="App.php" hash="e097bb0f10878f0fa813689889d28484"/><file name="Cache.php" hash="6b4502cb8f596f2c04b7e96416fd5ff5"/><file name="Calculator.php" hash="f7565ced7f75b5c0f38ca290ef4f6190"/><dir name="Config"><file name="Base.php" hash="3fd453d91eda0ee62b6d7d93780701e6"/><file name="Data.php" hash="a47121f002b901587af61db6672be643"/><file name="Element.php" hash="c9c49041d51f363957c63936c090b6da"/><file name="Options.php" hash="e582e00cf08bfe118d794fa86e592b88"/><file name="System.php" hash="c61e23bbeb5ceda5a6025e38bad1bbcf"/></dir><file name="Config.php" hash="5e214b2eb530121c0c984667ce7ee2f4"/><file name="Convert.php" hash="34cd7dc75bb4f0346c9bab88fb7f7d86"/><file name="Cookie.php" hash="29b5db1b3a93728e4686346ba0b0f93c"/><file name="Date.php" hash="dede2548cb32308a2a0a8a16b2bae1da"/><dir name="Design"><file name="Config.php" hash="df530eedf1f6feff7be7b637cb6813c2"/><file name="Fallback.php" hash="80bc720dcec5afcaf344c56058d2e7f3"/><file name="Package.php" hash="8175c48a6ac75c7ac1c18d5a177c4d27"/><dir name="Source"><file name="Apply.php" hash="47ba9fc0c45be610f95155e1ad6ef008"/><file name="Design.php" hash="9fc458c26da1d90754ed12477c99359a"/></dir></dir><file name="Design.php" hash="462b080e4d548675a0f765337c5da43b"/><file name="Domainpolicy.php" hash="6608467e7879164bf85e027b2a03bca6"/><dir name="Email"><file name="Info.php" hash="3a164cb67d10f6d04038f245fb55bccf"/><file name="Queue.php" hash="42e7e6abdfecf376752734d6e49d8111"/><dir name="Template"><file name="Abstract.php" hash="e358142e556d0cced3cc84b2a8f5f2f8"/><file name="Filter.php" hash="87fb084bc0c68d126da3ba5fa270779b"/><file name="Mailer.php" hash="6681e7b42df3281bfa7a8ee42b69c947"/></dir><file name="Template.php" hash="66676699de617c412441c3c28b9d8728"/><file name="Transport.php" hash="e4c9a71e9438e593ac59b8853d7501be"/></dir><file name="Email.php" hash="d807c53107619aac70f6be138daa693f"/><file name="Encryption.php" hash="cc2f535836d47868164b7b19a555fef3"/><file name="Factory.php" hash="a8329d328de0e5855513523407f7c146"/><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="7f70c39ebae0b69dd85f296375ba97d3"/><dir name="Database"><file name="Abstract.php" hash="8e02a5de6c912c8e7df8a4d56e6e3103"/></dir><file name="Database.php" hash="2e18119f9ce7fee1fb4cce71694d907c"/><dir name="Directory"><file name="Database.php" hash="12f974b3a4d9d5c2719e295358b6a381"/></dir><file name="File.php" hash="64f5cf70b7b2aac04ad2010e7726b2c0"/><file name="Flag.php" hash="fe629937cabf35ce797aa77a14534ec1"/></dir><file name="Storage.php" hash="1ee69792044faf29817a8555ab67fb40"/><file name="Uploader.php" hash="3d154fcb91174e16eeb04a229c6b6639"/><dir name="Validator"><file name="AvailablePath.php" hash="433fd6a4a8c419f7f86515298267554b"/><file name="Image.php" hash="b7fbcf231010f66273d3c907812f3050"/><file name="NotProtectedExtension.php" hash="14fae5d50b74784c586b54f2a91237e1"/><file name="StreamWrapper.php" hash="2966e45d4b779b006ff65afdc3d29fcb"/></dir></dir><file name="Flag.php" hash="5e9df0d7f21ec7ce6ad19a53f7273803"/><dir name="Input"><dir name="Filter"><file name="MaliciousCode.php" hash="9b87d312b7ad9882a418d58125280965"/></dir><file name="Filter.php" hash="527a8a30797a1451733d65666133510e"/></dir><file name="Language.php" hash="abe5b5349861e6eaba496c3418bf16ca"/><dir name="Layout"><file name="Data.php" hash="e353c25b8d41255b2b8f9333275d8a13"/><file name="Element.php" hash="9a1e14e44df962409655e23b8060c98f"/><file name="Update.php" hash="f5a5bd60a84b2215dbb53b32d0c6c70b"/></dir><file name="Layout.php" hash="f1a76bd7d8336aeb1e76075e0442b935"/><dir name="Locale"><file name="Config.php" hash="e297164e06185ca680c803e0226d66c1"/></dir><file name="Locale.php" hash="8cf95e8203a74b64f23ad5c3e98f45d9"/><dir name="Log"><file name="Adapter.php" hash="98ef08e1a2a2723107837369f2165f76"/></dir><file name="Logger.php" hash="763bd3ccd88755a381947852e2350f2e"/><dir name="Magento"><dir name="Api"><file name="V2.php" hash="8f482feb38b1cafca515884de54a950a"/></dir><file name="Api.php" hash="e4be9316b6bfc9f4b8e68aa5b9ef12dd"/></dir><dir name="Message"><file name="Abstract.php" hash="fce642f36593d58b30f9ee3be80c513a"/><file name="Collection.php" hash="88b98cebed98b1f99353152dd7f865ef"/><file name="Error.php" hash="655977a157fa50eb6b07b22f42c345bb"/><file name="Notice.php" hash="052f54af4d7689e6d22c07967138120b"/><file name="Success.php" hash="bffa6f6ebbe3d2de083d65a92884c671"/><file name="Warning.php" hash="32187b6734b82698bda722bfa4115db0"/></dir><file name="Message.php" hash="a95aa9f4a4b22d55849fb2402bcd3aae"/><dir name="Mysql4"><file name="Abstract.php" hash="3708704fae412a0d0247baf0224d1161"/><file name="Cache.php" hash="92c14ffee30326af3bc50a210ebded97"/><dir name="Collection"><file name="Abstract.php" hash="a7e6de8d9f759290881c80edac3b8b72"/></dir><dir name="Config"><dir name="Data"><file name="Collection.php" hash="f7dbe731a1f625a31603757c7300c8d2"/></dir><file name="Data.php" hash="130ed53184c7668ebf31e608294e091f"/></dir><file name="Config.php" hash="a3bf729bf497a384cbaeed34e6bac4b7"/><dir name="Design"><file name="Collection.php" hash="f7f10b12ebbfa86c1862b810ce6d93b6"/><dir name="Package"><file name="Collection.php" hash="b532dbace0f1a4275d73187bb183a4ec"/></dir><dir name="Theme"><file name="Collection.php" hash="c4ff4e160777903e9209130bd154167f"/></dir></dir><file name="Design.php" hash="3490465970f3eb4a00f5ce6278d6f6a1"/><dir name="Email"><dir name="Template"><file name="Collection.php" hash="05749d1d7446e51f63aa1faf663facdc"/></dir><file name="Template.php" hash="1ac03cd7ac86fbb73ae894de71c36fae"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="2a989b8aa3a1e2e880462ea9989a6f0f"/><file name="Database.php" hash="0645555755d39ca151ac4032506cf2e8"/><dir name="Directory"><file name="Database.php" hash="2210f93caf12401dc5f47d7ce46e1fd3"/></dir><file name="File.php" hash="772017c5419250a352d2841d09f8373c"/></dir></dir><file name="Flag.php" hash="94715a36f09bce0bed6ebe085285edb9"/><dir name="Language"><file name="Collection.php" hash="7f83183231ae71e38ec69209e583c127"/></dir><file name="Language.php" hash="db9c590813fe4c7da288b204269b3c88"/><file name="Layout.php" hash="9e3cb41d4c53be096099c997911175ea"/><file name="Resource.php" hash="843d7527e3908b9759bb16365e5e0bf3"/><file name="Session.php" hash="1a890927d43bdbae50314318d3117ffa"/><dir name="Store"><file name="Collection.php" hash="d425d0315f5a1977c5b6d6070f3d1a92"/><dir name="Group"><file name="Collection.php" hash="9113b6a4c8f90dd47b4886f7ca622586"/></dir><file name="Group.php" hash="8db5d7091ef1df0e95cb7674ce95a88f"/></dir><file name="Store.php" hash="d3ae0021d42acfd6a46af7059a67e65a"/><dir name="Translate"><file name="String.php" hash="61f98800fdea35f632ffe0d28c081f8d"/></dir><file name="Translate.php" hash="ecbe50a6490ae1c6381411fa149d4fd3"/><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="2aefce4731631e9465d0d23a19c779a3"/></dir><file name="Rewrite.php" hash="f349ed01f4fcdcd48dbd74bb13272315"/></dir><dir name="Variable"><file name="Collection.php" hash="199eca9e1659bfbcaa6c9460755f6b82"/></dir><file name="Variable.php" hash="d9262e41a163dd0c55fed55d3c6d7f8f"/><dir name="Website"><file name="Collection.php" hash="2a587a71bd36b68a77a4c8f02e2c2fcc"/></dir><file name="Website.php" hash="88ad625c889346e4cfe7c59e41233934"/></dir><file name="Observer.php" hash="094871e0c109142b4f68de0b281e5011"/><dir name="Resource"><file name="Abstract.php" hash="1caae9c8430ec6ce0c13606335894edc"/><file name="Cache.php" hash="48a7128434d90edd49485e90768c828e"/><dir name="Config"><dir name="Data"><file name="Collection.php" hash="cb889be83198c5b528e24316371d1883"/></dir><file name="Data.php" hash="639c91e3346b8a93cc361a942ccd5d14"/></dir><file name="Config.php" hash="bac269b45f33fce05eff8adcb63fb7ef"/><dir name="Db"><file name="Abstract.php" hash="192eb8200dc8a6a6c784cc5c57355457"/><dir name="Collection"><file name="Abstract.php" hash="bdcadbc916bfd95ef1a445803829aa35"/></dir></dir><dir name="Design"><file name="Collection.php" hash="d010ab011ac9e2d1ae73d9ea15dffdf2"/><dir name="Package"><file name="Collection.php" hash="b46bd0681a1468c4413aa917d10063ac"/></dir></dir><file name="Design.php" hash="f078ea6fed695c8f9f07468389001106"/><dir name="Email"><dir name="Queue"><file name="Collection.php" hash="8ae181824d19be3dd8d0e72279bf0d69"/></dir><file name="Queue.php" hash="a6a50894a43ce7189f14e1e7b4840ead"/><dir name="Template"><file name="Collection.php" hash="ca9653326c602a71e0a93c076e5e35b8"/></dir><file name="Template.php" hash="6ed0dee792b3bdfbe6531166d42b91b4"/></dir><dir name="Entity"><file name="Abstract.php" hash="c9e0bb6aa889ca36e2eaae296396a02e"/><file name="Table.php" hash="c06c09b2a03bcbbfd186c9aa98a634de"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="4d12a1ee3a12b35a1fd908588d207bd2"/><file name="Database.php" hash="770ed506ed0a2d82f4897b4a287ae694"/><dir name="Directory"><file name="Database.php" hash="7703449b22f643da8dd43712955fa6b3"/></dir><file name="File.php" hash="40d79daa54798cb4f810cf7e2a524728"/></dir></dir><file name="Flag.php" hash="82bc20374f8864d49b7293c1dc70a4f5"/><dir name="Helper"><file name="Abstract.php" hash="78e15036317fe2f704427e748e488696"/><file name="Mysql4.php" hash="555297623b7312cb4a5ee74014dcb33e"/></dir><file name="Iterator.php" hash="ec070c942fc8f7a67f4e26e5fcd08d66"/><dir name="Language"><file name="Collection.php" hash="50cf8598e78404829ad72d63c8388c66"/></dir><file name="Language.php" hash="7e23e3443583f40c7e3415d92a35730d"/><file name="Layout.php" hash="e8f6aeb0ba21e41d5067b4cb856dde9d"/><file name="Resource.php" hash="3eb9eedef05d21d0cc6c4e97142d1d9d"/><file name="Session.php" hash="88318f7f71df8fd9d82fd8b24ab7abed"/><dir name="Setup"><dir name="Query"><file name="Modifier.php" hash="813bd2670a0d73708b09ea92bbb9be86"/></dir></dir><file name="Setup.php" hash="4139a2d32143a8550f87ff50435e75a3"/><dir name="Store"><file name="Collection.php" hash="3320d22e0d1333d614ad290e0525d53e"/><dir name="Group"><file name="Collection.php" hash="1ac2b4c1de5e1903c26f4e3785e4e937"/></dir><file name="Group.php" hash="42e813bcbaf698881e1bf5a27c59f39e"/></dir><file name="Store.php" hash="fa3bf05b568294e02a6fe4c1c27cb9f8"/><file name="Transaction.php" hash="08fa1309658be97145d36d6f246d3775"/><dir name="Translate"><file name="String.php" hash="a2cb79ab5c6bc58a1d9f06b173c9b60c"/></dir><file name="Translate.php" hash="9a1a8fed6527f816b1b5eace64212c81"/><dir name="Type"><file name="Abstract.php" hash="5223eadca84d77cb2596c2776cb6d65b"/><dir name="Db"><dir name="Mysqli"><file name="Setup.php" hash="3fea549d4e4f8b68f0e576f6a12d17ce"/></dir><file name="Mysqli.php" hash="96292453517efdd07547eb8407d5f1dc"/><dir name="Pdo"><file name="Mysql.php" hash="c0ac5cf999e1d553f90c37e00e36e3de"/></dir></dir><file name="Db.php" hash="25034f3d1ae6ad136e39fae5d01ce0a4"/></dir><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="f8da7eb03c8fb8f83283e6314cd3c1c8"/></dir><file name="Rewrite.php" hash="fe8475fd925996ae8ab39258c85a53de"/></dir><dir name="Variable"><file name="Collection.php" hash="401b5e614ae732c5678a04a2b98879c9"/></dir><file name="Variable.php" hash="f84b3387796b375a8bf33c136d381dde"/><dir name="Website"><file name="Collection.php" hash="4ced4ca90dea76629bbc53f216421181"/></dir><file name="Website.php" hash="3521e6bba1c4688bc47d53f794cbebdb"/></dir><file name="Resource.php" hash="e7e6cf7f40b1a7c38a30e4cc0744b249"/><dir name="Session"><dir name="Abstract"><file name="Varien.php" hash="569c98dddeae79ca1cf6af5ae6de8a39"/><file name="Zend.php" hash="cfe635669d5b999b71fc6a2c0430158c"/></dir><file name="Abstract.php" hash="979ddef17c114d7f3f9b4ab43764381a"/><file name="Exception.php" hash="985b0f518cdeaa693ed2487bf0f6bc71"/></dir><file name="Session.php" hash="5290571c529b366f4932afdecc6aee34"/><dir name="Source"><dir name="Email"><file name="Variables.php" hash="9acd0ca901919230f0b04c6d37da62ee"/></dir></dir><dir name="Store"><dir name="Api"><file name="V2.php" hash="44da778a107458327526e71820b7b1ff"/></dir><file name="Api.php" hash="7fd2194a6736267ddf6990d01277433f"/><file name="Exception.php" hash="563bbd8d7ac0a433a77a456763c4c3e0"/><file name="Group.php" hash="1902252843de7b5774a4e81326e2fdad"/><file name="Observer.php" hash="63819493bcf83ad8e8ca370ca7f6aced"/></dir><file name="Store.php" hash="34c99c0b6717f26712d299e1a869a752"/><file name="Template.php" hash="fccd27ce17f7aa0afbcd52403221b342"/><dir name="Translate"><file name="Expr.php" hash="e9d7462a5fb8e7a393d5f54797d49235"/><file name="Inline.php" hash="e93b3c785268564f9c4c8407b20a3a10"/><file name="String.php" hash="0adb95a97362072d6e8ea38583887b59"/></dir><file name="Translate.php" hash="bc3e61e7886c80e4a27657083b7d73b3"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="2e681780b29fb80c8240c56c87f3d067"/><file name="Request.php" hash="5df0865b6561e78521ed01ac6b7d57c6"/></dir><file name="Rewrite.php" hash="a3390b9c5c1475415d8c5a274eba51ac"/><file name="Validator.php" hash="e3f18c399f4cc29dc71ec4b6bf79490f"/></dir><file name="Url.php" hash="12dfc1a9d4e7ed0958fd543a10d0295a"/><dir name="Variable"><file name="Config.php" hash="294323396e9d0cadc983c976033b2735"/><file name="Observer.php" hash="f202b59b429f4f2d02cb650f130e4258"/></dir><file name="Variable.php" hash="0e14c7251900724becb45597711ca75b"/><file name="Website.php" hash="4a6f6a97f9522c03590bb28e140f9885"/></dir><dir name="controllers"><file name="AjaxController.php" hash="a08f8290380cf11cf83500ca24bae20c"/><file name="IndexController.php" hash="f9ef6110cbc8a9666098fbef0e8e754b"/></dir><dir name="etc"><file name="api.xml" hash="86293f2f531b7a6ddf9bacc685c4fc5e"/><file name="config.xml" hash="403f77c0d3fe5be3d36acdf4a7026cdb"/><file name="jstranslator.xml" hash="b200108bfac41b69ee844c2bee267ec8"/><file name="system.xml" hash="99fadc897cd072625871d0a04231eada"/><file name="wsdl.xml" hash="79501d6ccf39846b5dd551e85880dcb8"/><file name="wsi.xml" hash="31fa195d527181c946019bcd44d819d6"/></dir><file name="functions.php" hash="361ce88daa9b8bb82caf26e5ba179245"/><dir name="sql"><dir name="core_setup"><file name="install-1.6.0.0.php" hash="99c037a0a1ac60718cd61bb66f2ce9b9"/><file name="mysql4-data-upgrade-1.6.0.2-1.6.0.3.php" hash="ab507b796172a81e53f7dea055f5747f"/><file name="mysql4-install-0.7.0.php" hash="5c744d9ec05924ba2a05443fc797c614"/><file name="mysql4-install-0.8.0.php" hash="d7eb01be2a8ae5c212a48e000cd0f2b3"/><file name="mysql4-upgrade-0.6.26-0.7.0.php" hash="4f20726fa1cf4822a6a8915dd427af4b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="a21956c396c1b967ede3ad976cfdf448"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="64a85f90819585aaaf7c5cbdf5ac9cf5"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="476423c81b0e11428d206f5a736bce3d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="337139e7657a6d1e7ef9fccddc23553d"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="57780327ffe3eba191534854bad676de"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b0f5f9f49140980d21565993f622ae81"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d4614e187cc7a85654ced0176b5688f3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="fe2ea548791820ac5c1801695b0f75ef"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="f42d281fce5121d5f411e6611c71e38c"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="0cfe8f124a171dd82663efad6127e14c"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="299207679a44c8d5ea8ac5754f8de98b"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="6fcd0f93e0d91905c073605aba88940b"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="4dbb9443f34a75b9f421b7b818446043"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="0de67179defca183bfb0b1c611a39887"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="a98d5c510f9e19ee903e957bf7eb3202"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="48eb471e3d57c8bd4c8e7f4c38d49d57"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="0d8dbd126c7140043695ceb63037324e"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="600c23395322527f7a0b9bf6955d72c1"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="f6830aa69a99fb2bf5c3e92f4cffcdf9"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="0fe329675e0340210bfe2a6fb4066377"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="1742e2c0c393bdb449636e2fbb35dcd2"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="ba27150f507d3def66478fb1be8a6f80"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="d43d803598bc07a5cc3622d7c4046efc"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="8050654374a57af43bd12d16fd5c8146"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="9fe12edd3f5a54bce363fb5c7c3a23a8"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="cb8112cd37d71d62e673e816623d1a9a"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="a57334d7c2206e31b7db077748949d43"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="69372713f802f2aa756d6c4e3b25706e"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="e82b56e0531638a1ccce30bc12cf6aa5"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="e8497ce884a5a14dacb68d6988e6db61"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="a825fb80da1068e176efc6559f8e3183"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="37d085e478c96b39c697b3b40506ae87"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="5cfd483b04eaccba4a2d509432c190bb"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="c9e92c9d8305a03222ab7562ea8ce2f9"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="38c349fc77a280f0d3ffedad22cc6d47"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="0ba1f78f11cf2d2cd2739cdd580def92"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7893e14572c2a1c90ef2a32b983b76bc"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="3688343c162f029654b67cfbc2387024"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="7cf54034cb33d05f707cd9db126a300b"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="de7f2c22f6094821ddcde05aee42933d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="015a4339c6e0d045fc73ed7864246a45"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="af573097ec2ebe58f82d4f4333bbc91a"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="d1a38f6c8e9d71dd44842a77cfdc378f"/></dir></dir></dir><dir name="Cron"><file name="Exception.php" hash="cf1dfad3794259101456ab530c5db5a4"/><dir name="Helper"><file name="Data.php" hash="27e5fd603d4ca44ff134f01c2204cd38"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Schedule"><file name="Collection.php" hash="82f4b5c141920cae628956674651e686"/></dir><file name="Schedule.php" hash="68a1f1d41f2881f5710794b74bc5fa4f"/></dir><file name="Observer.php" hash="ba0660d83c9189ba3f86b79d58a37b73"/><dir name="Resource"><dir name="Schedule"><file name="Collection.php" hash="1c4d160bf611d9e5d2ae329e718a5016"/></dir><file name="Schedule.php" hash="70b7a234326eb5f4a437d9c83c941a35"/></dir><file name="Schedule.php" hash="5af32d2624ad82e95d7ba0aaaeb69404"/></dir><dir name="etc"><file name="config.xml" hash="7f3d40612a48d9d5ff88aaa180db864d"/><file name="system.xml" hash="cf72373326f9de8c29898d577dec01ba"/></dir><dir name="sql"><dir name="cron_setup"><file name="install-1.6.0.0.php" hash="e880af79df0e64a24f25b9b6ca5a0a06"/><file name="mysql4-install-0.7.0.php" hash="f2fef9a649061718fced001da2d17ff6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="237886cabfccaf58b4baf26dc7d8173d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="6dd37c019fd015568fb404635e8fa3de"/></dir></dir></dir><dir name="CurrencySymbol"><dir name="Block"><dir name="Adminhtml"><dir name="System"><file name="Currencysymbol.php" hash="180872bd15491de4d7243f518637cc27"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="2268459f3c43056d7fd35adb8dfb2497"/></dir><dir name="Model"><file name="Observer.php" hash="844f97fd2d98a7a93c235421c7286567"/><dir name="System"><file name="Currencysymbol.php" hash="341a9557df26d4e1afd4f7eb4910214a"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="System"><file name="CurrencysymbolController.php" hash="0e2e34ce111da77949ddb67b21fb433a"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="e3b17991058dae47d0e9ff06418c3c01"/><file name="config.xml" hash="ea98c18686306119b6b936c5bb0d4b99"/></dir></dir><dir name="Customer"><dir name="Block"><dir name="Account"><file name="Changeforgotten.php" hash="8b663124bc516f05a5b6319db495e29e"/><dir name="Dashboard"><file name="Address.php" hash="aac0afce3651c4d72c76e28c43892ee7"/><file name="Block.php" hash="c956121184fb8d2f1ca3214293a86832"/><file name="Hello.php" hash="7fb0384b0f53cfe0eab7477130c036a6"/><file name="Info.php" hash="777950ea83313c7ccb2df5a632d95d79"/><file name="Newsletter.php" hash="fec02bad0bdb8016810da2f75d7af4e8"/><file name="Sidebar.php" hash="612e6c9109efddfcf09efab2bf19ad87"/></dir><file name="Dashboard.php" hash="669ca917a411643f2df70dedf77c7a03"/><file name="Forgotpassword.php" hash="4d4bb6faed3d7be132c6de8ba097d79c"/><file name="Navigation.php" hash="7814958a2f1504e592f60b94286fca91"/><file name="Resetpassword.php" hash="09f6699b3e8a5cfd801d9fce6be6caa4"/></dir><file name="Account.php" hash="43490efe5663f8252b0890dd67153725"/><dir name="Address"><file name="Book.php" hash="8dd1a6365d2cee386fa50f2bd9b67f95"/><file name="Edit.php" hash="93184bd1536389b9027bdc3b85738d87"/><dir name="Renderer"><file name="Default.php" hash="ffee9ef9dcf06f89ff6fa37881a09f5e"/><file name="Interface.php" hash="c3d67cdcde0d581ec8a884ae41320b9c"/></dir></dir><dir name="Form"><file name="Edit.php" hash="9681856afa02438569c99c4a39c71efe"/><file name="Login.php" hash="2f136fe58a89cddfdcae1c8a20374eb8"/><file name="Register.php" hash="dc2c0b46dba1b9d697e86f920f4b2b03"/></dir><file name="Newsletter.php" hash="4bbfc9637bcfd47df22a24d0ac332198"/><dir name="Widget"><file name="Abstract.php" hash="82d02521c1c154986f99a7cd5cc595bb"/><file name="Dob.php" hash="08eff27d1c12a2bdea2f02bb1beb9956"/><file name="Gender.php" hash="69ba0733ec5825d9c84aa2bd36518242"/><file name="Name.php" hash="2fe99449c98c4831c81499a996955bdc"/><file name="Taxvat.php" hash="f6a34e678cce8e9db4337a171e1eb5c1"/></dir></dir><file name="Exception.php" hash="84ed4a7311c3b067f5a9a2b4ebaf2701"/><dir name="Helper"><file name="Address.php" hash="b7d0e116bd13ee4040e4a3e7d7e10f54"/><file name="Data.php" hash="8b5c4cbf10617330771fb0179c3328a6"/></dir><dir name="Model"><dir name="Address"><file name="Abstract.php" hash="fa80923d3d564b19d139c8217d52c4db"/><dir name="Api"><file name="V2.php" hash="5264e405138723779708a01e0ad3a953"/></dir><file name="Api.php" hash="c625c51f21aebed93b312016d255a325"/><file name="Config.php" hash="81e4c387f3c84c6bbd6eeb85c6bb6415"/></dir><file name="Address.php" hash="4e2bdc078893483df4368f90ad9069ce"/><dir name="Api"><file name="Resource.php" hash="88a0a4742fcb4b506e0fe0bad02fbf42"/></dir><dir name="Api2"><dir name="Customer"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="6f3addc32e6948ff8b1427d8a5edfc6c"/></dir><dir name="Customer"><file name="V1.php" hash="ee1fa714d1b0d4c0089cdc8b78536901"/></dir></dir><file name="Rest.php" hash="dd7c4ad62e07cc33093b1825c91dc32f"/><file name="Validator.php" hash="68549f28fa41a68a9212ddb19c1e11cd"/></dir><file name="Address.php" hash="7763734d86e3092e92066cdecde510a3"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="df8b83b4419c9d7b00176578de386f3b"/></dir><dir name="Customer"><file name="V1.php" hash="15773c1ca13ed447f1734e30151d0aa7"/></dir></dir><file name="Rest.php" hash="13687d1d31f233b15bdd487a13e1c766"/></dir><file name="Customer.php" hash="075e0124ec757065f5343d92b66c74db"/></dir><dir name="Attribute"><dir name="Backend"><dir name="Data"><file name="Boolean.php" hash="432dd89c3a7c292b09f374d233ee88e8"/></dir></dir><dir name="Data"><file name="Abstract.php" hash="ce5306f1e0a22d3dcd993e5220fbb7ac"/><file name="Boolean.php" hash="f757034441c95c0c30917147e3899d7a"/><file name="Date.php" hash="c977b4c1e25a829d9dd2b56afb7e1ead"/><file name="File.php" hash="cff1562f1f09a1f77f446c15e9441405"/><file name="Hidden.php" hash="3d2815af68515718683db2cb2e2973ba"/><file name="Image.php" hash="65edcc06c39664fb4d244bd484543083"/><file name="Multiline.php" hash="6b16093b04c6724d52d294d8a7fda5a2"/><file name="Multiselect.php" hash="219e0b4179d1ff3fec774a53f8f9af34"/><file name="Postcode.php" hash="ba6c2c9e682d8720d7cfe3ec50177a42"/><file name="Select.php" hash="5e80c9f0c60d9173634b5fa0f287e328"/><file name="Text.php" hash="19c74a8d13af4e7a4862c4b89f954e27"/><file name="Textarea.php" hash="d4b77360bae2a6a748cf27367ea83d24"/></dir><file name="Data.php" hash="b02ad271accfaee388a7ad3bb222f09f"/></dir><file name="Attribute.php" hash="83f08943bca6efc1081de3af6d51d73d"/><dir name="Config"><file name="Share.php" hash="611a68be66eb8da9af205150c54e9fea"/></dir><dir name="Convert"><dir name="Adapter"><file name="Customer.php" hash="e803d6cb098208d70b601fc5593cde91"/></dir><dir name="Parser"><file name="Customer.php" hash="9d4b84d66f8d8b81ed939118a33be002"/></dir></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="b9bef0e5e64fa1bd9e390c99f3942281"/></dir><file name="Api.php" hash="167a33181ce2964937d5e7e73b9894d8"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="89c52c1b2f0bd8484df39ea7acb46b7b"/><file name="Password.php" hash="d3986a064f7d4cfefe4ff68332698665"/><file name="Shipping.php" hash="06ab66f794689e099ee95692283c12ce"/><file name="Store.php" hash="b0ef14e8531d2257a2b9de8fd180898d"/><file name="Website.php" hash="901f05d219245cb98170965bf8b014d7"/></dir><dir name="Source"><file name="Group.php" hash="0553e3010d7141c267a8749dcf4c1b39"/><file name="Store.php" hash="aec62dac295af5b5dd732c6ac1959764"/><file name="Website.php" hash="808118f1f0e66be0957876dbe8e9e57c"/></dir></dir></dir><file name="Customer.php" hash="9abb92d3d08028b277fda5db64f6bbbc"/><dir name="Entity"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="3662b45a02a564d622f1b570ab7aa2e9"/><file name="Street.php" hash="3d8358dbf971673582d68d977b2772af"/></dir><file name="Collection.php" hash="9b4b6effc2a69a7997605e3bd1bd9870"/><dir name="Source"><file name="Country.php" hash="681cded02921d688127cd30abab8efe3"/><file name="Region.php" hash="d6f544d7b9377c54b3e4f7546a3b2b38"/></dir></dir><file name="Collection.php" hash="bd986a57656ef8a1a39d9c66b927e451"/></dir><file name="Address.php" hash="8617ad0449bf5fa8eb64c37a08f6834a"/><dir name="Attribute"><file name="Collection.php" hash="b0d588d2382b7790638831b94ed26bfc"/></dir><file name="Attribute.php" hash="70d04a5d91848027fc7524f8abdc23de"/><dir name="Customer"><file name="Collection.php" hash="aa16d5336085baa3ba3eb2c1d312b7df"/></dir><file name="Customer.php" hash="f5d7eb3738e07eb83a334b2d4a4301c0"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="a7d64fa72682061c7e53586e866c7d9c"/></dir><file name="Attribute.php" hash="b02dec4db5d7fdc34d380f46793e47c6"/></dir><dir name="Group"><file name="Collection.php" hash="09b632cea0cf63a7340d570d7fc870a3"/></dir><file name="Group.php" hash="5546c3f3f4e4e576c99704a159181eb5"/><file name="Setup.php" hash="26ee35b14c5bc8cbd73cce9162aba1f4"/><dir name="Wishlist"><file name="Collection.php" hash="72b17e5c6b622a67428b49159d192676"/></dir></dir><file name="Flowpassword.php" hash="b37572d121efa8f7f5a6145220099c16"/><file name="Form.php" hash="5d6109e111b3246bdfa4fbae2eee62a3"/><dir name="Group"><dir name="Api"><file name="V2.php" hash="e41ba19167609e178625c837ffadcc0d"/></dir><file name="Api.php" hash="910ce41663a3aa1eb1bc5dec47f75c36"/></dir><file name="Group.php" hash="3434803d8e2a377e825534383e8827c7"/><file name="Observer.php" hash="8f3ad14644722c03bd6bfadd85f1a936"/><dir name="Resource"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="2480c7ff5479486acdc71d5c4041e5fb"/><file name="Street.php" hash="5df083ea021e34bfabaf561726310e56"/></dir><file name="Collection.php" hash="3407e94f14ea73174dee4ee51b1759fe"/><dir name="Source"><file name="Country.php" hash="8c31116b4df92372cb202bf015dcf110"/><file name="Region.php" hash="c8816ccc18de38c74aac9a0ee0fc736f"/></dir></dir><file name="Collection.php" hash="382ffc3ece33f6d97cbab480e876e4ad"/></dir><file name="Address.php" hash="47ea3ba9064ab22f183e7fa309ebac6b"/><dir name="Attribute"><file name="Collection.php" hash="dc11746c5e719d05443ab6abfc158f62"/></dir><file name="Attribute.php" hash="a6e8657bccc9b73bac42927538cd4cb7"/><dir name="Customer"><file name="Collection.php" hash="88d5a0089a3fa9f9d6f10ff7aa45e18a"/></dir><file name="Customer.php" hash="cc0f7b29dc56a062795a42cc0085e5e4"/><dir name="Flowpassword"><file name="Collection.php" hash="ef19c2c10862f6e5362184291436e5af"/></dir><file name="Flowpassword.php" hash="968e8244a0c27d8c67a2569f655ecb0d"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="9315c60166317f2ef4c5a8105d5741c5"/></dir><file name="Attribute.php" hash="160eef2ee2908ef291e4ebe34f1f15cc"/></dir><dir name="Group"><file name="Collection.php" hash="9db3838edca76b5984f6b8ee7a32c66c"/></dir><file name="Group.php" hash="d7eae76b439b0dfa8c07557f3cba28d9"/><file name="Setup.php" hash="a271ee2dfeea1fdd49d24faacfc6cbe4"/><dir name="Wishlist"><file name="Collection.php" hash="63dfa1eef06f3064f6f8321ddf4a8654"/></dir></dir><file name="Session.php" hash="19447307e588272469dff208c75ad4ab"/></dir><dir name="controllers"><file name="AccountController.php" hash="efc462f991abe87c53cbcb265def3a42"/><file name="AddressController.php" hash="f9b92db500258202d88fe74b567e43cc"/><file name="ReviewController.php" hash="b4220956b1abdb7d143ce458d1b72fe5"/></dir><dir name="data"><dir name="customer_setup"><file name="data-upgrade-1.6.2.0.2-1.6.2.0.3.php" hash="af7950ce248f9a9017052f7e1de00ac5"/><file name="data-upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="28ead7be0a5853812b0d0c5e57968990"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="692e9ed764e5480a906b6c5819113acb"/><file name="api.xml" hash="e7cf0b9531cdef20c4898881e22d9988"/><file name="api2.xml" hash="6156af439bc63e66ca40cf2a26080640"/><file name="config.xml" hash="2b831a3d541c36c78dabf3cfaafd2aef"/><file name="system.xml" hash="0f3ff65c4195a6bcfa2720f6d15f0faf"/><file name="wsdl.xml" hash="b31ebf1de4a58469781b383f455991f5"/><file name="wsi.xml" hash="4c81aee30c525677be5c38e078b98408"/></dir><dir name="sql"><dir name="customer_setup"><file name="install-1.6.0.0.php" hash="8b5aa8cc89e2641c6853319b9546675e"/><file name="mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="4872ec3fc02eb5eb00f103700aa77041"/><file name="mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="28a7c7051a1bcd86dc8309b852ea8c29"/><file name="mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="5ffb0490d8258a783e7ac941286d048b"/><file name="mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="f8c846cdbe95a76586d1ce92064015dc"/><file name="mysql4-install-0.7.0.php" hash="cd96a8f93ad9e49f55db79733320975d"/><file name="mysql4-install-0.8.0.php" hash="aa7e8a1483150b61f53a5d7c1578d6c2"/><file name="mysql4-install-1.4.0.0.0.php" hash="6a6c0b7b9460e1fb4c536a2aa0b2f5e5"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="3e2055145079f629026415a460010553"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f2cbbb1b7ec6902b75a9955e6abb0610"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b85fc366d0e7d0e087ddaf00f0705ff3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="35525103f1307dac9df768192fd2e9d9"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="37a2056b43079d14d0128e60566f8c52"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="3285eea05014e0c9b320e70e23de2ea9"/><file name="mysql4-upgrade-0.8.12-1.4.0.0.0.php" hash="d6feb52da70cb181bdddc8f33e1a16d1"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="4c7cf47f2f0324e2fa56ea6074e7eebf"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="46cf00d3651186a07a4129c23670c581"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="80d616f36e92d58504a08574115177a9"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="64fd262a2923be67f079266d36168a69"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="b52810769b33bdd85dd2efe64e4b3e56"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="4f5c33afe8389600c49ac4830de89ddb"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="62243eccbc11be32cf0c6627404bf5c5"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="0cdad1e573d83ddfa65de2e8bb1ca548"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="7950a9f2a7dacf4e4c485f403ef1f43f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="8fbc3cf7e2c7c9f0479c7a9733174f68"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="1fbc98105825cd6e2a74ad876693abde"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="3f4745fc93d60c54d0786994fed3c4d9"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="2aba57c96240a0d360c1592e0e1aef74"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="aedd52a3f2cc4cfe9425cc4603a712ca"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="a049b659f24e9ffee7a567dc02a49e64"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="8ffd9139acb5c755e97d3d6541ad6700"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="be0bbb074cd8e0a3a32f984ec7bd0a40"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f176af847c112f0928b51cc3083729c8"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="fdd18814b345085bf323079bb855573a"/><file name="upgrade-1.6.1.0-1.6.2.0.php" hash="84a048767e0b1123ce58fa66c9323963"/><file name="upgrade-1.6.2.0-1.6.2.0.1.php" hash="dd06b50b358acf47a2dc7b8cbf14637f"/><file name="upgrade-1.6.2.0.1-1.6.2.0.2.php" hash="d2ce3d712996dbe1f3ba7c282060d44c"/><file name="upgrade-1.6.2.0.3-1.6.2.0.4.php" hash="6bb3b5b87199ed5d39609dddd5ba9bfa"/><file name="upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="26b3352e206d19a1d317014b66a966a6"/><file name="upgrade-1.6.2.0.5-1.6.2.0.6.php" hash="18abac53655791f7eb8bb296463998c7"/><file name="upgrade-1.6.2.0.6-1.6.2.0.7.php" hash="97804c97f4ab9d2ae87c39f85c16aa0f"/></dir></dir></dir><dir name="Dataflow"><dir name="Helper"><file name="Data.php" hash="e08ebbc2fd4e1d69f37837bd6879e617"/></dir><dir name="Model"><dir name="Batch"><file name="Abstract.php" hash="7fdc20cf4337b2e8e6ec98996355851e"/><file name="Export.php" hash="44de5ec437a2e8f8962a30f6a0aa7fbf"/><file name="Import.php" hash="438a63fba93182fbb849695e7f14ec9c"/><file name="Io.php" hash="b5faecc9e049d11969ef6888e847301b"/></dir><file name="Batch.php" hash="14e83b5b30bede8dae90cfb6444bd09e"/><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="9a037b33e482074fa3d913e478597727"/><file name="Interface.php" hash="5451a3ae2d36340211f5db410cfbd618"/></dir><file name="Action.php" hash="133f901570f109f9af35ab17a7a7bf2c"/><dir name="Adapter"><file name="Abstract.php" hash="51fd62ea51d6e990429d3fdc6e870c6f"/><dir name="Db"><file name="Table.php" hash="a4f0bed5a537c6dd4f04a1875a3e5f29"/></dir><dir name="Http"><file name="Curl.php" hash="c62a57836e8e36d04621c2ec4f41adbc"/></dir><file name="Http.php" hash="6fed3d72666b24902601a4ce5b2478cb"/><file name="Interface.php" hash="d2f28a724dd13c880372397ead2416f7"/><file name="Io.php" hash="62e2beb0db33f5845d6221428d144325"/><file name="Soap.php" hash="1cb9b54a4968108f511e86da5c30b5b7"/><file name="Std.php" hash="5c9c797d238d5731484fed2669c4320f"/><dir name="Zend"><file name="Cache.php" hash="cb121f8c7129317b181b80dda9946fc9"/><file name="Db.php" hash="457dd7726d2a30ec193ed8f4e7116031"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="03d6e312e776303d9cf1dc8de1c77478"/><file name="Collection.php" hash="52edd435007eab55dd6c44b61cdd9841"/><file name="Generic.php" hash="2dcbb8dac8a4d8d68157d8c742f74b2f"/><file name="Interface.php" hash="99565c4df1b032f1276db130f99cb723"/></dir><file name="Exception.php" hash="076118f579fded6e5ee39631c8a74505"/><dir name="Iterator"><dir name="File"><file name="Csv.php" hash="e8d574afc2c3bdf922eea8387ea68b06"/></dir><file name="Http.php" hash="80d1c7d31b2641cef4d9b81dca74b07b"/><file name="Interface.php" hash="8a2e0ea004e8ec1c10163f73f96374bf"/></dir><file name="Iterator.php" hash="54bdd6114b22be7319333103fa3e8c76"/><dir name="Mapper"><file name="Abstract.php" hash="93ae0b13a5352a620825298c5ed66c05"/><file name="Column.php" hash="f392976ef13863f5f32f04a09ab6aba5"/><file name="Interface.php" hash="0437e7aacc6b135b6ae383b463616287"/></dir><dir name="Parser"><file name="Abstract.php" hash="3236fe8798302c48929726e03e141ecb"/><file name="Csv.php" hash="949f7e32e0199ea94577f670e273f1df"/><file name="Interface.php" hash="dd7760a2cf2b5e49ef67990189647ab7"/><file name="Serialize.php" hash="ae87fb54224bfddafd7efd95c87d9066"/><dir name="Xml"><file name="Excel.php" hash="cc4a18db41565711ec48b471ac7c55d6"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="0ddcfa647231d5e2a0d9fdfcb54419e6"/><file name="Collection.php" hash="406521382cf7603b8054c6ef4131fb72"/><file name="Interface.php" hash="a0a9fba52399f7946b7743d8011c3ebf"/></dir><file name="Profile.php" hash="834a4d150f1597dbdc251db0ef543e14"/><dir name="Validator"><file name="Abstract.php" hash="e765aea7e8f5193277899c5418a7578c"/><file name="Column.php" hash="1a5b7cffadecce6e2c687ad6e1606e57"/><file name="Dryrun.php" hash="edb950b748d40593f34594db0911715b"/><file name="Interface.php" hash="86f42e70518c14452d499c1d73884a1c"/></dir></dir><file name="Convert.php" hash="e125ca51eb5ea388a4226984e077bb55"/><file name="Import.php" hash="8838b197445f884cd96d210057768a6c"/><dir name="Mysql4"><dir name="Batch"><file name="Abstract.php" hash="2b6f51758706c99b5f5694c4bf59400b"/><file name="Collection.php" hash="6d31df66ebb4c838e937ced0950add33"/><file name="Export.php" hash="14e075cd437463318c4918c87d51f142"/><file name="Import.php" hash="6d7a15cc0ee4750440e27169f1458165"/></dir><file name="Batch.php" hash="8c72af2813e71735947b59224512fd7a"/><file name="Catalogold.php" hash="24ed373e2153ac1553a8f5213d1cb3db"/><dir name="Import"><file name="Collection.php" hash="931767370c3cd538c2d61137ef81c270"/></dir><file name="Import.php" hash="b1845aa3d075528f559e4278c0545c90"/><dir name="Profile"><file name="Collection.php" hash="667d27ab098a1cc0d7b63add7f846bee"/><dir name="History"><file name="Collection.php" hash="561468d39bea85e329273488cfd2e25c"/></dir><file name="History.php" hash="a671fb7398cc9013b5679924a9576121"/></dir><file name="Profile.php" hash="423f9c09e862da840aff3c1045671760"/><file name="Session.php" hash="9f2de6e0336f990f406c314f848d80d1"/></dir><dir name="Profile"><file name="History.php" hash="952111190cf3cf31c4a293ff30a42a1a"/></dir><file name="Profile.php" hash="d6f8175d00db20f1d44690a467d56a18"/><dir name="Resource"><dir name="Batch"><file name="Abstract.php" hash="adf8bd1d47bfb44429d1f22557e09c4c"/><file name="Collection.php" hash="a107007ee0f2e1d33a075b2042cac37f"/><file name="Export.php" hash="6de19c09e9b2cdfb339477eab9536cc7"/><file name="Import.php" hash="8b2ecc68b077493284aa7ea723b1f202"/></dir><file name="Batch.php" hash="31fa2a981414ba9cbb1d36d9fce80ac8"/><dir name="Import"><file name="Collection.php" hash="bc29b52fd643bba0973be87265fd32ed"/></dir><file name="Import.php" hash="cd5b7cd2631393c4606fae225ba5fdef"/><dir name="Profile"><file name="Collection.php" hash="c4d4a9004563e08fd051316dad4695ce"/><dir name="History"><file name="Collection.php" hash="2f30f6a4d76e22bffa55cc493b01cd29"/></dir><file name="History.php" hash="b7aebcdd049fb2be0481f25a058e592c"/></dir><file name="Profile.php" hash="b12abc950a618c3239ffd0b087fafb89"/><file name="Session.php" hash="24cba703ea2a3899f1ceaec111445da2"/></dir><dir name="Session"><dir name="Adapter"><file name="Http.php" hash="c3992d945b4f9e2cf948827ef4b97675"/></dir><dir name="Parser"><file name="Csv.php" hash="165232a998562cb26a5a5664c0ca06ba"/></dir></dir><file name="Session.php" hash="8bae06d98900fb274e96676edc00df20"/></dir><dir name="data"><dir name="dataflow_setup"><file name="data-install-1.6.0.0.php" hash="e8a25ff1d524d64663da553ac0bbe530"/></dir></dir><dir name="etc"><file name="config.xml" hash="d8bf8f4863632692e44a1ee692bb7874"/></dir><dir name="sql"><dir name="dataflow_setup"><file name="install-1.6.0.0.php" hash="d97858ba4c95f9baca0091f37df58654"/><file name="mysql4-install-0.7.0.php" hash="e6a1202a88b8be57424e537535bd8546"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="b031906d286d82ec0d22c3c00438a387"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9e7d95b914f360a1a342f7364886ed61"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0399490704f187860be377f3eca679d4"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="84740102452a11d71c2e94790d8c94e1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="8041c24d939a69eccc8da15b2a27b175"/></dir></dir></dir><dir name="Directory"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Currency"><file name="Base.php" hash="dcb443aff27519bec9c0fb1eadebddb4"/></dir><dir name="Region"><file name="Updater.php" hash="84e993fa8725770c162375474f6162fc"/></dir></dir></dir><file name="Currency.php" hash="a209e62973d545d82a06c3d37c3b2494"/><file name="Data.php" hash="814cd0a83516e4040436918d176e6b73"/></dir><file name="Exception.php" hash="ffe766fa980bcff2159ee53263c01805"/><dir name="Helper"><file name="Data.php" hash="339c9514b741d43f50db4f7a3a18353e"/><file name="Url.php" hash="67ccb2a02f260665556beb8946de1be7"/></dir><dir name="Model"><dir name="Country"><dir name="Api"><file name="V2.php" hash="f1f135eb3faa33d17f66ec80daa125a8"/></dir><file name="Api.php" hash="3ee2f9ed300a8728203243e70b1bce82"/><file name="Format.php" hash="f2f2ad752bcba7dc3297bf101157e8e0"/></dir><file name="Country.php" hash="e0e56529d3f42681f39f2d550c12d71b"/><dir name="Currency"><file name="Filter.php" hash="f70bbe7b70f72e3eba142ef51a2f53e6"/><dir name="Import"><file name="Abstract.php" hash="9438914132e0315803cf7411034a9f57"/><file name="Webservicex.php" hash="2c0f90fa66b24589ee74f3c67649a40f"/></dir></dir><file name="Currency.php" hash="53fbd10d7e037604c4b68b0afca9eb3a"/><dir name="Mysql4"><dir name="Country"><file name="Collection.php" hash="0d944c0a19c1a348d3ff86809697a289"/><dir name="Format"><file name="Collection.php" hash="b82c10c3e3bf81b493ffbab4dca55013"/></dir><file name="Format.php" hash="30e47385420534e5fcf5c5494ed50e4f"/></dir><file name="Country.php" hash="1fd1f772fdb465235910ff7b4db1573c"/><dir name="Currency"><file name="Collection.php" hash="53291e3cf2239398b21fb65843b9e8c4"/></dir><file name="Currency.php" hash="7e14f08f128342f007f48546924a0bd5"/><dir name="Region"><file name="Collection.php" hash="471cfe58eefc3b8051b3cfd8a53cbb6d"/></dir><file name="Region.php" hash="4b79281b66b206439339f899e008800d"/></dir><file name="Observer.php" hash="b6b3d68e879e2c2f4c9d1d28453dc7e7"/><dir name="Region"><dir name="Api"><file name="V2.php" hash="a741b57fb273d9b2e8ce4c7ea72eacef"/></dir><file name="Api.php" hash="281487c558f2a3dddb36958063951cf8"/></dir><file name="Region.php" hash="0d87c99bd12fc091889fce254c77e04c"/><dir name="Resource"><dir name="Country"><file name="Collection.php" hash="972013305c612d9c523559de14fd93d1"/><dir name="Format"><file name="Collection.php" hash="901c10028b32a68a938458b299355945"/></dir><file name="Format.php" hash="f39efabaf3ebdb0c45870b2a8b58333a"/></dir><file name="Country.php" hash="c29b853734688ee76e3745b1883336e5"/><dir name="Currency"><file name="Collection.php" hash="b7a063492f8b0521a0bb6f00ad06464b"/></dir><file name="Currency.php" hash="717ac0dfd9e752ec0c3737fe24fbe239"/><dir name="Region"><file name="Collection.php" hash="f75aac9e2cffc3d608977516f85e5de5"/></dir><file name="Region.php" hash="aa6161845be2b0c5d01d95b97aa236df"/></dir></dir><dir name="controllers"><file name="CurrencyController.php" hash="598938459dedac62bfb4195a2242fd8f"/></dir><dir name="data"><dir name="directory_setup"><file name="data-install-1.6.0.0.php" hash="66a3d2eaa39070958ca9809798102c3d"/><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="354710cadd7abd6dc5a10a2f6842b190"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="3207bee7088f4c11f6c57f2f9bb173dd"/></dir></dir><dir name="etc"><file name="api.xml" hash="78c8bdd46e7a897a74f6455ee688f419"/><file name="config.xml" hash="0ee1b74bccf3c7bba0cfad8326c6193b"/><file name="system.xml" hash="e7ced71e07c4449402bbeded8860a5db"/><file name="wsdl.xml" hash="cc488b81c0eae648a0ee360d6e2d9960"/><file name="wsi.xml" hash="66de37cc17e24c0c66f74c52e2df616e"/></dir><dir name="sql"><dir name="directory_setup"><file name="install-1.6.0.0.php" hash="97df790b958ebbedcba5764fe4dd1011"/><file name="mysql4-install-0.7.0.php" hash="a87b5313783e11a0dd0f0cf8be739ea9"/><file name="mysql4-install-0.8.0.php" hash="ecec00ae456029ca8822f18a20e42e47"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6c70b08a6df461765456c2ac2f026fcf"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0c0e79dfc15370c558cbbabc0d1f8b9b"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="49fd5e3faf9bf452bfa8b7ebe100f346"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="a19b84e51cbc261efec34caaa6f2df7b"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="e328f0f70c75b98ae002d51b4ea991d9"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="2fc37e8f57d83e61a8e2c79a66c26e4f"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="60e3b937063bfb51a4372641c1e7c2b8"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="85297cb10426b170b0d19d2bac8fdc25"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="1dc8216499faf835c7ed62970336fa04"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="39387527f2128086ef2400517a125591"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="8d899b7db31e1e8503d1e3e4ef688a15"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="bd555e1bdf284e094aa80ddac5406049"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="2ab87429050aac0a4df755873cb9b189"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="83bfdf5ef0248ece192862d9c92ddabb"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="2c8baba0cbab3ead3938c8448adf9138"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="572730242d7420bd723f775e67ec9c3e"/></dir></dir></dir><dir name="Downloadable"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Downloadable.php" hash="5544e55e911f0d9603563313d8a5ba88"/></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Downloadable"><file name="Links.php" hash="5464679fcaef509dba28069874a27e77"/><file name="Samples.php" hash="436ec7541c855576c7db3af0742e6e51"/></dir><file name="Downloadable.php" hash="717fb4bed3c4d7469ee3789cc7ffbb40"/></dir></dir></dir></dir><dir name="Sales"><dir name="Items"><dir name="Column"><dir name="Downloadable"><file name="Name.php" hash="08465b9e4605219116e890219740bc9f"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><file name="Links.php" hash="dc4eb48f451ba86bb70139315b481c05"/><file name="Samples.php" hash="6078e472cabebeb0cdc4a3a357034bf7"/><dir name="View"><file name="Type.php" hash="e68a8cf189a41520d5f0ad72dff79e9f"/></dir></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="5cc371580b1e272048c7a21340a3c708"/></dir></dir><file name="Success.php" hash="df0d8053cc9b3a78dcc97e8897d856ad"/></dir><dir name="Customer"><dir name="Products"><file name="List.php" hash="623c68e1145d21ec434ee61cbdc2a2eb"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Email"><dir name="Items"><file name="Downloadable.php" hash="e01c820dd9d434855510c3eb75e566c7"/><dir name="Order"><file name="Downloadable.php" hash="11f1993afc36f2382f9115178fc5d821"/></dir></dir></dir><dir name="Item"><dir name="Renderer"><file name="Downloadable.php" hash="d922d37364e371d75723b7a7ea2597ef"/></dir></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="cef93d38c9bf07a97c29b47db1cdbdca"/></dir></dir><file name="Data.php" hash="cce44b4432c3a168625e7e57932b18d9"/><file name="Download.php" hash="f9f893a3aae7ae404efb0c1543df2ff5"/><file name="File.php" hash="b288bd80241f90020a9fb606c572cd6a"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Downloadable.php" hash="106ce95f23424fec86b33737bc66ad6e"/></dir></dir><dir name="Link"><dir name="Api"><file name="Uploader.php" hash="6b4ff7b40832964c7beacea27513f349"/><file name="V2.php" hash="c4cc027f7ee0d8fcc4e850e55ff90652"/><file name="Validator.php" hash="64c1aa175dd35795f3d2e34efa349b29"/></dir><file name="Api.php" hash="c60626720f452220954577fec210e2a4"/><dir name="Purchased"><file name="Item.php" hash="1c448bd68d1307b8835a6033762d32a0"/></dir><file name="Purchased.php" hash="a7d59c19ef70336d8cc142bbbec8a9cb"/></dir><file name="Link.php" hash="0217b7584fef57c6954c16d6adcaa3b1"/><dir name="Mysql4"><dir name="Indexer"><file name="Price.php" hash="872bec0182625153cda0d1f1bf472c13"/></dir><dir name="Link"><file name="Collection.php" hash="77d4839d3861a3071e6d8396fdcd256d"/><dir name="Purchased"><file name="Collection.php" hash="c0d5586d288467fdaf479b7b0c911b7f"/><dir name="Item"><file name="Collection.php" hash="cf6773d1b912235af2ccdbab5dbb79c9"/></dir><file name="Item.php" hash="76cd2e07c02c2c2c964d7bddf4102aa6"/></dir><file name="Purchased.php" hash="1147feab13010c4719a84f1f767e822e"/></dir><file name="Link.php" hash="f11eaf4cd02f64961e5672751d4a166e"/><dir name="Sample"><file name="Collection.php" hash="fadf9932b2f36dd6813e7ab44b0ac474"/></dir><file name="Sample.php" hash="16e8fc69977438abcd8acdfed3dec4e8"/></dir><file name="Observer.php" hash="dbdb75ba95873d2af9f73636c140a2cb"/><dir name="Product"><file name="Price.php" hash="7ee60315804a76c4ac13a442fa75e546"/><file name="Type.php" hash="20db85d75642ce7fceb7f9354b6f139d"/></dir><dir name="Resource"><dir name="Indexer"><file name="Price.php" hash="ad05b2ed96af42e014e7e9056cd05215"/></dir><dir name="Link"><file name="Collection.php" hash="430a3e0f8cf92d1c2c2f1cf8ca3a22d8"/><dir name="Purchased"><file name="Collection.php" hash="ccdffcce054283303fa2b57f55bb2478"/><dir name="Item"><file name="Collection.php" hash="b72144d20dd7a94c491c484bca5993d2"/></dir><file name="Item.php" hash="1870b346f2c46e5501390aa6fcc6bd7e"/></dir><file name="Purchased.php" hash="e098613b94c59cd7ad0c86d305c4c6e3"/></dir><file name="Link.php" hash="c6f124b3611b837957d2a1b87e495308"/><dir name="Sample"><file name="Collection.php" hash="9e69c792b71ff1b74d4fd774e50ef8ff"/></dir><file name="Sample.php" hash="d40abfd991963a6dcf395d79a6994608"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="d66eb5e3f7cacd8f8f5be7278a700047"/><file name="Creditmemo.php" hash="2c16eefe0e064ecdb82bbcf48ccd9f0f"/><file name="Invoice.php" hash="b49d92df09b7cd688c98368227124c30"/></dir></dir></dir></dir><file name="Sample.php" hash="c0ef89aebd738dd0fb5d0953cbf54aeb"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Contentdisposition.php" hash="17876b9510afa671206c4ba1fdc85ac7"/><file name="Orderitemstatus.php" hash="10912ec89ce9a860dc65577b0ba3afc7"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Downloadable"><file name="FileController.php" hash="a0eb299dc9ef7811ca4c495b29ddddb6"/><dir name="Product"><file name="EditController.php" hash="4ae0fec76ce03173441bfe71f08a0327"/></dir></dir></dir><file name="CustomerController.php" hash="c4fbec7c76733cda3b1b5916a6f73ebf"/><file name="DownloadController.php" hash="f9e435211ad4d9552a5368649d30e881"/><file name="FileController.php" hash="870f184cd5cd1e2d7cad96b7d05e3bc2"/><dir name="Product"><file name="EditController.php" hash="30c279baf5ffe4a5902015780ad8630c"/></dir></dir><dir name="data"><dir name="downloadable_setup"><file name="data-install-1.6.0.0.php" hash="0856a374d51df586dc44049643d69c97"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="c3d749dddcef5a546dda075abce68322"/><file name="api.xml" hash="2a1e953ddd8fb42c48b0bd9199b16d5f"/><file name="config.xml" hash="f889323cbc6b12cd75f042a6da641de0"/><file name="system.xml" hash="1673c3db704574c12a117cbf51f1d235"/><file name="wsdl.xml" hash="b3935ff3bf7e2ca40ddd304b4c78577f"/><file name="wsi.xml" hash="7eef36b29c2abf88596e63b6a042626d"/></dir><dir name="sql"><dir name="downloadable_setup"><file name="install-1.6.0.0.php" hash="73025eb4881191a625ff8e4d1d4cad1f"/><file name="mysql4-install-0.1.0.php" hash="3f91840c8450bbecc18d9341d6f99e26"/><file name="mysql4-install-1.4.0.0.php" hash="7bcf4612674cdd43767c86d24fc9c91a"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="65cdda44f8abb16f5831193b0a894160"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="2e41ac0d97b013779f8aea4e9c660fee"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="d3fa7bb5ecfb83e0c1c492c895b963d4"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="108af92cb4d9c9e6bdf081789733c1d9"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="020a4ffe85262a22fda6a434a23c9d76"/><file name="mysql4-upgrade-0.1.13-0.1.14.php" hash="148e7cce3138f3880f2b3c66865f70a2"/><file name="mysql4-upgrade-0.1.14-0.1.15.php" hash="23f6349cd7cdb4851518b60c7e429056"/><file name="mysql4-upgrade-0.1.15-0.1.16.php" hash="e00c6062b8353456aa06352dcc1a5e8f"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="dc74191e6087ea0d6a00d6af0c9fc58b"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="540575730433e088edc3dc0cbbe6f943"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="4c2065c26097a369bc666e82dbaff7ae"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="bcdf26984f17320f3a1336b69f99fd94"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="9b026da94cd3b6b45ab968ef3214fd86"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="c440e7df19344e1d439538e5c55da8db"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="b13ea4ce5555f4e0665abe5742cdfe2c"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="fd75df74eca07dd8b6fc2cefe64f4257"/><file name="mysql4-upgrade-1.3.9-1.4.0.0.php" hash="1f9d156b0cbd54eb0eeb2eeae8d24150"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="07e2648baa8a10a806458e82ebbcd0d8"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="1bc757aced95279cd466f815c1285b48"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="4c9892da7cb86c07246592c6f47b8ca5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="27359d8b56d13b44bbeca5eeaa839c2c"/><file name="mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="b0b63d81f9e951a28608a5cf35691a9d"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="5a18214628e2734e899e21632229d814"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="3f5a16909ebda690210c9be08dbe1859"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="e807d4c8365f32b0a4aab3d0552cc1a6"/></dir></dir></dir><dir name="Eav"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><dir name="Edit"><file name="Js.php" hash="8002101c678b99ac6f8b59eb03d2382b"/><dir name="Main"><file name="Abstract.php" hash="a7a149707b945eca823a2ca098adb59f"/></dir><dir name="Options"><file name="Abstract.php" hash="e0b64d061e2fcd87526641c2ec6f6774"/></dir></dir><dir name="Grid"><file name="Abstract.php" hash="d5c599e249678648d293cb9ed83e2249"/></dir></dir></dir></dir><file name="Exception.php" hash="692892ea4ef5d5e1b6da23cbabe22d38"/><dir name="Helper"><file name="Data.php" hash="469b64a28f1b7ea088989d1d45803204"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><dir name="Inputtype"><file name="Validator.php" hash="47eac458550c8af64457669f0ac3d9f6"/></dir><file name="Inputtype.php" hash="b67a8dbd70de6eb89cdb1479f1387339"/></dir></dir></dir></dir><dir name="Attribute"><dir name="Data"><file name="Abstract.php" hash="18b807dbce7f4e21dfb7d226b481cf48"/><file name="Boolean.php" hash="448ffc80b75e90aec463ba51e050aa48"/><file name="Date.php" hash="7a2cc647db45fbcabc84d98c71ba1940"/><file name="Datetime.php" hash="b7e86e04808abb6740f77da62852d5c0"/><file name="File.php" hash="d4a0899d5d9b3b1daff4eb7e18b584fc"/><file name="Hidden.php" hash="5cabcb3cc942d369d485498abb15a27f"/><file name="Image.php" hash="23813e4f849dd850a42ffb317805ccb2"/><file name="Multiline.php" hash="9e2c79401a1ddf91f7635ca1e891b1d1"/><file name="Multiselect.php" hash="6d3a8e7d0bdadf02122a7c93b7bbff86"/><file name="Select.php" hash="1bb3420d77077d7f4fd1f5eb1b586695"/><file name="Text.php" hash="70ebf479764a19c96d0de26bc6b82485"/><file name="Textarea.php" hash="30f51d262e78a9fab2199555732e009f"/></dir><file name="Data.php" hash="7bdccd4e5d8ee6d29f5c7e4b99bbe561"/></dir><file name="Attribute.php" hash="7b68850f63e3de9fedfb181d44baabf7"/><file name="Config.php" hash="f57eadd2adb757beb19123576734e006"/><dir name="Convert"><dir name="Adapter"><file name="Entity.php" hash="7655752075b807bed3af49cc549faa50"/><file name="Grid.php" hash="ac7a302dc3a2b9c392a440a2db37dc34"/></dir><dir name="Parser"><file name="Abstract.php" hash="1057d89923122d529e273dffcf5f4a0f"/></dir></dir><dir name="Entity"><file name="Abstract.php" hash="8eee99942b9582fa010e040a875d7c1c"/><dir name="Attribute"><file name="Abstract.php" hash="4efa349be932010e7b6cb566de9114c2"/><dir name="Backend"><file name="Abstract.php" hash="9a640786c043cde90f01f6dbb1a35d96"/><file name="Array.php" hash="0a711643fa35be28798dc184c627e700"/><file name="Datetime.php" hash="dde5423ae42ddbf1935ba015f2e1002a"/><file name="Default.php" hash="0d67f3e45c2837cf97cab5ea4332e569"/><file name="Increment.php" hash="27e72f5a631fe9e8317b6e97173fbbad"/><file name="Interface.php" hash="70a21176e2194e7b2494f50954c4b178"/><file name="Serialized.php" hash="1d30c28c6ddb374758a9a189035c3ec2"/><file name="Store.php" hash="f1a93a8001c7b9a943fbe8bda205983f"/><dir name="Time"><file name="Created.php" hash="a7c20601a78ca7dbf51ad0a8847e972f"/><file name="Updated.php" hash="21a98e318fca4efc9d360a5e08990e57"/></dir></dir><file name="Exception.php" hash="794a727bc18b5bd60b349a2a858fef79"/><dir name="Frontend"><file name="Abstract.php" hash="2fad37d0d105191e3e764af900f793cd"/><file name="Datetime.php" hash="9c434461bc5f2b9800a072d040b29465"/><file name="Default.php" hash="991f8adc6ee272e59749753e021fcbfb"/><file name="Interface.php" hash="7f8db3081bac40a4411b219ed4c86b15"/></dir><file name="Group.php" hash="2da22de349ceb7b41b4df05e3e63bfb9"/><file name="Interface.php" hash="cf6e7cdd174f51cfc7f7e62d37aca049"/><file name="Option.php" hash="1a4439116682f14f492d0e155aa5adf5"/><file name="Set.php" hash="67c868057c968a2806890122a9d0bd84"/><dir name="Source"><file name="Abstract.php" hash="4f2f467815b3f475038d60bcbca97c6b"/><file name="Boolean.php" hash="60c477201e65a1dfd8bd6026c92e2905"/><file name="Config.php" hash="2e7a518ddb3c8e61489de5f11620c319"/><file name="Interface.php" hash="5895a4fb491b6d0190ecf2f179a34480"/><file name="Store.php" hash="c3d40f6aacc4977a98261d64f67d170e"/><file name="Table.php" hash="a13af459d41f4e38fca0494f5b0cdd36"/></dir></dir><file name="Attribute.php" hash="e41967fbcb581b0082d9f4ce4ac04f01"/><dir name="Collection"><file name="Abstract.php" hash="abe40e0d6c5f48e82410446329eab621"/></dir><file name="Collection.php" hash="dd3182d0409c9dfef8703a04d05ce6bf"/><dir name="Increment"><file name="Abstract.php" hash="88913be1b543278355276369c687cf2c"/><file name="Alphanum.php" hash="55dd05c0cd441d15e16d44e7824846cc"/><file name="Interface.php" hash="8a3cd897b1d0f8da29cf529362384570"/><file name="Numeric.php" hash="7aaac9e675d0e684fdfb0090a3f86251"/></dir><file name="Interface.php" hash="6492dcc4320e059b4dcfbbef7cd3660f"/><file name="Setup.php" hash="765e2c9b0391ced119e70b51041c6fdb"/><file name="Store.php" hash="9b190b04359b1055cc38f14ec34bf210"/><file name="Type.php" hash="48b9da0b09cea5525ae11e66eeeeecef"/></dir><file name="Entity.php" hash="a43519b11a54664e6f567d6c64cb7566"/><dir name="Form"><file name="Element.php" hash="958c9fe3092b2cb584fb6fd367f65e4d"/><file name="Fieldset.php" hash="9d541ea5e7fa884a5aef36b358f4584e"/><file name="Type.php" hash="297b10819a97e098e398dafce6bf9e2c"/></dir><file name="Form.php" hash="1f3db6caa1e69d6fa7d0270d125b7fa4"/><dir name="Mysql4"><file name="Config.php" hash="88ddce2de8762b473e5f11ee15863ea5"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="f4bad2b7c97aff236c4d59ab9d11d80b"/><dir name="Group"><file name="Collection.php" hash="e5e8ae843ffab0d11e7306ecb3f76d36"/></dir><file name="Group.php" hash="b034badccbbc0e7102f085ac7d788b40"/><dir name="Option"><file name="Collection.php" hash="17e9bb8286b55de90c59cfe7da7d5f7b"/></dir><file name="Option.php" hash="3a058b88276a2fdd8b34cc39c7b66993"/><dir name="Set"><file name="Collection.php" hash="5d5f48626da06576b673c039de164606"/></dir><file name="Set.php" hash="01e30e73fbae7885c6808ee532f15e12"/></dir><file name="Attribute.php" hash="0bc50d42a753a0d38b027ed6e8125cb9"/><file name="Store.php" hash="022bb925298448ce0515c8902c950ae2"/><dir name="Type"><file name="Collection.php" hash="bc9361e0e15cea6007ddd2ff3756e906"/></dir><file name="Type.php" hash="563ecb5bc3160660ee2cd981db54e83f"/></dir><dir name="Form"><dir name="Element"><file name="Collection.php" hash="b5c98a418630ef3df9ab3f94c7b675a0"/></dir><file name="Element.php" hash="c8ad10c8cc7a5871ee92b972111cbabc"/><dir name="Fieldset"><file name="Collection.php" hash="daa73b54fa5aeb8ab5a310f910e64d80"/></dir><file name="Fieldset.php" hash="bc071d0b1c94bdc5a1dcd0a8496f051c"/><dir name="Type"><file name="Collection.php" hash="0196365ca85575c2f188fcf564906647"/></dir><file name="Type.php" hash="8ae370004548e992999bf7d1c5b8bf72"/></dir></dir><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="884adb14175e8728ee1757184d595297"/></dir><file name="Attribute.php" hash="977d832c7bf13354773879120e02a47a"/><file name="Config.php" hash="0c92be60b44d8f3f3872598662b484f0"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="c5dadd8439567c5ce0bdebfea23a3cb7"/><dir name="Group"><file name="Collection.php" hash="df9ab23eec5d042f5f44019dff458faa"/></dir><file name="Group.php" hash="3d732769aff3b8cc4af392346edb4f6d"/><dir name="Option"><file name="Collection.php" hash="fd5336332f8520dafc0213ef56d46f46"/></dir><file name="Option.php" hash="ef41db5b623b60125f36dd3166a73694"/><dir name="Set"><file name="Collection.php" hash="a218c8eaeb97080247c1f33f6763ce6d"/></dir><file name="Set.php" hash="ce0178c652fe12485b7e93ab22bacd5a"/></dir><file name="Attribute.php" hash="b35cfacaeda83f88f4ffabdcd637e9e3"/><file name="Store.php" hash="c922ae9b3f5ea5dc1cbabda637529252"/><dir name="Type"><file name="Collection.php" hash="f5ac2bd4f51c6a5caf49fb17526474d0"/></dir><file name="Type.php" hash="63c0bca51b1a0022c55fd4991f048981"/></dir><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="b0ce3e921c386fdc8127a7cf632fc9bf"/></dir><file name="Attribute.php" hash="b3aa3ef3de1bfc985d5b0dff837435c2"/><dir name="Element"><file name="Collection.php" hash="ed90d49ac06f3c6fbb8db1c5e93e70fc"/></dir><file name="Element.php" hash="cc8254b4f9231e1ef8bc62c7961c952f"/><dir name="Fieldset"><file name="Collection.php" hash="25e2bbc43a6a3f717687ab2f02ce3908"/></dir><file name="Fieldset.php" hash="d53c80a906104fe1c027e523230d8693"/><dir name="Type"><file name="Collection.php" hash="bb1bbec0dbabd0d2d1c384b7cd664e51"/></dir><file name="Type.php" hash="2ab9c6d0e36d4df5ad949b9a647b4e19"/></dir><dir name="Helper"><file name="Mysql4.php" hash="640baca7f4fed199db4f3be9229b997a"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="0ce463f61644eee879ef38dcff13de24"/></dir><dir name="sql"><dir name="eav_setup"><file name="install-1.6.0.0.php" hash="bbe35ca1128ad7dfcfce6b549a659920"/><file name="mysql4-install-0.7.0.php" hash="7f785666cb5dc104ba63eb2dbf2c57a2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ec0c99ae4cbf859972139d00f6e728c1"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9393b28c723fb6167bd688303cba8059"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="ad12f666f57394e5636bb0ba4379b445"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="89b66b6c969e6dc8bdc12956942c009b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="f471ae0351ea4f1127b40a299e937881"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dde737bbb90c59b57dd29cbfad286f32"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="4e210a99ea80498b338a7e533056e627"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="1aed43be7928f84ad7412e2df09eeae3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a760b5658978091af5a9dfeb5388969b"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="565d7aa6ef731bad0e3c836a5e6a3a21"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d53449b41c1fe3670909ffdbb2d66d30"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="b0497e262a4bc2ceede93bd6ef5cabfb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="d46637cee88d0cff61ab92a67485c141"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="b9cb4c015ee2e6f7aeb171c7326920cb"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="6784ed5afa90ba51e354e85c24cb4717"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="4929c7c613e6c07343551b83efe1cde5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="d5402afc2fa0f998be3ac372ea6cfd05"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="cb254f182f6e7c6f47fb2c5508499111"/></dir></dir></dir><dir name="GiftMessage"><dir name="Block"><dir name="Adminhtml"><dir name="Product"><dir name="Helper"><dir name="Form"><file name="Config.php" hash="86d11101a35df5731e8a4dc3a8e3dcab"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Create"><file name="Form.php" hash="548ab4b117fadee4331d5d00b0b231cf"/><file name="Giftoptions.php" hash="194289650bcccaf4483bfe3fb08ea933"/><file name="Items.php" hash="ef73476667ab8864ce6b65c5c0f3d1ae"/></dir><dir name="View"><file name="Form.php" hash="7b686e304e00f3da4a47c46362ccc5ad"/><file name="Giftoptions.php" hash="6c876c5fcbfc4e8204405b36c97865ec"/><file name="Items.php" hash="b7024780e706585ca268cd2522424946"/></dir></dir></dir></dir><dir name="Message"><file name="Form.php" hash="05dda3c7407fdf1bea7786218d99e529"/><file name="Helper.php" hash="5674ff6321c3b9502799786ad0bc45e9"/><file name="Inline.php" hash="3ea27c962a3bbb24da93694e7c3187af"/></dir></dir><dir name="Helper"><file name="Data.php" hash="bb0cda0f10afc6b6f736387f2a42db5c"/><file name="Message.php" hash="ad71d72f75008e1ae2b478a519cb57af"/><file name="Url.php" hash="e4e08bb1c1beda2657e17f4736b32579"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="f98276d7e1d2b4fe7d3cb742a18de8b2"/></dir><file name="Api.php" hash="26bb46739aee15f2398f2878c1150656"/><dir name="Entity"><dir name="Attribute"><dir name="Backend"><dir name="Boolean"><file name="Config.php" hash="f8f406d90bc9932c7b0e524c6403e465"/></dir></dir><dir name="Source"><dir name="Boolean"><file name="Config.php" hash="1e172c45ecdfe20d430f47e325470a8b"/></dir></dir></dir></dir><file name="Message.php" hash="5dfb4882a1a9b17ace6c4e17e5dae1ac"/><dir name="Mysql4"><dir name="Message"><file name="Collection.php" hash="1fd013a786ec1689feb96cf55fe8640c"/></dir><file name="Message.php" hash="4808d235da64c332355a757e6b2b1484"/><file name="Setup.php" hash="789d8e3ce35e92b8397a047c4dc10d90"/></dir><file name="Observer.php" hash="0e5d615565c62715ab68880aada4b619"/><dir name="Resource"><dir name="Message"><file name="Collection.php" hash="c973909813993d83be31e54742148e39"/></dir><file name="Message.php" hash="a78200d1df9b33523802f1dfd28285d8"/><file name="Setup.php" hash="165848ac03e71df30203c50a7bca0736"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="c4fdd6ed77fbd0ed2a72dc4d6be5508d"/></dir><dir name="etc"><file name="api.xml" hash="0cd624a5a4b2992eab91bab7db9c1a54"/><file name="config.xml" hash="934f6208ca8ebdb88531557d83c9fab6"/><file name="system.xml" hash="38ddfe6859cffc50f20bb4a0c5f0e808"/><file name="wsdl.xml" hash="b99aaaac0126c6e09a7ba59fa4dbcf30"/><file name="wsi.xml" hash="ab77c7cfecb0f5d6cb7b07c0b5abc1d1"/></dir><dir name="sql"><dir name="giftmessage_setup"><file name="install-1.6.0.0.php" hash="374dd23fc10fb776a6e7f846e5790330"/><file name="mysql4-install-0.7.0.php" hash="d63d56da8d880d297f1599a627e71fb3"/><file name="mysql4-upgrade-0.1.3-0.7.0.php" hash="05728dfb17eae1882e1a61ae3a571201"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5bfa3f68a0c188afcbec03f564f2c19c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f3c3dcb39ffd2293e252c66677ece0a7"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="cb6e77e20e91cdd2497c91dc6f751c8a"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ba851bc9df9c5a6a6430e1670116870c"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d4b64697af7b1b59edeab9120245c546"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="616ecca5d7296f027061084f550936bf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ee1e9039080b7cf8fbbe72a5781b1257"/></dir></dir></dir><dir name="GoogleAnalytics"><dir name="Block"><file name="Ga.php" hash="d2e0e76bf461805d7efa3504ba40778b"/></dir><dir name="Helper"><file name="Data.php" hash="d1e53e2c360d075b464fd9de2c564821"/></dir><dir name="Model"><file name="Observer.php" hash="16fa8e062f7aa80cb58c229d4cc4c27d"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Type.php" hash="27d5bbdac178313b3305c6308cc85565"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="7609f9a30ebed87c2cc808090733f522"/><file name="config.xml" hash="09a0c00775ae054bc1f6c2d93c426b47"/><file name="system.xml" hash="850dae8ed5870d335ece5cb8fedc9844"/></dir><dir name="sql"><dir name="googleanalytics_setup"><file name="install-1.6.0.0.php" hash="e484246fe4b335068b52afebc226ae6f"/></dir></dir></dir><dir name="GoogleBase"><dir name="Block"><dir name="Adminhtml"><file name="Captcha.php" hash="8ffb81bcaac1a9364c7dff92029209a0"/><dir name="Items"><file name="Item.php" hash="daf200d9b85bcc045c94d3922c97b247"/><file name="Product.php" hash="7e331a3ca0ca01b963e24772a821daf9"/><dir name="Renderer"><file name="Id.php" hash="1b72b62226dab4a38740f1e76a58252c"/></dir></dir><file name="Items.php" hash="85998c466c9bea59a59fc7ab3b890e6d"/><dir name="Store"><file name="Switcher.php" hash="2286a7c57c5b3c6068a63588bc083e4a"/></dir><dir name="Types"><dir name="Edit"><file name="Attributes.php" hash="ac180cb7663f5cc2e32990f83dad0cbf"/><file name="Form.php" hash="ad97b610567b0d3443f8cae9107ca766"/></dir><file name="Edit.php" hash="498601bd79e9965875f081a4d728750a"/><file name="Grid.php" hash="2acaadd9464546bbec77f5d9815f831f"/><dir name="Renderer"><file name="Country.php" hash="74417b955dac939a295eaa7ae64ce979"/></dir></dir><file name="Types.php" hash="96fc7c42735308df6bdd6f5d400e1afc"/></dir></dir><dir name="Helper"><file name="Data.php" hash="37dc22c51575825470397f02a1497b8a"/></dir><dir name="Model"><file name="Attribute.php" hash="de7147676dc2b9efc9e3b2ebe3f2dfde"/><file name="Config.php" hash="186ad497d6e756dafb7ab1e683c1fddf"/><file name="Item.php" hash="5c34a976ae0bc4979e1c77a3521045ea"/><dir name="Mysql4"><dir name="Attribute"><file name="Collection.php" hash="0ac995159720299072572e59b3f56703"/></dir><file name="Attribute.php" hash="0db990e969d8f15ca0202651b16d869b"/><dir name="Item"><file name="Collection.php" hash="6ab601ff75fbb3c02080067924940893"/></dir><file name="Item.php" hash="65aa28e83d4a2d8f56608db3f8e31765"/><dir name="Type"><file name="Collection.php" hash="acba8831466758db65e6a1a47a7147cb"/></dir><file name="Type.php" hash="0b063bc2ce8d0855771db6e4c0f74d41"/></dir><file name="Observer.php" hash="4ee39b5218f1fed7dbaaa36d9a29db6f"/><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="03615a6272451f12f8b43804e99ee5d6"/></dir><file name="Attribute.php" hash="92d0b4aa81e38442e1efb2dbb1d34258"/><dir name="Item"><file name="Collection.php" hash="9dca709ca6c169cd79b7b5ead827a08b"/></dir><file name="Item.php" hash="bfb7069e9a061e2ed5b0e0da2b2d01a0"/><dir name="Type"><file name="Collection.php" hash="64ce489b343309f3f39140a4f4cd7583"/></dir><file name="Type.php" hash="76003cbab0af46881bbd98bb957b66f8"/></dir><dir name="Service"><file name="Feed.php" hash="309cdd632278bb8bc5c29c0e2be1e360"/><file name="Item.php" hash="530d7616fc9ce908de7db459fc322015"/></dir><file name="Service.php" hash="24af7082a46a4932cbe03ed0bd6b6166"/><dir name="Source"><file name="Accounttype.php" hash="ce9af7fa322b94b4ec2e47cc6e6c1ec7"/><file name="Authtype.php" hash="b994b36c46031fedfff7b57f612f55a6"/><file name="Country.php" hash="0203b52aa4a28c0254d65a9b920efda8"/><file name="Statuses.php" hash="22ee2dba81cd494972b1fa7ece5b315b"/></dir><file name="Type.php" hash="76076f761fdfd28d59ff8b5577aabadb"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Googlebase"><file name="ItemsController.php" hash="c6de78715aa3017758bbc536b7afb095"/><file name="SelectionController.php" hash="9dfdedde2800187671c629f47971f2d0"/><file name="TypesController.php" hash="2fe00008ed2b55db767718ab1d5c0103"/></dir></dir><file name="ItemsController.php" hash="ee346770e2d88bcb674115d38e7949cb"/><file name="SelectionController.php" hash="8b96306c9cc7321029936c92737b3ccb"/><file name="TypesController.php" hash="709cecf3c0315f9a9063b31f318692a4"/></dir><dir name="etc"><file name="adminhtml.xml" hash="91b17d231331e23446d66dd5a2ac10b9"/><file name="config.xml" hash="26f5d7d23b12a0ca718d897b2595001e"/><file name="system.xml" hash="f31a03a47863c57e568f032001c6bef9"/></dir><dir name="sql"><dir name="googlebase_setup"><file name="install-1.6.0.0.php" hash="bc2387664571480a407c5182ca69a67d"/><file name="mysql4-install-0.1.0.php" hash="b1f74e7e4dc785db8c4821a7f9853659"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="37f586dcf8833a97e9fe0e992a5cf6cb"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="b060d55e1f64d3f672ff025af945dbc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="60867115973ae9449f221d742b319ae0"/></dir></dir></dir><dir name="GoogleCheckout"><dir name="Model"><file name="Payment.php" hash="982c96bcbfa5311070d550a8f8a1f948"/></dir><dir name="etc"><file name="config.xml" hash="c4d1bccf03be132b9dcb2c6822bf76be"/></dir></dir><dir name="ImportExport"><dir name="Block"><dir name="Adminhtml"><dir name="Export"><dir name="Edit"><file name="Form.php" hash="1d2694e45c6ad541957c42ee3eb1782a"/></dir><file name="Edit.php" hash="0666e8af99efef7ab7761b129ce09442"/><file name="Filter.php" hash="2b0d68c9414048ea234afe4d9d1ce8c6"/></dir><dir name="Import"><dir name="Edit"><file name="Form.php" hash="c47eeda645e5a6b54f7841a5528f8b03"/></dir><file name="Edit.php" hash="ca6507375bc594466a773a1530ee7abf"/><dir name="Frame"><file name="Result.php" hash="0a30864c11e996bdc9c66a0b8280b808"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="384c6172dc31bae831d96dd3569df8a8"/></dir><dir name="Model"><file name="Abstract.php" hash="5a230ebd046c2cd899ed245bc79706ef"/><file name="Config.php" hash="435812ed04e558d4a74963b8ab7796ee"/><dir name="Export"><dir name="Adapter"><file name="Abstract.php" hash="414836b6ded4008e9655417472429c1b"/><file name="Csv.php" hash="8f1f89d704be424c63c2e1e44437e224"/></dir><dir name="Entity"><file name="Abstract.php" hash="04a03c5b7fcc6b4849cef58a27b98f0a"/><file name="Customer.php" hash="eb5f630dc3ecfa946626a420046ceedb"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="908f6355594c01b95316e7bd14f1a568"/><file name="Configurable.php" hash="8df99a951ecdaa8ce418a8c147d1dc98"/><file name="Grouped.php" hash="14d26d03645a505f4516e65b65da1d58"/><file name="Simple.php" hash="90901b89f0cb6cfc465333f8f102af2e"/></dir></dir><file name="Product.php" hash="e2ecef0dc27574f76ee24f5bafe3ff31"/></dir></dir><file name="Export.php" hash="19776fb654cfc20955e253b83882a902"/><dir name="Import"><dir name="Adapter"><file name="Abstract.php" hash="28a61f3dd03568c018026619ad87d49c"/><file name="Csv.php" hash="ce14a1f5d90265a12fe0dc10ddf44b87"/></dir><file name="Adapter.php" hash="fd89afe4e1be5fbc2389d31d7a51e5a3"/><dir name="Entity"><file name="Abstract.php" hash="79006dccac27958e000d88020097a5b4"/><dir name="Customer"><file name="Address.php" hash="b8237c9fe5dba6466339393c3b000d08"/></dir><file name="Customer.php" hash="6871e8a4a23051a1e218aace81406d22"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="ffe2e9103a1e2693edd6891d3e83d47a"/><file name="Configurable.php" hash="fe9623029e842b6472369433b53d243b"/><file name="Grouped.php" hash="a6e1f3c1f9faa1739de0ac23318b846d"/><file name="Simple.php" hash="3a777da7bab161878964364b415080ac"/></dir></dir><file name="Product.php" hash="0397765d44718b3b4395da27b6d483a7"/></dir><dir name="Proxy"><dir name="Product"><file name="Resource.php" hash="06e6798c23ceb6319383e0120d5a571b"/></dir><file name="Product.php" hash="3050c471b6b0192716ea1cc51b4ef3ce"/></dir><file name="Uploader.php" hash="cc526896e36375ed0321e7fb5a80c9f4"/></dir><file name="Import.php" hash="c6c7206c1ec35924116392b6182e21b0"/><dir name="Mysql4"><dir name="Import"><file name="Data.php" hash="1088760a7325fc7a0e0f26427dfa4e03"/></dir><file name="Setup.php" hash="80bc724ecc0f935c2d5ebee1e3c2ad60"/></dir><dir name="Product"><dir name="Attribute"><dir name="Backend"><file name="Urlkey.php" hash="f9990ba2139c5bc3ec895b7bd339bc24"/></dir></dir></dir><dir name="Resource"><dir name="Helper"><file name="Mysql4.php" hash="4f156d994d5e68ce68dd7d2f95a7fc89"/></dir><dir name="Import"><file name="Data.php" hash="0235fb91f691b156680c160c68837ab2"/></dir><file name="Setup.php" hash="9dc5c3f7624900b8850a6e846f1e4f9f"/></dir><dir name="Source"><dir name="Export"><file name="Entity.php" hash="7eba440adcde3b91c888c21318f72447"/><file name="Format.php" hash="13d3a2ddef316c63a973541b299e3aa5"/></dir><dir name="Import"><file name="Behavior.php" hash="d923c67f2a43f414e9dd40eb13dcd10b"/><file name="Entity.php" hash="0970c1703c08c869269728ff3d2b634a"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ExportController.php" hash="46827924b3eee05f89aabcd67a4163a6"/><file name="ImportController.php" hash="be2058650aa5bb4a70b19665e6c92c86"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="91d91549fa6eed9d051fe0483b72df42"/><file name="config.xml" hash="f136ecdde7858eb0e921dc9689c8f560"/><file name="system.xml" hash="26aee9169d1cecd5def38f997c36d959"/></dir><dir name="sql"><dir name="importexport_setup"><file name="install-1.6.0.0.php" hash="440ecd2e1477d34e5cae67e86dac1b9a"/><file name="mysql4-install-0.1.0.php" hash="429e13933993d2ea22656edcdbf5ef55"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="c22f7d3f8c739ca64843cf2d45fcd73f"/></dir></dir></dir><dir name="Index"><dir name="Block"><dir name="Adminhtml"><file name="Notifications.php" hash="922e03c645be00419e2d8e5844d062e3"/><dir name="Process"><dir name="Edit"><file name="Form.php" hash="0cdf857a98eb42c9b579667a8678afdb"/><dir name="Tab"><file name="Main.php" hash="331b2a59a8d978f81c5b8a05b72e54ca"/></dir><file name="Tabs.php" hash="de2c47f1acf23d9360772ae00c8a859e"/></dir><file name="Edit.php" hash="ce7d7d368479e54c2b01b77dd3886b1d"/><dir name="Grid"><file name="Massaction.php" hash="aaa57991d6610fb6d00077818d532128"/></dir><file name="Grid.php" hash="f81a407a489b12d8ed8ea9c4b2e434c7"/></dir><file name="Process.php" hash="0a14d84d462e2cb2401ef3819389e7ff"/></dir></dir><file name="Exception.php" hash="a1dbeaf5fefc1d31b558fe93f9f73d1a"/><dir name="Helper"><file name="Data.php" hash="8d867f1179f6b39c5f7acdf175784a92"/></dir><dir name="Model"><file name="Event.php" hash="0f4c9a287f5a8679762952b86b8f8677"/><dir name="Indexer"><file name="Abstract.php" hash="cd9c4708d9a38c4c1afc672d04357030"/></dir><file name="Indexer.php" hash="d5143bacc2a4eaa4f6daf9c5cab5dc86"/><dir name="Lock"><dir name="Storage"><file name="Db.php" hash="0c22416871c8f81efa730ace6d992ac9"/><file name="Interface.php" hash="58327d8efcf1dcda6d5ec9c9c1cc1ac7"/></dir></dir><file name="Lock.php" hash="1c6666fe4cda94096d3668bcb8dfc9a8"/><dir name="Mysql4"><file name="Abstract.php" hash="5f9e45269f0beb215a04b7a5cbd7c01c"/><dir name="Event"><file name="Collection.php" hash="63dc340d2fcd37ec6993c171e6a112a6"/></dir><file name="Event.php" hash="720b92789910ef0c519e9e475b683a06"/><dir name="Process"><file name="Collection.php" hash="20ef6b9356da622286766d7acd1d929c"/></dir><file name="Process.php" hash="785aff05f0ac621b6d9a1a845cb1655e"/><file name="Setup.php" hash="c1ddc6c82badb71770af13c90d0cb812"/></dir><file name="Observer.php" hash="b9886ab72e3bd3db214ef31e464a2f1b"/><file name="Process.php" hash="e8bb4432a50efd682dd9419c0a82ef4c"/><dir name="Resource"><file name="Abstract.php" hash="ac3749b23996a6429c36ca137638ad02"/><dir name="Event"><file name="Collection.php" hash="1b03f9d9680463e2e60358052d8b82f8"/></dir><file name="Event.php" hash="d29ee78ac7d82ac16d32bcb7ef28d881"/><dir name="Helper"><dir name="Lock"><file name="Interface.php" hash="4bc86572aea98f639d4babf2ef538cc4"/></dir><file name="Mysql4.php" hash="ccc14816287dc75db167ca32ff5593cf"/></dir><dir name="Lock"><file name="Resource.php" hash="b2f87d6274785e35c8f06f966bf09f66"/></dir><dir name="Process"><file name="Collection.php" hash="82885a920f616ebbc109ca797efb232b"/></dir><file name="Process.php" hash="192269bd7cd4c37abfb4ee71303e0801"/><file name="Setup.php" hash="1464247cd3a97ccd6647a29262c1dde5"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ProcessController.php" hash="c60849c043f9fb2a8ed433ed63288dc0"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="838e8a8273f5f72317ac60721dfa9b03"/><file name="config.xml" hash="738fe1d9e58823a3ad48dff298540bb5"/></dir><dir name="sql"><dir name="index_setup"><file name="install-1.6.0.0.php" hash="fd7edf27ce1ab3e2d8604e13482c7e75"/><file name="mysql4-install-1.4.0.0.php" hash="73f12feb17accae95d4edef62c916a17"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="fac3d6ccb754170d8a8d7554bb6fa3d6"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="4e1513cafc48d3d1c51e39bad877b88b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="58861d9d24e1b40f78e4a0e8b6a23839"/></dir></dir></dir><dir name="Install"><dir name="Block"><file name="Abstract.php" hash="2dee98d086c168ab90698e8161f57066"/><file name="Admin.php" hash="efb15900c41ed3f02e39283193d391ee"/><file name="Begin.php" hash="659b15e410b828a97c6dfd9bae429ad2"/><file name="Config.php" hash="99dbd0a1160a5438c1b7ceb10a917d15"/><dir name="Db"><file name="Main.php" hash="5c56f37b937236cecc7cd22b065273b0"/><dir name="Type"><file name="Mysql4.php" hash="c20eb4b3c95316815677d5fbc4884b11"/></dir><file name="Type.php" hash="51040fddc22a85428577619c0b977464"/></dir><file name="Download.php" hash="52051c99cb5c5f99e6012d1f25f66074"/><file name="End.php" hash="16f06df1910ea6c4f49a6aec46ae086f"/><file name="Locale.php" hash="22c2f158faa1a3f13003a0c503faa2d5"/><file name="State.php" hash="24efc1866c5f33f0a0b993bedadbb8a4"/></dir><dir name="Controller"><file name="Action.php" hash="b682d197f541961e81213972c7244013"/><dir name="Router"><file name="Install.php" hash="8f69b3ce427d0fc0dceebd0030577e0d"/></dir></dir><dir name="Helper"><file name="Data.php" hash="9e855f685abce78835481bc484328719"/></dir><dir name="Model"><file name="Config.php" hash="dc4ee654173a7d2ef41e6a93199d70d5"/><dir name="Installer"><file name="Abstract.php" hash="4e0e0c729c308107360de80096e19540"/><file name="Config.php" hash="057a8c084c4476ae13a2d1fcf92c1f12"/><file name="Console.php" hash="f85d1f5d4880c7f4a50c8a98b398fd50"/><file name="Data.php" hash="3d90094a839ba4eadaf686cf2f9b56da"/><dir name="Db"><file name="Abstract.php" hash="1ba6d04a4d72970398883f7253263b17"/><file name="Mysql4.php" hash="e8cbc16eca193558c741eb22ac1c60f8"/></dir><file name="Db.php" hash="b67daec31cea6f3375db1ed7e56e4a7f"/><file name="Env.php" hash="639d6290361f4c1c4d5412229773e4f3"/><file name="Filesystem.php" hash="8b12da553f8a2b883da4bd4e19b7c33e"/><file name="Pear.php" hash="201cb7f98f8c34e96ced050fa828cf87"/></dir><file name="Installer.php" hash="e6e46a2976a552552306dc215ba865c2"/><file name="Observer.php" hash="8e6bffd30e9cb2e8a2eb696cf9ac5a68"/><file name="Session.php" hash="ed74c7aa62da86885edcaf79ca9bed8e"/><file name="Wizard.php" hash="c3489d3ad1292e06af7c3844f310aecf"/></dir><dir name="controllers"><file name="IndexController.php" hash="20e64a56f684c04619511846a99cc400"/><file name="WizardController.php" hash="7a00f69b6de90423d3ab53c9964b1492"/></dir><dir name="etc"><file name="config.xml" hash="fdcd1dd42be74df06a8419d8029023f8"/><file name="install.xml" hash="3d9ab17da44031cdc16c5d93e7b60773"/></dir></dir><dir name="Log"><dir name="Helper"><file name="Data.php" hash="8e1ea37dfdb3eb2127ae32b73117b934"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><file name="Loglevel.php" hash="6bc16da4c393f8244728accef3152b3e"/></dir></dir></dir></dir><file name="Aggregation.php" hash="10552339d8cb158c9b119bc060a0dbb6"/><file name="Cron.php" hash="f834b2b13b33226ef9da72a88cc5874f"/><file name="Customer.php" hash="702b0517de7e854d1700dd4ee045052b"/><file name="Log.php" hash="d44fe18e726aa473d7a0cbe329222965"/><dir name="Mysql4"><file name="Aggregation.php" hash="559d0acec067d9f127f84fcd34eb9696"/><file name="Customer.php" hash="79fbe550b2e61a2b05770265256ce170"/><file name="Log.php" hash="dda701b3c34ef8ce11d3dc30ac96b75c"/><dir name="Visitor"><file name="Collection.php" hash="8d7620ed8c7aeee03683108eca7617c4"/><dir name="Online"><file name="Collection.php" hash="55fd5d38e12430dfd58daf87f9b72d52"/></dir><file name="Online.php" hash="d7c1ce6bd2ceebc4f3f1b1206c4dc67b"/></dir><file name="Visitor.php" hash="755c2ff87d1df51e12e66fb285087c81"/></dir><dir name="Resource"><file name="Aggregation.php" hash="66ec9a927a8fdd273851cf5842ee477d"/><file name="Customer.php" hash="33684fd547fcfa2051fc3d950fe8173f"/><file name="Log.php" hash="1344865f7b485fff14925a226938d6d8"/><dir name="Visitor"><file name="Collection.php" hash="edd5b89c8bd514761aecd16574e9bc3a"/><dir name="Online"><file name="Collection.php" hash="6a059f3701221bcecc2e14d2689624ae"/></dir><file name="Online.php" hash="0b67cc2b5a714f8d76931574745ddbaa"/></dir><file name="Visitor.php" hash="e0a81fc458bc333f4de45282426b4716"/></dir><dir name="Visitor"><file name="Online.php" hash="f227139761c63b469710a03562dcc5ce"/></dir><file name="Visitor.php" hash="6eef64209506c68e05cac75702b8f09f"/></dir><dir name="data"><dir name="log_setup"><file name="data-install-1.6.0.0.php" hash="3e1982a81ee050ddec1949bb6a893c07"/></dir></dir><dir name="etc"><file name="config.xml" hash="eba13997054a59d8b5c1658c2999a4e3"/><file name="system.xml" hash="e333f423f247ee85fe09df20458fe362"/></dir><dir name="sql"><dir name="log_setup"><file name="install-1.6.0.0.php" hash="dc7295d342fda0d6cbcf4157a197d4ec"/><file name="mysql4-install-0.7.0.php" hash="d575dd42f8c7472d4d8ea8b1d90d8f9a"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="34b5ec712445eb9387594ca1f75fd87f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="129b7e5e5c06180fd48a218db32c7ea0"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="3a12eac2f81c762507914389c904618d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b78cb4e596f7f1be79f12b3e746c4db9"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="fd33161e285e2a0c8b3d6b5607f73273"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="6d3b11e2e5a4aa4b41aae94b68384d60"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7eca6d3b4caf1bdd7372f5ff95039d1f"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="bce437dd6f47db768f109624c4fb60d2"/><file name="mysql4-upgrade-1.6.1.0-1.6.1.1.php" hash="f8726e38a05a6cc876982e61cce65217"/></dir></dir></dir><dir name="Media"><dir name="Helper"><file name="Data.php" hash="a1f43339bdd5d2955ccec8e961f7d44b"/></dir><dir name="Model"><dir name="File"><file name="Image.php" hash="ef90f58f95934ece51b84add82393dbb"/></dir><dir name="Image"><dir name="Config"><file name="Interface.php" hash="2ec657e2417a814d9865c04ebddd2cdb"/></dir></dir><file name="Image.php" hash="cd22c32eaf0da58d4439c238b06947a1"/></dir><dir name="etc"><file name="config.xml" hash="ae68c69fff953c068f256fc2ed885794"/></dir></dir><dir name="Newsletter"><dir name="Block"><file name="Subscribe.php" hash="28e440fb31532edcc299b24c25fad0b2"/></dir><dir name="Helper"><file name="Data.php" hash="b6883b716785a6ae298ae474923bec8c"/></dir><dir name="Model"><file name="Message.php" hash="1750703765bb9f7376f8cd7afef95bdf"/><dir name="Mysql4"><dir name="Problem"><file name="Collection.php" hash="6de593241173f716441cd525a60b29ac"/></dir><file name="Problem.php" hash="5e980ad89adc06f1a064d88264db41c8"/><dir name="Queue"><file name="Collection.php" hash="560faac4ebac5cbdf08b20ce11419564"/></dir><file name="Queue.php" hash="f7f3bb7fa9173b6e51a6cc726c6c03f5"/><dir name="Subscriber"><file name="Collection.php" hash="f6e8ad8d1f24c2614ea758c7a683511f"/></dir><file name="Subscriber.php" hash="28a84169e8bf4563ee77d9a8795ea864"/><dir name="Template"><file name="Collection.php" hash="1385706b684c75f98c575beb981f2988"/></dir><file name="Template.php" hash="343c97a25be170240522e7cf682dab37"/></dir><file name="Observer.php" hash="34aa358337b40b41e062250a37ada85e"/><file name="Problem.php" hash="b84eab3f567814c02ddffd94224c2a9c"/><file name="Queue.php" hash="130624a59c5c70fde0b59d810a7f1917"/><dir name="Resource"><dir name="Problem"><file name="Collection.php" hash="73d5c8ac0bc852b1797deec496552102"/></dir><file name="Problem.php" hash="bc291b49df5cdabea16ef9ed3061a487"/><dir name="Queue"><file name="Collection.php" hash="245e312c2cd091994ad9f45838632360"/></dir><file name="Queue.php" hash="ea511beb43d47d27a98e3aaeaecc4474"/><dir name="Subscriber"><file name="Collection.php" hash="36c88e4f143f94d5ab8963df2f9cd32f"/></dir><file name="Subscriber.php" hash="e3edbe990f15e0e1893f351a3dbda922"/><dir name="Template"><file name="Collection.php" hash="c5ca290fa43abb9fc4748930b3a9d1bb"/></dir><file name="Template.php" hash="0309012892a386b48535d9a59c6d6b25"/></dir><file name="Session.php" hash="f5eb66ba88eb752da13607d4e031dd01"/><file name="Subscriber.php" hash="81525dee3bbd0db4bf1e584e0e6a1a43"/><dir name="Template"><file name="Filter.php" hash="bde6a148d876981d2a36ff0959f86e89"/></dir><file name="Template.php" hash="2cdca2731d3bef3098acca40bbfc7417"/></dir><dir name="controllers"><file name="ManageController.php" hash="5d567820c8d976ce8defd9b1b0da5206"/><file name="SubscriberController.php" hash="3fc6fdadccd2afa4692f0ab6b1bbd488"/></dir><dir name="data"><dir name="newsletter_setup"><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="b7a3d19fbaef5a6fdf37fe71176047df"/><file name="data-upgrade-1.6.0.1-1.6.0.2.php" hash="6c8c4e7d435bb50eddd6e7dbb14249cd"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fe2493b1ef093e63bb504edc5bd2ccd2"/><file name="config.xml" hash="2c22e3965d2256f71fc152e081e34527"/><file name="system.xml" hash="e37205b0b99e719c7623ffa5258b37bb"/></dir><dir name="sql"><dir name="newsletter_setup"><file name="install-1.6.0.0.php" hash="3c620e075f2a9298d52f36bec4ef92b9"/><file name="mysql4-install-0.7.0.php" hash="e81ce4f738b532d5435bfc8008293b8c"/><file name="mysql4-install-0.8.0.php" hash="bafb7e57fb822c4aca123fa6b9ed5920"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="c054de290c7c5fa3e116aed41eff4f17"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="663667dd1923f3890b855fc691375908"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="848b4eb72c16c4e2ac5cd2e12236b326"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="13ef7177c48460bb04dad80c456837a1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0367dc658bd286502e97f7b648fd6d04"/></dir></dir></dir><dir name="Oauth"><dir name="Block"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><dir name="Token"><file name="Grid.php" hash="faf7492adfcdb46928d76030eff74f65"/></dir><file name="Token.php" hash="ce4dddfe298fc02b2b381a7c6469092e"/></dir><dir name="Authorize"><file name="Button.php" hash="1c81a60de78cc606e79a1d8be57bb869"/></dir><file name="Authorize.php" hash="8f4665e6545dde37434ed9c10b3645a7"/><dir name="AuthorizedTokens"><file name="Grid.php" hash="cb6f809f97a7bf7d46b932e13aadff99"/></dir><file name="AuthorizedTokens.php" hash="85a9f2d4d7e7d12aa7d6b4eebfe9a0a2"/><dir name="Consumer"><dir name="Edit"><file name="Form.php" hash="26442ba5d70ad3bcee2f2787d3032191"/></dir><file name="Edit.php" hash="69ea6261b2de4c0179720f16d771b81e"/><file name="Grid.php" hash="5295e58ea863f40074ce4c590990118c"/></dir><file name="Consumer.php" hash="2a43bb7b1a6ec96fafa2fb0d2b850993"/></dir></dir><dir name="Authorize"><file name="Abstract.php" hash="3e3aba461e6008ecdd38749558530364"/><file name="Button.php" hash="6dd4651aa52e7094c95ca40aa40fe559"/><file name="ButtonBaseAbstract.php" hash="0d30faefc4fd63c756ce97c699e530d2"/></dir><file name="Authorize.php" hash="12557ebc607496441344055642e1fc89"/><file name="AuthorizeBaseAbstract.php" hash="c7286fab6fad35da2af69251df23c927"/><dir name="Customer"><dir name="Token"><file name="List.php" hash="ab6a503fd7351a57ae0c38ab7cbe1bc7"/></dir></dir></dir><file name="Exception.php" hash="f2cce047a249d5042a8196eb2eb1188b"/><dir name="Helper"><file name="Data.php" hash="3cdfd4b295606df93d44cb6e97b453eb"/></dir><dir name="Model"><dir name="Consumer"><dir name="Validator"><file name="KeyLength.php" hash="41a23ef35ba4f1ecb26430a0b15e90b1"/></dir></dir><file name="Consumer.php" hash="48e78ecd656ce1caf445eb7d07c7fa37"/><file name="Nonce.php" hash="c6fbea1ee4b0853402b34214e5a4e7c2"/><file name="Observer.php" hash="af0fe3ecee5ee39ac6f20a34b162b3ac"/><dir name="Resource"><dir name="Consumer"><file name="Collection.php" hash="6a0ae20a1d9598df8cc13c66ff7857df"/></dir><file name="Consumer.php" hash="71aa68f1f659032f19fed5bd7f16954b"/><dir name="Nonce"><file name="Collection.php" hash="a6145078c6830243e6c35521467de6ff"/></dir><file name="Nonce.php" hash="0c2fc104df8c98ef3bf10a06c82c9e4f"/><file name="Setup.php" hash="664fcc4e6ce0c5de4aada29f49ef283d"/><dir name="Token"><file name="Collection.php" hash="c2c31414bdf93a1bf642de15be611a25"/></dir><file name="Token.php" hash="083a0594d61845cb68e28cc118b7bb17"/></dir><file name="Server.php" hash="9468c0b29cc165fc0ef20cd95d47e6f6"/><file name="Token.php" hash="ee05a1801416a8bb440d3d7c8d004dd6"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><file name="TokenController.php" hash="c2435d97eb91f835014d403354354ec6"/></dir><file name="AuthorizeController.php" hash="659b7948384ab393209f296f5be15b43"/><file name="AuthorizedTokensController.php" hash="bb7df560a7595deaeec96ae63a7e9b2b"/><file name="ConsumerController.php" hash="8e3244262dc3a34a89cf54984b2ec74e"/></dir></dir><file name="AuthorizeController.php" hash="9536f67c302706a93b5a844f6826d870"/><dir name="Customer"><file name="TokenController.php" hash="f9f9ed1f0041c5ae518005f2e90e78f6"/></dir><file name="InitiateController.php" hash="7bc4b0605282cfc629011ca094863175"/><file name="TokenController.php" hash="3a734ab905de6197146e7de47376de6f"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c3c51c34ae5979c2e0df148ddbec7113"/><file name="config.xml" hash="446b689f37981498a1dc86f5ab1bb0e3"/><file name="system.xml" hash="38bcf79677c20f5821bf6f54dcfe6297"/></dir><dir name="sql"><dir name="oauth_setup"><file name="install-1.0.0.0.php" hash="7d70d6610ebf50a9782337e6f3d0f5ef"/></dir></dir></dir><dir name="Page"><dir name="Block"><dir name="Html"><file name="Breadcrumbs.php" hash="1fe5ffca8e5b2f2f2b7aa78700217c6c"/><file name="CookieNotice.php" hash="f70b0a12cfccafcaa7125478dbd6a8d9"/><file name="Footer.php" hash="77f2fb87201b33dc34fdb7fae4ffc030"/><file name="Head.php" hash="cb019fb8e30bbd8064c3418f6c291a47"/><file name="Header.php" hash="2cbf7f560f06289367d825e99a784355"/><file name="Notices.php" hash="7782add14339c49bbbfa074baff2bcae"/><file name="Pager.php" hash="e946ed0f6a5deb4021ddd415e3dcada2"/><file name="Toplinks.php" hash="be7cbec75d231b5f40cecc45ce6aced9"/><dir name="Topmenu"><file name="Renderer.php" hash="f6df51661c07d24a2cd45ada7a195c16"/></dir><file name="Topmenu.php" hash="7fa8066846bd784d4da25a7638ff83c9"/><file name="Welcome.php" hash="c588210d17985afdd4b70016862a3f58"/><file name="Wrapper.php" hash="c43925e6af41f952a246d38de7acd924"/></dir><file name="Html.php" hash="ebff82d47412ade15f091533080a8cb0"/><dir name="Js"><file name="Cookie.php" hash="97ad94ecbdfb73f1523169f105148de6"/><file name="Translate.php" hash="5b3273d29f989c8348d93788dcbc4d8b"/></dir><file name="Redirect.php" hash="d8b5ddb87a79497acc2136d117aa4cb8"/><file name="Switch.php" hash="92e0ee78127e737abc1d0de28aa39668"/><dir name="Template"><file name="Container.php" hash="58c4e09110863b559c899e766689db3c"/><dir name="Links"><file name="Block.php" hash="a1fd263db9149683be177f12b3d21403"/></dir><file name="Links.php" hash="d3563e74d4e9be5ca574d26980f87ae3"/></dir></dir><dir name="Helper"><file name="Data.php" hash="643200eb25af3286d89295821ccd215f"/><file name="Html.php" hash="ff435cfd6fa058784e5047bde5059cc0"/><file name="Layout.php" hash="68a7da8957b6bf38391076c6dc1d8b89"/></dir><dir name="Model"><file name="Config.php" hash="d3353eb7388747f28106cc422b7c0178"/><dir name="Source"><file name="Layout.php" hash="f6c47751ce94f1202f51f74240576f16"/></dir></dir><dir name="etc"><file name="config.xml" hash="093b9598b2072c232feaed596cdae921"/><file name="system.xml" hash="b639cd00ba12888b93846adf7b7a06ce"/></dir></dir><dir name="PageCache"><dir name="Block"><dir name="Adminhtml"><dir name="Cache"><file name="Additional.php" hash="980caec50a3cbf58f41da2327a565021"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="3b8e9e8eb1d3c56bcb47f4b3eecdb7cd"/></dir><dir name="Model"><dir name="Control"><file name="Interface.php" hash="fd10161bdb54026cff06db39a4dbb5c2"/><file name="Zend.php" hash="21b1db8392b9f2f3d078705e2ec26ba4"/></dir><file name="Observer.php" hash="537fb8952f611b797e394e4569de1ffa"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Controls.php" hash="ea5031f742689bca2a1b08144ea39cd0"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="PageCacheController.php" hash="a4905697051657f96098ec4076fdfe2b"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="97661944ee637ba8e00a6596bdba3969"/><file name="config.xml" hash="c3e7a37ca8c0a930bea08751ad362a2e"/><file name="system.xml" hash="f8301b232c7614412428a0fb526bf5bc"/></dir></dir><dir name="Paygate"><dir name="Block"><dir name="Authorizenet"><dir name="Form"><file name="Cc.php" hash="d657a3be38a02106dde73a4892b0c77e"/></dir><dir name="Info"><file name="Cc.php" hash="378841b3fcda8fbec605b62c3fe7a9c8"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="008e92608958a3a7ac08ade7ad142ccf"/></dir><dir name="Model"><dir name="Authorizenet"><file name="Cards.php" hash="d81581da931610d0e8868b4accb3690b"/><file name="Debug.php" hash="977a9c8240e3f572bbb64d6a6f238b87"/><file name="Request.php" hash="ba5a4763ece9bf688257ce424212b459"/><file name="Result.php" hash="219a7a26b1ebfb4c58da9f287f386d6a"/><dir name="Source"><file name="Cctype.php" hash="93635248391f764267488c9584d9690b"/><file name="PaymentAction.php" hash="7dbc905942c6359af597c5dc9c80094f"/></dir></dir><file name="Authorizenet.php" hash="dba6893ddc37660cc8e1a09a7953130d"/><dir name="Mysql4"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="75ccb15a446e4a32e853f2fcba210ab3"/></dir><file name="Debug.php" hash="71d0f733c94f22dbcb887d64dc27d16a"/></dir></dir><dir name="Resource"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="2bbfd8a9516e70297630bb01a52f6f50"/></dir><file name="Debug.php" hash="e21392b38f8cb291d1803ce24400a886"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Paygate"><dir name="Authorizenet"><file name="PaymentController.php" hash="267d17f09c387babc09a9b065cd145ca"/></dir></dir></dir><dir name="Authorizenet"><file name="PaymentController.php" hash="7943c655501133002d695e8dd980d62e"/></dir></dir><dir name="etc"><file name="config.xml" hash="e8090f4993067b18e61a600994d704a5"/><file name="system.xml" hash="4b712d693e127e77f876a4497c399e24"/></dir><dir name="sql"><dir name="paygate_setup"><file name="install-1.6.0.0.php" hash="512f727b16737444feae450851679a7e"/><file name="mysql4-data-upgrade-0.7.0-0.7.1.php" hash="bb83ae3d9fc7ade47467ca1fadaab284"/><file name="mysql4-install-0.7.0.php" hash="40b964a9db67dc645b20735a0d69d586"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6f2857623a2baa373fb4d01d8cdf597d"/></dir></dir></dir><dir name="Payment"><dir name="Block"><dir name="Catalog"><dir name="Product"><dir name="View"><file name="Profile.php" hash="725706ecf3c9f45fa76a43aed9f4fd0e"/></dir></dir></dir><dir name="Form"><file name="Banktransfer.php" hash="a8065e642e9b9d36d7b0ed5f333dc152"/><file name="Cashondelivery.php" hash="a3704a4d200caff8a596736650bae112"/><file name="Cc.php" hash="145d796f6c98a11a230cb4292cb683ea"/><file name="Ccsave.php" hash="c25e2aa496f3665a7d22ebaa0046041e"/><file name="Checkmo.php" hash="0e34baf58c26715ab229e2053736a5c6"/><file name="Container.php" hash="7e93316090e0517da04392d2db08623b"/><file name="Purchaseorder.php" hash="4ee06729fdce364077a746e10ec016ca"/></dir><file name="Form.php" hash="08da59955c049b2a436a92c86c42a71a"/><dir name="Info"><file name="Banktransfer.php" hash="8253079b2a3f295e9212ffd471f1fb8c"/><file name="Cc.php" hash="0bc912ea4a40f5f413f501866900f2b9"/><file name="Ccsave.php" hash="c99aac57be0c839c3761bf63b42f9b63"/><file name="Checkmo.php" hash="bdfa5eb12e51b24dfa520d2ce9df0878"/><file name="Container.php" hash="8b24dd8c3fc825879faaeaddda23bdf6"/><file name="Purchaseorder.php" hash="97c4838b60a46f7a2ae9938b1f02e1c4"/></dir><file name="Info.php" hash="df4007e93b95af8440adca3d7a2f003a"/></dir><file name="Exception.php" hash="2f764ffbd8d0325189157a5166961ce0"/><dir name="Helper"><file name="Data.php" hash="4bba6d904ff25cf084a34bc5e67e9562"/></dir><dir name="Model"><dir name="Billing"><dir name="Agreement"><file name="MethodInterface.php" hash="40affb7dbc6e36c9d412acf3752d49ad"/></dir><file name="AgreementAbstract.php" hash="cb98bd16da8df19373a4e2fb4d695c45"/></dir><file name="Config.php" hash="5e882d7781c0b77ae07556af497a0237"/><dir name="Info"><file name="Exception.php" hash="9e329becc170b4510db0a958b85d9992"/></dir><file name="Info.php" hash="f1a313479034fa1cd9cc4a55c754de07"/><dir name="Method"><file name="Abstract.php" hash="e540ef077370453a0caf0f043bf20ee2"/><file name="Banktransfer.php" hash="2c3cef4f19d6c50cfbcad2417881e506"/><file name="Cashondelivery.php" hash="ba5a710d5848130b9bc853fcb5975387"/><file name="Cc.php" hash="936a4c4e2a4ec708d1f7b9a904955a67"/><file name="Ccsave.php" hash="d23c43b145c29936b4f0270f2bd5461b"/><file name="Checkmo.php" hash="e9e42a8a7e6fac87ba540707b971f721"/><file name="Free.php" hash="dbb00b6ca11ff0b713028460fdb4c7fe"/><file name="Purchaseorder.php" hash="5ac8af393668e8293d99edd49448e5fc"/></dir><file name="Observer.php" hash="60a511f336a4e4929f0d493c35ae8a0c"/><dir name="Paygate"><file name="Request.php" hash="6bc7e8cd45e164af3323eb8555334474"/><file name="Result.php" hash="2e4a62d1d983538db34bce670dec9139"/></dir><dir name="Recurring"><dir name="Profile"><file name="MethodInterface.php" hash="7c3753a6b14e1f405bcdb6e9842cdba6"/></dir><file name="Profile.php" hash="a619cf76b0eb8846919935ed8c644995"/></dir><dir name="Source"><file name="Cctype.php" hash="4aa5f460d8dbd3365a37d5a777833284"/><file name="Invoice.php" hash="94cf713138fce0d1e839aff0f4835640"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2ffac8b147628b2f2a905c7c6863f873"/><file name="config.xml" hash="8088a0540e8f4c16af7cdde7f6114397"/><file name="system.xml" hash="73d212e7b1a6299a5aeb3252036481f8"/></dir><dir name="sql"><dir name="payment_setup"><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="8a85b32c4db60c3f8841f3e4a54b9b95"/></dir></dir></dir><dir name="Paypal"><dir name="Block"><dir name="Adminhtml"><dir name="Settlement"><dir name="Details"><file name="Form.php" hash="6ddcb1cc4019de3b6959bca28115ac36"/></dir><file name="Details.php" hash="7ac366f7c6119905719aec713aec003e"/><dir name="Report"><file name="Grid.php" hash="85f1eaa79a7efedcc68b2b55a2996fb4"/></dir><file name="Report.php" hash="36bb9f80863bb5a1475ea1558c474b27"/></dir><dir name="System"><dir name="Config"><file name="ApiWizard.php" hash="0bc7455b8a819c2d72639ea6bbe37e4c"/><file name="BmlApiWizard.php" hash="090124ca3d6b8a7871676c057abbdcde"/><dir name="Field"><file name="Country.php" hash="4c60e38dd22c3b9fb23e3a0ca9a7cb6a"/><file name="Hidden.php" hash="e069a192a35b54b1bc29f9e8b03b06a1"/><file name="SolutionType.php" hash="889a1b47c5fdfb1a8d56e618afffc83a"/></dir><dir name="Fieldset"><file name="Deprecated.php" hash="01f954b46d2bf35bbcb4181fbdc18a37"/><file name="Expanded.php" hash="5feb995a9b9368a7335645cd659e0069"/><file name="Global.php" hash="2edadea19ce037b63b5b9d5f43e0639a"/><file name="Group.php" hash="10a1bd0c6519d110c1da6cf34f2f3e88"/><file name="Hint.php" hash="1b39b3d40b5602d53ddb83aa96285623"/><file name="Location.php" hash="ba3f315238325790ca09dbfe1f3c98b7"/><file name="PathDependent.php" hash="125f5c38eba04b953f6c770de5794982"/><file name="Payment.php" hash="47d6650b3d19fa72cd0be0799a4bc58c"/><file name="Store.php" hash="f3c73d65c6a3830dd320a252b9719c37"/></dir><dir name="Payflowlink"><file name="Advanced.php" hash="c9504cc07b7e8dd2b53b7732ccea5f37"/><file name="Info.php" hash="452702b941cd07c4604d27744768927f"/></dir></dir></dir></dir><dir name="Bml"><file name="Banners.php" hash="b3eec8eed2340570b3992dc5cc91c3eb"/><file name="Form.php" hash="e18437ec63789b079fcee9da6584a6bf"/></dir><dir name="Express"><file name="Form.php" hash="c638da5fe28a9499e97ae54912b39814"/><dir name="Review"><file name="Billing.php" hash="b5b3816f3de318c64cf64c90f56b8c0e"/><file name="Details.php" hash="93b80e5b28ba63323a3e7f1121e56c26"/><file name="Shipping.php" hash="81ad721a1affbfe1e5e1b149819e9399"/></dir><file name="Review.php" hash="accd58014e0a151ad8b9dfcfaa43a57e"/><file name="Shortcut.php" hash="b0e47e3854c9249353b08634818fe367"/></dir><dir name="Hosted"><dir name="Pro"><file name="Form.php" hash="a5cf9e2d9706c4d51f52ecca876cc51d"/><file name="Iframe.php" hash="a6631c676e7b70c2f3c98e37fb4c7938"/><file name="Info.php" hash="66918e15ea5383ae03982360a7d3395c"/></dir></dir><file name="Iframe.php" hash="d9dbf2ed604febfdc93d7ec861416959"/><file name="Logo.php" hash="c1d496b3c83f9b048fc6a6fec17868b8"/><dir name="Payflow"><dir name="Advanced"><file name="Form.php" hash="a53c2c390019833e86255d468ea00ce5"/><file name="Iframe.php" hash="d004c0ecd462b5bd3aa40e60f0eaa98f"/><file name="Info.php" hash="d8b493ddca4388198d58de4f29928575"/><file name="Review.php" hash="e76212ba90c607a6fb4e8937e15157b1"/></dir><dir name="Link"><file name="Form.php" hash="cd8607afb8baf8e7076414aa80af47b9"/><file name="Iframe.php" hash="9fa8a536ea14470f7edbd6542e345361"/><file name="Info.php" hash="adeb4b8a88c9744ea7e7a135b6cf92e9"/><file name="Review.php" hash="79fe2f6d55f6c77ff499e900b8aae56a"/></dir></dir><dir name="Payment"><file name="Info.php" hash="ff95d5e77f8273c3df147339dc2a809a"/></dir><dir name="Standard"><file name="Form.php" hash="74f3f12f2f645bf65d4c7cbd07b41bb4"/><file name="Redirect.php" hash="29dbaaac7d961dbedb27b22ff50a6fd5"/></dir></dir><dir name="Controller"><dir name="Express"><file name="Abstract.php" hash="200daa8f5bfd9cc60308e1c70b48fdfc"/></dir></dir><file name="Exception.php" hash="fcdfd6d4dac7c1f3bf1fd539eb7f7769"/><dir name="Helper"><file name="Checkout.php" hash="615868ddf2e733a90a1530ca7f76e76a"/><file name="Data.php" hash="8bfe0b91a3782f2a3a2589cbff79c789"/><file name="Hss.php" hash="a214dc03517c059962b4b0ae0b3062d4"/></dir><dir name="Model"><dir name="Api"><file name="Abstract.php" hash="83fa994337a3ea71000be3929819339f"/><file name="Nvp.php" hash="9afffc68e2b7f5b088368cfcf852095d"/><file name="ProcessableException.php" hash="3912a3f9f4916ada603c2903f8195a6b"/><file name="Standard.php" hash="6025fea50bc134ae53d7a7253e40a849"/></dir><file name="Bml.php" hash="c8ef5747ef0e41edff08224c8b09780e"/><file name="Cart.php" hash="606f045a4c3441fc3f2a43127840f9be"/><file name="Cert.php" hash="dec38db38574e00681a0171e2ddcbdf7"/><file name="Config.php" hash="8f8e36240b38e64509ba5c14c774e9d0"/><file name="Direct.php" hash="c2a94320efb7745eee4db1ccc22822f0"/><dir name="Express"><file name="Checkout.php" hash="341134b019a81f5132df773034b11ffa"/></dir><file name="Express.php" hash="bb9d000176a507ee2f8f189e2a0cde1d"/><dir name="Hostedpro"><file name="Request.php" hash="349a1a20f529fa148d557b655618b5b8"/></dir><file name="Hostedpro.php" hash="fc7b44c2d2b7a6b2e16555ca779e3cec"/><file name="Info.php" hash="841b30d7eebbf3df26fe71937243c4e3"/><file name="Ipn.php" hash="992d9a3d7eac13cc92e4006bd82cf6d6"/><dir name="Method"><file name="Agreement.php" hash="024ff9253ccbd340ab4d3e1df3b462ec"/></dir><dir name="Mysql4"><file name="Cert.php" hash="cc765655e8978b4a65343cf307e3fd7b"/><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="57ebccbb3c85463714004f17b5944ffb"/></dir><file name="Row.php" hash="f73aa04ec3103f999023738fb56f3efc"/></dir><file name="Settlement.php" hash="c2a3667e985551055c032ceb3269843f"/></dir><file name="Setup.php" hash="d332223394ea48a9316ece62f9d87c2b"/></dir><file name="Observer.php" hash="921ff85011967dace873135b17c4473d"/><dir name="Payflow"><file name="Request.php" hash="bce9a2a096c7948d82f8b376e2a2a178"/></dir><file name="Payflowadvanced.php" hash="7bb0e3274015050ae2fc9c56057b2cb4"/><file name="Payflowlink.php" hash="a5808cb2562f13ad2430c2150a28e023"/><file name="Payflowpro.php" hash="71d8794bc0c48b63cf31312b1dbef978"/><dir name="Payment"><file name="Transaction.php" hash="fa8636d02751123e68d3907326dc3844"/></dir><file name="Pro.php" hash="4f2c1c4e4175db48b24dfd5d074c78f3"/><dir name="Report"><dir name="Settlement"><file name="Row.php" hash="d6c2cd48c2cc14acd7807ae0ecc075b9"/></dir><file name="Settlement.php" hash="4a116d46a8a412baf390b4f660092e85"/></dir><dir name="Resource"><file name="Cert.php" hash="dc4fee682268206f22c450f11ee77ab6"/><dir name="Payment"><dir name="Transaction"><file name="Collection.php" hash="a738465839e6bc7060399d4ea1018811"/></dir><file name="Transaction.php" hash="fc74fade61f3ed060dfd1908d0f3568c"/></dir><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="b86233296208bf48edf315e76af3841a"/></dir><file name="Row.php" hash="b5f4467774406898083bc0a3b381e4a2"/></dir><file name="Settlement.php" hash="00be4934c8645f49be6dfb2f95c2df6e"/></dir><file name="Setup.php" hash="72ee97eac0bf6dd489e87a90f0739f94"/></dir><file name="Session.php" hash="01e89821d349210313e7601a52163253"/><file name="Standard.php" hash="e64d7379830e18577f72f07c2b1bcbcc"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Cert.php" hash="39dee3020d56b4d99acf2dbaac2d8313"/><file name="Cron.php" hash="b9f70827fcf4a140a0dd93d1a6377f32"/><file name="MerchantCountry.php" hash="d8fc9fa97b38b8e5d6e59a10863903fe"/></dir><dir name="Source"><file name="AuthorizationAmounts.php" hash="0c3a38379dc3cf8d7822a91df9bd2fea"/><file name="BmlPosition.php" hash="df2ad0b79c16fdc21b28442544ca6021"/><file name="BmlSize.php" hash="e80300a818111d09ca8c84a535508516"/><file name="BuyerCountry.php" hash="d897c4000b9d38da67e649b1552120c6"/><file name="FetchingSchedule.php" hash="07344b50f6ca9f10e9be3234d57e8957"/><file name="Logo.php" hash="ae5253ff2eb86d72a9d4a48eefd71516"/><file name="MerchantCountry.php" hash="ef1e498e5aad6a3c0af03a5ed5f4faa8"/><dir name="PaymentActions"><file name="Express.php" hash="bab12455a570699163625c6452458116"/></dir><file name="PaymentActions.php" hash="c2593f853dbab0a41dc5175c020b3d3c"/><file name="RequireBillingAddress.php" hash="b73a2c1762c33aad94c8878bfec02eff"/><file name="UrlMethod.php" hash="52cdf00f20176c80a1c099e5f635a8f2"/><file name="YesnoShortcut.php" hash="cad52eb5e45fe480327631f6272f907e"/></dir></dir></dir></dir><file name="UnavailableException.php" hash="aa39aecb2766d59f98b32030254d34fa"/><dir name="controllers"><dir name="Adminhtml"><dir name="Paypal"><file name="ReportsController.php" hash="5c6bf3de5a00da49b48565f92afedec7"/></dir></dir><file name="BmlController.php" hash="b8b1d029fdd2d73ff389c9a100f30054"/><file name="ExpressController.php" hash="5733d778477b5a08dfd3e64992320f77"/><file name="HostedproController.php" hash="0152fbfc438e30b70c7f647278701d75"/><file name="IpnController.php" hash="563d93416c1482581dee5112ab0aebb1"/><file name="PayflowController.php" hash="1a303bea93bcdd01445e5efc7ea2691b"/><file name="PayflowadvancedController.php" hash="640e848bfe279f7585bb877b9571415a"/><file name="StandardController.php" hash="1e8b7292120096b0b9fb38c94b1e314b"/></dir><dir name="data"><dir name="paypal_setup"><file name="data-install-1.6.0.5.php" hash="31f40b7d79be358edb0a9cc0e9b103db"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="c42ee4ee4739cb2ea92a422fd0b404fc"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="a8bf81ac635dfd2bd045904a25c64da6"/><file name="data-upgrade-1.6.0.5-1.6.0.6.php" hash="ebee289417ad5f5c222be7b1af256393"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5d13ccd9736705a6b2eb7f6de4f833c3"/><file name="config.xml" hash="83aaa17324edbd5bef47af753ea350de"/><file name="system.xml" hash="114ca5f13f1da5b517f023e332d03a01"/></dir><dir name="sql"><dir name="paypal_setup"><file name="install-1.6.0.0.php" hash="2090e14614dbdce1ff27be6516bc594c"/><file name="mysql4-install-0.7.0.php" hash="378e4be279f4bbc8d04cbdf861094b21"/><file name="mysql4-install-1.4.0.0.php" hash="14d77731070a888c43bf107f45756d76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="10e54e4c72b929cca1c933fda6f08ada"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="781db6012e61655eb559c282e49601dc"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="bb99253212b7a2593936f557c434b370"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="56e09db439d9d5cfa73e06beffd5fc3a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ab6fa9235bae2eedf82869e288af1b83"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="5ef1829af7dfb20fc92b3dbdcbea82a7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="37589fcebf8a761344345ae9fb7850b4"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="bca45a121f607c44b0f63975db8cbc03"/></dir></dir></dir><dir name="PaypalUk"><dir name="Block"><dir name="Bml"><file name="Form.php" hash="3c0edcbe9705ed2744098b851d3fba7a"/></dir><dir name="Express"><file name="Form.php" hash="d256cb349d523a2321e1597cfab93939"/><file name="Shortcut.php" hash="e69f67262822e930f82394a4f0bbc89c"/></dir></dir><dir name="Helper"><file name="Data.php" hash="90c53b8383f4258113adfc5ef79af65a"/></dir><dir name="Model"><dir name="Api"><dir name="Express"><file name="Nvp.php" hash="651c60d497003cb572dbb69a1eaffa17"/></dir><file name="Nvp.php" hash="4e46dc410d3afb2f18da008e45411d1d"/></dir><file name="Bml.php" hash="1e160b4ef8f118a09d8cb4263f96a01f"/><file name="Direct.php" hash="ccd3c98de05755972fb5d89fa806767a"/><dir name="Express"><file name="Checkout.php" hash="17089c92caeb7c8c6fd3059e0bd1a0a2"/><file name="Pro.php" hash="f0c3e779d8623d4f27706dda66decab4"/></dir><file name="Express.php" hash="7e5fa1857cb0696aa9297ceb0f6546ca"/><file name="Pro.php" hash="e8311225b0d975ef699328964807165f"/><file name="Session.php" hash="21a99ed402af561bbb41f6c62bc4ea3e"/></dir><dir name="controllers"><file name="BmlController.php" hash="7386a0d6715cc32a3f07888f3f42b0d3"/><file name="ExpressController.php" hash="a0e8d1669b5e48b3b038fc1cfd8d8b66"/></dir><dir name="etc"><file name="config.xml" hash="4a88d9c97e7fe9ed8ac729813eb02768"/></dir><dir name="sql"><dir name="paypaluk_setup"><file name="install-1.6.0.0.php" hash="778b39aed49df6932c24b93b90de5374"/><file name="mysql4-install-0.7.0.php" hash="04d22ff231e6052b2a7045ceed56e823"/></dir></dir></dir><dir name="Persistent"><dir name="Block"><dir name="Form"><file name="Remember.php" hash="6938ee73ae4b23175929291352627c1d"/></dir><dir name="Header"><file name="Additional.php" hash="fe21d5ba74ee87c8fd1f078820862459"/></dir></dir><dir name="Helper"><file name="Data.php" hash="74c064583b94e204e3d2a9ebb531e83a"/><file name="Session.php" hash="30ec18375b1721d96e419ba1ae51bfd6"/></dir><dir name="Model"><dir name="Observer"><file name="Session.php" hash="26f1f3914a611968042f33448b29493e"/></dir><file name="Observer.php" hash="9c8fc1d64e5475e7999c9adb951b9227"/><dir name="Persistent"><file name="Config.php" hash="97c699aab82390187319a99d6fd8d397"/></dir><dir name="Resource"><file name="Session.php" hash="73fee31ec3e22f4ef5fe35d8572a8086"/></dir><file name="Session.php" hash="f60ed020730dae8723e95b9a7c4f910e"/></dir><dir name="controllers"><file name="IndexController.php" hash="dbe7fb77826b94758eb83510a3f824d5"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ee4a02d8045e01f972d7a819fcb534df"/><file name="config.xml" hash="1556d41acedff911c7eb7f7984bfdb0c"/><file name="persistent.xml" hash="3b9b7c3c2c765d6c999ce496a1712dce"/><file name="system.xml" hash="a551b1dbfd9b4932f1902233199f388e"/></dir><dir name="sql"><dir name="persistent_setup"><file name="install-1.0.0.0.php" hash="087ca130d306aa6b3ff8213a45f39dfc"/></dir></dir></dir><dir name="Poll"><dir name="Block"><file name="ActivePoll.php" hash="0efc7679648818186af612d4783d656d"/><file name="Poll.php" hash="27d6ea8ad7f802de02180374f9d25f6f"/></dir><dir name="Helper"><file name="Data.php" hash="9ace323d9bbe7107ecf78d55bf368f52"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="fcff690bfd2b25a997d966a3ad215d57"/></dir><file name="Answer.php" hash="5b008cec3bd71a09124ec5122d125a47"/><file name="Collection.php" hash="9abdf28422a7199aa63d51c5ac08b0b8"/><file name="Vote.php" hash="4cc3b62377628d468f70de60c7225838"/></dir><file name="Poll.php" hash="5af07cffe3ab1047d194a88db092bb35"/></dir><dir name="Poll"><file name="Answer.php" hash="9ee53f75ee1cb0730a56bab3ca65b051"/><file name="Vote.php" hash="bdde76ff3dc7fa32a2a34aba8bbf0cee"/></dir><file name="Poll.php" hash="04c789d42b6b6195e760d641869a5c9d"/><dir name="Resource"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="ad2c1626fa1a4efb5b6b7cc8f8a87299"/></dir><file name="Answer.php" hash="d54f1545c087c996dc4cc8265935efec"/><file name="Collection.php" hash="1f92a6035921131de16b08c77f16a15d"/><file name="Vote.php" hash="3556ee4ac6bc5c48ec5b46ff3c229a13"/></dir><file name="Poll.php" hash="79cc676bf96e3eea566be1b271155ca1"/></dir></dir><dir name="controllers"><file name="VoteController.php" hash="75a4dc065025244db68fdde35dc27b23"/></dir><dir name="data"><dir name="poll_setup"><file name="data-install-1.6.0.0.php" hash="81bc077023380193b961ae812b755e28"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="bebf784876fa408411acba8347fd07c3"/><file name="config.xml" hash="fbe5e0b634f3890830c99d1e19571fa4"/><file name="system.xml" hash="fee2ec0817191ecc52699b6bef1cf5bc"/></dir><dir name="sql"><dir name="poll_setup"><file name="install-1.6.0.0.php" hash="517679e2f811306884b81b50f1ff9153"/><file name="mysql4-install-0.7.0.php" hash="e7e4bad7b4e74accd4ebb402f2d0aeed"/><file name="mysql4-upgrade-0.6.0-0.6.1.php" hash="58897150966041bfc0e59485b3f03712"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="61d60cfd460cf5bebd9937631fb99985"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0f5c35f33dc93513a5f795502a7256c3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="5d4d2334726cb8f948f6b9ed8ef48405"/></dir></dir></dir><dir name="ProductAlert"><dir name="Block"><dir name="Email"><file name="Abstract.php" hash="d4584e39cf64f1519770dc136c4ed161"/><file name="Price.php" hash="c696a8a63f39e8a52d2e79fdded85022"/><file name="Stock.php" hash="ca4bf9d8aa0e94555fe07717d143ad30"/></dir><file name="Price.php" hash="ebe9e1281e2bdabe74dfb394a0847220"/><dir name="Product"><file name="View.php" hash="eadba6f14baa5ec9809405b19c6df677"/></dir><file name="Stock.php" hash="9fbb5d57defc5b98978cff84db56b362"/></dir><dir name="Helper"><file name="Data.php" hash="41646f457da8ca144d27aaf0a6f92b6c"/></dir><dir name="Model"><file name="Email.php" hash="a9fb2a4d7235b1d68dfcd57b81cfe148"/><dir name="Mysql4"><dir name="Price"><file name="Collection.php" hash="88a48bedb0107bcd757e7aaac39a6f62"/><dir name="Customer"><file name="Collection.php" hash="5943e6821711e0e9e0266e0b415c467c"/></dir></dir><file name="Price.php" hash="a91bce1d6069a5c25e6dbcbd8f9bb8b2"/><dir name="Stock"><file name="Collection.php" hash="e2af3546fff475cde3bb9df4cc5e2578"/><dir name="Customer"><file name="Collection.php" hash="e11445992cd1db1bb3f4935d3c5794b5"/></dir></dir><file name="Stock.php" hash="eebeb5ce217c58b557f10eda30911313"/></dir><file name="Observer.php" hash="d1c3f4359a48e887c91ad80791f7db36"/><file name="Price.php" hash="c96bd123fb217872e6f24fb1414c710a"/><dir name="Resource"><file name="Abstract.php" hash="2544041fe5c5be4af7a084afdfdd228c"/><dir name="Price"><file name="Collection.php" hash="e3cc13eb4fac8731b1da5b82b3adc3b7"/><dir name="Customer"><file name="Collection.php" hash="30a328daac7a1dff800060817b47f299"/></dir></dir><file name="Price.php" hash="ecc8828fb2d20b0d4ab06861c987694a"/><dir name="Stock"><file name="Collection.php" hash="1c5d42dbe9c792490dd89928aca889e4"/><dir name="Customer"><file name="Collection.php" hash="f81d09b722478c8ea10f507bea29e889"/></dir></dir><file name="Stock.php" hash="db05538712e2f718318195ac5a4e69d3"/></dir><file name="Stock.php" hash="3f5bd3faf55a0978fe76958ea5592642"/></dir><dir name="controllers"><file name="AddController.php" hash="967cdb1b04d2c534c222232be1346613"/><file name="UnsubscribeController.php" hash="fd8b03509b6c9ca09ad802504c1994d8"/></dir><dir name="etc"><file name="config.xml" hash="8c76943b68ac296be813ba5fd7249c15"/><file name="system.xml" hash="8b462f95ac48ac5350d3aad9bb3b0324"/></dir><dir name="sql"><dir name="productalert_setup"><file name="install-1.6.0.0.php" hash="0241d37ef70e2a735100a50cd07164af"/><file name="mysql4-install-0.7.0.php" hash="1b86eaa23d5d830e157515c848c2bc66"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="1c2c5e094b3773c400177de03e13fdbd"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="18bbf5de2c4f24dcb6dbfff25ab9db8a"/></dir></dir></dir><dir name="Rating"><dir name="Block"><dir name="Entity"><file name="Detailed.php" hash="c337400133e34ad71b6857e4cb9dc7aa"/></dir></dir><dir name="Helper"><file name="Data.php" hash="aa08b748843d918a4f64801a34fb1155"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Rating"><file name="Collection.php" hash="bf5daff55dfd9638ad4068100e9f9801"/><file name="Entity.php" hash="2b8b613f66fb4f0d194530a2e041f90d"/><dir name="Option"><file name="Collection.php" hash="bc1d8b91473af46272fd5ad54d974072"/><dir name="Vote"><file name="Collection.php" hash="b7a023cb71d55d3bcb1ad4c4f71b1eb4"/></dir><file name="Vote.php" hash="88291cb4df65fb6305440350a1e1d569"/></dir><file name="Option.php" hash="e061db0760437a11256d92612ac599f9"/></dir><file name="Rating.php" hash="3b873eddd0c4d3f94274ba13c76f30bf"/></dir><file name="Observer.php" hash="2b1375aadc070ee4dc237b5ee0bbc626"/><dir name="Rating"><file name="Entity.php" hash="e92cb9b2f7d48d365bd58a2a579bb115"/><dir name="Option"><file name="Vote.php" hash="a7ee8de255dd46e91c1aa2d412cb4b22"/></dir><file name="Option.php" hash="c1b61fdc362c81d9a838b301a4307f47"/></dir><file name="Rating.php" hash="53a1e432211ada9a75b7b19016f8e154"/><dir name="Resource"><dir name="Rating"><file name="Collection.php" hash="f5d06f8dbc8a3f5bd10da9c6c6ba3fdc"/><file name="Entity.php" hash="5d7027e01a7c430c159064c74f957502"/><dir name="Option"><file name="Collection.php" hash="f9ac2b03c8abdc7b4728c500948923a9"/><dir name="Vote"><file name="Collection.php" hash="fde61681ae5f8d35e2f6777fb4303e77"/></dir><file name="Vote.php" hash="bf1e516fc97e7266a07cd0cf1f2ef398"/></dir><file name="Option.php" hash="c5072273eb4611d4c7f93873801433f5"/></dir><file name="Rating.php" hash="b67c23b781c0971d2a196d070923a466"/></dir></dir><dir name="data"><dir name="rating_setup"><file name="data-install-1.6.0.0.php" hash="12900433b5a26cbe769bde7ddc66f2e6"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="74579ad431dac104175d33ff02c10822"/><file name="config.xml" hash="2cdae0e1ff2a7e3a63dd7c42805fdb1d"/></dir><dir name="sql"><dir name="rating_setup"><file name="install-1.6.0.0.php" hash="b957611e9c176b0800c472f7d51a73e2"/><file name="mysql4-install-0.7.0.php" hash="a4263d1dacf3e8ea82371fc2aa00288d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5b2fda173988176fc92e242667b48a76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0903ea1ed5a6fc1a926dce7d7c0c3a34"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="221a4e86db85c68e5b5e7a3db40f59b3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="366c0d1c4af6b53d486505665270ad7f"/></dir></dir></dir><dir name="Reports"><dir name="Block"><dir name="Product"><file name="Abstract.php" hash="9381d2f3817997e6b12bf6d1fb59a571"/><file name="Compared.php" hash="9401b0b87c2bcbbffafb8d27bf7160ac"/><file name="Viewed.php" hash="5cc5ea78c4dada735baa33fa470c99f3"/><dir name="Widget"><file name="Compared.php" hash="35b6e1c66895d7e5f972827daf8345cb"/><file name="Viewed.php" hash="e5ec75a90229bc827323e0101ddf1a99"/></dir></dir></dir><file name="Exception.php" hash="608a94b2ffadf371f1b5a92df71441fa"/><dir name="Helper"><file name="Data.php" hash="2808507ba066be921f54fade9f7f7360"/></dir><dir name="Model"><file name="Config.php" hash="8ac452add42e1efa4653842fb351bb06"/><dir name="Event"><file name="Observer.php" hash="38c5a6b2f62648efc5bd900c804f1131"/><file name="Type.php" hash="1bd1bee7108cdf48005b522da3b4e5c1"/></dir><file name="Event.php" hash="b1a4de5241ff78cd457fcfb25cf50b1b"/><file name="Flag.php" hash="74831f5918109873c14eb9bdcef76419"/><dir name="Grouped"><file name="Collection.php" hash="8adb854bcd467bca3afc6a932c61024f"/></dir><dir name="Mysql4"><dir name="Accounts"><file name="Collection.php" hash="6384e2c0b0d981921ec0b04178008278"/></dir><dir name="Coupons"><file name="Collection.php" hash="a8a142a4a3c3b6a34e8938b2cad17c6e"/></dir><dir name="Customer"><file name="Collection.php" hash="41d4be8a6c9daae9f5bb7dea2e4d3137"/><dir name="Orders"><file name="Collection.php" hash="99d08265d68e69bdb7eec18c65fa6ea5"/></dir><dir name="Totals"><file name="Collection.php" hash="e2440c39383c54276dc5122651ece92d"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="10850a1bb4d3106d61a97c35f3e72b35"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="f5a8b4cd57f1cad485ad148902e74a34"/><dir name="Type"><file name="Collection.php" hash="52b034d02ac4fee39387ebf6afa30a16"/></dir><file name="Type.php" hash="4e168e5eb91c2357424e1c59ba48db6f"/></dir><file name="Event.php" hash="f8485c5e772ce4820d914a2d430c598c"/><dir name="Invoiced"><file name="Collection.php" hash="b55329ae04cba3ecc78633ae1666624b"/></dir><dir name="Order"><file name="Collection.php" hash="7c9906ac0c28aca240db23a70d7aaf14"/></dir><dir name="Product"><file name="Collection.php" hash="5e2511ee63229e9c481701d3e8ea81bd"/><dir name="Downloads"><file name="Collection.php" hash="a7a59e694fdd839bd5e7c95f1034ed6d"/></dir><dir name="Index"><file name="Abstract.php" hash="8351ce388ded1083578edd5b61697b30"/><dir name="Collection"><file name="Abstract.php" hash="ec2f7042e58fe0d135e2fc22880006ea"/></dir><dir name="Compared"><file name="Collection.php" hash="95153672ccc9044236c7220e3805f864"/></dir><file name="Compared.php" hash="f9a0ab36e1d389b869057426ce5757a6"/><dir name="Viewed"><file name="Collection.php" hash="f84f3c7fb46a5976a1e676355efd41f8"/></dir><file name="Viewed.php" hash="ee216881da4db2c3e0578768749240b3"/></dir><dir name="Lowstock"><file name="Collection.php" hash="129cda12e29ee74730dcd9f00f280309"/></dir><dir name="Ordered"><file name="Collection.php" hash="8a04b617e9c1a99aa5e632044079f1f8"/></dir><dir name="Sold"><file name="Collection.php" hash="2423be35980f9f6ee1684a6c52862a83"/></dir><dir name="Viewed"><file name="Collection.php" hash="7a65fa98452f67e8ead531b27c4ec7c7"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="4f412c1b59c80f980c2758b04800aaa9"/></dir><dir name="Refunded"><file name="Collection.php" hash="272cc7c309b60ced27a8bf05e4732a21"/></dir><dir name="Report"><file name="Abstract.php" hash="9074336e20298296f48160e7d4e7f88c"/><file name="Collection.php" hash="5981974079e5479aa0eb59977617bdb8"/></dir><dir name="Review"><file name="Collection.php" hash="b19a21cd5373bd77b4508236fc175a63"/><dir name="Customer"><file name="Collection.php" hash="9c7cced8de4d055915d4d94bd5a86571"/></dir><dir name="Product"><file name="Collection.php" hash="b84410ab5000133b9bf3b9e819993641"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="5bc46c5198f98b78d50da2387c58b368"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="5d45215574659235c1e54b01fffec62c"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="7df40ab2b4df1591c691e1eee5ffafb1"/><dir name="Customer"><file name="Collection.php" hash="08398ac0f332002c23d326ec580e2a05"/></dir><dir name="Product"><file name="Collection.php" hash="911eb9cc4fe1c260a1cb6c2b8f6d1623"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="667d111f18687a46988da9b17290c929"/></dir><dir name="Wishlist"><file name="Collection.php" hash="8e57527ad0cf1166cc7e4559a67ab727"/><dir name="Product"><file name="Collection.php" hash="de66493523d35c12fcd0a3ba31a652b6"/></dir></dir></dir><dir name="Product"><dir name="Index"><file name="Abstract.php" hash="354eaa0207964474411899338d9b9585"/><file name="Compared.php" hash="019eb677e0a89b1770cdb5c077330c7d"/><file name="Viewed.php" hash="9095d81fcc6cc892cb67709beac5aeb3"/></dir></dir><file name="Report.php" hash="f5dc6494cff99fb052875b882b702fb5"/><dir name="Resource"><dir name="Accounts"><file name="Collection.php" hash="ac257f532f927cc28943690e7fc8ba6a"/></dir><dir name="Coupons"><file name="Collection.php" hash="5abde4f7b922579e593b868d76c4ca5b"/></dir><dir name="Customer"><file name="Collection.php" hash="ba5e14a4cf75c59ed5baf2099fa2f1d2"/><dir name="Orders"><file name="Collection.php" hash="60dd7f21909c02a2bc1c8d60c6cbf481"/></dir><dir name="Totals"><file name="Collection.php" hash="b91fbcadb349f8762f45a9f8a53547e2"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="1136c8a67e6a1057b17476d0c7d85966"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="ac353d066d90d4c6f25f2e8770e9247d"/><dir name="Type"><file name="Collection.php" hash="8382b58a7462573c16432e0445d76d4b"/></dir><file name="Type.php" hash="3cbccf5eab8cde3bbda74004cefcc618"/></dir><file name="Event.php" hash="0a692a6a09ffc5fdb317d2cff1385291"/><dir name="Helper"><file name="Interface.php" hash="eb1b4518956d271e57dfca77652960ee"/><file name="Mysql4.php" hash="45f718471263a3d85b823488046944ed"/></dir><dir name="Invoiced"><file name="Collection.php" hash="5e7bf13e329243d88d2ce5572eb7f43c"/></dir><dir name="Order"><file name="Collection.php" hash="c961a023b52f2fc6ea28ff161bbe0967"/></dir><dir name="Product"><file name="Collection.php" hash="ed3780d956f83154f218e62970414c4e"/><dir name="Downloads"><file name="Collection.php" hash="641329ba2982601f084b07b8693b2871"/></dir><dir name="Index"><file name="Abstract.php" hash="88e2dc2b27500d435b8e22280943efd1"/><dir name="Collection"><file name="Abstract.php" hash="71630411364a2552ac383b63e0fbf831"/></dir><dir name="Compared"><file name="Collection.php" hash="696b12dd05e1f0d23a7e3a75949ce668"/></dir><file name="Compared.php" hash="f5dbc6ea9aa23b8fac130be6bacc2ee4"/><dir name="Viewed"><file name="Collection.php" hash="636cf44005f888d8bb62b07f9eb6e370"/></dir><file name="Viewed.php" hash="95171e2b6d01fa477231c9f427307ccd"/></dir><dir name="Lowstock"><file name="Collection.php" hash="8e1d09a3d67337acb37305948a37f7ae"/></dir><dir name="Ordered"><file name="Collection.php" hash="9efdf0700de6cab7243a7a88c20a1559"/></dir><dir name="Sold"><file name="Collection.php" hash="5e3d829af728da0bde83e50d9b581dcc"/></dir><dir name="Viewed"><file name="Collection.php" hash="481d4fa98830ab3f42cee09a2c9aaee0"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="9f3b12f7d20632fbd52dcc33ba37a467"/></dir><dir name="Refunded"><file name="Collection.php" hash="66e1f3f5767dbe8833f3e15d3636468e"/></dir><dir name="Report"><file name="Abstract.php" hash="d67e66718893814b9659b0e9ea8b3e6a"/><dir name="Collection"><file name="Abstract.php" hash="f604fff5aca66711811461d9824fc1e0"/></dir><file name="Collection.php" hash="5fcde9791b16799d130e54ac1819dcb0"/><dir name="Product"><dir name="Viewed"><file name="Collection.php" hash="09cd77b4152936ffb6c807f786207077"/></dir><file name="Viewed.php" hash="99cffde7efbb7cfd449505f83b843b06"/></dir></dir><dir name="Review"><file name="Collection.php" hash="da8c3edf5aed4c1cf2bc5109ec3f1ec5"/><dir name="Customer"><file name="Collection.php" hash="2839e9b309c2750b569d64b872e02dcb"/></dir><dir name="Product"><file name="Collection.php" hash="9edc35ef7f987d4fcc89a88ed501e5bb"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="17cb03c7cc5109b4a6f99610a60dbb22"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="44dcf5437f060c0ed58efaba9d16d665"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="cfd6e0454369ff72e419bc232ac3dedf"/><dir name="Customer"><file name="Collection.php" hash="11d7ae7f503e1272fd80face588c543d"/></dir><dir name="Product"><file name="Collection.php" hash="6f2a8754391eac9cd12f0510bccb0853"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="34cf644c296e126f26d20ee0d86e3520"/></dir><dir name="Wishlist"><file name="Collection.php" hash="3389d8396885176702e0b5ac2bef8de1"/><dir name="Product"><file name="Collection.php" hash="965402449bb92e67c3addcec8b2dda62"/></dir></dir></dir><file name="Session.php" hash="c318347dd17ef625e851fe821f59a037"/><file name="Test.php" hash="1c65ee41eff9c26a65ba571d1036282c"/><file name="Totals.php" hash="9a52631051f75ea9436b42febf8c5373"/></dir><dir name="data"><dir name="reports_setup"><file name="data-install-1.6.0.0.php" hash="5d87abb48aedfc1019383ba77ae9d424"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="ade02826599b06c791beb38e752a0a54"/><file name="config.xml" hash="50bc806c9348a42d1413533d68ec4ccf"/><file name="system.xml" hash="2404876dca1c4a1dbc45ea99d0e143aa"/><file name="widget.xml" hash="87134e1fe691d2bf377ef3159e043329"/></dir><dir name="sql"><dir name="reports_setup"><file name="install-1.6.0.0.php" hash="dc8d574c567ff98a0c27768b2f721342"/><file name="mysql4-install-0.7.1.php" hash="6058a42394e2a6d1f3884d08b01d036a"/><file name="mysql4-install-1.5.0.0.php" hash="ad670ce1011e84d3027a29458499603b"/><file name="mysql4-install-1.6.0.0.php" hash="08c55d04a829df9b1bfced10dd7abdb6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ed4fa0f6004262fe49db95861e721c06"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="16440bfbbc893acaa2ff39192c639690"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="e4d91582c78cf488b6762b8c02452319"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="085cc5b0cffb7c3ae5bd087648ad519b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="47e81be68ed4a18b2a6f72c18dca7d5e"/><file name="mysql4-upgrade-0.7.5-0.7.7.php" hash="e056f1c250f5a831587539c10b533f80"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="8edf4a8b3eb12800e15c7f829747267c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2a2af08d7a93fec5d949c9fe52d69fcc"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="beb5107a2beb2b4f8c23495b4751fbdf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="020dd3cc9ea0a3a47db93fef4bc2cf78"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="989fba539a23d744efe24bf3bbe1f704"/></dir></dir></dir><dir name="Review"><dir name="Block"><dir name="Customer"><file name="List.php" hash="75258599abbf2981862edf563aa80e24"/><file name="Recent.php" hash="1a913d3169511e51882470cd0d5c8853"/><file name="View.php" hash="24b8876f7614500ceee5695de6c0171e"/></dir><file name="Form.php" hash="578aa1bb652f5a4cc1acbbd3dbc8bf67"/><file name="Helper.php" hash="e0f2826aba59b1fadc3a3e98cbb45db2"/><dir name="Product"><dir name="View"><file name="List.php" hash="a1ef1ac325677b79f7bff957e3940867"/></dir><file name="View.php" hash="47e6c007eb6e024c888289c9350420c9"/></dir><file name="View.php" hash="c2c3227084a3c4d5dd1a380b926d2582"/></dir><dir name="Helper"><file name="Data.php" hash="cde72b775603ee4b6d144baf55d4d0b2"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Review"><file name="Collection.php" hash="36e926d673bcce527ab001ef75ac6d59"/><dir name="Product"><file name="Collection.php" hash="c57f813e17f672eab2bf5f4f33157b3e"/></dir><dir name="Status"><file name="Collection.php" hash="d79e8912b6077609e6bcd7f939c40c70"/></dir><dir name="Summary"><file name="Collection.php" hash="712e89eda07241326bd73eba5cfce3ee"/></dir><file name="Summary.php" hash="a19372cb153ef832ec65c799f30f8fd5"/></dir><file name="Review.php" hash="be633fb27d76ae1805b218e8e2dfa4f7"/></dir><file name="Observer.php" hash="f2fb97c8b99a01000322c87e8b506209"/><dir name="Resource"><dir name="Review"><file name="Collection.php" hash="f187a2386bace27e55ea8caf311b9f6e"/><dir name="Product"><file name="Collection.php" hash="12961346f71a630ecfefd64f7e6eeae5"/></dir><dir name="Status"><file name="Collection.php" hash="dd5a3e9a6e99ecb95d9946a1a161b46e"/></dir><file name="Status.php" hash="62b11d858f207ba1b81fbf9a86e47d7f"/><dir name="Summary"><file name="Collection.php" hash="292ec5a712b7f3bbcce63a8d8a0de40e"/></dir><file name="Summary.php" hash="2f46abb517f3f4b4c9a72f0055827bbb"/></dir><file name="Review.php" hash="b1432744f6df1fd38df903080602cc44"/></dir><dir name="Review"><file name="Status.php" hash="bfa530e158e2a41abad88448a5cfa75d"/><file name="Summary.php" hash="195a6570b452f499010b89aa29f43117"/></dir><file name="Review.php" hash="32401cc14dc04763601bca8aef509241"/><file name="Session.php" hash="f53a5a0528a2d93ac879b4a0a43e626f"/></dir><dir name="controllers"><file name="CustomerController.php" hash="8ad4aae4ebf43ba61a20be80c3ba971c"/><file name="ProductController.php" hash="944b7de015c7b693aa633a0967ac8012"/></dir><dir name="data"><dir name="review_setup"><file name="data-install-1.6.0.0.php" hash="36aae8d61319eef243cd891db00a91e2"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="643914e5212e3f7fa45185b5261eb6a8"/><file name="config.xml" hash="748472a893d4fb83fb1a1f327342607a"/><file name="system.xml" hash="a45dcfcb2a455add5f1204551109a3c6"/></dir><dir name="sql"><dir name="review_setup"><file name="install-1.6.0.0.php" hash="9bffc27b2df8f5d8b31da8b1130b659f"/><file name="mysql4-install-0.7.0.php" hash="63f50ba59bcd3126e2035b564c148fde"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="345e05077ab1f31240cbd2a97ed65c02"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="4aa3caf337afd47178a7723f7c7c1417"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="4cf527e131117f1b4cecf3c8d4101744"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="dc9e6a7b04391d3aff8b1d0e9a8d2e96"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="7260cb9368214b9ec23e6cef126978d7"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="324a8629ce44e1630819999498b198af"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="897902ad56188bb2119eb082e64f5465"/></dir></dir></dir><dir name="Rss"><dir name="Block"><file name="Abstract.php" hash="78b1e316fa251bd9072e370c69671bab"/><dir name="Catalog"><file name="Abstract.php" hash="0c04f1d3b359467765db675efbdb8db5"/><file name="Category.php" hash="639e02c0987dcae62f5767bf19014764"/><file name="New.php" hash="cc0b203243fa96d7205287276722dac4"/><file name="NotifyStock.php" hash="6dec5508cce929a912eb1d62784894fd"/><file name="Review.php" hash="a2d3ec4e7237a7ea9bff9543439e6b0d"/><file name="Salesrule.php" hash="935c030eb4e0e7e78ed606f3c4762154"/><file name="Special.php" hash="2ad46b236308cf322ea230c2dad2cdcb"/><file name="Tag.php" hash="1569866597c7998a8df5795c4655654a"/></dir><file name="List.php" hash="4cfbf0ecee48a0b3aea463e087f98522"/><dir name="Order"><file name="Details.php" hash="2ad732aa559d4378096c344e45ac8739"/><file name="New.php" hash="236c63a10c0b4fa74b3b93d89c0e58d1"/><file name="Status.php" hash="814d72fab5555894ec00e4233731249a"/></dir><file name="Wishlist.php" hash="0e41bb7a1d52eb4b292267ada80d1a85"/></dir><dir name="Controller"><file name="Abstract.php" hash="800fef71c54dbaa4ee5d14def6ad374c"/></dir><dir name="Helper"><file name="Catalog.php" hash="72b3e51589b9a45c4b79624e2e9e63a8"/><file name="Data.php" hash="784c8bbf33cb18724bb2e89376a6d3f9"/><file name="Order.php" hash="db4a311a8a8e449e551dfef72d49bb19"/></dir><dir name="Model"><dir name="Mysql4"><file name="Order.php" hash="a714c74aa9b2b08eaa25025ed8bae861"/></dir><file name="Observer.php" hash="91f50bed4e811ba74dfe1b6706fe88c5"/><dir name="Resource"><file name="Order.php" hash="06e83d676c21c78a978c5204eb299999"/></dir><file name="Rss.php" hash="b82ec9f4706f3cd88e47d44c69148107"/><file name="Session.php" hash="88190872a65a7b8cc6c0f97b87117fe1"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="77af8de35a234eca3f85eb3eab1c74c3"/></dir></dir></dir></dir><dir name="controllers"><file name="CatalogController.php" hash="b0f5ff39a3ea319af8f1cb7dc72c64f5"/><file name="IndexController.php" hash="4aa833fe228b6f1347f0f03c3b0e3968"/><file name="OrderController.php" hash="4a78ace5090f6e43da34a47bde93f05a"/></dir><dir name="data"><dir name="rss_setup"><file name="data-install-1.6.0.0.php" hash="4a3e745f2b06780b810168f41e465fbb"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="719cc211ae152410041b215441302c96"/><file name="config.xml" hash="670a8d9348a1b9e5b5507713df1d8c87"/><file name="system.xml" hash="9992a900459d27147cb07a3617340659"/></dir></dir><dir name="Rule"><dir name="Block"><file name="Actions.php" hash="6610fb70932429b38248d2a2cb64833c"/><file name="Conditions.php" hash="ce8574b771220536f394089ee2beb6f6"/><file name="Editable.php" hash="cde8b6b2ba9a6d446813f5add9d50ec9"/><file name="Newchild.php" hash="d7c60ffcfac3a6019e08d30ef1d513dc"/><file name="Rule.php" hash="051685923b2392615c1594414c87fc98"/></dir><dir name="Helper"><file name="Data.php" hash="805f12fa0f9b45188625c45b682d0059"/></dir><dir name="Model"><file name="Abstract.php" hash="15333fa84757f9392b98ed5c0bd8cd8f"/><dir name="Action"><file name="Abstract.php" hash="337ba9c8479e1f8608137d0d4406c947"/><file name="Collection.php" hash="8373977869aae94fed30607913586599"/><file name="Interface.php" hash="a303f317f385252e6e394e99d4bb35c1"/></dir><dir name="Condition"><file name="Abstract.php" hash="1f683530e9348e26a9413f9bbb978b3e"/><file name="Combine.php" hash="c12fe8c3c64a58eedf81c9c9d54e0546"/><file name="Interface.php" hash="4e255c250a249f3c71fd5e0ad51fdce7"/><dir name="Product"><file name="Abstract.php" hash="befc50797a7c2ffa464a389cde6208a1"/></dir></dir><file name="Environment.php" hash="e01cb8bcbed1e56dcc51a42c9c15a5bc"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="c62062f2104b04e8f42da83bdd7fb630"/></dir><file name="Rule.php" hash="923f75b95afee693b39d8024acdef931"/></dir><dir name="Renderer"><file name="Actions.php" hash="cd8b6ec25840af7dac2ba99414c4a93c"/><file name="Conditions.php" hash="ca49f7b765b420cd490f2219cf8fb602"/></dir><dir name="Resource"><file name="Abstract.php" hash="d412ec94e493e31b0d052686f9fc5741"/><dir name="Rule"><dir name="Collection"><file name="Abstract.php" hash="aaa0a5c1b5db55160f9b6d78b3bfa45f"/></dir><file name="Collection.php" hash="69a1dbbf809f3a956c60006688ef46e7"/><dir name="Condition"><file name="SqlBuilder.php" hash="2bfce51eaf1077c49eb14b010e72607a"/></dir></dir><file name="Rule.php" hash="60161377f1ba79604a8385ade41b5ec7"/></dir><file name="Rule.php" hash="ee5ca4e39044fac00f020c1850c88e16"/></dir><dir name="etc"><file name="config.xml" hash="0308eb30269e8277974478f8b6f8801a"/></dir></dir><dir name="Sales"><dir name="Block"><dir name="Adminhtml"><dir name="Billing"><dir name="Agreement"><file name="Grid.php" hash="fef66ee16f00b29c84027c10aba81a52"/><dir name="View"><file name="Form.php" hash="1a86a3173f4d954b0c585a03f1f8a041"/><dir name="Tab"><file name="Info.php" hash="7dcce2f205c6f2da7a2383bed74760ed"/><file name="Orders.php" hash="9da38e7f7d07a4a8c6613924f8ed209f"/></dir><file name="Tabs.php" hash="bf8f53c4af65b488ec7d1b248088609f"/></dir><file name="View.php" hash="b8bf13cce32b6e719c7f87843f7a2a7b"/></dir><file name="Agreement.php" hash="4083da4fe5031bb1d0b8287912e1c82a"/></dir><dir name="Customer"><dir name="Edit"><dir name="Tab"><file name="Agreement.php" hash="a65e2d4a78d1006988d708b34d8cdad0"/><dir name="Recurring"><file name="Profile.php" hash="78ef77388e6c8ffc9bea8bd47a87d57d"/></dir></dir></dir></dir><dir name="Recurring"><dir name="Profile"><dir name="Edit"><file name="Form.php" hash="9279e2d6dbae446d2cb949f773a88211"/></dir><file name="Grid.php" hash="0d32af9ab885a9df05ac6f5eb6f339b2"/><dir name="View"><file name="Getawayinfo.php" hash="b9f496477acceadfd22adf5639854e57"/><file name="Info.php" hash="c525974a9aa0487e294eabca4f5b4113"/><file name="Items.php" hash="d0a4335bf5e22e83a1c75d59d100de86"/><dir name="Tab"><file name="Info.php" hash="4e895b956b76697afe0721b8f7c4e8ea"/><file name="Orders.php" hash="e1f95a70f025194e0d550daa520a8f14"/></dir></dir><file name="View.php" hash="b307b50baa307fc74e0f4b6c8a3219e7"/></dir><file name="Profile.php" hash="95f367babe1d664f0d6bac9fb07b7df0"/></dir><dir name="Report"><dir name="Filter"><dir name="Form"><file name="Coupon.php" hash="42d5d95abc0c3fe1817253a86e0c013c"/><file name="Order.php" hash="f4177c41f2f0d34a4124ae04fc91e619"/></dir><file name="Form.php" hash="b9b8ac502065c6f95a7a6b155284319e"/></dir></dir></dir><dir name="Billing"><dir name="Agreement"><file name="View.php" hash="34806b08430353c0c752c67573239728"/></dir><file name="Agreements.php" hash="149bc6329618f80fa1c82f614abc8fa3"/></dir><dir name="Guest"><file name="Links.php" hash="fbf86ecd7a9c3faf3e238a15b364cadf"/></dir><dir name="Items"><file name="Abstract.php" hash="6423bc55cc7e7c5aaeac666743f81b42"/></dir><dir name="Order"><file name="Comments.php" hash="a033815154ae896efc6e6947a109ff6c"/><dir name="Creditmemo"><file name="Items.php" hash="d9409c330900ac3fd50a6e0b6573d8a9"/><file name="Totals.php" hash="f97a4c171b571bbf4c999d07d29fd716"/></dir><file name="Creditmemo.php" hash="33b366b6894ecaf805a021c97a7ddba1"/><file name="Details.php" hash="9e117a5f8963fc689bfd34f6fbc57390"/><dir name="Email"><dir name="Creditmemo"><file name="Items.php" hash="c3abe3d0f0bafbc0f8a02167f60315aa"/></dir><dir name="Invoice"><file name="Items.php" hash="f122cb0a8c0909415883094ebaa76d1f"/></dir><dir name="Items"><file name="Default.php" hash="393e76596db55f0cab3db8622df19464"/><dir name="Order"><file name="Default.php" hash="d71a2b453dfd0f288694fb7a35610ad1"/><file name="Grouped.php" hash="7d18cecbcee39d9fd29befc8cc10ff12"/></dir></dir><file name="Items.php" hash="7b721ab6a462b662304b8d79e077df6c"/><dir name="Shipment"><file name="Items.php" hash="ec02e251e375e75f899d517a22aa44a8"/></dir></dir><file name="History.php" hash="174769627458bd9e71f9d8318c77a4cb"/><dir name="Info"><file name="Buttons.php" hash="04c841c1f16a53a09c6fe0b7ee4c495d"/></dir><file name="Info.php" hash="f48808e8c857b62578d75666964f59bd"/><dir name="Invoice"><file name="Items.php" hash="e836090b717d386e2938652a690d410a"/><file name="Totals.php" hash="585c8b5346a6a881f651ae2c85d960cc"/></dir><file name="Invoice.php" hash="061c0fad24390ee4fab4531721196b6e"/><dir name="Item"><dir name="Renderer"><file name="Default.php" hash="cbdc1858cc4c72c35f1fb6d3b0306f84"/><file name="Grouped.php" hash="7934d30462776f4eaa056cbb59f42559"/></dir></dir><file name="Items.php" hash="6f0636e12a64c5212f26f928711046e0"/><dir name="Print"><file name="Creditmemo.php" hash="02f0f0fa58e7441e59944ebb88264719"/><file name="Invoice.php" hash="e54128f7afc117787aa623a4d0b8af00"/><file name="Shipment.php" hash="35380109c64056fbe0ecc004a103d579"/></dir><file name="Print.php" hash="878669c71c801bd08cb288fbff97c93a"/><file name="Recent.php" hash="33fca43621bc85a175f50ba238c73376"/><dir name="Shipment"><file name="Items.php" hash="622048f99d9f7e266737d3ff52227de2"/></dir><file name="Shipment.php" hash="f77ffdd6745c19c233da4c733c5d3abb"/><file name="Tax.php" hash="16083f37a2591b8f488f5ae3a9cc3a1b"/><file name="Totals.php" hash="03225737c81193a65bb8580e81f3e847"/><file name="View.php" hash="850fd65e3a39b1876100de48ea2541a2"/></dir><dir name="Payment"><dir name="Form"><dir name="Billing"><file name="Agreement.php" hash="cd0b1ff96a419f14dcd7b0ff321724d3"/></dir></dir><dir name="Info"><dir name="Billing"><file name="Agreement.php" hash="3214efb275f83c788f5efc31b582ebaf"/></dir></dir></dir><dir name="Recurring"><dir name="Profile"><file name="View.php" hash="6b22675cfefa43d6f1733648b7985630"/></dir><file name="Profiles.php" hash="3ad863e0afda8cf52abb65bd0db1d5d3"/></dir><dir name="Reorder"><file name="Sidebar.php" hash="46a27506c5829e0542ee45aab3ca0672"/></dir><dir name="Widget"><dir name="Guest"><file name="Form.php" hash="c2967b98e93ab61a7a094d7b5284c078"/></dir></dir></dir><dir name="Controller"><file name="Abstract.php" hash="1f0ffd7a63f093d9164432d5d6b24a7b"/></dir><file name="Exception.php" hash="b2c312840dbc62b8dbc7723b3c7a42b1"/><dir name="Helper"><file name="Data.php" hash="1004e1652fa50e93a21e8a58823141e0"/><file name="Guest.php" hash="d35fedc9902ec64bbba80052187f48a6"/><file name="Reorder.php" hash="7092ac100d733a48a6b2c3a68cbb7cce"/></dir><dir name="Model"><file name="Abstract.php" hash="07efb83eb2281c9abadc549f84df6c56"/><dir name="Api"><file name="Resource.php" hash="6bdd0361747d25ca846832c96a749eef"/></dir><dir name="Api2"><dir name="Order"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8f1aba6fae933a2b4bd6e3bd4f6c5389"/></dir><dir name="Customer"><file name="V1.php" hash="efad7a521ba151226ef438fe30405d6e"/></dir></dir><file name="Rest.php" hash="54c33502d2bfec77aa5735f0e8f23a5b"/></dir><file name="Address.php" hash="51702d27c5eefb9219ae08303b7f98fe"/><dir name="Comment"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="f2c0511ff538c27f5eab792c05792759"/></dir><dir name="Customer"><file name="V1.php" hash="73f856dcdaf15db656a80b533bcf0b4f"/></dir></dir><file name="Rest.php" hash="e2baaffd28d5ee0ea25418b0a7375387"/></dir><file name="Comment.php" hash="6c2b51994d77f1dbba28592e393c131b"/><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="fdb4f6c87f633b80e9a733503209041e"/></dir><dir name="Customer"><file name="V1.php" hash="f6bec0def4d992e1207aca7dfc267912"/></dir></dir><file name="Rest.php" hash="4d34daf2e2f0fa6a6685f1e0083d70e3"/></dir><file name="Item.php" hash="989a4f2e3ce1cee2666bc91894ed4c71"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="080cbf5d63dfdb0fa74615ccf9f16c46"/></dir><dir name="Customer"><file name="V1.php" hash="ca9b754da5e11e2ab7449d2a8bdc8e00"/></dir></dir><file name="Rest.php" hash="b129022f37d1dfbe3fd34e17de97ca3a"/></dir><file name="Order.php" hash="bf8448d9cbd2b1ae4dc776d05f91e73c"/></dir><dir name="Billing"><file name="Agreement.php" hash="dc3110bfcd5aa6a10ff5881d7fbb670b"/></dir><dir name="Config"><file name="Ordered.php" hash="39b93b978aa3db28068ef8ddd33fd1a5"/></dir><file name="Config.php" hash="648e93992a3d7a83147332be1b3e86ba"/><dir name="Convert"><file name="Order.php" hash="bc2f1e45d6a5b02c7617f1fb23901297"/><file name="Quote.php" hash="0d299e87306356a2936c72e313055969"/></dir><dir name="Email"><file name="Template.php" hash="282e7d7486a63eeedc56d213e17294bb"/></dir><dir name="Entity"><dir name="Order"><dir name="Address"><file name="Collection.php" hash="1f912f0f6afaf7f0c97388eb817dcf99"/></dir><file name="Address.php" hash="6c7dc37688bcb3543ed7fb51e60f08b7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="861bfe37e0e2a3e8d397a7fef2b79e60"/><file name="Child.php" hash="32e2e2f27bfa2d6228a5e5ea52e95a0d"/><file name="Parent.php" hash="d0c59f53b0fd3b31019c4880bef0236c"/><file name="Shipping.php" hash="174751e68b10d15292fd4781ef2b9b2b"/></dir></dir><file name="Collection.php" hash="2837a7f5177feee8ed29c2752cf661b8"/><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="9f781f34dd65a08fc2cc0393b8cf828e"/><file name="Parent.php" hash="7e56c2cb6ee40e91311fde8c75a72802"/></dir></dir><file name="Collection.php" hash="a320322759710dfe01b2a22fd79bc860"/><dir name="Comment"><file name="Collection.php" hash="c98f05f953d0bfb92abe7c48fd1c0706"/></dir><file name="Comment.php" hash="cf31a5278f7ae28cb40396279456d781"/><dir name="Item"><file name="Collection.php" hash="31cc31022439310311152f81706d8b06"/></dir><file name="Item.php" hash="44b44e47e85ac4defbce067f2a5efbbc"/></dir><file name="Creditmemo.php" hash="fa9d7d9e5a182aaf5be33f57ffa96fb9"/><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="17d2f6acddf70955340cd16ca123f790"/><file name="Item.php" hash="350b2e92d565e1ca8f136341f9dd13e4"/><file name="Order.php" hash="71b4e11cd8ce30f4e849daf82bda36f9"/><file name="Parent.php" hash="17014ef1c8c55460d585792240589b30"/></dir></dir><file name="Collection.php" hash="e4fd5d1f010a81a38d0f69e1e69999e9"/><dir name="Comment"><file name="Collection.php" hash="39bf207a29d25f4026cf562e32514eb7"/></dir><file name="Comment.php" hash="6c0a8c3af07163bbc67f1e455fa2e795"/><dir name="Item"><file name="Collection.php" hash="6fb21806efade3609d74ac362340e202"/></dir><file name="Item.php" hash="af4e2b636b26ad8552e9a39e7bb14ff2"/></dir><file name="Invoice.php" hash="9244fb3d79789b51056af4ca334bdd27"/><dir name="Item"><file name="Collection.php" hash="d0f1974f5df6d4d4ad8118a7a4a33331"/></dir><file name="Item.php" hash="ebfb18aa744fb65cd0bb4bcbcd3b0159"/><dir name="Payment"><file name="Collection.php" hash="f86601c550633f0b86184558fa65edb8"/></dir><file name="Payment.php" hash="017b137b936fff5560dc52ff7be4db19"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="485af88c697482dfdeb660fba19aba1d"/><file name="Parent.php" hash="0d5463f462b0d95c35de762516ec8d71"/></dir></dir><file name="Collection.php" hash="de45615f732677a52bfd52c37cb6303d"/><dir name="Comment"><file name="Collection.php" hash="95845b75c54ea2360803a22bf1547511"/></dir><file name="Comment.php" hash="7f635292f8d94b496d5d9a924e679797"/><dir name="Item"><file name="Collection.php" hash="ea423b588ed1cf35b7893260d85e5010"/></dir><file name="Item.php" hash="3400a881edb8ddbc6392fa8c4a2f31af"/><dir name="Track"><file name="Collection.php" hash="79151ee6ffe9fe4fa66036d1d549db63"/></dir><file name="Track.php" hash="cf89f156c74844a3fc5becf420270301"/></dir><file name="Shipment.php" hash="522f8dc832513471f7f187053e1d1faa"/><dir name="Status"><dir name="History"><file name="Collection.php" hash="9d3587f093d4f5f985571df4115ed8d6"/></dir><file name="History.php" hash="574b5234e98cdf2dd6c887956169efd7"/></dir></dir><file name="Order.php" hash="ab0a6a94a06aad7663068783775ea885"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="8a7d48caa3ebfe50e244016ffa8f6d51"/><file name="Parent.php" hash="c1b6a8ce250c28503037d446ebeb675f"/><file name="Region.php" hash="00e741ec4cc5a131e1227c87de3ba781"/></dir><file name="Backend.php" hash="47a248dade8bfaafa1aa8d9613c6c7b3"/><dir name="Frontend"><file name="Custbalance.php" hash="da8e0105b25c2db53884eabf680e51c5"/><file name="Discount.php" hash="461fc93850f71621932c0ace20c42c1c"/><file name="Grand.php" hash="5f1bb2676fed3d05e45b524fa331473e"/><file name="Shipping.php" hash="7dfb3b96b2fff10b016e6e38d84bd3ef"/><file name="Subtotal.php" hash="f6dec9c5f5033e17b497aa4d7403827b"/><file name="Tax.php" hash="e97883a76f504a91e3b2e25ac589c916"/></dir><file name="Frontend.php" hash="68416b77686a2cbaa742dafc35b97c6b"/></dir><file name="Collection.php" hash="0d1effb4746b5ef2731f8a3db77591d8"/><dir name="Item"><file name="Collection.php" hash="2b23c9b0fa7bc8a568ac10873fe644ea"/></dir><file name="Item.php" hash="3a359de393d4a2481eefad5ec951a6fe"/><dir name="Rate"><file name="Collection.php" hash="0a9e1a909e6dedf3fd011711ceeb6819"/></dir><file name="Rate.php" hash="d98592762b0bb5dbd074438cdf274e4b"/></dir><file name="Address.php" hash="6c57625623ba17c72f936dafcf354542"/><file name="Collection.php" hash="00b7beb8a10a8717031b80932582ab62"/><dir name="Item"><file name="Collection.php" hash="e706b468a9fc83aeb90c87231e73b808"/></dir><file name="Item.php" hash="0263186f0984a5776acaf8597b9f6bf8"/><dir name="Payment"><file name="Collection.php" hash="0c68fd9376d580ba31b083a9e05083ca"/></dir><file name="Payment.php" hash="3920ade27c8d49d90ccaa37785f3385f"/></dir><file name="Quote.php" hash="b35dbb3c3ad4f1d557ee3b48137f0c8d"/><dir name="Sale"><file name="Collection.php" hash="a05db285ef3378e726ecab7b7c610098"/></dir><file name="Setup.php" hash="d3b20ae6df83b255f7803e0ec1ddcbca"/></dir><dir name="Mysql4"><file name="Abstract.php" hash="b0db47393634ae2f2e3e43f731996aa4"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="877605c9d028346183f66a166fb80d97"/></dir><file name="Agreement.php" hash="a17834c35bf457593b1fd608c18ba20f"/></dir><dir name="Collection"><file name="Abstract.php" hash="2f9b09bf0929b54b6ed60f032fd6ef2f"/></dir><dir name="Order"><file name="Abstract.php" hash="3ee44859719a0d126f4f16dbe99546ad"/><dir name="Address"><file name="Collection.php" hash="6f9fd6530a6e0ab930a26e99787a1e62"/></dir><file name="Address.php" hash="d530f4c4bf6c216f13904b8f871111e7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="ccdc5106fea0b1d175a143442aa706e9"/><file name="Child.php" hash="ce3206207546abbc4e7e2d65ca268872"/><file name="Parent.php" hash="253a2ab63e2c7ba62a483764da207119"/><file name="Shipping.php" hash="5b41a69cbea2e558ccf12b15b95b916e"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="47f8ca61139eef629c833a69f0dc9425"/></dir><file name="Collection.php" hash="3b3cdd03bd52c7a6c662b8d81250a416"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="d7eae0947befb3406727cc6371bd5bec"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="90eeba23e00c6a7815baefe8c9f033af"/><file name="Parent.php" hash="9e1d0f68e5b5713fd554233b70a2cac3"/></dir></dir><file name="Collection.php" hash="13620d383b2db66173b8f0e28ab361bb"/><dir name="Comment"><file name="Collection.php" hash="93c787446d443e1fb947bc3eafc8f11b"/></dir><file name="Comment.php" hash="3efd0d6b04ff71dbe8747f8557010899"/><dir name="Grid"><file name="Collection.php" hash="8514c0d2572f47668736e9622cb1b747"/></dir><dir name="Item"><file name="Collection.php" hash="32078954b6ba46954b8bb76bb1fb7e9e"/></dir><file name="Item.php" hash="ca5e729c4f28926815cb2d35716dcd01"/></dir><file name="Creditmemo.php" hash="30a6bfe52bfd4c758c851f630a3ca79a"/><dir name="Grid"><file name="Collection.php" hash="d7621e63dc0f77fa94882507b558bf05"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="a29d3787865836132e83d266e79a8260"/><file name="Item.php" hash="40dc8b6364b0eb4742b55105331d8544"/><file name="Order.php" hash="ec82a177d214c96512f3556d11845b69"/><file name="Parent.php" hash="d2f24bdd157fe64e74177d3b8693e09b"/></dir></dir><file name="Collection.php" hash="8362cd59b4a7208afeae25642c921fbd"/><dir name="Comment"><file name="Collection.php" hash="2d3e26e2c5df7481c226d5fd9dc3e0b7"/></dir><file name="Comment.php" hash="4d68aca8967d97f04d462ff3bcba3f11"/><dir name="Grid"><file name="Collection.php" hash="6982b6cb3d2314cc9c9c9afda713327c"/></dir><dir name="Item"><file name="Collection.php" hash="09dda6d9c226fdad0bcb3d94de00216e"/></dir><file name="Item.php" hash="ee70addd50a7f6ac3719ceded067d40d"/></dir><file name="Invoice.php" hash="3da796261362ff3520542e936ac72d9d"/><dir name="Item"><file name="Collection.php" hash="5886223d56b9c5985913b035e9cbf789"/></dir><file name="Item.php" hash="8a97d0b600df39519ee5ffe53ccf48f6"/><dir name="Payment"><file name="Collection.php" hash="85a071a0702bec16e9280ad975b9e197"/><dir name="Transaction"><file name="Collection.php" hash="8970c3547e1966c415f8202d11d58c12"/></dir><file name="Transaction.php" hash="8f33aa78a64fe29bb1a2e8334fbd6b4f"/></dir><file name="Payment.php" hash="3c4c9266744a0fad5e4f2455a5722974"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="99d6cab63a21092408dff773054b9d93"/><file name="Parent.php" hash="50b6a40f22b9125e0a5f36e86db458fd"/></dir></dir><file name="Collection.php" hash="a059e54adb61bae5bfed655322ebde46"/><dir name="Comment"><file name="Collection.php" hash="b774124e32109950bbac93dea4588423"/></dir><file name="Comment.php" hash="f1dc455fe288891112e443a79bf53c18"/><dir name="Grid"><file name="Collection.php" hash="577564a98b72b6cd085165675705175f"/></dir><dir name="Item"><file name="Collection.php" hash="b6603794026494fd06fb5a4c45148fdc"/></dir><file name="Item.php" hash="711002d18fe28027f06ebc7a957aaabb"/><dir name="Track"><file name="Collection.php" hash="7611e9e72c1c8a3ab6e28bd69e4c7535"/></dir><file name="Track.php" hash="79e07fcce0ec1703777145ec544d0192"/></dir><file name="Shipment.php" hash="03d47ab43f685ece425f5638da9272fc"/><dir name="Status"><file name="Collection.php" hash="9f192ee27d9025ff9b4a767216c54d00"/><dir name="History"><file name="Collection.php" hash="48cfde1f1aa77484801117b25d14cce0"/></dir><file name="History.php" hash="d87bb0bf7e67f97ed88d574a1e934b94"/></dir><file name="Status.php" hash="21c7c1bc5c1a569118464f453f759c22"/><dir name="Tax"><file name="Collection.php" hash="9eded0afa051a25402911d17f881c659"/></dir><file name="Tax.php" hash="ccc2f221d2dfa06b63358daacb92bc52"/></dir><file name="Order.php" hash="c18b134589da38ec43c3bb0d82f9a91a"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="323ba6a863a0028ce315abead027d842"/><file name="Parent.php" hash="57dea111c8a4c38aa883c40cd5393e82"/><file name="Region.php" hash="657ab14d9fd351a8a047ba3ed756d13a"/></dir><file name="Backend.php" hash="20a973dec7d179b85d998275f1e06299"/><dir name="Frontend"><file name="Custbalance.php" hash="01da6eeb31194f578368e20e97bd1ce5"/><file name="Discount.php" hash="39955e5fe27a3668f5823859a8177cfc"/><file name="Grand.php" hash="ec54ee5503816d1ac68b77df348fb475"/><file name="Shipping.php" hash="24cbc84a2cef6b7579f6928f677f5ea2"/><file name="Subtotal.php" hash="0f576ad50ae1e87f41af1be267f7a970"/><file name="Tax.php" hash="a71555e6e0b97bc170fc2e5768b4f643"/></dir><file name="Frontend.php" hash="e9b14b0517b6dd3b202d19c039aedc45"/></dir><file name="Collection.php" hash="698f91405eac99e675da2ec5b0725f79"/><dir name="Item"><file name="Collection.php" hash="353e572a64eae0c4dd41247071a3bf9c"/></dir><file name="Item.php" hash="862d09a82f154ce69aa987eb072753eb"/><dir name="Rate"><file name="Collection.php" hash="94586c57fab25507f25517375b3fd6f9"/></dir><file name="Rate.php" hash="995bd0134fff2787b0b8582834b468a5"/></dir><file name="Address.php" hash="a0ce255d1e4df344e6a1cebb02b69d25"/><file name="Collection.php" hash="a54e42a302459a2ec0526d661ba3140d"/><dir name="Item"><file name="Collection.php" hash="5249b32713d5d80d6e419cc1e41abaed"/><dir name="Option"><file name="Collection.php" hash="7a08c0e8746cf374b68c6f4848b7ac52"/></dir><file name="Option.php" hash="7bbd8559002aa7cf3184a0ea60f7f02c"/></dir><file name="Item.php" hash="054f02aaac27f775de7286c652959d89"/><dir name="Payment"><file name="Collection.php" hash="a36deac36cd4cf30ed2c7ec66d4d082e"/></dir><file name="Payment.php" hash="c707e36f7b26fd5a1df4492fd7bf3243"/></dir><file name="Quote.php" hash="3694a2ec87135cb2f294dca9031a39b8"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="a2f16ce21d1d54bf58494eb7d889ee6e"/></dir><file name="Profile.php" hash="d79c55769f48e85709e6ed188d5a2fcd"/></dir><dir name="Report"><file name="Abstract.php" hash="251869ae0d7fab61e0f4398a0ee87216"/><dir name="Bestsellers"><file name="Collection.php" hash="ee0d2208c210d6a9cf8ddaf83c44328a"/></dir><file name="Bestsellers.php" hash="9176061a9d47038adf11bd5fc970f2a9"/><dir name="Collection"><file name="Abstract.php" hash="84c33f81cd1a5506b5989f296676e6fd"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="7fe5d21618431a6a48683b36c6898018"/><file name="Order.php" hash="d7a0958f14b0ae6d7469666505a32639"/></dir></dir><file name="Invoiced.php" hash="e6abb2a9f77d1951fd2433c44b8af3ee"/><dir name="Order"><file name="Collection.php" hash="d69baf4a6a4d2e47d2dc7b35cea0db63"/><dir name="Updatedat"><file name="Collection.php" hash="a925704447a04862aa6e760bc1c18106"/></dir></dir><file name="Order.php" hash="788ac7cfa70e0eeb2684c0675eb3b043"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="58420cb4a9e359195f587616d2379e6c"/><file name="Refunded.php" hash="37412528117ce7ae9544b5d2bf3264cb"/></dir></dir><file name="Refunded.php" hash="263fb59ceda14e4d836a3c544ff8857f"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="cec5e052f66d42a13cde5e36ab9a27b3"/><file name="Shipment.php" hash="c9581b73a854aa2f09df26d20e9b1141"/></dir></dir><file name="Shipping.php" hash="17c9236ac60fc0b991efdfbea2c7d630"/></dir><file name="Report.php" hash="77e1cf47540bb466e47447de3a972793"/><dir name="Sale"><file name="Collection.php" hash="d3d918f2b86c04b05244235c618d04c0"/></dir><file name="Setup.php" hash="034dd3a9f5b6b11ba008db9da36a3c96"/></dir><file name="Observer.php" hash="88b74b05c1d9c20a33ac3e09c5e35f37"/><dir name="Order"><file name="Address.php" hash="8916c4a42f48f388704a4facc5fee598"/><dir name="Api"><file name="V2.php" hash="53aecd75b1462122c4a5d80b6163cc50"/></dir><file name="Api.php" hash="9c7c6e95ff9d4808e31e9af6a9a8afdd"/><file name="Config.php" hash="7b62138f46b25e0f7ac47fdc02a59259"/><dir name="Creditmemo"><dir name="Api"><file name="V2.php" hash="33173dce34ec581719a9e1938d75037e"/></dir><file name="Api.php" hash="38f6d8318a71da652818390cb75d4bc3"/><file name="Comment.php" hash="cfe413b370dd450ef53986b75260b95b"/><file name="Config.php" hash="6df18821a105e506024d96cd383e73b2"/><file name="Item.php" hash="375c60679803b76dff4562329b8c5317"/><dir name="Total"><file name="Abstract.php" hash="46960310e82267bbb570745478b973cc"/><file name="Cost.php" hash="41b7062e0d7db18066d6b8634f3f33c4"/><file name="Discount.php" hash="2b70875f83ce8b84d55261a3e36ca75a"/><file name="Grand.php" hash="5480cb990680b2713db61ff7b3314e78"/><file name="Shipping.php" hash="efd1231c25d2b746d7edcafdeb466535"/><file name="Subtotal.php" hash="92e4788b748de21fc935430aa4a0c738"/><file name="Tax.php" hash="4b4d88cb5f840ba2099a1c3a654e7dce"/></dir></dir><file name="Creditmemo.php" hash="742ab7fc0bbcb80afd3e6e5964effabd"/><dir name="Invoice"><dir name="Api"><file name="V2.php" hash="3900df4ccc52977228c30c3e8b906034"/></dir><file name="Api.php" hash="fecb5690f768fc84ecdc296aee40ff73"/><file name="Comment.php" hash="df87e2a5bfd53856ee6280973f9fd99b"/><file name="Config.php" hash="cf03f276ce0dafd479bdd58aa06f53b4"/><file name="Item.php" hash="11425073c24ebf9eb613f123a0a32d52"/><dir name="Total"><file name="Abstract.php" hash="00ea50a41ad21f922b95cd08a5c8731f"/><file name="Cost.php" hash="3efa402ade37898b38b74f84adb89f7f"/><file name="Discount.php" hash="1529a1e0bf4a85474e17bec098339673"/><file name="Grand.php" hash="acc0bc6c08b724cd7d3d6fa0ab19cd48"/><file name="Shipping.php" hash="98c2805c93e8e1c89d3b3aefbf5ed7c3"/><file name="Subtotal.php" hash="7bdd77b2c41d4b74d45c9cbbc58ef80e"/><file name="Tax.php" hash="f092d289deca0c49b99ca6f368ca22bd"/></dir></dir><file name="Invoice.php" hash="0aa1fa01567a69372f75fa041c5d421d"/><file name="Item.php" hash="e6699d0a2621e12e151c26b9c38f6ccb"/><dir name="Payment"><file name="Transaction.php" hash="387b5696d397809fa31d850e92c43116"/></dir><file name="Payment.php" hash="86fca1ca2b2b314d7dbb0cd12f0aa1ba"/><dir name="Pdf"><file name="Abstract.php" hash="1efbaf2a4c3c19857662423556eaf6d1"/><file name="Creditmemo.php" hash="054630d48a754d8e9b83cdd22a92e2fe"/><file name="Invoice.php" hash="b2fc61c9816a9c7486cad2612efdf61a"/><dir name="Items"><file name="Abstract.php" hash="a87743efef9cc641171c700c086d6c92"/><dir name="Creditmemo"><file name="Default.php" hash="d7d0b9417f57164c3b760911aebc3f1b"/><file name="Grouped.php" hash="8a2ac12006fe8ed7ad728646f115f8c8"/></dir><dir name="Invoice"><file name="Default.php" hash="802dd4b102870533abefc3d7cb971d42"/><file name="Grouped.php" hash="b881d57c8e647a7a65dbdeb16a55abd1"/></dir><dir name="Shipment"><file name="Default.php" hash="bcdd58a6b6909374eb49814affd3d71d"/></dir></dir><dir name="Shipment"><file name="Packaging.php" hash="15c3cacfd1811f8e6fe7249ca987e617"/></dir><file name="Shipment.php" hash="4c64a7963af25e192d96a7fc11042521"/><dir name="Total"><file name="Default.php" hash="2405a97489855173f3df6a212dec9fe5"/></dir></dir><dir name="Shipment"><dir name="Api"><file name="V2.php" hash="7da2711d8341b3d03c58ec0a147516a2"/></dir><file name="Api.php" hash="6733ac7ae00096ef48e80f7ae8d96c7b"/><file name="Comment.php" hash="6ba3d5f7fd14212d41e75c510bb54658"/><file name="Item.php" hash="dd558f3d378bfd1b06c38e320eb0aca8"/><file name="Track.php" hash="0d132e1caaa80ea2b1e23cb3ff17a13a"/></dir><file name="Shipment.php" hash="9563c1a893b2e490dc0fcc6538a40576"/><dir name="Status"><file name="History.php" hash="56c69ef7957d32fac4e53fed47f672cf"/></dir><file name="Status.php" hash="d1c61f6ce1621935d9f2652cf2dddee4"/><file name="Tax.php" hash="adcc923fa9c2c6e2f862cefa1445ec51"/><dir name="Total"><file name="Abstract.php" hash="31cb81413da3aa688c15f2d31763561b"/><dir name="Config"><file name="Base.php" hash="7a30dcb898e00ad6dbd1044dceba54d9"/></dir></dir><file name="Total.php" hash="70d33c7cf4e96e3d5042f54a1304945f"/></dir><file name="Order.php" hash="05337465ddb568649d304c818d2d8814"/><dir name="Payment"><dir name="Method"><dir name="Billing"><file name="AgreementAbstract.php" hash="858f28ccdb7efb39531e48b6086dc1f7"/></dir></dir></dir><dir name="Quote"><dir name="Address"><file name="Item.php" hash="13167c8797b8d40f7624503edb80c42b"/><file name="Rate.php" hash="3d8160aaa1535a5ecc3bbddc3e5cf60b"/><dir name="Total"><file name="Abstract.php" hash="998eb1780efd04ae4fb2dfeb9b1da06d"/><file name="Collector.php" hash="bd9e85908788e72d1bfdd391caf9c4c5"/><file name="Custbalance.php" hash="ffaef95a9108f670fc8e25628b69da14"/><file name="Discount.php" hash="8d636214de72db05ba44c1a4b9896ef9"/><file name="Grand.php" hash="aa41c6640092a0a48ef4dd6feb0eaa03"/><file name="Msrp.php" hash="fff13c6912b5ae52cf139fc08733331b"/><dir name="Nominal"><file name="Collector.php" hash="953c4bd896cffa053253ae9bd46d7413"/><dir name="Recurring"><file name="Initial.php" hash="60476d4d1380a5bbb33be228b5e1b125"/><file name="Trial.php" hash="81e47180d95ee44b26761c2488763d67"/></dir><file name="RecurringAbstract.php" hash="068fcca6018196d6c9a4a8dab5cbfea8"/><file name="Shipping.php" hash="c6a723be5898cb394f5c5ece5ca93b2b"/><file name="Subtotal.php" hash="149b0984813abbcab03ebf4cdd78ce78"/></dir><file name="Nominal.php" hash="8328b2300cf771afa0f5f84a681d5f20"/><file name="Shipping.php" hash="bd4dd3b11a26f2e810f66d55953fb030"/><file name="Subtotal.php" hash="81110672832ae415ca383a900844ed2a"/><file name="Tax.php" hash="8faf93c094702542955ab4baf50cfe2c"/></dir><file name="Total.php" hash="d836886553dda5c5c26265c8ac0ea359"/></dir><file name="Address.php" hash="ae8cf173f9312f2add53a18783ef7933"/><file name="Config.php" hash="cc48d9cfb97d5b05e2df40e82cf97ac7"/><dir name="Item"><file name="Abstract.php" hash="35895a3a1c1492a971bcb03ba3983ba6"/><file name="Option.php" hash="505a1627ea636d6b84604ba6d05562a2"/></dir><file name="Item.php" hash="40debc8bc6fbc6082920941891de8fb5"/><file name="Payment.php" hash="f2f75f09e0ec0b96510f4151be8969c7"/></dir><file name="Quote.php" hash="c7b11d2b08b94f0a0a3c9e711487a325"/><dir name="Recurring"><file name="Profile.php" hash="6523889790dbc100ab3c90ca32785eaa"/></dir><dir name="Resource"><file name="Abstract.php" hash="06798d2bae372e5d5744318e627a7d76"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="3a69e98730657ebf9b9da9086a225c6b"/></dir><file name="Agreement.php" hash="8e9efd873709fdd8ae6cf0f6f4fa162f"/></dir><dir name="Collection"><file name="Abstract.php" hash="ce9aec922526609215f1038782f9e777"/></dir><dir name="Helper"><file name="Interface.php" hash="03049c9d6a48a70a6ff3d2c1ff64cde1"/><file name="Mysql4.php" hash="387b0b29e187a32aeb3cf47b2706f5cf"/></dir><dir name="Order"><file name="Abstract.php" hash="c6bcdf9d41e749010b4fff0262f98390"/><dir name="Address"><file name="Collection.php" hash="b92fd2f5b157dd6546763dc83e50e00c"/></dir><file name="Address.php" hash="c6f6b1f5bb03ce120aac229a9e10181c"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="d8a6abf75315b4230695e17706d1e22c"/><file name="Child.php" hash="a17ee5ee0ce105ba44fe088f778c8ba3"/><file name="Parent.php" hash="94a1d88f86e59d4256164d592876cca0"/><file name="Shipping.php" hash="18ca118303231681e53ece31d15d549c"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="4dc3ee4846909bcf704476a2785ce51d"/></dir><file name="Collection.php" hash="15582c6d423aa21d838709eb80bd0732"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="8e4c6ca0755eb57a6787eb92ea690bbb"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="43d42de1f5b84c38f65f0848fd489a37"/><file name="Parent.php" hash="78274d33ccf1d07c9552c791d2ace796"/></dir></dir><file name="Collection.php" hash="c5de7575c4e7f77e45f5e32ff930f418"/><dir name="Comment"><file name="Collection.php" hash="b6ce7282472670bc07ed65db12ad0c4e"/></dir><file name="Comment.php" hash="55125fc902f1b341d8d55d0a5197ac5b"/><dir name="Grid"><file name="Collection.php" hash="c2d7c0562273dea783196cfdebd1a0de"/></dir><dir name="Item"><file name="Collection.php" hash="9ea88230bb081da061d0c950eb32f015"/></dir><file name="Item.php" hash="d2bfc4c13fa06d03ccbff896522d8470"/></dir><file name="Creditmemo.php" hash="ad7a44336cf27fecbdb0b0e42168b259"/><dir name="Grid"><file name="Collection.php" hash="b97470cd6f0d203e5e18912b614f08fd"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="7c361107c04f9622b2404ded426b3931"/><file name="Item.php" hash="808ee216324a1342f4188cc1642c00cb"/><file name="Order.php" hash="9b25cb53b48355c923674af68226e44e"/><file name="Parent.php" hash="74f2d01b5b0c72e3303318bd56617401"/></dir></dir><file name="Collection.php" hash="22a1357726e3c914d38fe54ab9981543"/><dir name="Comment"><file name="Collection.php" hash="9177dbc3dd739beddacd6cd531d91d9a"/></dir><file name="Comment.php" hash="e7df04fca8aa7c24ec56bc8560c503ae"/><dir name="Grid"><file name="Collection.php" hash="bed2f149ed5df505d6a196d68b5b1301"/></dir><dir name="Item"><file name="Collection.php" hash="e3360d66615e407be221d97d179fe044"/></dir><file name="Item.php" hash="57bd03e9b419fc15edb75b04c09004a2"/></dir><file name="Invoice.php" hash="4ce11cd9dd6d5ee7bb373cbc958b521e"/><dir name="Item"><file name="Collection.php" hash="af905f388ddae3eec6b1ab297379205b"/></dir><file name="Item.php" hash="512defaeaed0f1a8d00804df39e3aec6"/><dir name="Payment"><file name="Collection.php" hash="02da4d7775cc4013e9c16aabe3589997"/><dir name="Transaction"><file name="Collection.php" hash="bf937a25f0c7df1031a09433c9842c4b"/></dir><file name="Transaction.php" hash="1a64212246c615d53b8a8afd0eb8d932"/></dir><file name="Payment.php" hash="f6aad82c2999d65ff80acf09fb23a7cc"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="3bc1895d0f5e7ca581ee4e8d0fff6bb8"/><file name="Parent.php" hash="8b03ebab28ae10bcabd87b464cf02ab1"/></dir></dir><file name="Collection.php" hash="f87c1eba0c18fe329589998ca3516b73"/><dir name="Comment"><file name="Collection.php" hash="1b28c7f3ae35c30a413e69138ce56791"/></dir><file name="Comment.php" hash="e9a097c3f151fc3499455278f6f151da"/><dir name="Grid"><file name="Collection.php" hash="b419fb2d905b2ce911c304641b586c8c"/></dir><dir name="Item"><file name="Collection.php" hash="f8fbd616c36db514ce5280388d157c53"/></dir><file name="Item.php" hash="3a693ede88944e180463e241c3bf1d75"/><dir name="Track"><file name="Collection.php" hash="f092f45120fb61b7eca9b31a5c45350f"/></dir><file name="Track.php" hash="886bdcdfd193a9a233428f471e7f3831"/></dir><file name="Shipment.php" hash="afc9386f4ebb3ca7a5a4b4762f5101b2"/><dir name="Status"><file name="Collection.php" hash="8c9bbd30a771da83c9874b334c7020a5"/><dir name="History"><file name="Collection.php" hash="e94c4590c682e89d57fd22d3464a9b29"/></dir><file name="History.php" hash="26fe553862db8065db57c697ae82cfef"/></dir><file name="Status.php" hash="f49eee0230598a22e8985ccd5700e29c"/><dir name="Tax"><file name="Collection.php" hash="4ae4b3ee863688a1ebc506443a6d2606"/></dir><file name="Tax.php" hash="c1a9f6c1b5d5d73182d0d932f7300e59"/></dir><file name="Order.php" hash="0fa2698612cf4622c07e36e087b3cd8d"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="fb22141b138c5e0e50513f15bc26a7ac"/><file name="Parent.php" hash="16d8bd420feca1b901d5e04d773ad618"/><file name="Region.php" hash="e6a34fade1af2de288cfdbac10923a5a"/></dir><file name="Backend.php" hash="91e5c98cda7d74c18ce94468049a4d9b"/><dir name="Frontend"><file name="Custbalance.php" hash="d3bb99b3eb04a9015acb64818d348156"/><file name="Discount.php" hash="1ac67dd5a166a2beebd5e5e28a3cdfa3"/><file name="Grand.php" hash="5390b3419a7b7ffbdfea5a5d461a74b0"/><file name="Shipping.php" hash="b90e09fbec681375c4fe797f5ba05e1e"/><file name="Subtotal.php" hash="b548298ef6284d214b77ce28bbcd105f"/><file name="Tax.php" hash="a0bbbd4cd0a823a1a03b6d2b6d05c75b"/></dir><file name="Frontend.php" hash="3e145300f6c2bbc7da8065ed2127b7fd"/></dir><file name="Collection.php" hash="614c9e681787b9e07926a8b2db538fe9"/><dir name="Item"><file name="Collection.php" hash="717fce4bb8b5be14d6804931fdedbea2"/></dir><file name="Item.php" hash="df52f7b5f964f968d2a2cbab2a20f850"/><dir name="Rate"><file name="Collection.php" hash="b1a6d36d4d0deb3514e1a710ba0964e2"/></dir><file name="Rate.php" hash="73c20b025222353dcefb33539c84a496"/></dir><file name="Address.php" hash="2b3cff37667b5609b9b93165d48dc5d7"/><file name="Collection.php" hash="c808ab68be9ead5f47720c82a60f78a7"/><dir name="Item"><file name="Collection.php" hash="666f34fcb64d15b4d64cae4266980547"/><dir name="Option"><file name="Collection.php" hash="2920aea6b88281281aeb58884e44ce54"/></dir><file name="Option.php" hash="d34f1dc3bc8eb9f3bb7bbd1f4e198924"/></dir><file name="Item.php" hash="abca577432cfb2cc219ccce735c11f5e"/><dir name="Payment"><file name="Collection.php" hash="50e02948cdcb847c5ba330fcf4a0a736"/></dir><file name="Payment.php" hash="c8aa350b64846464e465b959007382dc"/></dir><file name="Quote.php" hash="63add8e0f1afbf189ec39289b93ce644"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="c86282d515fe55cec5d91d121d6b2fe0"/></dir><file name="Profile.php" hash="354252e2618207c5aae3e77845da39cf"/></dir><dir name="Report"><file name="Abstract.php" hash="42e7075a7e81c8d013fa51f8dc8d8fb7"/><dir name="Bestsellers"><file name="Collection.php" hash="308e0ea60f24f45a5fb6ccf8a321b29f"/></dir><file name="Bestsellers.php" hash="ec935ec54f750a3337955d11124acb73"/><dir name="Collection"><file name="Abstract.php" hash="4d979463398fa003e2bd7245be2a2349"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="9f3886e190425851e71520cc7128eb36"/><file name="Order.php" hash="42db6ff58f5e6e5c73a09c2ec946d9f7"/></dir></dir><file name="Invoiced.php" hash="73005cba3e5df382cea54947a09a535b"/><dir name="Order"><file name="Collection.php" hash="734498dccb843dc88715bc0a3b83f04b"/><file name="Createdat.php" hash="fa0b3c1186587c6fca3fe7a84fd040c5"/><dir name="Updatedat"><file name="Collection.php" hash="dab368a79fc05593c94d52367641feb5"/></dir><file name="Updatedat.php" hash="94f641b4589c3a81286c926689500b69"/></dir><file name="Order.php" hash="c87912b9d48633e6520d586319d0cd77"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="41df56a612e9ac30fb1f23bab73679d6"/><file name="Refunded.php" hash="fad2658a14ad11de6be64791f1962387"/></dir></dir><file name="Refunded.php" hash="300935148418cb44d7303908d3377e57"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="88f0441418c4588c6f9cf4c4f3388a77"/><file name="Shipment.php" hash="4c320e03fbfbd7f64347015a3746d682"/></dir></dir><file name="Shipping.php" hash="8ee5cc8cd06446c300316ea80ba6bdc3"/></dir><file name="Report.php" hash="00e8090be521bae44556e85278a8a50f"/><dir name="Sale"><file name="Collection.php" hash="72c86de402df84a75807c5ee1808138e"/></dir><file name="Setup.php" hash="16b2ee3f2c3251ce26b9bf0202ca0bed"/></dir><dir name="Service"><file name="Order.php" hash="79c00b67105e67eed86edfa5c3989704"/><file name="Quote.php" hash="96c5e6a97ce62533f351d4959b400c42"/></dir><dir name="Status"><file name="List.php" hash="a95825954b50003525fb82228a9292de"/></dir></dir><dir name="controllers"><dir name="Billing"><file name="AgreementController.php" hash="6fbfc7001982d36aa06483c90898b0ed"/></dir><file name="DownloadController.php" hash="49594a42bf13124463382faf965394fb"/><file name="GuestController.php" hash="728699f2a41bbb6a026ef8e2e55653ff"/><file name="OrderController.php" hash="673ae998510996c015ae21e18da60958"/><dir name="Recurring"><file name="ProfileController.php" hash="0cc8c8d91d19ea96a1419fddc432d5b1"/></dir></dir><dir name="data"><dir name="sales_setup"><file name="data-install-1.6.0.0.php" hash="6ab71ddde7cb62e41cd3978f77ab7b2b"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="24bc0e8094427988f236bbfb8998e5ae"/></dir></dir><dir name="doc"><file name="invoice.txt" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="order.txt" hash="5dce876530c94ebbedbba7a234c23846"/><file name="order_actions.HTM" hash="b955e61bff753ea0534f907ef6ba9bb6"/><file name="quote.txt" hash="55ecfbdd576958ff1b1fbf16957ba9df"/><file name="test.php" hash="75f5888687bd149423ad2262dc6be83d"/></dir><dir name="etc"><file name="adminhtml.xml" hash="64f3215b378e7cce530d2bbc1b5770ec"/><file name="api.xml" hash="20eba043e5bc0f7d826378f9239da63a"/><file name="api2.xml" hash="2dd8189de81a1cee9acccdb63d6dfd3f"/><file name="config.xml" hash="decb9d37095adc9aa779c392c77d9ad7"/><file name="system.xml" hash="cbe84ff8e194da1d5f619f88618e52aa"/><file name="widget.xml" hash="1ea392cd1357530eb3fb76396fde54b4"/><file name="wsdl.xml" hash="ed13de1dde6408ab508892374ef57b81"/><file name="wsi.xml" hash="6aba2f44765955ec8bcd1afcebfb0800"/></dir><dir name="sql"><dir name="sales_setup"><file name="install-1.6.0.0.php" hash="2c287c2fe9601ef04ff961b56c2967f9"/><file name="mysql4-install-0.7.0.php" hash="7d0d1fea503a57617f35fb7d4321e64e"/><file name="mysql4-install-0.8.11.php" hash="0f7b7ad16927275d67466655799f63f5"/><file name="mysql4-install-0.9.0.php" hash="df39d6b00a00297dde8bb809a3ce8d36"/><file name="mysql4-install-1.4.0.0.php" hash="ab55fbc1f42b45f62a8e25b00f3f8ec0"/><file name="mysql4-upgrade-0.6.2-0.7.0.php" hash="4b377082c213d2bd5fc011024ce5d38d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="66dab89a7376dd328305a3c2c4363484"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f626b8de75933ed846c8fc1ab7989b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="faf0a62c9033c06dc4142661630347f0"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a582cc340f96512440da05c34d4efdc3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="4386c0a34c4ab15be88788dddd68eff4"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="b829b43451acd8d04045ec093c8b4dd2"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="328d56f9f7ebabe79ade0a1621e41d71"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="d2b6362bd9f351691adc12b4319351ed"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="17900afa4f64d66a9ac672f276912ea8"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="5ee57dce22f85605a6a6102faba2d90a"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="baec5a1400bf8826769266e1322503a0"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="f9cd2aecddc0fb919155cf2b7b62be10"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="f120725f256959ac634271b2352c0683"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="8076b36a75778b6545d82d7c0eb75576"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="8792c0f1b2e7545e52d0b8549ce11739"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="d1861afa10be4a63b988775d63b89eac"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="e41a5cb53beb7bdf5f85906af0e64af3"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="cdfd46b4c76f91d81832bcbac76d1f7e"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="1ef6d4fc564bef1e8883d9c55dda1d9f"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="8cd0c4b432833a8480e855822e182db0"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="36548ad7e5f7008c4feebc1ca0125449"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="7fb800a27788be2681a07dcb9e7138a3"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="eb14adbff9fc9add9d41ee53b80e3f1f"/><file name="mysql4-upgrade-0.8.28-0.8.29.php" hash="acb795a8927fb7eb42e26cc631b9eb9b"/><file name="mysql4-upgrade-0.8.29-0.9.0.php" hash="51700bb3315b81683d5297393915ba5c"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="6f76404ed26c596214b76cfa7acbd2fd"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="291a933edceb5b0d0bf820d889a41dfd"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="d1d401880667acde9910dbd94baf45df"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="a08c394d9ee9e3b603271c87d9cdccaf"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="eee0131d0c1ff81d6a8217024328fd93"/><file name="mysql4-upgrade-0.9.10-0.9.11.php" hash="7dcad0f3276ab1c90aec34066cdf9af2"/><file name="mysql4-upgrade-0.9.11-0.9.12.php" hash="1419527e1368381becf382e165974eca"/><file name="mysql4-upgrade-0.9.12-0.9.13.php" hash="106cc11270541b4ad03bcf01da097a08"/><file name="mysql4-upgrade-0.9.13-0.9.14.php" hash="9a544c38081d67a9bf7ada5eea628ae6"/><file name="mysql4-upgrade-0.9.14-0.9.15.php" hash="3d94dfc65777523496ba202ac5481a32"/><file name="mysql4-upgrade-0.9.15-0.9.16.php" hash="288e17dfff62ec6e15de30218d96a4f3"/><file name="mysql4-upgrade-0.9.16-0.9.17.php" hash="a269dc8079c9566e5be0f4bab75379bd"/><file name="mysql4-upgrade-0.9.17-0.9.18.php" hash="c0a0fdde0cbb71fd548d2965e01ab3ea"/><file name="mysql4-upgrade-0.9.18-0.9.19.php" hash="be7b8ccda6a3e658ea86e0f2d99ee020"/><file name="mysql4-upgrade-0.9.19-0.9.20.php" hash="f6272f05d9077b84f9e9c5724c84b783"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="b6240c3ae6f61375f6723735345f3c7a"/><file name="mysql4-upgrade-0.9.20-0.9.21.php" hash="80230b5d45321b886002b4783a1178c5"/><file name="mysql4-upgrade-0.9.21-0.9.22.php" hash="9c2be0b2fd92f326dcff1a2425d255a6"/><file name="mysql4-upgrade-0.9.22-0.9.23.php" hash="71dc008ec0b1e195f853113329944b6c"/><file name="mysql4-upgrade-0.9.23-0.9.24.php" hash="ad08f3386682ab27c86fc9bfbd91f8e3"/><file name="mysql4-upgrade-0.9.24-0.9.25.php" hash="1dc0d317074dea066f265a40d00ed6f7"/><file name="mysql4-upgrade-0.9.25-0.9.26.php" hash="d69e73a174d61eefe0034c148cd09472"/><file name="mysql4-upgrade-0.9.26-0.9.27.php" hash="58353aafa8bcdb32a6d64184b6a3d60b"/><file name="mysql4-upgrade-0.9.27-0.9.28.php" hash="0213f58c16ab8bf2485bae528140ba69"/><file name="mysql4-upgrade-0.9.28-0.9.29.php" hash="da5ef2d5d6e6cfd6ef0d5e44136029a5"/><file name="mysql4-upgrade-0.9.29-0.9.30.php" hash="5c376558e9f329281c8363322f05e45a"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="fb67ff85b5b8e395e0e11598f2e202b7"/><file name="mysql4-upgrade-0.9.30-0.9.31.php" hash="0e4bc71fab792ede8edb992839b7fa66"/><file name="mysql4-upgrade-0.9.31-0.9.32.php" hash="59aa185b9b61d345081a24913f67d87c"/><file name="mysql4-upgrade-0.9.32-0.9.33.php" hash="f742c43458fbbe3cc4ecaf9679b444b9"/><file name="mysql4-upgrade-0.9.33-0.9.34.php" hash="ed2650dacba9c9c315b1bd15399ce8c2"/><file name="mysql4-upgrade-0.9.34-0.9.35.php" hash="4ea762659260ddb6ef8521fa1ea59af3"/><file name="mysql4-upgrade-0.9.35-0.9.36.php" hash="43ebb2aa25a9302eaad2fe67e29e187f"/><file name="mysql4-upgrade-0.9.36-0.9.37.php" hash="5eef7f246dc3135de09fa4ad63668236"/><file name="mysql4-upgrade-0.9.37-0.9.38.php" hash="7f1264d789044b4e0d53d88d6fae9aad"/><file name="mysql4-upgrade-0.9.38-0.9.39.php" hash="394b1c87ec14026fc9ec73a7aed8d164"/><file name="mysql4-upgrade-0.9.39-0.9.40.php" hash="f525b598b5e6a411e0fbf78f3e698b97"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="ae0c33db1187c63db22e3abb9b135e92"/><file name="mysql4-upgrade-0.9.40-0.9.41.php" hash="9606fd627ca520b83a8cbaa1af210f36"/><file name="mysql4-upgrade-0.9.41-0.9.42.php" hash="e3f73f0616866b38d27b455a29c884ef"/><file name="mysql4-upgrade-0.9.42-0.9.43.php" hash="86ae3db2278241132ecf0d78e94e4a6b"/><file name="mysql4-upgrade-0.9.43-0.9.44.php" hash="634530214656d52e0ebf1bc1796ba820"/><file name="mysql4-upgrade-0.9.44-0.9.45.php" hash="0ef1f74e5ff76cbdb77ef5c1cf1cff54"/><file name="mysql4-upgrade-0.9.45-0.9.46.php" hash="c836ec8263903c699810ed331018cdf2"/><file name="mysql4-upgrade-0.9.46-0.9.47.php" hash="c57f7c39b85e675a294487970842bf96"/><file name="mysql4-upgrade-0.9.47-0.9.48.php" hash="b15d0fe3d2da3fd72f11960ebe3944f4"/><file name="mysql4-upgrade-0.9.48-0.9.49.php" hash="2a21dddd1ee15ae790005478066c7e24"/><file name="mysql4-upgrade-0.9.49-0.9.50.php" hash="6cdb649f2797ab3dbe3609f64a2940fe"/><file name="mysql4-upgrade-0.9.5-0.9.6.php" hash="be8975bf7f0e7304212c2aaff5d9b23f"/><file name="mysql4-upgrade-0.9.50-0.9.51.php" hash="9a624fe9a93a011ea20fdc38f5dab386"/><file name="mysql4-upgrade-0.9.51-0.9.52.php" hash="97a685809fe84907429291f0d8a7da21"/><file name="mysql4-upgrade-0.9.52-0.9.53.php" hash="6b592cc19f7243afedefec86dcb2a314"/><file name="mysql4-upgrade-0.9.53-0.9.54.php" hash="67a7688245f2021ed2b9a421e483cc53"/><file name="mysql4-upgrade-0.9.54-0.9.55.php" hash="673b59dd7062eb7610d5a4f1237ad7a1"/><file name="mysql4-upgrade-0.9.55-0.9.56.php" hash="5665cbaa78fc32405f927db451b57b1d"/><file name="mysql4-upgrade-0.9.6-0.9.7.php" hash="6075078eb301b31f123ac710e0a2a0d9"/><file name="mysql4-upgrade-0.9.7-0.9.8.php" hash="a6087a1421def6bbe443c54ed7c85a8b"/><file name="mysql4-upgrade-0.9.8-0.9.9.php" hash="a803ee3e2911b1f245dd0549369ecc9f"/><file name="mysql4-upgrade-0.9.9-0.9.10.php" hash="2639b36ba32deb87f752d022d588078f"/><file name="mysql4-upgrade-1.3.99-1.4.0.0.php" hash="709b954c683e80cf4526303870128d82"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="6e96cade5538a2e661b1cdf8c08a7d44"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="c63f548243fce20ee961f6f80435bea3"/><file name="mysql4-upgrade-1.4.0.15-1.4.0.16.php" hash="88f689b208a1702ec4facf6e2b5ab134"/><file name="mysql4-upgrade-1.4.0.16-1.4.0.17.php" hash="3f5527bc6f1c015e3007ec2b43f25f95"/><file name="mysql4-upgrade-1.4.0.17-1.4.0.18.php" hash="a21261050a55e7b580ef646d1a0bd314"/><file name="mysql4-upgrade-1.4.0.18-1.4.0.19.php" hash="8d99789daac557da4ced224d36635e00"/><file name="mysql4-upgrade-1.4.0.19-1.4.0.20.php" hash="6f339125108f34c0b5477d214963d32a"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="740256606f0d22e7d2d4a1f8896c0b52"/><file name="mysql4-upgrade-1.4.0.20-1.4.0.21.php" hash="25cc7a47798177c4f52cf387a67125f7"/><file name="mysql4-upgrade-1.4.0.21-1.4.0.22.php" hash="f2ec84706e64018a70c0198a560bb917"/><file name="mysql4-upgrade-1.4.0.22-1.4.0.23.php" hash="9c6771fc168bece647cfc6c9fd4b478e"/><file name="mysql4-upgrade-1.4.0.23-1.4.0.24.php" hash="49febdd803be93c62dc09e51bdd330f0"/><file name="mysql4-upgrade-1.4.0.24-1.4.0.25.php" hash="d5fbae1bd7d9d45a6a284f8e93ae8314"/><file name="mysql4-upgrade-1.4.0.3-1.4.0.4.php" hash="303dd6693f7160546d6c1aad96d1348c"/><file name="mysql4-upgrade-1.4.0.4-1.4.0.5.php" hash="68ddd54ec15ac6f60213215682176f37"/><file name="mysql4-upgrade-1.4.0.5-1.4.0.6.php" hash="784a77ef434acf0ebe803805a213876c"/><file name="mysql4-upgrade-1.4.0.6-1.4.0.7.php" hash="2c560f9f57454ec7130e6c293cbf5266"/><file name="mysql4-upgrade-1.4.0.7-1.4.0.8.php" hash="357db82d9b817ecea185abaaeb70d317"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.15.php" hash="cdcd4d6492a5c27b73b5b1b3b9ac8d4a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e8356d6a48d76369b34f6e8bd27dd816"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="dfd84a2a8044c259c6f6e7feea9a5de7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="6ac3f9c8119c28fd6796dc98ec54e82a"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c83205c28df3a6063f268f11195d27a8"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="3bbd8e0ff9448fa2d0bba25ac87b8492"/><file name="upgrade-1.6.0.4-1.6.0.5.php" hash="3b963ab1fa610c36577e8e43b279471d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="0d6e967b2a6bc110e143171210c80e54"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="2eaf612b1ddcf939fec17e441c29c08e"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="ef8e890ad206740f2c9d72803f30d063"/><file name="upgrade-1.6.0.8-1.6.0.9.php" hash="9d5a988492bd42371c47ee69186f7150"/><file name="upgrade-1.6.0.9-1.6.0.10.php" hash="40feccfa23344470891176db52fb26ba"/></dir></dir></dir><dir name="SalesRule"><file name="Exception.php" hash="462c8803b4baa19dc11ed76cf231a786"/><dir name="Helper"><file name="Coupon.php" hash="01e644f9fe0632bfb43cc46139af99f2"/><file name="Data.php" hash="0de3ba8633aa6d88b2696a28727b47eb"/></dir><dir name="Model"><dir name="Coupon"><file name="Codegenerator.php" hash="d8ac08012695de7a731cd66de91c6257"/><file name="CodegeneratorInterface.php" hash="af2ace052c52d6a73801866cc77db152"/><file name="Massgenerator.php" hash="37cea27a50d91b2aa86986e52231d31e"/></dir><file name="Coupon.php" hash="27ddc5154f825c75ca366042e2385ae5"/><dir name="Mysql4"><dir name="Coupon"><file name="Collection.php" hash="334608369ac389b1b67def7ada1aa5e0"/><file name="Usage.php" hash="40be9a4493b0936c1111ea7991f912b2"/></dir><file name="Coupon.php" hash="7844b0bc3fdb9de95382c1b12421123d"/><dir name="Report"><file name="Collection.php" hash="384fe7d3e3777b6233791bcb7a0e5a2e"/><file name="Rule.php" hash="7b9f3131640951ab7ddfcf8316ba78b0"/><dir name="Updatedat"><file name="Collection.php" hash="fc1d0841db7b9eebe8c15a18f694a742"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="8b5900d5125b47cbb540a6e2ccf47f41"/><dir name="Customer"><file name="Collection.php" hash="9cd01232278163f711a5c5283f94a21e"/></dir><file name="Customer.php" hash="4d45597acba3e88a0eb04b69349b9c68"/><dir name="Product"><file name="Collection.php" hash="4cc4b5b1fdf0b3a832bb7859288b303e"/></dir><file name="Product.php" hash="53b758f2c61474ba10c87c256e108314"/></dir><file name="Rule.php" hash="eb958a1b99441e8912d1d46510feeaf4"/></dir><file name="Observer.php" hash="4364e6fa8639634d504f66bbcc3cf808"/><dir name="Quote"><file name="Discount.php" hash="e41ec653892d0e8ecf82d9a52b62c676"/><file name="Freeshipping.php" hash="b035df813ef118ff1a1fb5ed875083f3"/><dir name="Nominal"><file name="Discount.php" hash="68a50a271796a47f8f55f2e7bad7d28a"/></dir></dir><dir name="Resource"><dir name="Coupon"><file name="Collection.php" hash="31b1a8e0fa51a8923ead28d407bf9c05"/><file name="Usage.php" hash="d7b327e2e3222cef7a55fd4f9e682e44"/></dir><file name="Coupon.php" hash="15b26e3aa1646ee2878b6bf46ab7bbae"/><dir name="Report"><file name="Collection.php" hash="e9236e12f64f8cdcaa8d8fb2a1224be4"/><dir name="Rule"><file name="Createdat.php" hash="d4d03fad7d85d3691dde82114687797a"/><file name="Updatedat.php" hash="5dfd0e8a15d115a4c14b2973415f0825"/></dir><file name="Rule.php" hash="505b8920f90d7af5cf09e815e5730a93"/><dir name="Updatedat"><file name="Collection.php" hash="a0f90a993ed70fd1adda36dc1a66ed1e"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="771b2c8b33d233eb6d9bce7a7f880e7a"/><dir name="Customer"><file name="Collection.php" hash="bc371db1391974074a8aa8a8b719c4bb"/></dir><file name="Customer.php" hash="bb7ce9191d72f004a44013641bf38ac4"/><dir name="Product"><file name="Collection.php" hash="a8a62df60340b9a20035fb5c88872457"/></dir><file name="Product.php" hash="743ac84f509801340ac92952d97521ef"/></dir><file name="Rule.php" hash="c972025412fb5f531b709b8339a4867d"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="fad48a1e0d172cf50015cfed489df9a9"/><file name="Product.php" hash="899cfda115a181f3ed1e7f7dc320f017"/></dir><dir name="Condition"><file name="Address.php" hash="57556435014163ba73961cb8b2413f74"/><file name="Combine.php" hash="776e2fb5e3f152e70c3280d476011f76"/><dir name="Product"><dir name="Attribute"><file name="Assigned.php" hash="d981c3f7486bb60becc566329267d7d5"/></dir><file name="Combine.php" hash="ef7cc6d43ca96c3a0cf35095801e91a1"/><file name="Found.php" hash="351ebe3769717330a8b9ef971319e2b5"/><file name="Subselect.php" hash="56844666a23899ed9454aeadfe236e7a"/></dir><file name="Product.php" hash="44f952d096aa380ffcd16669eef5fa8f"/></dir><file name="Customer.php" hash="c67ccf31dc11f70be34803c04199debd"/><file name="Product.php" hash="48d130bb0e52c6eed39917b0e6e8ec41"/></dir><file name="Rule.php" hash="0095ccf926ee7550cf5811744a481774"/><dir name="System"><dir name="Config"><dir name="Source"><dir name="Coupon"><file name="Format.php" hash="00a3d50d33a25ead7adcb8b78b6a11bc"/></dir></dir></dir></dir><file name="Validator.php" hash="a77360dd111bb67dc3ff3ab8e19eb118"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f1d641409e95b4a606cf7ae575243cd4"/><file name="config.xml" hash="8fb7fdc054daf869b4adca215adafeda"/><file name="system.xml" hash="62888a487f9a077a97e962f9f5fe363f"/></dir><dir name="sql"><dir name="salesrule_setup"><file name="install-1.6.0.0.php" hash="4ff588a3f0c4ccf35fa2397c8b91a1e1"/><file name="mysql4-install-0.7.0.php" hash="a23c56ff9cbdac7509024202840d23c6"/><file name="mysql4-install-1.4.0.0.0.php" hash="a39e70beef1c7ea3e75ff031168c9d00"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="997f2d5225bc7918a86cfbb7046e3208"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="bcb109871d08fe03746b2d099d3f7e2e"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="2a33766197a359ff0069b9402cfe63ae"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="ca200dc284898ef45e3bea7d3e119db3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="10e7b1b34289ff835d99eecb9a61dfec"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="aea3f32ffa01c60ddfc3925aa7ec3778"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b966df9afad448c96c16cb7c78a9eaac"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="0db66744ac0846c22876582edee3c9e7"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="0517c2de9b809c31167d808c9939d185"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="2485c3b72c509b73892dfacb03f148a3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="bbbd8c952701e3893076386e453e2f81"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="e5519218dcf0950044bb7c0d6028187f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="ac46d45460c5c897c5a7facaa3e4b8d7"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="e0b75159537f13c2b75b1f83fbfc2083"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="253ca68169f6f044f04b18fafd74d540"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="b11964330203c4e34192b34e86d65b21"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="004721ffbc5a2d380a14864f08611b56"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="941b4b839bfe16a1f3874ba67f14f419"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ac7e333071eb428749527e640bcd2c1e"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="27ce0d5d1598027bad1ace2feada0bb8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="18fa5d2dad035852fca429b986df8a4d"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="ae38a3fb75abc1a3dafb3b5278f27e0d"/></dir></dir></dir><dir name="Sendfriend"><dir name="Block"><file name="Send.php" hash="d0900cc748ef56c40c3551157156b6e3"/></dir><dir name="Helper"><file name="Data.php" hash="c8282d8b6b3610c761db46736e08fc8b"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Sendfriend"><file name="Collection.php" hash="122b8c8b50c55b13d867759cbdbaa9c6"/></dir><file name="Sendfriend.php" hash="61244da4dcae30c16dbb8d52fe2571f8"/><file name="Setup.php" hash="7b9ed257cc9bd891bae4bff716f22d0c"/></dir><file name="Observer.php" hash="301aa366775afba3bccc67529bdd0e65"/><dir name="Resource"><dir name="Sendfriend"><file name="Collection.php" hash="432e0466d874a74b3e1f4e10f1919b78"/></dir><file name="Sendfriend.php" hash="e5d542480b994ea78db380743bd782a0"/><file name="Setup.php" hash="6cb8411f99ae31fb4c7277675e3e26a9"/></dir><file name="Sendfriend.php" hash="0ccbc1ee40bc4796c2a3639399f891d9"/></dir><dir name="controllers"><file name="ProductController.php" hash="546740ca17ac1742f3e083e95c1541b0"/></dir><dir name="etc"><file name="config.xml" hash="5b71c820ab10d80f54460b6727687c4c"/><file name="system.xml" hash="3a06ef185cd518ca05a43eb3807bca55"/></dir><dir name="sql"><dir name="sendfriend_setup"><file name="install-1.6.0.0.php" hash="8337cc0478de35a6cbb12b2adfa46782"/><file name="mysql4-install-0.7.0.php" hash="495330536e267ecff7803b69d6a6ce58"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="db5bbae44f93fefeca37bc5f4a7ad02f"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="46cba5f2ec5161773cd2de5d40bb50be"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="905ed91131d6469ea8f8fc9b95b3c15a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e699566eab2ede860af95c67836e0c1d"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="0321ede85958c89dff2672b3122fa975"/></dir></dir></dir><dir name="Shipping"><dir name="Block"><dir name="Tracking"><file name="Ajax.php" hash="60eb152db709b70af3a1301d7578c572"/><file name="Popup.php" hash="b3827ba58f592e3e378ba645db89b88d"/></dir></dir><file name="Exception.php" hash="c37e69239674d32986f8ff04caf09ba8"/><dir name="Helper"><file name="Data.php" hash="b176cad5e70504b035065f8790f56a33"/></dir><dir name="Model"><dir name="Carrier"><file name="Abstract.php" hash="1da2a6fe120aea258289b491a177b39f"/><file name="Flatrate.php" hash="b963278ed8e6f9a2c2d772b635d2a401"/><file name="Freeshipping.php" hash="6d35e8d3cd6ec02b1996435c87ed8d82"/><file name="Interface.php" hash="ec7d94e778fc9b56da5033417630587e"/><file name="Pickup.php" hash="3d6461ff7539d666ac8a91fa86ef6907"/><file name="Tablerate.php" hash="e26312f735d0740f7fe67700099314f4"/></dir><file name="Config.php" hash="e287066af283499ef8a2094963d4ac84"/><file name="Info.php" hash="49da8bcfd1fb2588bf3f358bbb595fa2"/><dir name="Mysql4"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="eb37ac0e4242114d7efc067ab84fa86d"/></dir><file name="Tablerate.php" hash="c1c7891ed4d60eaa07c2031050c118e4"/></dir></dir><dir name="Rate"><file name="Abstract.php" hash="c8120b50d7bd267a1cd5c2d709e17efe"/><file name="Request.php" hash="f0fb6eb354e53d6462614a2c219d3635"/><dir name="Result"><file name="Abstract.php" hash="e02a769764e6d75ef60ca85f8bd0b8a4"/><file name="Error.php" hash="ac860d8dff2e14d66bcdc3340d5be70b"/><file name="Method.php" hash="daae81ee20835511b24ca7367bf9f5f1"/></dir><file name="Result.php" hash="98ed87516d9efb709b14c395631bb9bf"/></dir><dir name="Resource"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="7265d1074c2edb0e64bf4a6fae8a74d0"/></dir><file name="Tablerate.php" hash="95421d9235b9935dcff724af1bfb061d"/></dir></dir><dir name="Shipment"><file name="Request.php" hash="e4efe7c8ad51ff44bf51b928b41d293f"/><file name="Return.php" hash="d4a688c26c39df16e3c22c526994d9d3"/></dir><file name="Shipping.php" hash="e3a8c48c31b9db700d0675f431773f75"/><dir name="Source"><file name="HandlingAction.php" hash="5b208e34e6b351c9aa7cff2b13983047"/><file name="HandlingType.php" hash="814c09576fde7947ef0cadffdf74aaec"/></dir><dir name="Tracking"><dir name="Result"><file name="Abstract.php" hash="159774fea23b004463db2ee8a9a60bcb"/><file name="Error.php" hash="dcfb4279dc5396c4e0b62b4e5c127e6d"/><file name="Status.php" hash="80df6a16b056bb8d87acdc1719824a34"/></dir><file name="Result.php" hash="bae51d8ec387de5741b61fd8638074bd"/></dir></dir><dir name="controllers"><file name="ShippingController.php" hash="1b3e10d476e8fe5d2e2d5fc62c4f3d57"/><file name="TrackingController.php" hash="fa19d9a3587e22e4027aaf0638470af1"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3c1d155b5a034afb2250d25a8e3deb5f"/><file name="config.xml" hash="fd973e156b9c7525451d89bb19642035"/><file name="system.xml" hash="fc9f6b3f95040d578b12221fc8253f21"/></dir><dir name="sql"><dir name="shipping_setup"><file name="install-1.6.0.0.php" hash="36e7362e400987cecc8f40cedc89b207"/><file name="mysql4-install-0.7.0.php" hash="40a1d235256297f5b8356646b5d44b27"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0cb07570004b1b9c15aae9fc53b3b3ef"/></dir></dir></dir><dir name="Sitemap"><dir name="Helper"><file name="Data.php" hash="0d1da1f7efa331833eea2e8d05ae2ef1"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Catalog"><file name="Category.php" hash="7cb44704862831285f1fb3024fe7bdc5"/><file name="Product.php" hash="8819b5bac443d29058a0caf7f36d6903"/></dir><dir name="Cms"><file name="Page.php" hash="c31f3e6eedbd0abbac79a0eca5f5c978"/></dir><dir name="Sitemap"><file name="Collection.php" hash="c9e5b30798bcf9de29efe6753a818c46"/></dir><file name="Sitemap.php" hash="080840f73523fc3c0cfbc26ef936f1ea"/></dir><file name="Observer.php" hash="0c525f0c8827adf6d45977abb0402997"/><dir name="Resource"><dir name="Catalog"><file name="Abstract.php" hash="ddeadf2425c985b44414fa19bdefde0c"/><file name="Category.php" hash="0805c996fb090101c66dbb187cc7a2dd"/><file name="Product.php" hash="3cb064607f3f8fbda715703fbd45c35b"/></dir><dir name="Cms"><file name="Page.php" hash="4f45f86704cdf27e8692bf92a07f38ec"/></dir><dir name="Sitemap"><file name="Collection.php" hash="f8f4b4c5c5227b4f2f2fc81ec39f47c6"/></dir><file name="Sitemap.php" hash="3ead76a8aaa778f199ba6a8846e9a46d"/></dir><file name="Sitemap.php" hash="15c53139c1f7417e58af0e0a50bd62dc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="1af1c3ddee5195d95d8d2c6b4f7751e3"/><file name="config.xml" hash="e2e449e864d63173cd0decd800a1976d"/><file name="system.xml" hash="b2fd807782eb88310235daa07b9289a5"/></dir><dir name="sql"><dir name="sitemap_setup"><file name="install-1.6.0.0.php" hash="baa0c6a53cde49b484eda4027d249f5f"/><file name="mysql4-install-0.7.0.php" hash="2f99e2e6056dcb50bb50b16dd3adf6c3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3eea98e870b7a12f972b711972a41187"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="b7a5bf92b87d01f5fc7da34dcf779e08"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="b08a230d237e71d5c4d14113515c7b1b"/></dir></dir></dir><dir name="Tag"><dir name="Block"><file name="All.php" hash="9c586fa6c438210796b468861f021367"/><dir name="Customer"><file name="Edit.php" hash="48d9e49362f4d5624122a0c349a9da81"/><file name="Recent.php" hash="39a93ccd93d60d313ddba2430eb14278"/><file name="Tags.php" hash="575bb1a6e7321d4c07c80e85c1e536db"/><file name="View.php" hash="c51497ef2e787f5ed2d76ff31d297f94"/></dir><file name="Popular.php" hash="5e5aca7c58279a31ac8b7d819068c5d3"/><dir name="Product"><file name="List.php" hash="61bed3264fee80e1d495d705c78e3d96"/><file name="Result.php" hash="46df943675b8b838565df0df27834aa2"/></dir></dir><dir name="Helper"><file name="Data.php" hash="63d5f8bac429ec76ded751f08f199ea7"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="41c01c559d89f06ee8023984e39f341e"/></dir><file name="Api.php" hash="8c474827c3bd4085e3555e5b15518362"/><dir name="Entity"><dir name="Customer"><file name="Collection.php" hash="8d3f5a320ff6b9d8043dce39a6b00e28"/></dir></dir><dir name="Indexer"><file name="Summary.php" hash="da30d3f02de6867f52c02f74e5555c43"/></dir><dir name="Mysql4"><dir name="Customer"><file name="Collection.php" hash="b15f6d56b7a0370e8c36960e37c40ad8"/></dir><dir name="Indexer"><file name="Summary.php" hash="1677838d9e08726293ffdcc1a2a6a85f"/></dir><dir name="Popular"><file name="Collection.php" hash="e4b4a4d0a72ce42fba06b8d4df7cf881"/></dir><dir name="Product"><file name="Collection.php" hash="1b9c603a27674640553f8dddae1c3f61"/></dir><dir name="Tag"><file name="Collection.php" hash="195c1947f180ecd78bd8cc847a1c7541"/><file name="Relation.php" hash="74f25bf44aa6b8cac257e1563d5d2c0d"/></dir><file name="Tag.php" hash="efbd45b16d9062b73bee4e08732a6b2d"/></dir><dir name="Resource"><dir name="Customer"><file name="Collection.php" hash="ccef3608754c4bcfa32f17bae739d8ac"/></dir><dir name="Indexer"><file name="Summary.php" hash="363aaf754a1fef7684d995eaaa22c28c"/></dir><dir name="Popular"><file name="Collection.php" hash="656a1074cce99c835368a024ba45b58e"/></dir><dir name="Product"><file name="Collection.php" hash="71615e51db871bbf120514b12b456769"/></dir><dir name="Tag"><file name="Collection.php" hash="44a1ed8a1bff0c2b03dffcce228e4212"/><file name="Relation.php" hash="c80e4c0ba17e7f652c1dab298a07b615"/></dir><file name="Tag.php" hash="59dfe8a1e9621b64d8931b3b8a2f3157"/></dir><file name="Session.php" hash="b368fc576c8007cc36fcb51a28bb9a0d"/><dir name="Tag"><file name="Relation.php" hash="46200ffd008a5c7a40b620efe55b9272"/></dir><file name="Tag.php" hash="f6a664777ff027c6ff42fe3490125280"/></dir><dir name="controllers"><file name="CustomerController.php" hash="1e1bf9cb8bb6bd08e4b323673f6f0df7"/><file name="IndexController.php" hash="b3af6f013465abf3f0919b1bee6edf36"/><file name="ListController.php" hash="6d959bda65cdcb6f4d42a64e0c158f13"/><file name="ProductController.php" hash="9d02acffcfb4fe104f4c968bb4c3a7a6"/></dir><dir name="etc"><file name="adminhtml.xml" hash="87ff7b15b28edcfe304e4e5e68181339"/><file name="api.xml" hash="f5d2a45711c4a0dc4a7a53b7a0073769"/><file name="config.xml" hash="551ae7849f99b711c7e803e84e7800d9"/><file name="wsdl.xml" hash="e87343a710e0068dcc555ffc4b302a9b"/><file name="wsi.xml" hash="1d31787826a686590acf89ec2703b76e"/></dir><dir name="sql"><dir name="tag_setup"><file name="install-1.6.0.0.php" hash="c20cb71c35fc2bf52e63d91ffb03ab85"/><file name="mysql4-install-0.7.0.php" hash="ef39d408e4238c387220c3f03fe0a2f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3ac5fb48d5d88cfe81eddbecd5999840"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="421fe4350055fe9d9cc0e344215a3191"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0e9ffe30aa58782b7d98db353edd7b43"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="15ab9bc5f0b17b294442748151f589c7"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="5eabbeea53bdb58142c8e77c35ada312"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="8d4b452e1f4a48eca7cee4d93ac57ad4"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="11efa2e8721861477941822c798799c0"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="65b46e90600a4da74ddf399dd6d566b9"/></dir></dir></dir><dir name="Tax"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Region"><file name="Updater.php" hash="beb7c108a4d58bf1807da68347e998ed"/></dir></dir><file name="Notifications.php" hash="877b42a681cb850d2f810b3c537b0b25"/></dir><dir name="Checkout"><file name="Discount.php" hash="f6b150a93995ffb864e841dd0c8da3a0"/><file name="Grandtotal.php" hash="18984bad028645b775779fdcd0d1ece1"/><file name="Shipping.php" hash="9af18eb97f235ed93a29b0cf9d60c525"/><file name="Subtotal.php" hash="62c887dc953d0cb81e82c20b50f6d53a"/><file name="Tax.php" hash="d100b6329e5c2109c995eaa0e0bed2ec"/></dir><dir name="Sales"><dir name="Order"><file name="Tax.php" hash="824870e67250cef4dad26ff4d5ad3163"/></dir></dir></dir><file name="Exception.php" hash="0288092bf16f117a251a68cd4615da1f"/><dir name="Helper"><file name="Data.php" hash="f00cd6b47d65f6cc4491af4dc8b77579"/></dir><dir name="Model"><dir name="Calculation"><dir name="Rate"><file name="Title.php" hash="eb8738069f4b44b0a4ef8848cf76fc10"/></dir><file name="Rate.php" hash="598d9df4f531764c227bac73584d787c"/><file name="Rule.php" hash="bddc2fa731b7233bc5fbedf45b97940b"/></dir><file name="Calculation.php" hash="b5519c3f29d263d9f0cee6b9aa3b20a2"/><dir name="Class"><dir name="Source"><file name="Customer.php" hash="0bd655313bcc6173ef8a567738eace67"/><file name="Product.php" hash="67cc75ab50a0dc7c2fe4a7161c082b5c"/></dir></dir><file name="Class.php" hash="1998d3c9588d16ba5a09142e76cf08ba"/><dir name="Config"><file name="Notification.php" hash="7208ba27883fd27e2806501d6259c2ba"/><dir name="Price"><file name="Include.php" hash="9415f30261fd589c0eab19d01a8e49ed"/></dir></dir><file name="Config.php" hash="d76e7f2c21563f450be0ad26e979ec03"/><dir name="Mysql4"><dir name="Calculation"><file name="Collection.php" hash="aaaf63f8d359ae9db2e7e211c6362d63"/><dir name="Rate"><file name="Collection.php" hash="8101da309f4bec11d9fff4afcd712379"/><dir name="Title"><file name="Collection.php" hash="6e50bf3eb1876c57b38745540fbb48d7"/></dir><file name="Title.php" hash="2a7c7e0ba65a7ea3a7af60941c1d464d"/></dir><file name="Rate.php" hash="9d8c18fa37a08f999ba9b22802d79aa9"/><dir name="Rule"><file name="Collection.php" hash="930edbdf3be5e2639a6d36ce5ca3da83"/></dir><file name="Rule.php" hash="221b5b00fff11e724cfc0cbdababa293"/></dir><file name="Calculation.php" hash="36495ff2315c6f8de48d4f28067ed567"/><dir name="Class"><file name="Collection.php" hash="77fdc197709c96c363fbf0d99dd71e8c"/></dir><file name="Class.php" hash="a13f5209537394288b026be6e04a105e"/><dir name="Report"><file name="Collection.php" hash="3e81ba620644a90f092bd0bc49366aa2"/><file name="Tax.php" hash="a5f9f107397fbc625105e7320c727c67"/><dir name="Updatedat"><file name="Collection.php" hash="a957bc0a2e1b24154ec184459c776178"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="077b167b7c0f031bc5113663d8880869"/></dir><file name="Tax.php" hash="d4702750f1bf5998e5056fb3dee8ed8f"/></dir></dir><file name="Setup.php" hash="e47b718538ded1126b82b9602d681d41"/></dir><file name="Observer.php" hash="d7efde9dd0cf39008662e2a8fec7a1a1"/><dir name="Resource"><dir name="Calculation"><file name="Collection.php" hash="1c569680aecbe5eab48ac45d05bdb6d2"/><dir name="Rate"><file name="Collection.php" hash="502be4d7ff30a162b7fa6368ab2112cd"/><dir name="Title"><file name="Collection.php" hash="aa43e7ad8084224399c9c066151bf705"/></dir><file name="Title.php" hash="8775240533d3a739b9b2fa9cd9482954"/></dir><file name="Rate.php" hash="d87edc2b2de1d830769bf91f72130ac8"/><dir name="Rule"><file name="Collection.php" hash="076e02339bd518be4fe9be6b3fbbff5c"/></dir><file name="Rule.php" hash="32803fa33d812af96fe1b9ceaab4abc9"/></dir><file name="Calculation.php" hash="688202244165823959d54e9d4b6363ab"/><dir name="Class"><file name="Collection.php" hash="5b47f5009f103c633bde387ac7adea4f"/></dir><file name="Class.php" hash="332c61fe7cb39e8203e55ae0f0d99fad"/><dir name="Report"><file name="Collection.php" hash="8bcdfc9f2d9211061822dfc870b98f62"/><dir name="Tax"><file name="Createdat.php" hash="d50b75e5628b6986f83479c6de48c369"/><file name="Updatedat.php" hash="069f0f7f45a8491b1eb51b1329674919"/></dir><file name="Tax.php" hash="e608ad7cfdd88ea1f9b6c7295708527e"/><dir name="Updatedat"><file name="Collection.php" hash="45bc6713a12931c6c43417182a5e6d67"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="4798023eae71bac870b9bf164f57c21c"/><dir name="Item"><file name="Collection.php" hash="801e5275a9825c988327d6a1e0b55681"/></dir><file name="Item.php" hash="76adc830a3be5a27cf1bf1306221809e"/></dir><file name="Tax.php" hash="b1ff6195e235e016961f77cdaaf0cbed"/></dir></dir><file name="Setup.php" hash="dbdaed9eebb4822bda049ed4817a88af"/></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Item.php" hash="1b581b47646f91bd1b98532595d6e44f"/></dir><file name="Tax.php" hash="9d4682194bcbbb567b6955b5e1ebe5c7"/></dir><dir name="Pdf"><file name="Grandtotal.php" hash="107952415d87c39e57cb64b34e4808bb"/><file name="Shipping.php" hash="1e86efcc35e93d89a13f239ee6b909b0"/><file name="Subtotal.php" hash="67ad16e534c7a6cd9cd2ea403b104460"/><file name="Tax.php" hash="d50ccdb4ae7f9f6f4cee8881740cf0d5"/></dir><dir name="Total"><dir name="Quote"><file name="Discount.php" hash="68e59646d4b3ed53cbef37278cb7fbbd"/><dir name="Nominal"><file name="Subtotal.php" hash="4f93a5807d975b92dad5b352f016697b"/><file name="Tax.php" hash="c809da9b571e1261579fa4e71ca1792f"/></dir><file name="Shipping.php" hash="1d0b5484d1912fc947ad4ab0527ea34a"/><file name="Subtotal.php" hash="5bb1ed31fd267d596f755d01a959a65e"/><file name="Tax.php" hash="10de0057288a63ed198dd29b5385dc84"/></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><file name="Algorithm.php" hash="347f5adebdd1619f6959cd3cc134f939"/><file name="Apply.php" hash="53d1f5b5c4a08070a783db8b72caeffd"/><file name="PriceType.php" hash="57c083bbde3ebd93602c6a40d2a6202e"/><dir name="Tax"><file name="Country.php" hash="12331f21e79b44fef3d6e9b1c0b34acd"/><dir name="Display"><file name="Type.php" hash="fcfcb7a434ea1fa9db79cd09cbac31b1"/></dir><file name="Region.php" hash="4b59757baeba8007f3809864d360f62e"/></dir></dir></dir></dir></dir><dir name="data"><dir name="tax_setup"><file name="data-install-1.6.0.0.php" hash="94b4f10de8f7a5a83fe087f06ac92739"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="4468e87f67dfbf16d33b9b2707ee26ad"/><file name="config.xml" hash="350957182c80c7d5e65451b96518fcbe"/><file name="system.xml" hash="bc6897ce79eacc48bd78a78c05828dc0"/></dir><dir name="sql"><dir name="tax_setup"><file name="install-1.6.0.0.php" hash="e0be5cd38897e0a29101a479a3c46576"/><file name="mysql4-install-0.7.0.php" hash="7fe22036e27e3228ef62c1b33ec84dd1"/><file name="mysql4-install-1.4.0.0.php" hash="9dec0361305355dc82b262882ccd81a9"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="d10c616c3450a99a2a070bd82be749d3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8ca3ac7b724434fc4580e89544ffc74c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0d67a01efd09ef2052d61e0c5e7bd980"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="8bbdcaf5614446a39c3cf669a45aa607"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="76a54f836cacb813942ffffc0f6cde04"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="579ed14c0fe3b95f41853eaef2d37374"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="c2dd0bdfccdc77a0a29d555a9b625ae3"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="e72fc20271969d7dc72fd6e11c87e562"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="326b3250a99912852647ae1f1a617f0b"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="2044ce6c72fa421cebbc936cdc3b9551"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b4345cee38819d7335f8a4ac43a719c5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d81466fa4aafe13fa8b643b9d9604a8f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="005cb7ce377789522ee6113cc6faaf01"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a45ecf83147580fd0b205cc5ba8ceb93"/><file name="mysql4-upgrade-1.3.9-1.4.0.php" hash="51c32172a42fe9bfb70246891955f7ac"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="1f40a8d2e8e62f6c7a5c6a801dcefec5"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="38940a651a3ccd71d6b51f2c56292df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="99f59a5a323d2ab93979bd978a71596b"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="c7b5e7a2c05c6bb645b16677ad022aa7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="c40b4ac8f47a6e66aed870bc548424fe"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="39a4fa13ba11365822088398b51e5d7c"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="a4fc58b853d6f51e1984160027bb54aa"/></dir></dir></dir><dir name="Uploader"><dir name="Block"><file name="Abstract.php" hash="3e4c27fef40ca4b4d06e9fbade2fc708"/><file name="Multiple.php" hash="6ad3435e9621366e3002f0fffdbb87a5"/><file name="Single.php" hash="6b7a9c61b8638188d753fd3d61326019"/></dir><dir name="Helper"><file name="Data.php" hash="9d9fe520b988530cf96c9d63df4e0273"/><file name="File.php" hash="74ec342ff936338e70a26356dd7a7008"/></dir><dir name="Model"><dir name="Config"><file name="Abstract.php" hash="9c894362a1fe640a42d12e2ab9dfd8d6"/><file name="Browsebutton.php" hash="33d4e27b9df48a99becd6b4804236ddd"/><file name="Misc.php" hash="f329b6490eec11bbfacb36becfd0331c"/><file name="Uploader.php" hash="458ca8fd03fb3358c8d44c551dec43b1"/></dir></dir><dir name="etc"><file name="config.xml" hash="910b0e0ba92f5510fb8a8de346fc9b47"/><file name="jstranslator.xml" hash="40957bd0383e10b88d3d245e7402b432"/></dir></dir><dir name="Usa"><dir name="Block"><dir name="Adminhtml"><dir name="Dhl"><file name="Unitofmeasure.php" hash="10997c949618283fcff3700837ddc369"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="558952e017a826983a6520f46e055ff0"/></dir><dir name="Model"><dir name="Shipping"><dir name="Carrier"><dir name="Abstract"><dir name="Backend"><file name="Abstract.php" hash="f69a281efe5ecaa85da5aec4b006f76c"/></dir><dir name="Source"><file name="Mode.php" hash="778451ea932baa5cf37697361ba5cae7"/><file name="Requesttype.php" hash="bb39b74b50887b170b0e9d838b5e2c66"/></dir></dir><file name="Abstract.php" hash="e1907149de0a3216004d3b4afa7afcb4"/><dir name="Dhl"><file name="Abstract.php" hash="0efbaa4bd4be9577339b213e882c548b"/><dir name="International"><dir name="Source"><file name="Contenttype.php" hash="e5359c32016f64a446917a655febd027"/><dir name="Method"><file name="Abstract.php" hash="ec7de521c44ed74b7a2803e3b81b1731"/><file name="Doc.php" hash="e58bed061386ca4a31f5c3520880b59a"/><file name="Freedoc.php" hash="f8ff29721fd591b809e51386a6ddbb9d"/><file name="Freenondoc.php" hash="655f111e076d1df9e9ba2a28397b561f"/><file name="Nondoc.php" hash="ce6ff2b22825d59552add3e3b3447c9a"/><file name="Size.php" hash="7b6e56c60b13a2dda8cf36ca4e1dc9ce"/><file name="Unitofmeasure.php" hash="9439cef75a91f110f5bec57c9677f545"/></dir></dir></dir><file name="International.php" hash="1aa74aea3c781fad751eb0721d8c5a70"/><dir name="Label"><dir name="Pdf"><file name="Page.php" hash="e66a0164e6463860135a132dc7895f01"/><file name="PageBuilder.php" hash="5bc6169b5bb68bc2da765e22cef408b4"/></dir><file name="Pdf.php" hash="46552005b344e2ad2daa13c2d8425177"/></dir><dir name="Source"><file name="Dutypaymenttype.php" hash="411ea53d37b0f580aef05290e7c69418"/><file name="Freemethod.php" hash="27aa2a02f19a892afec2bdfd862ea345"/><file name="Method.php" hash="841058d6dc0799bfacf30117871b0bc9"/><dir name="Protection"><file name="Rounding.php" hash="5107a44097c80fe3cbdbd833e7aa05d9"/><file name="Value.php" hash="14acb56219a067f77d7a3eab5406ac0b"/></dir><file name="Shipmenttype.php" hash="1305407602b8d6dbe650a32615bea321"/></dir></dir><file name="Dhl.php" hash="1525b3a3027bcaa419070242fb169599"/><dir name="Fedex"><dir name="Source"><file name="Dropoff.php" hash="aa425f98db3ba3bf9db264c20f2bf416"/><file name="Freemethod.php" hash="4eb4e8853d7f22f520c9d9b45ce27bca"/><file name="Method.php" hash="ac3c72ee7ca1ed4ac173660962e5b0b2"/><file name="Packaging.php" hash="e1111b6983c3a17869a51acd2d0f66cb"/><file name="Unitofmeasure.php" hash="7a5a94c0b97a5edc53782429b3927e86"/></dir></dir><file name="Fedex.php" hash="96d58629ed7b43932590a2a1d1c2e8e7"/><dir name="Ups"><dir name="Backend"><file name="Freemethod.php" hash="578cfe6da0fc52a9ccbf6896c7814030"/><file name="OriginShipment.php" hash="9f63eb33f4d0b9049a99d0d09251a974"/><file name="Type.php" hash="63f031871c1afd0ad464739002d6d18f"/></dir><dir name="Source"><file name="Container.php" hash="49f0d3eb8e52d5f8475a46f1952f52e5"/><file name="DestType.php" hash="fa1e1c6fcb60164ad648354e4648c6d0"/><file name="Freemethod.php" hash="7001561ea932cab7850b2136639c729b"/><file name="Method.php" hash="d1764d9b630f3306457384f87d262b79"/><file name="Mode.php" hash="6cbed4f0cfc486d75e35a7f9fca2a682"/><file name="OriginShipment.php" hash="5984b00f373bc8e95b344b32c3ae8d3a"/><file name="Pickup.php" hash="0b71e6481183c757ee6f3838bd7d146d"/><file name="Type.php" hash="5cd443e78fc2b12b8f96ad35b2cbc488"/><file name="Unitofmeasure.php" hash="8638b87440d4879ad2f5ee66898350cf"/></dir></dir><file name="Ups.php" hash="6454a3a22b8c6c6a8b8d3e38c7e2e1e1"/><dir name="Usps"><dir name="Source"><file name="Container.php" hash="ee6ba442e8ef11d24e53863075076575"/><file name="Freemethod.php" hash="57a6bcdc91fd3349d9f3a9544b7104fb"/><file name="Machinable.php" hash="eee52b5666bd94d3715b57346c1e0c32"/><file name="Method.php" hash="8efa1defbf4156700d26d60fbde252d5"/><file name="Size.php" hash="945f74071f8d37f367c5401cd90ea637"/></dir></dir><file name="Usps.php" hash="7c7a5d30b09e9f79d2e15ca492ad5d96"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f1246bda795b64de06487596bb03afde"/><dir name="dhl"><dir name="international"><file name="countries.xml" hash="8d254d9563909fbd3e7f103efb4b4cee"/></dir></dir><file name="system.xml" hash="f93f4300a2166bd43f9f208e79098e39"/><dir name="wsdl"><dir name="FedEx"><file name="RateService_v10.wsdl" hash="352ed0cd739b31d42d206aba31bf4c31"/><file name="RateService_v9.wsdl" hash="5e698519a3b3ae3dcea2105545053763"/><file name="ShipService_v10.wsdl" hash="4e661e70491a1af695c27878610054e2"/><file name="ShipService_v9.wsdl" hash="9c3779aa87540dcae41b43b16b724df6"/><file name="TrackService_v5.wsdl" hash="89cc7077a8fc439446e70bac0ca0f0c1"/></dir></dir></dir><dir name="sql"><dir name="usa_setup"><file name="install-1.6.0.0.php" hash="60c7ae9339249f390863deb05fe47784"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="1d01eca26e39ae48c0d3e427cfa1ab34"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="2ea78f90b818e7cd228e83b8537b41e8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="1e2088d771a4e0b83d6e93891517b6f1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="758ef4152248dd60f9b3d941cbfd5026"/></dir></dir></dir><dir name="Weee"><dir name="Block"><dir name="Element"><dir name="Weee"><file name="Tax.php" hash="fd0f736c3d8545402e22118356162592"/></dir></dir><dir name="Renderer"><dir name="Weee"><file name="Tax.php" hash="3e6e14e572b75bd7294f08492fcf2402"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="fd44707f27deb17645e7751740474cc6"/></dir><dir name="Model"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="84e0853d03e58f02dcfe8516110d4507"/></dir></dir></dir><dir name="Config"><dir name="Source"><file name="Display.php" hash="dd9b92f8467686bbea476a3ff1bfdcaf"/><dir name="Fpt"><file name="Tax.php" hash="3a4856fc7ef23c693b9e80ca535a0e70"/></dir></dir></dir><dir name="Mysql4"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="860cc567b8fc31a75afd88aba680a725"/></dir></dir></dir><file name="Setup.php" hash="07f6c26a85349e879b1ed3cbc5404ab4"/><file name="Tax.php" hash="d401f1ab63bd5f3a8f7bc821ccb394d4"/></dir><file name="Observer.php" hash="b513b4d768c5ba4adc809485fdae6f24"/><dir name="Resource"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="77a42d4f015dceb9c8f4417415264b21"/></dir></dir></dir><file name="Setup.php" hash="fb6cd54cce66fa17c1830c238e29f377"/><file name="Tax.php" hash="c56763433b9e30cb95098e87ed696397"/></dir><file name="Tax.php" hash="32cd2697d7378f1eb60338b50aef134f"/><dir name="Total"><dir name="Creditmemo"><file name="Weee.php" hash="c56a76968ee4caa1864464fd29cefad1"/></dir><dir name="Invoice"><file name="Weee.php" hash="209638b57ec140cd66d5ac20a0cde1c7"/></dir><dir name="Quote"><dir name="Nominal"><file name="Weee.php" hash="8ae9e90a10b8dafab07435b26448bd99"/></dir><file name="Weee.php" hash="2f8c089417d978dcaaa3d656753e5952"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f157980d75f3045c3a3a37ba7f6946f5"/><file name="system.xml" hash="43de9ea6b63cc96ab3e604e05ccb3247"/></dir><dir name="sql"><dir name="weee_setup"><file name="install-1.6.0.0.php" hash="a034deb1eddaa3d760f78ac3eb89dc4f"/><file name="mysql4-install-0.1.php" hash="2be73cb26708c54b64e7ed7165871924"/><file name="mysql4-upgrade-0.1-0.2.php" hash="200335244e836f11760a34534644126a"/><file name="mysql4-upgrade-0.10-0.11.php" hash="d2f31b8932743ebc6d497b910a106c83"/><file name="mysql4-upgrade-0.11-0.12.php" hash="98b5c962ad1991f4d698141fb41f212a"/><file name="mysql4-upgrade-0.12-0.13.php" hash="834fefba3bbf0cc63fb9997963ff1589"/><file name="mysql4-upgrade-0.2-0.3.php" hash="742e6f9e862bc4ebce15fa024805759e"/><file name="mysql4-upgrade-0.3-0.4.php" hash="4862530eb12a216c98dadb26793ff88a"/><file name="mysql4-upgrade-0.4-0.5.php" hash="0f301cf23c99e77c07649927172588bb"/><file name="mysql4-upgrade-0.5-0.6.php" hash="7b3bc07ac584ec31d163e9dd6c35d750"/><file name="mysql4-upgrade-0.6-0.7.php" hash="6dcd142adc03c785556a68679e4499f5"/><file name="mysql4-upgrade-0.7-0.8.php" hash="e0c094146fd1441de27c04c25e7c5e37"/><file name="mysql4-upgrade-0.8-0.9.php" hash="3b45b9510084a408c5370a6b9d323807"/><file name="mysql4-upgrade-0.9-0.10.php" hash="38844cce782c07afea0fe477a24c1fcf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="bbb550408e834459dc0c24e395e301f3"/></dir></dir></dir><dir name="Widget"><dir name="Block"><dir name="Adminhtml"><dir name="Widget"><file name="Chooser.php" hash="f41f4a5d4abbb5317de07d76c0af9ce5"/><file name="Form.php" hash="2f430de2e4b79346ac15bc2db84a6086"/><dir name="Instance"><dir name="Edit"><dir name="Chooser"><file name="Block.php" hash="35b0a2189584bd507cba9273413713bf"/><file name="Layout.php" hash="4a3c6e4105a35ca9469b83a677a15aab"/><file name="Template.php" hash="d5bff7a35634d46aec79c838ef8028c7"/></dir><file name="Form.php" hash="e5c088065bbcc2f34b6b921a29434873"/><dir name="Tab"><dir name="Main"><file name="Layout.php" hash="4f72e2287ef012ae37a7d7ef1e56ecac"/></dir><file name="Main.php" hash="856e66104b67ba24ac31f8db4d90d36e"/><file name="Properties.php" hash="a03aabc3764bb85938af96b9f8865a8b"/><file name="Settings.php" hash="66721fb67187c4d84a064349697b4383"/></dir><file name="Tabs.php" hash="cd9abdda69b86e35e80d62282d7c083b"/></dir><file name="Edit.php" hash="e44bea2b39f359f75cccec1996681143"/><file name="Grid.php" hash="fc2f183e4fdb3120aa8132f3f045fe71"/></dir><file name="Instance.php" hash="2d2368b22010c6aa68698b61d9412702"/><file name="Options.php" hash="0ee8355dd026bf75ca4026cd5e6eb3a3"/></dir><file name="Widget.php" hash="0efda79c01989b1b371be56f094df65d"/></dir><file name="Interface.php" hash="7e8e943dbf9c350738e0c7b87bf33873"/></dir><dir name="Helper"><file name="Data.php" hash="fb9cd633320087c35b78e251572d4a3d"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="fb7c16f16ca147b4b0277f705264615e"/></dir><file name="Instance.php" hash="33b19185739fa245b0ab24743f0da1ff"/></dir><file name="Widget.php" hash="669f7241dfd0a221866b183488d5d676"/></dir><file name="Observer.php" hash="3da4b54327a1f24dff9d479ea39d4004"/><dir name="Resource"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="e07e92d933818e5ca96c67778a3f9286"/></dir><file name="Instance.php" hash="531253749642a5e9d5038879d48bab57"/></dir><file name="Widget.php" hash="ac5884a08704af82ca4b8a0dcbc61127"/></dir><dir name="Template"><file name="Filter.php" hash="72fd9c6fbcb49e145fc78728fb927ea0"/></dir><dir name="Widget"><file name="Config.php" hash="f439b671f2f89ca440a7f9ea3e01c60b"/><file name="Instance.php" hash="c5d1e18924f417073eb5ee65917cb7e4"/></dir><file name="Widget.php" hash="d691a3d871172a98fa64684d2c6e4910"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Widget"><file name="InstanceController.php" hash="63939b7121ca34e33ec7c5c303ec79ab"/></dir><file name="WidgetController.php" hash="5296aaec9297cc6a5eae90ddeb423ba5"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2d49ebc683d76e660e80f670aa824cb3"/><file name="config.xml" hash="d513372267bcab378f3490305c74aac7"/><file name="jstranslator.xml" hash="33ef3294aecd2ecf7d7918a12b8ccbd2"/></dir><dir name="sql"><dir name="widget_setup"><file name="install-1.6.0.0.php" hash="ee2405ce1bda7a5fd724c6e6579e6c23"/><file name="mysql4-install-1.4.0.0.0.php" hash="303d557b443da9a0b648e0b489db8df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f26a2433a7568fdcc02a348d95efb285"/></dir></dir></dir><dir name="Wishlist"><dir name="Block"><file name="Abstract.php" hash="d41153ea1f2fd24037aa23ea1b02bbb0"/><dir name="Customer"><file name="Sharing.php" hash="693a4499b8c54044686c0450eb624f4f"/><file name="Sidebar.php" hash="c5a5f3501e9e4d95835da6beb107b569"/><dir name="Wishlist"><file name="Button.php" hash="9116b58cbcd737532fa9ab1368226915"/><dir name="Item"><dir name="Column"><file name="Cart.php" hash="1abc6a7fbce4370166aede5f704efcdf"/><file name="Comment.php" hash="411e2ffd53fecd487f416e8c97466be7"/><file name="Image.php" hash="e4fea81d458007fff38347b281f46016"/><file name="Remove.php" hash="183986e5e3c1ade450540b0061cfe184"/></dir><file name="Column.php" hash="ffd2c66332126dd318f30a5e285c3fe2"/><file name="Options.php" hash="3113081b2adcc919ce92a727ed83bd8e"/></dir><file name="Items.php" hash="d2bb5dff0a7138d97df7819fa1755149"/></dir><file name="Wishlist.php" hash="e80f560419ea9dc2ea0d3a9216638a8c"/></dir><dir name="Item"><file name="Configure.php" hash="3e9b9a068f1d885f7ba02c5d941529bb"/></dir><file name="Links.php" hash="25b1030ea691741332070314c09507e1"/><dir name="Render"><dir name="Item"><file name="Price.php" hash="9b022ae29781b7b542130588ad72e080"/></dir></dir><dir name="Share"><dir name="Email"><file name="Items.php" hash="d6a9ed3eb79687ba3fd613a80b0b77cb"/><file name="Rss.php" hash="49efbf8d871afeba9f65b5fcc0dbcd1b"/></dir><file name="Wishlist.php" hash="1d541e90a5793b84fe6eaca98dcbd49f"/></dir></dir><dir name="Controller"><file name="Abstract.php" hash="8645269d5466e6bd4b5e4e875a9d2216"/></dir><dir name="Helper"><file name="Data.php" hash="86851e022187af87ad203e235da38d53"/></dir><dir name="Model"><dir name="Config"><dir name="Source"><file name="Summary.php" hash="7a2b80db4fe6a978b5786e76a5c904fc"/></dir></dir><file name="Config.php" hash="2b2911baaf1c7185c3326e0ce0557a31"/><dir name="Item"><file name="Option.php" hash="6dd700cd04aab1da4261c3482b314bf2"/></dir><file name="Item.php" hash="1c0f79a254b69e888c6a59d781aa2c44"/><dir name="Mysql4"><dir name="Item"><file name="Collection.php" hash="ee47fa47f801be5897e46cb6a1b414e4"/><dir name="Option"><file name="Collection.php" hash="1d69f4047866ceba682ebba1760b7882"/></dir><file name="Option.php" hash="e8d6eb6783c0d110e1fb9019c18ae1bb"/></dir><file name="Item.php" hash="ed1dee8fe9f393fbbc09080bec44bb0e"/><dir name="Product"><file name="Collection.php" hash="d0d3b256caa2f2cf82b6749e71a1e250"/></dir><dir name="Wishlist"><file name="Collection.php" hash="f0de345db6724cf0f2215ca3d6e2c55a"/></dir><file name="Wishlist.php" hash="847ae12dfb58e6a7cfce9f225aa3c208"/></dir><file name="Observer.php" hash="2d1514b092fc4e0bc9476950f56d2e98"/><dir name="Resource"><dir name="Item"><file name="Collection.php" hash="1cb2d243a6a5f3e0a68fd3adad2ad37a"/><dir name="Option"><file name="Collection.php" hash="d0929064f2c7a8342fda1e353d672e1c"/></dir><file name="Option.php" hash="689b388fdb474b0a070a0e855e09aabc"/></dir><file name="Item.php" hash="21a88028b07b955f2bf263f17c2442d2"/><dir name="Product"><file name="Collection.php" hash="e83f7c166b796125b3b85ae4acb6642c"/></dir><dir name="Wishlist"><file name="Collection.php" hash="b88d95c758cf27ae03a3c9a4bbfbb943"/></dir><file name="Wishlist.php" hash="6f5081c171d93eb92a9c2920b0e0c67c"/></dir><file name="Session.php" hash="d2ae560ea5c56b10055d49fd4e66ebc3"/><file name="Wishlist.php" hash="b1fe5e818d5b092c37559f30437cb05e"/></dir><dir name="controllers"><file name="IndexController.php" hash="409f16b88fdceb021f5bdb3be84d44cd"/><file name="SharedController.php" hash="fa0c415383e783f70014b0f9376b60eb"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9213f2e94f8cab90211fb80826a700c2"/><file name="config.xml" hash="34fc8f3562566125f8f093f4a165726d"/><file name="system.xml" hash="ee72b4a7f5247c4b29e3b4d94b4054ad"/></dir><dir name="sql"><dir name="wishlist_setup"><file name="install-1.6.0.0.php" hash="5d61c25439596c2594416b8eaebe9009"/><file name="mysql4-install-0.7.0.php" hash="932ebcea937b1affa6567809f946df3e"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="648bf1ff930a83ce088b2cb881d43758"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f65eaaf98841a9840acc3b3e5209c1"/><file name="mysql4-upgrade-0.7.2-0.7.4.php" hash="b4f3216bd940240253079c6899aeea46"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="15e4be127414d41faeabb193b044f543"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="11f60666b29d10381c810f39dd64fa1b"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="04074c4d3e41a0fb1eee82feba0537b5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="7e43180e183e6236eea1a75c471d24ac"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="cf7c5d37479155a28c180252f3222bc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="afc76dcb77fca764870c502db86d244d"/></dir></dir></dir></dir><dir name="Zend"><dir name="Controller"><dir name="Request"><file name="Http.php" hash="92d5e6e2538a8c23af43faae8200c60b"/></dir></dir><file name="Date.php" hash="95bf218944785f606f22c2ea0c077f5d"/><dir name="Db"><file name="Select.php" hash="28f3efa5f9797af22f899fb525dbb44f"/><file name="Statement.php" hash="4b5b39a1e1c651ab9d6db332c882fdf7"/></dir><dir name="Filter"><file name="PregReplace.php" hash="1b5bbd52c2b2d17f19db273606e5ddfc"/></dir><dir name="Form"><dir name="Decorator"><file name="Form.php" hash="fbd6a6687ef13a8b7ba416c1ca50dd38"/></dir></dir><dir name="Locale"><dir name="Math"><file name="PhpMath.php" hash="a95d7d3d0d7220b47d0e518ffad508f7"/></dir></dir><file name="Mime.php" hash="f216d84221e3d7601822b4c95948aeaf"/><dir name="Serializer"><dir name="Adapter"><file name="PhpCode.php" hash="d19044ca7b67e672bb9627f572f1a069"/></dir></dir><dir name="Validate"><file name="EmailAddress.php" hash="e04917b783b4880bdc984e7774abf7a6"/><dir name="File"><file name="Upload.php" hash="a5de679b71a82a061dbddd3afde626b2"/></dir><file name="Hostname.php" hash="08c032ea8831e62e79c792e274220aa9"/></dir><dir name="Xml"><file name="Security.php" hash="7366a7b9e2dab5551b557f49d900d6a1"/></dir></dir></target><target name="mage"><dir name="app"><file name="Mage.php" hash="83a4cc5f50ce35888e567e4cefa8ddeb"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name="bootstrap.php" hash="5692f824efc22a75246f10e88b1bd3b7"/></dir><dir name="."><file name="cron.php" hash="52235435ed8bf309f9fbbf2c47e80f04"/><file name="LICENSE.txt" hash="59563e7be45096d0833dade102989042"/><file name="index.php.sample" hash="a605f93d48608b283696e2473319f32a"/><file name=".htaccess.sample" hash="971c336db60ac86ae96b5c5871be1e8c"/><file name="LICENSE_AFL.txt" hash="45a399f2095030865fb962263ccd7506"/><file name="LICENSE.html" hash="caf0a79ffb5e4719f9f4de286f253a61"/><file name="cron.sh" hash="64e5df07f32d93c83a0c986bbce6bcc3"/><file name="install.php" hash="c9154ce64d8ce2c96aea25b242b7b077"/><file name="php.ini.sample" hash="d7412c2f78440a96fc2d9378ccf460cb"/><file name="get.php" hash="0e147e2a291707ab75091fe1b0f764e1"/><file name="RELEASE_NOTES.txt" hash="5a3d5fce3e536ce74dbff0ed9afc2a21"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="api.php" hash="2605aef23c3d1030ab6a10f91c7cbdd2"/></dir><dir name="errors"><file name="404.php" hash="557eebe76671c3f51ef07b0892802c67"/><file name="503.php" hash="5843bd0da9d8a0ef173154a81dc89305"/><dir name="default"><file name="404.phtml" hash="fd358b5b2dba922be64b1d711648c309"/><file name="503.phtml" hash="8b7b63a9e1c2a23179280af48e6b3633"/><dir name="css"><file name="styles.css" hash="730771c6f889a40e64e712541a909012"/></dir><dir name="images"><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/></dir><file name="page.phtml" hash="09c7f4694acf2c1936e15e1304965840"/><file name="report.phtml" hash="e9dfdea4409fc2e8463de932b3a6147b"/></dir><file name="design.xml" hash="7bf4d647bade27485007ceff382c77eb"/><file name="local.xml.sample" hash="8c65e80b446b4b52592a216c2a4b9d8b"/><file name="processor.php" hash="34adac569448ace7ab4b33ad977e960a"/><file name="report.php" hash="2c28c37e5a006ce64946150a1c12168c"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/></dir><dir name="var"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="shell"><file name="abstract.php" hash="3e9ed270d023a86541744119c8588fb7"/><file name="compiler.php" hash="0b90e3996b5f315e133a71b5613b957f"/><file name="indexer.php" hash="b80a6c7b2f641e98e487662eb5d1aaa6"/><file name="log.php" hash="0c2c4db2ac3b778106070484edf5b951"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="lib"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="media"><file name=".htaccess" hash="08de5b2f5ea1ce6f51f40a19bacbf42e"/><dir name="dhl"><file name="logo.jpg" hash="68500df59e568e01333ba078a262ca27"/></dir><dir name="downloadable"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="customer"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></target><target name="mageetc"><dir name="."><file name="config.xml" hash="cd99effb308b25632010f59726b1894c"/><file name="local.xml.template" hash="ff798ff56329f93e4d253ee50083e07f"/><file name="local.xml.additional" hash="8504141dcf1d0b1f2e2ed54b19c902d3"/></dir><dir name="modules"><file name="Mage_All.xml" hash="fa6a5ea2883abbba8e96b84c96f2cfed"/><file name="Mage_Bundle.xml" hash="9c247f8a5d4a6fd39ed58ab6f4722058"/><file name="Mage_Api.xml" hash="48d6e1dee18721bd3048da0918ac246d"/><file name="Mage_Downloadable.xml" hash="6f0c7caf9bab79db23c43fd8f9bb4827"/><file name="Mage_Weee.xml" hash="5448953a4ace9de652ab42dae4836154"/><file name="Mage_Widget.xml" hash="751d506bebd89db6ff302f3cb5926875"/><file name="Mage_Connect.xml" hash="0df11e64ef7a39ffa53f65bbbda70d7d"/><file name="Mage_ImportExport.xml" hash="16908a3f3cdaeac311ea90dabec3c80f"/><file name="Mage_PageCache.xml" hash="4f7b1d28d3d6c002ed3b7d3923affcc5"/><file name="Mage_Persistent.xml" hash="5055d23f9ad54f04e64a8b54a304b25d"/><file name="Mage_Authorizenet.xml" hash="e4267c93799b07c3dcb2f192f51bdfda"/><file name="Mage_Captcha.xml" hash="c2f88e068ccee9bb077e02dd80299abf"/><file name="Mage_CurrencySymbol.xml" hash="7c0400eafc6d0f44e456852491f5476e"/><file name="Mage_Api2.xml" hash="c106f0994020cf2c392d6ba6732b8909"/><file name="Mage_Oauth.xml" hash="28c9f32075749d7711720fc73c20060e"/><file name="Mage_ConfigurableSwatches.xml" hash="3ca495f8c747f71eab4f15a892f75211"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Varien</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Google_Checkout</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.18</min><max>1.51.1.18</max></package><package><name>Lib_Js_Mage</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Phpseclib</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Mage_Locale_en_US</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Mage</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Magento</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Pelago</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Unserialize</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_IDNA2</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package><package><name>Lib_Mcryptcompat</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Mage_Core_Modules-1.9.4.2.xml b/var/package/Mage_Core_Modules-1.9.4.2.xml
new file mode 100644
index 0000000..4336f3d
--- /dev/null
+++ b/var/package/Mage_Core_Modules-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Core_Modules</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Collection of Magento Core Modules</summary>
+    <description>Collection of Magento Core Modules</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:12</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="Admin"><dir name="Helper"><file name="Block.php" hash="458b8f115baadb9bb2a64772ecf6faaf"/><file name="Data.php" hash="ee37966b67fede75d28e2bd4b642a206"/><dir name="Rules"><file name="Fallback.php" hash="63a2a06fcc65d1365fe14389b0cc8590"/></dir><file name="Variable.php" hash="e6a48f57af455ab3f3610a7094680bf0"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="df761d8226d98aebd5047558c90dddc5"/><file name="Time.php" hash="8581922d946be6f1e6496228f250d63f"/></dir><file name="Resource.php" hash="c78602679aa503a4641100a70d87dd21"/><dir name="Role"><file name="Generic.php" hash="8e268c160dc69b1f052e1948b3772cf4"/><file name="Group.php" hash="85cbd9ce11fa91cd866387e7f2241cf3"/><file name="Registry.php" hash="10ae5d0ae8eb22282213406a3b1c6b57"/><file name="User.php" hash="45dfe3b059b4d76232dd0f4266d27de4"/></dir><file name="Role.php" hash="8319d780dd06ac1ee61b34b9bd9b1cf5"/></dir><file name="Acl.php" hash="f1a340153512be4e5809f5dac8369d90"/><file name="Block.php" hash="5aa8ca761232ebfc510aff6c0c206123"/><file name="Config.php" hash="5a9ff605e890d318845b08fce172cd87"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="1d6d5abcdf73801aa101061e1aa65f06"/></dir><file name="Role.php" hash="86f57a0a161f1c2f83f6d024f4c2912c"/></dir><file name="Acl.php" hash="4d305204a82da4aac2da4610b1e0124d"/><dir name="Permissions"><file name="Collection.php" hash="18351c0c29cfc2b5aeda23676981ee6b"/></dir><dir name="Role"><file name="Collection.php" hash="81c32bf683040142c56c4d7908eea7b2"/></dir><file name="Role.php" hash="c273803640f531fe3a70789c138bb2d5"/><dir name="Roles"><file name="Collection.php" hash="c49a4a37edecd189de05abd22317afb9"/><dir name="User"><file name="Collection.php" hash="d2a2541d7b716cb149e8bf85892de2e5"/></dir></dir><file name="Roles.php" hash="7ce5c01f31ab0a0a17733dd5d287d971"/><dir name="Rules"><file name="Collection.php" hash="d899f64d25b4b94c8af851758d7aae23"/></dir><file name="Rules.php" hash="bb1854a73b92b474a8b08e1cc3744a55"/><dir name="User"><file name="Collection.php" hash="4c660da859de8fc555ec5762ddcb36e0"/></dir><file name="User.php" hash="2476a65f5413ca88bc472e667d1e2fae"/></dir><file name="Observer.php" hash="fa5800ac1cf353a58ac6c54302b00092"/><file name="Redirectpolicy.php" hash="63c1657f8bc4057fbff402a787f5b4b3"/><dir name="Resource"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="f303429166be37291210a09bf5a5b7b0"/></dir><file name="Role.php" hash="024d8fd83ad0202cabd4681ad49d5353"/></dir><file name="Acl.php" hash="4fcc23cfdb5640f0d7a586106b11b1a4"/><dir name="Block"><file name="Collection.php" hash="47c9c77cf4fbcf4e23e92177883e61c4"/></dir><file name="Block.php" hash="6da7836e73f2b7bcd6ffe441dcb2d8b5"/><dir name="Permissions"><file name="Collection.php" hash="f189808b46860de0a1371b6e4c4893cc"/></dir><dir name="Role"><file name="Collection.php" hash="a08a34456c4d21b735949239d8c88158"/></dir><file name="Role.php" hash="9f10fd18cb941f3282ab0b6612fdc2eb"/><dir name="Roles"><file name="Collection.php" hash="9bee6ac75a949e5b403cfd19d259fd06"/><dir name="User"><file name="Collection.php" hash="e7e9996a1128f35cb87b9aa75fdbe2a5"/></dir></dir><file name="Roles.php" hash="6d9d4a4704bd62b7c2af7f7c1f0e244e"/><dir name="Rules"><file name="Collection.php" hash="9aa586accf6b402ca57b5930dbdbc21d"/></dir><file name="Rules.php" hash="9b48b047903611a52d91dda257048da9"/><dir name="User"><file name="Collection.php" hash="d68fbdc9b6e0b59ece07b8a9e6786735"/></dir><file name="User.php" hash="19f9662e179ae93b95a7414197e1e97b"/><dir name="Variable"><file name="Collection.php" hash="bf75d58b6748a9061cf9f0d894444d6f"/></dir><file name="Variable.php" hash="381276f5ab482fac9f276a7bf09edb1c"/></dir><file name="Role.php" hash="0c579d2eb5a9f993e5e3329286ba02e7"/><file name="Roles.php" hash="be8be3c2225ad59cec09aad3696cd154"/><file name="Rules.php" hash="9aec2dcc8843a9b2aa7c2f169b27967d"/><file name="Session.php" hash="6fb43a7459f0af522f74b9044f41ed66"/><file name="User.php" hash="c73d7e37c1e524201333dc1b2644e993"/><file name="Variable.php" hash="aec37b73e2b07b24642873047404f20c"/></dir><dir name="data"><dir name="admin_setup"><file name="data-install-1.6.0.0.php" hash="7113336c6b7992a5336c8ca3d38a2c52"/></dir></dir><dir name="etc"><file name="config.xml" hash="fa53dadd6e1989703d157a53dfc29920"/></dir><dir name="sql"><dir name="admin_setup"><file name="install-1.6.0.0.php" hash="1c84ae65e4147d21198b1f6ff96a8090"/><file name="mysql4-install-0.7.0.php" hash="dc2ec63c66efe0667052f5695093efe2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="893eba8a43a2437db98f8f089deba809"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="c256c803009aaa3b08c09811fe01ce64"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="3c493153e71d4fa917b648c4b3ab0399"/><file name="upgrade-1.6.0.0-1.6.1.0.php" hash="1558790a6f8e8cf5c778a242fbe756ee"/><file name="upgrade-1.6.1.0-1.6.1.1.php" hash="4d46adc07a9f68c089c6ee25ebb54064"/><file name="upgrade-1.6.1.1-1.6.1.2.php" hash="9025a95c29a05a354458e97a9d7444b9"/></dir></dir></dir><dir name="AdminNotification"><dir name="Helper"><file name="Data.php" hash="bdf63a1450e6a0d77647163e535a1a7d"/></dir><dir name="Model"><file name="Feed.php" hash="1cbe43f8f0f79d4ba4d104d022485e40"/><file name="Inbox.php" hash="822e30a30c67ebc5651a059370edc50e"/><dir name="Mysql4"><dir name="Inbox"><file name="Collection.php" hash="0c711250151fb41968688e8a7baaa8f5"/></dir><file name="Inbox.php" hash="c8767a365e9f9b0302aebc42e72d8761"/></dir><file name="Observer.php" hash="a85254ea61683a6146e266c46e4cfa91"/><dir name="Resource"><dir name="Inbox"><file name="Collection.php" hash="8a1c2a44972cfbf2a0b5c24da5133318"/></dir><file name="Inbox.php" hash="95e2ddc1912bd2efa08a618bdc542721"/></dir><file name="Survey.php" hash="c71fe449197c0a95484361b06e1acc9c"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9184c5e0cd123342fef181533713a39a"/><file name="config.xml" hash="4bf128768d14ef45927ca932d8423d58"/><file name="system.xml" hash="a875bfd316e096b935277ced23132470"/></dir><dir name="sql"><dir name="adminnotification_setup"><file name="install-1.6.0.0.php" hash="fabadefeaa0cbadc7d765e49b00c03e2"/><file name="mysql4-install-1.0.0.php" hash="7be8540787e2171bca831efa9692cdc2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f1039f623c2ce22aaa01d97277e0523e"/></dir></dir></dir><dir name="Api"><dir name="Controller"><file name="Action.php" hash="bd77a9bdaf5850d9bfad340174c12d17"/></dir><file name="Exception.php" hash="d1e38258a214dc8db2751c8e67058737"/><dir name="Helper"><file name="Data.php" hash="0235c25d21316a6b1bf71e5f06602892"/></dir><dir name="Model"><dir name="Acl"><dir name="Assert"><file name="Ip.php" hash="4c325d339c19b0bbb8a14b180556920a"/><file name="Time.php" hash="06cc212749e4d7e2a8f5afd03705414d"/></dir><file name="Resource.php" hash="aac365b2c3ee9b552e7fc375a609187b"/><dir name="Role"><file name="Generic.php" hash="1a92e79f592330147dfc5812c749b7fc"/><file name="Group.php" hash="7524be45a0860a7ade02a8d94037464f"/><file name="Registry.php" hash="c728275604c9e3710b3001973d10fd00"/><file name="User.php" hash="653adf396b08780f2175f7c96548aecc"/></dir><file name="Role.php" hash="bc68c60309dacff590e7ca5687b0618e"/></dir><file name="Acl.php" hash="6d3a947164d97c653d7408b28965ebee"/><file name="Config.php" hash="0d7cbdc5a29b2ea9e0018b9ec3084bcc"/><dir name="Mysql4"><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="0021a4898d1b458957eb82bc056f468e"/></dir><file name="Role.php" hash="9dba1e6bb824820fce1b2e3cb878bebd"/></dir><file name="Acl.php" hash="f9a5a4868835e3fb9ef2befc2e2fca97"/><dir name="Permissions"><file name="Collection.php" hash="93e7ed97d480968828126f8cbac2b664"/></dir><dir name="Role"><file name="Collection.php" hash="e564b8136d2beebd7dfd3c8795a6e7fb"/></dir><file name="Role.php" hash="d2303886929c5a2d9484ab6dc9fc648e"/><dir name="Roles"><file name="Collection.php" hash="39f697e304e7a4a2978c35a4d89cf0fe"/><dir name="User"><file name="Collection.php" hash="d51c2908f06e072ed90c8fd252383549"/></dir></dir><file name="Roles.php" hash="6305b9320e2bd030fb2081df86e91004"/><dir name="Rules"><file name="Collection.php" hash="e3edf62d099fab993099fe7978f509e1"/></dir><file name="Rules.php" hash="e6b2ebb7b9f814d6707a299b239dd5e5"/><dir name="User"><file name="Collection.php" hash="b0f3a87ba9cc21ec9cad2c3f70c8006a"/></dir><file name="User.php" hash="2a6f6b9b53cdf0a51ad2c9e253c483a9"/></dir><dir name="Resource"><file name="Abstract.php" hash="b40505a25b52fec30b0301500a4c496e"/><dir name="Acl"><dir name="Role"><file name="Collection.php" hash="c39386eacf0f62cb47f5f5e0d7014901"/></dir><file name="Role.php" hash="2928e279cac38426a7412c14807c2213"/></dir><file name="Acl.php" hash="b4d9d34d5da6ed935cc21116435dc471"/><dir name="Permissions"><file name="Collection.php" hash="1ed55c2383301800a07667bc81cc64b3"/></dir><dir name="Role"><file name="Collection.php" hash="389bc113941dbc97b9d66f1f466bc517"/></dir><file name="Role.php" hash="d7024cb60533f6f695d7b2640cdb3b29"/><dir name="Roles"><file name="Collection.php" hash="2ecc66e5450ce840ba0815baae50b628"/><dir name="User"><file name="Collection.php" hash="843c0817b32d47a643fe228d8da97658"/></dir></dir><file name="Roles.php" hash="7ec43dce63b207595cdf18d11f3678de"/><dir name="Rules"><file name="Collection.php" hash="bce86b29edc97fcc30288a6c17087cb9"/></dir><file name="Rules.php" hash="5c5e0f6b3f7ebfcf40b262897eb3136b"/><dir name="User"><file name="Collection.php" hash="74e42dad01f99a8d90ecc0ee9bc434f9"/></dir><file name="User.php" hash="940e1623c70b37ba21d9f379298d068b"/></dir><file name="Role.php" hash="1a34866ab10a5126f886b37ad9393026"/><file name="Roles.php" hash="b69872a87d5080c393bbee4946347e41"/><file name="Rules.php" hash="bfad6890c425f6ef2867454dc7a09257"/><dir name="Server"><dir name="Adapter"><file name="Interface.php" hash="49d97f0fdf244cba251f2e71df4532d6"/><file name="Soap.php" hash="aea4f7712b8e053cfb3ad0b2aa579a58"/><file name="Xmlrpc.php" hash="f4d77d694c5c55097cb816f94217f438"/></dir><dir name="Handler"><file name="Abstract.php" hash="cf7483db39b44c1234fb852592770d05"/></dir><file name="Handler.php" hash="402d95a6f76155ddfc676b6a71baa259"/><dir name="V2"><dir name="Adapter"><file name="Soap.php" hash="3a179c5fb3150c3d8aba66e8999866e2"/></dir><file name="Handler.php" hash="6a939cce44aa9cde7be5b5954c5d753a"/></dir><dir name="Wsi"><dir name="Adapter"><file name="Soap.php" hash="9b2e5affb656129f9e71a0c64853eb84"/></dir><file name="Handler.php" hash="edc38c50fd82505aec0352afc03e691a"/></dir></dir><file name="Server.php" hash="b18193c91fb496f53ad7b089a4dc354d"/><file name="Session.php" hash="11b03d4e7981b9cfb1084591a0aea701"/><file name="User.php" hash="96d22cd787a295bb80a5260d134b372b"/><dir name="Wsdl"><dir name="Config"><file name="Base.php" hash="29d45f55afd1d66cf64af7444e18c559"/><file name="Element.php" hash="93d907a44ab1bc5f7d0424b83c1c501f"/></dir><file name="Config.php" hash="c5a618233b98eb5b0e37d67b65a18597"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="568e76f1884f10d0f5bf8e645ea875bd"/><file name="SoapController.php" hash="a94f525c875292024c976a3274954024"/><dir name="V2"><file name="SoapController.php" hash="7a128ce7e5dc7ba6807e059e45c346fe"/></dir><file name="XmlrpcController.php" hash="7368bbf60c4f6ea50c07b8b555ddc0ed"/></dir><dir name="etc"><file name="adminhtml.xml" hash="b4264dc427c433e5e98207dd637e5e57"/><file name="api.xml" hash="01302962e36ba24259cb3c19a035e856"/><file name="config.xml" hash="26783afff003adf6af459ea1679581ae"/><file name="system.xml" hash="b6a534e8fa06ee34c7befd27b4e44339"/><file name="wsdl.xml" hash="f0db676b04733b38f310355bb44bc3cb"/><file name="wsdl2.xml" hash="7d527421ba4b63a8a812ab6b1095891d"/><file name="wsi.xml" hash="9fb1700cf935a26e7fada90a07fae7fe"/></dir><dir name="sql"><dir name="api_setup"><file name="install-1.6.0.0.php" hash="066ad21052c5b083ab2778e26bbe4db4"/><file name="mysql4-install-0.7.0.php" hash="5d039bc1aeb7f803ab216a1139919bb1"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="4cdf27ca6d95a560f40cbc7eb2665094"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="25e09696a22644ac6aa111ed73b5655b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="15efffec7b0ef3361156df41d15946de"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="1e64826e6d3ca3d0846017cf8acaa4b0"/></dir></dir></dir><dir name="Api2"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><file name="Buttons.php" hash="4376dded28b4aa5586685e2f732ad2ab"/><dir name="Edit"><file name="Form.php" hash="0af6dc58ce485e2f59bac5a46c0d7163"/></dir><file name="Edit.php" hash="1f99242190399def7e2ca9283fe5c410"/><file name="Grid.php" hash="30bd3ba3317f12cc7c52844cf150b994"/><dir name="Tab"><file name="Resource.php" hash="7856f0dbbcc9be2dbf353d58ce480b2f"/></dir><file name="Tabs.php" hash="f54db50cb4a392c688ae6d1be77c58e2"/></dir><file name="Attribute.php" hash="d2dcf496bc82ffdf9a705a3877bb8b2d"/><dir name="Permissions"><dir name="User"><dir name="Edit"><dir name="Tab"><file name="Roles.php" hash="72a6b7a56e4274b02a365ad0f30c8165"/></dir></dir></dir></dir><dir name="Roles"><file name="Buttons.php" hash="4c579d0bc782554233f06cac17412895"/><file name="Grid.php" hash="cdbb76a0a3d30ef0daf01283767fb85a"/><dir name="Tab"><file name="Info.php" hash="e43741793c49f3777e6b392c842c1fd9"/><file name="Resources.php" hash="7054ebad58581afc4407ad8da7c079b0"/><file name="Users.php" hash="f993e6653358f42ff71db5cf9286a429"/></dir><file name="Tabs.php" hash="9d35522fc2a4c3b02255f3d60e9331d1"/></dir><file name="Roles.php" hash="af1a304185f658eb382267e449f7ee47"/></dir></dir><file name="Exception.php" hash="c21f7e48d91909cdd8ff34c7b5f5996c"/><dir name="Helper"><file name="Data.php" hash="3b3b8c14d3e0062cc169f5170e865860"/></dir><dir name="Model"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Operation.php" hash="09038220fb9d14e00b7fb1161f443e40"/><file name="ResourcePermission.php" hash="0afbf662990f30b973a7000f90e130f4"/></dir><file name="Attribute.php" hash="0a5693b841c58a4cf2b11a586ab015b6"/></dir><file name="Filter.php" hash="3c35c99209e0e44972db68289427d0c5"/><dir name="Global"><file name="Role.php" hash="fbcf77d11b3ad6b3d76f62de2631cfd9"/><dir name="Rule"><file name="Permission.php" hash="b562dc5aface03f159f364dfb221046e"/><file name="Privilege.php" hash="0e758f46f64b58efed6ef6330417bb8a"/><file name="ResourcePermission.php" hash="7c7d8f9f33daeec606c5dc68d72aa6a0"/><file name="Tree.php" hash="7b5a5f72cc5f5bcb4c880e5c1b3e0533"/></dir><file name="Rule.php" hash="b4c30ae4bf8ad5111f56d5cc5c1f4c22"/></dir><file name="Global.php" hash="b8740f8a74f44181cfe72594c9962156"/><file name="PermissionInterface.php" hash="a2da51f36241c2f2cdadb52227ebc6cb"/></dir><file name="Acl.php" hash="1573afb52fc330438eac73bfc6d11763"/><dir name="Auth"><dir name="Adapter"><file name="Abstract.php" hash="3720722eff5b1948e4b8e8283cfc991b"/><file name="Oauth.php" hash="6cb6dc6f5e261710a5a217262e300725"/></dir><file name="Adapter.php" hash="b5759916b5235990ebaf3509b3d02790"/><dir name="User"><file name="Abstract.php" hash="ba1a6bba6d01055fda5fb3efc9e5342a"/><file name="Admin.php" hash="9fb3184fd96676702c15184ea14eae12"/><file name="Customer.php" hash="4c14d7df43453f52af73fa10e773e015"/><file name="Guest.php" hash="6402fa2d5ef1b6b688ca15057675ee59"/></dir><file name="User.php" hash="53283f1d82f3f704c4dbec8808ba22f9"/></dir><file name="Auth.php" hash="d2b4b8b817d6618ff2310e7d66f82be9"/><file name="Config.php" hash="65eee46fe1d1099fb3b0516e9279ee61"/><file name="Dispatcher.php" hash="bffc0249f6f9dbb2e8f52e8558b9baff"/><file name="Multicall.php" hash="f303ee72911f0628a181b206f5727c09"/><file name="Observer.php" hash="acf8944643c694c1e0b555d12c33cdae"/><dir name="Renderer"><file name="Interface.php" hash="d580bba55508a29b09eddb0e0f753eac"/><file name="Json.php" hash="038ae9d48ddd2d00fb3a73c0dcfc90bc"/><file name="Query.php" hash="5a3fc89d32a6e4540039fd7ae36feefc"/><dir name="Xml"><file name="Writer.php" hash="b5f2fb511668c0e713b7d569460dace8"/></dir><file name="Xml.php" hash="05844d8a79ef772e98eb1516fca69c75"/></dir><file name="Renderer.php" hash="a6dd26eadb27238cc5a39fc970ce60e9"/><dir name="Request"><file name="Internal.php" hash="85db2090307e0b32c11662dc274bd260"/><dir name="Interpreter"><file name="Interface.php" hash="7adc09d4d35ea0693d440e951b02d422"/><file name="Json.php" hash="c155284d01ba4967c03bcaf2ae6f2d04"/><file name="Query.php" hash="f1a500e1b52d781ffd85214111ec46fd"/><file name="Xml.php" hash="1474e9963e826ee65adf3d83d82d5b3a"/></dir><file name="Interpreter.php" hash="55520f65c5f50dc164784d328b7cc391"/></dir><file name="Request.php" hash="dbd1366ad80c96f28e9c6df621d1ee84"/><dir name="Resource"><dir name="Acl"><dir name="Filter"><dir name="Attribute"><file name="Collection.php" hash="e5a758eb30a4ee0b406e14d90fed3f7d"/></dir><file name="Attribute.php" hash="bff17f4c6dae72f866075aed2143a7ea"/></dir><dir name="Global"><dir name="Role"><file name="Collection.php" hash="27100e15437eaf77ad1442c57512efd6"/></dir><file name="Role.php" hash="0573edd7fbdaec6c60677bf9524081b8"/><dir name="Rule"><file name="Collection.php" hash="f0e7595e6a38d6908f02a80f51d69a77"/></dir><file name="Rule.php" hash="bf31ec43122c7148631e8353ce072ee6"/></dir></dir><file name="Setup.php" hash="39bae99a03d25ec831edfe03dae94c6e"/><dir name="Validator"><file name="Eav.php" hash="7d5b412a1011ae3ebe26f5bedcd53b55"/><file name="Fields.php" hash="e49f90a6054e9668ece648c8af135400"/></dir><file name="Validator.php" hash="0f31952b0282cb8ce0c6de1a61e6faed"/></dir><file name="Resource.php" hash="f626093895fb369a857b3d93e895f595"/><file name="Response.php" hash="cf5bafdb46c7c5cd6954b2e64f3a581b"/><dir name="Route"><file name="Abstract.php" hash="b63d027e93acd4fac077146537be06c9"/><file name="ApiType.php" hash="4e239e1601c6604a185e267f8ae126d0"/><file name="Interface.php" hash="3191c533ce588c2df505c1504c66f5ad"/><file name="Rest.php" hash="e49d49128fb02808fe5c72d4a4b06f52"/></dir><file name="Router.php" hash="ac09ccb08d4a7da221e078d8c0faafb0"/><file name="Server.php" hash="97ce9fe49ceab3e8f87fab8cef1840d1"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Api2"><file name="AttributeController.php" hash="0780ce523414d956dc51b46867b51f15"/><file name="RoleController.php" hash="0f3e02c6804c03e4c76ca8458d9aa6da"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="9b99c5a3de756424196e58a98487e4e5"/><file name="config.xml" hash="c2c3d2f8ee69cce25c6cd662391b77f8"/></dir><dir name="sql"><dir name="api2_setup"><file name="install-1.0.0.0.php" hash="790f059183189cfa3fbb348c362403eb"/></dir></dir></dir><dir name="Authorizenet"><dir name="Block"><dir name="Directpost"><file name="Form.php" hash="951236a941f006e8d3067949dbb93eb0"/><file name="Iframe.php" hash="4ee9b7b6b588d7a36108af6b36d807f3"/></dir></dir><dir name="Helper"><file name="Admin.php" hash="242ce0696a5ea9123097869120543fb2"/><file name="Data.php" hash="745bce8bee42112c10d9e52705b96e67"/></dir><dir name="Model"><dir name="Directpost"><file name="Observer.php" hash="bc0cb094c3f4393861b2f5d3c45ac219"/><file name="Request.php" hash="3ac73d3f5ef193aac5b9fc0cf7d538da"/><file name="Response.php" hash="f17712b757ec4d41bb5fbaf9b4db9622"/><file name="Session.php" hash="94b77b8be59e39571d4e0d399a330e4b"/></dir><file name="Directpost.php" hash="7f05004fe006c917bc42c6ff3560d638"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Authorizenet"><dir name="Directpost"><file name="PaymentController.php" hash="2fe86219e1e9eec3b40eed97e5ca31ce"/></dir></dir></dir><dir name="Directpost"><file name="PaymentController.php" hash="5fad7bd1934637ff441eed6ed08358f0"/></dir></dir><dir name="etc"><file name="config.xml" hash="b9e07ee15a531eb7e5dc9ee6eabffae7"/><file name="system.xml" hash="794b307b2bc88cbfc9452bf791fa3ffd"/></dir></dir><dir name="Backup"><file name="Exception.php" hash="baa8812918560125167c4b3dff59fd4b"/><dir name="Helper"><file name="Data.php" hash="a74e2b999e106365de6d702acef15621"/></dir><dir name="Model"><file name="Backup.php" hash="2f0baa336548120691c2f86c5d7d6158"/><dir name="Config"><dir name="Backend"><file name="Cron.php" hash="e3afe2dac55f4c0c21035509a7ad03ff"/></dir><dir name="Source"><file name="Type.php" hash="80d255889f3ab648ecd2b96789cd5b8f"/></dir></dir><file name="Db.php" hash="20de8464af9b44585d86542770d84424"/><dir name="Fs"><file name="Collection.php" hash="bda11a66e9485d39bbd65ef106a5827a"/></dir><dir name="Mysql4"><file name="Db.php" hash="c709100f98d4c0e594ac781818ae91c4"/></dir><file name="Observer.php" hash="e15b50bd82367ba32a07ff7e920448f9"/><dir name="Resource"><file name="Db.php" hash="126e3ee2b9bd03fb2008f958852a9931"/><dir name="Helper"><file name="Mysql4.php" hash="433085a484930534865c7096108e5b18"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1bdf439e0dd516b2793aed5b29292595"/><file name="config.xml" hash="c116519a1ac0e6b14344a154addb3bd8"/><file name="system.xml" hash="c561811e44bbf97968fbde0d3f93cabc"/></dir></dir><dir name="Bundle"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Bundle.php" hash="7ba4af5e0cc19fd57543a1e8a435e463"/><dir name="Options"><dir name="Type"><file name="Checkbox.php" hash="b4802f23317cec64155a0a854fd05f38"/><file name="Multi.php" hash="666954cfc526ff66a93794c3a4a4329d"/><file name="Radio.php" hash="3e16ee3943c4dd6db44e6aaf43669534"/><file name="Select.php" hash="bf93776f105756314e810a20aaedfbcf"/></dir></dir></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Attributes"><file name="Extend.php" hash="6b15e48fbb1d64f91c9b33bf48117d0d"/><file name="Special.php" hash="ba9c7de799a80bad0f37c88a92bbc0ad"/></dir><file name="Attributes.php" hash="282fe2257c01625167d2499502b8f28d"/><dir name="Bundle"><dir name="Option"><dir name="Search"><file name="Grid.php" hash="0a157c18808c8e97a7090ca4014f88b3"/></dir><file name="Search.php" hash="ed0a329442cf1207bd9f7e2c91e9dcc0"/><file name="Selection.php" hash="2a3d2c794fbf9754978a8e751b935821"/></dir><file name="Option.php" hash="66bb0e76f1810c7f4908f2a8b531418e"/></dir><file name="Bundle.php" hash="4076b8967fe5d7507058338ba36c473a"/></dir><file name="Tabs.php" hash="e31c5a810990ab5c089df54761082bc7"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="c0afda9392dde9b38bc71eb09151a1fe"/></dir><dir name="View"><dir name="Items"><file name="Renderer.php" hash="9a5c04f6975466b25c3baf9436bbade7"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><dir name="List"><file name="Partof.php" hash="f14e5c86ee5482519933627ec0ac3da8"/></dir><file name="Price.php" hash="cf6e7d8dfdeb7c20102d78d955c3a08f"/><dir name="View"><dir name="Type"><dir name="Bundle"><dir name="Option"><file name="Checkbox.php" hash="234a0dde586568d352a2d63bdbc1a203"/><file name="Multi.php" hash="247fb02f6773737d566cd4f30dd42585"/><file name="Radio.php" hash="e69225f7462c36f62092b9264dc3ccad"/><file name="Select.php" hash="aa02b9e489a4b817875cf8352c5cca71"/></dir><file name="Option.php" hash="4a4049d3d4528214818366dd4238a73c"/></dir><file name="Bundle.php" hash="78e470548ba63160e4c3fb5eefe3c5e0"/></dir></dir><file name="View.php" hash="adf9d177b5f714144f732974a75f693c"/></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="b4846bf466d14816fdc960bad99253bf"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Items"><file name="Renderer.php" hash="8328adc7ab06c404b5f678f52c4b36ba"/></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="c3b92627d497d6af3420a70884a9900a"/></dir></dir><file name="Data.php" hash="1df35d7602d491b3a3a5896dbe1c4439"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Bundle.php" hash="07e8532dfdf36af78680fe629726df65"/></dir></dir><dir name="Mysql4"><file name="Bundle.php" hash="a42904a5602a94bd4bc682866b4db372"/><dir name="Indexer"><file name="Price.php" hash="2d31c9d360c0c3483157283f9675399f"/><file name="Stock.php" hash="178db785d8bd219a0cd789bf1c998259"/></dir><dir name="Option"><file name="Collection.php" hash="094532247ebc66e7531f8b4d37448a6b"/></dir><file name="Option.php" hash="757bbf29c2788e7ad3c46a1abe6e8c6f"/><dir name="Price"><file name="Index.php" hash="188f493c00e63966bf9bcc817e99c578"/></dir><dir name="Selection"><file name="Collection.php" hash="450f5c62e214a2739bbd65a8bf37cafb"/></dir><file name="Selection.php" hash="94b63b71c7d37885385223f7ff0d1f4a"/></dir><file name="Observer.php" hash="086ce0bea7d0b7e9c2c6862a0445cf6f"/><file name="Option.php" hash="c3286cf424d27fa9474691f44a8fe0aa"/><dir name="Price"><file name="Index.php" hash="b6ad3d5912b14b50e83105a5cb89171b"/></dir><dir name="Product"><dir name="Attribute"><dir name="Source"><dir name="Price"><file name="View.php" hash="999c58650a57146f6115b6152c931d12"/></dir></dir></dir><file name="Price.php" hash="5714d620d44a3b78e1824fb5ed3ae01c"/><file name="Type.php" hash="940953a610d3ddf54452750d4eb09ba6"/></dir><dir name="Resource"><file name="Bundle.php" hash="dff534e1e5b1bdd46d381e534163787d"/><dir name="Indexer"><file name="Price.php" hash="87e595b484a5e306e8a9111cdc41b770"/><file name="Stock.php" hash="467fd84b1330cc43410f9a11c9a7569f"/></dir><dir name="Option"><file name="Collection.php" hash="f933036863523dac13f6d4e0c5192de9"/></dir><file name="Option.php" hash="40c76760181b30092e745caf7e71a825"/><dir name="Price"><file name="Index.php" hash="156ea664373d1e7074f604e150b47416"/></dir><dir name="Selection"><file name="Collection.php" hash="5e637bea02628db76299f9141cd69280"/></dir><file name="Selection.php" hash="b92a36a662d7c15da0b6be34a72abd28"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="03572513aa7302634912cdb25682700d"/><file name="Creditmemo.php" hash="72830f7b86d48f04fabe7dc149d0c8a8"/><file name="Invoice.php" hash="4eb93c31fddd2743e9fad84f82468403"/><file name="Shipment.php" hash="ff978de79d7517c9665d43519f2ce386"/></dir></dir></dir></dir><file name="Selection.php" hash="69baeefb547cd3e266695ba07fe05428"/><dir name="Source"><dir name="Option"><dir name="Selection"><dir name="Price"><file name="Type.php" hash="0125cebe6acd7c5d8d5ba5471c560cc5"/></dir></dir><file name="Type.php" hash="b132757f9677ca55c605266de6357df8"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Bundle"><dir name="Product"><file name="EditController.php" hash="590760cfa7cba02f55192b805db49bb7"/></dir><file name="SelectionController.php" hash="c67d92020a00d1e92fb6d1ce2d143478"/></dir></dir><dir name="Product"><file name="EditController.php" hash="c707c3f48f3513035a2e0370fb5aade8"/></dir><file name="SelectionController.php" hash="c9865d2186f986d57d2024076914b381"/></dir><dir name="data"><dir name="bundle_setup"><file name="data-install-1.6.0.0.php" hash="834e88f6e39a4494fcd6e38c054c6928"/></dir></dir><dir name="etc"><file name="config.xml" hash="6b7ab06798a4fa4854b29ea2055d1d5a"/></dir><dir name="sql"><dir name="bundle_setup"><file name="install-1.6.0.0.php" hash="262c230428893cb4bdd1a4302009b98a"/><file name="mysql4-data-upgrade-0.1.13-0.1.14.php" hash="4998433373fab9c5c49160a29a0506b5"/><file name="mysql4-install-0.1.0.php" hash="6fa016bc3431841ce3207fec2d523b54"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="effab7ebe8c2e84c0f22657191758711"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="6e550a3d455cef957ecca7ead0d280e1"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="76ef43ee7da599cd9373ef468bf005c2"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="d1ba25ae101d380cb8d68335f2ab06b4"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="124054e21b0980238b0366f0a62bb42d"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="6f5ae289258acc4522d12ac5abf4ef3a"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="ebca03c63ca3d4cb2e99f0b35e994b3f"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="3773f524d98c2e47bf89d251f80fb2b3"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="f30a13c3101129c7235e51e5354dd6eb"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="68e4f5cafb451800272abc27d177ca99"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="6eecd8118f59a2207d79b30ba264f2b0"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="ad618762396db26f49047f72c70c1c8d"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="c118caf7158504dd027d7281e447d263"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="78643674b5e2a23ee8a7fde720863e25"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="caadeb7ff995da1e38205162eba466c4"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="58c22c0e8cd208b2d835653a3dde61aa"/></dir></dir></dir><dir name="Captcha"><dir name="Block"><dir name="Captcha"><file name="Zend.php" hash="3977d0d2bf3559ea2d1a8b61e34117f2"/></dir><file name="Captcha.php" hash="43bfc5969f3760b7722881264b40e0f7"/></dir><dir name="Helper"><file name="Data.php" hash="4c2c154247df498f877b454c1502d9be"/></dir><dir name="Model"><dir name="Config"><file name="Font.php" hash="16fe5a425b5904f4f0b00812cad7942b"/><dir name="Form"><file name="Abstract.php" hash="0597e90c9258fc7e9de472b9b25953bf"/><file name="Backend.php" hash="644d7f0c08686657a8ce89e644a86ca9"/><file name="Frontend.php" hash="6653882a570c41743beaa0067a8e2cf5"/></dir><file name="Mode.php" hash="0fcefa5ea27784bdd4b6e125ef68fff3"/></dir><file name="Interface.php" hash="fb4478e8efbcf6e5da049262cf66d888"/><file name="Observer.php" hash="b092094a1eddec47b3154d929d77bae6"/><dir name="Resource"><file name="Log.php" hash="5a0fcf217682a204b35e418f9651fcad"/></dir><file name="Zend.php" hash="0cad6772c236172521bd055e52f4b0ef"/></dir><dir name="controllers"><dir name="Adminhtml"><file name="RefreshController.php" hash="0a547debcf1ecf94f5cbf45af9df3ae1"/></dir><file name="RefreshController.php" hash="82f8029551cfd90cd49f2564b1d326ba"/></dir><dir name="etc"><file name="config.xml" hash="c61bc3cbc21b8f5962ad064b6360227c"/><file name="system.xml" hash="6b7e2abc886b31929e708032016d596c"/></dir><dir name="sql"><dir name="captcha_setup"><file name="install-1.7.0.0.0.php" hash="f55e8b44e85eb45a1c269ca812673ab9"/></dir></dir></dir><dir name="Catalog"><dir name="Block"><file name="Breadcrumbs.php" hash="fddd5639798e608beab3083ba2c8cbd7"/><dir name="Category"><file name="View.php" hash="20e9ffebff3b3b815744a1004c1ace17"/><dir name="Widget"><file name="Link.php" hash="958b7b4d4451c45c87eeec162fb036a0"/></dir></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="233349b4ed30754552beebf2017befaf"/><file name="Attribute.php" hash="89f25995def2df558d16cd5a789a62c0"/><file name="Category.php" hash="ea73ccf086dae6e75ab42f12a1e0fd4c"/><file name="Decimal.php" hash="a234d3e3d8ce706a6dc2d767dd3c1d2c"/><file name="Price.php" hash="8534996d8cef258d71058e8f7bd2a39a"/></dir><file name="State.php" hash="13dcb224587b9aa0713b328036823842"/><file name="View.php" hash="5704d8dc8c9eb75eefb2c0ab944ac23a"/></dir><file name="Navigation.php" hash="7b1ac252eb61561c2d5469f3334a4999"/><dir name="Product"><file name="Abstract.php" hash="7251ca5141601e62788d7ec8e45a90e1"/><dir name="Compare"><file name="Abstract.php" hash="4c5b544b7f377b24e37b00932c0a0cea"/><file name="List.php" hash="e955111eebdc60c2a544ad66ab97c676"/><file name="Sidebar.php" hash="e75063e747180ee5770d5ddf94acb21e"/></dir><file name="Gallery.php" hash="889da5cbd69b57dc962cab3b06005779"/><dir name="List"><file name="Crosssell.php" hash="16207ddc8747afd0e69498864dc3a709"/><file name="Promotion.php" hash="089d616d1256ba1c07ce77636ea7a8a7"/><file name="Random.php" hash="57fc65f888bf1dd0dfd9d42a21998e2e"/><file name="Related.php" hash="d247df0901913879c9c1087b72a21d9f"/><file name="Toolbar.php" hash="966dcf34a0eafd655d3a4ea7eaddb3a5"/><file name="Upsell.php" hash="c92ae83f08e6c4c45760728b3f40891d"/></dir><file name="List.php" hash="a9f4e8afa57585edb4a258c76f319898"/><file name="New.php" hash="999949bf0fcdb227134c8e961868586e"/><dir name="Price"><file name="Template.php" hash="8f0bc8a4e7c7461d36bc7a33a78ca1d2"/></dir><file name="Price.php" hash="9acaf5c95cb91048fabe750592f6db2b"/><file name="Send.php" hash="75f97faddb731f029cf699e65e2b8b3c"/><dir name="View"><file name="Abstract.php" hash="6e63017428696209c585e9bfd1385d28"/><file name="Additional.php" hash="802f73ac1e8a66549e5b5b40ffee88e5"/><file name="Attributes.php" hash="4d82fbb43a89e9dfcaae01d1a5b4436e"/><file name="Description.php" hash="f9fbc548fe417a1f1b633415d9f0a63d"/><file name="Media.php" hash="e2bb92043c1cbb187de2956dfa6876b9"/><dir name="Options"><file name="Abstract.php" hash="725b81be39c3848fcbc3fb70721db151"/><dir name="Type"><file name="Date.php" hash="f3678e2b3c39fa5d715cc05785312cb2"/><file name="Default.php" hash="72366888ca379300c605f731eccde59b"/><file name="File.php" hash="8686ba6fdd775c2ab0d4af2c60543eef"/><file name="Select.php" hash="1b8b22cfe146d294cd104ad63c2ef4ee"/><file name="Text.php" hash="7373b44ae870027f493e095720b84b0e"/></dir></dir><file name="Options.php" hash="946b45b2199ba1ec1e10896adbf43682"/><file name="Price.php" hash="6dbe44af12aa2cd9b2a7651f67edea8e"/><file name="Tabs.php" hash="e175ecbef45eea4c478d31c9d31fa31e"/><dir name="Type"><file name="Configurable.php" hash="99b1835743bd3aa1b53e80e5795ff037"/><file name="Grouped.php" hash="1352247682029865c76f704eb233c124"/><file name="Simple.php" hash="d7aaf15d55146d78d812d38b7fa6368f"/><file name="Virtual.php" hash="e64c5c2a8b71912d27657a44426727c5"/></dir></dir><file name="View.php" hash="621ca1ecc0cb4f21bb91ea26a0cfe29c"/><dir name="Widget"><dir name="Html"><file name="Pager.php" hash="d23f158ebb2383b7ff7a299915becc49"/></dir><file name="Link.php" hash="511a83b5c1328cd36f134d8f0814aab3"/><file name="New.php" hash="cb6dc0d7bd0c57d6a7c24e49fb279687"/></dir></dir><file name="Product.php" hash="5c2ad3dd5f5397c65efbf724f53f7d1b"/><dir name="Seo"><dir name="Sitemap"><file name="Abstract.php" hash="40505e53a280121520a9ab520c663a83"/><file name="Category.php" hash="620007da4f8211cdfb98fe9869f076ab"/><file name="Product.php" hash="4ef93e4a8947ff83f217e4af62c30037"/><dir name="Tree"><file name="Category.php" hash="931c98b2d937398ff7d4c1d8c3bb3965"/><file name="Pager.php" hash="0c7e6eb90729ea43712e6aef24e5b1ce"/></dir></dir></dir><dir name="Widget"><file name="Link.php" hash="e342be9976dbaffc9dcda7114f4ff07e"/></dir></dir><file name="Exception.php" hash="f12a83054d1a20c8e3aa4cd1d7aeed1d"/><dir name="Helper"><dir name="Category"><file name="Flat.php" hash="b25f4a4413c48058f1ad39cc58fc9d7c"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="14862f6ce3841239fb8e716978c1a311"/></dir><file name="Rewrite.php" hash="f6d564c29c38d9a0ef4aae9b80b91d64"/></dir></dir><file name="Category.php" hash="a3b276b2a88e1f97d986ed410fc89ea5"/><file name="Data.php" hash="f059c4211b1e40dc7c6bcb36b3b92d74"/><dir name="Flat"><file name="Abstract.php" hash="734af81e26cd91683decfd37c6fdb3bc"/></dir><file name="Image.php" hash="caccf877e69bcd2d1ddf44d4bdff0732"/><file name="Map.php" hash="8b29bb2b08a1db72f9e503a1e0e6b6c7"/><file name="Output.php" hash="3f66589fc28f12e2ae0ee9e64b42c17b"/><dir name="Product"><file name="Compare.php" hash="2f123719fa790283470f7014b3438d19"/><dir name="Configuration"><file name="Interface.php" hash="1f160deb5cc07c0b0cdc7f76939e4caa"/></dir><file name="Configuration.php" hash="834c453253c40cb83b407221589890e9"/><file name="Flat.php" hash="c3e13a893302fe1bc6a0cf7fb578d093"/><file name="Options.php" hash="69f21b6b8265daa0e9d05b9d92cb468d"/><dir name="Type"><file name="Composite.php" hash="d7a74a64416804402b0d285bbcabf41d"/></dir><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="031aa4fca8c3e0b1f55ddf8eadae6a8d"/></dir><file name="Rewrite.php" hash="edcb3ca25714d5898bedcc551022bc65"/></dir><file name="Url.php" hash="2f859186a0b33b2ffd81ce381515c003"/><file name="View.php" hash="2ebc969f69e0d229b68b6462a52cbfcb"/></dir><file name="Product.php" hash="154dfe17cb1bd4b44240ff9fa6f7dd95"/></dir><dir name="Model"><file name="Abstract.php" hash="a8752cda0d7483ff1f2abe8c6d8667ac"/><dir name="Api"><file name="Resource.php" hash="c864b1f333f93a7e7f4e9dae32cf514b"/></dir><dir name="Api2"><dir name="Product"><dir name="Category"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7d7df63a06284862387fd3e183c10ff6"/></dir><dir name="Customer"><file name="V1.php" hash="8f4f1df79cd262f164d4830de2457792"/></dir><dir name="Guest"><file name="V1.php" hash="985d982fe174e9c574f79ecf71fdc79b"/></dir></dir><file name="Rest.php" hash="3e6a87ed62de65906241b2fd744d2d1e"/></dir><file name="Category.php" hash="8ee8aff92291ff265125a2a09c89cd60"/><dir name="Image"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="b99a15e80fcba83b69da3f0577732055"/></dir><dir name="Customer"><file name="V1.php" hash="b77c0d708c7341a755e7019cda0d638f"/></dir><dir name="Guest"><file name="V1.php" hash="1b25d97bb413a07e3cdedc4315d80552"/></dir></dir><file name="Rest.php" hash="3bedc3fdcb449e4fc552d51b4db3befe"/><dir name="Validator"><file name="Image.php" hash="8f563a0dd5eae33f59bb02d2350c8362"/></dir></dir><file name="Image.php" hash="4a435d724c9449619b9dfeada3c7f349"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="783b786dba0cfc0d7ac426f21985d332"/></dir><dir name="Customer"><file name="V1.php" hash="93bbb0c279c14210ccf40efda631ce66"/></dir><dir name="Guest"><file name="V1.php" hash="a6c70a60cb465ea65ae9d6dc5bd4a77d"/></dir></dir><file name="Rest.php" hash="168cc5bd719b85c205ec26742231701e"/><dir name="Validator"><file name="Product.php" hash="b1aeba72fd9478aa254e00befe7749d2"/></dir><dir name="Website"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8af3b32ea6a088a5eba8897a27b0fc0f"/></dir></dir><file name="Rest.php" hash="bce18e8c16db4be5067cf2e6ba364196"/><dir name="Validator"><dir name="Admin"><file name="Website.php" hash="8d22190d53b13b51a94eff9fd04f0aeb"/></dir></dir></dir><file name="Website.php" hash="6719ea0d36732907b897e377613d475c"/></dir><file name="Product.php" hash="11f9ccd6151a00d1cc19458ac5d05ee0"/></dir><dir name="Attribute"><dir name="Backend"><file name="Customlayoutupdate.php" hash="8a21fffdaf1cc4ffdf99f8ea7aa6d597"/><dir name="Urlkey"><file name="Abstract.php" hash="601a5cb04d820a1d28303e419708076b"/></dir></dir></dir><dir name="Category"><dir name="Api"><file name="V2.php" hash="5f0d39fc8300b9c4cdf080930ec27000"/></dir><file name="Api.php" hash="06db8ae01d1d3dcc9aca5a6ad4a8682f"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="c523122e1a5372678021801313f5fc49"/></dir><file name="Api.php" hash="b903a006267395b79ed6597c1f4743c6"/><dir name="Backend"><file name="Image.php" hash="8fd6fde98705cddced3ecf8253d5e9d4"/><file name="Sortby.php" hash="691af9d6173479fe7de0e82a3041ccfa"/><file name="Urlkey.php" hash="aeaa47c7a3aa478890f34d813456a40d"/></dir><dir name="Source"><file name="Layout.php" hash="ed247fde90f503a0ff797d9c019a3261"/><file name="Mode.php" hash="73e70a70a5aefbde6deb297882682fce"/><file name="Page.php" hash="9ab54c333bdb3458cc4ed5772cbda275"/><file name="Sortby.php" hash="8e19aea914848a0cbb31f3052677c255"/></dir></dir><dir name="Indexer"><file name="Flat.php" hash="604655e7cb987b716c2cf5b53f67d7f3"/><file name="Product.php" hash="9292cdefc56b9a80d68bb89a50b2b8db"/></dir><file name="Url.php" hash="937cbb08cf0df2a7f0c5ad78fcab17a7"/></dir><file name="Category.php" hash="fa9eab482b2dc9c89d9872963ddda499"/><file name="Config.php" hash="bfd4ebc72a0af7794c5866dea818db39"/><dir name="Convert"><dir name="Adapter"><file name="Catalog.php" hash="4a5dc0d4e4d513722ecb1e65507b9cac"/><file name="Product.php" hash="480c3893ac68ba8d5543e807cc8baa3c"/></dir><dir name="Parser"><file name="Product.php" hash="93fe85cc3b5d9c30adef55c6d17a9a99"/></dir></dir><file name="Convert.php" hash="d30056fc529cbc17b30ab1e9eade55d0"/><file name="Design.php" hash="015dc04db309159146bac792dc095356"/><dir name="Entity"><file name="Attribute.php" hash="17a40b3517dbe7ffe701f1da46970638"/><dir name="Product"><dir name="Attribute"><dir name="Design"><dir name="Options"><file name="Container.php" hash="7455da8147f8507b60bb0ba1418bbb4d"/></dir></dir><dir name="Frontend"><file name="Image.php" hash="f732289725a78b3c6632fa7990751899"/></dir></dir></dir></dir><file name="Factory.php" hash="12e1d2c3eda1542ea68d815255811d89"/><file name="Index.php" hash="d0b063d15d53b5cce0c43a04c98bbd68"/><dir name="Indexer"><file name="Url.php" hash="38765eba8afe37e6b2684e5ac29f8dc3"/></dir><dir name="Layer"><dir name="Filter"><file name="Abstract.php" hash="dd2cc2f440246631303bced9048750a4"/><file name="Attribute.php" hash="6a2c1c5cbe65138ef8bf33e274b61fe0"/><file name="Category.php" hash="98fa713a3a3bb451be05dd417be1c655"/><file name="Decimal.php" hash="e90016c6d18a189530fe888920dba47c"/><file name="Item.php" hash="201f811b88c46bf8a69db078eff5a3c5"/><dir name="Price"><file name="Algorithm.php" hash="544a88b82e4d3c494a479e8ea73e0b92"/></dir><file name="Price.php" hash="7cd7c428a372882153a61a032df62de9"/></dir><file name="State.php" hash="76bc7ddbb78683b65e71e905b575a5eb"/></dir><file name="Layer.php" hash="9a9b65ebd5a1c36011aaea477e198563"/><file name="Observer.php" hash="4bfd941d75131dd2232f888985849389"/><dir name="Product"><file name="Action.php" hash="decd0145a0f07fe7cbd7393fa118c9ec"/><dir name="Api"><file name="V2.php" hash="793a4b99d025fc6dfabd2da709cbdcd7"/></dir><file name="Api.php" hash="4501c79b530a237fce07c6a60d9ecbf3"/><dir name="Attribute"><dir name="Api"><file name="V2.php" hash="3685f98a45122c256ede43ece696d5c5"/></dir><file name="Api.php" hash="bd1e32f897684f8dbd33bf8a05bbf072"/><dir name="Backend"><file name="Boolean.php" hash="2a5a0456c6620dea4221748911124d3e"/><dir name="Groupprice"><file name="Abstract.php" hash="b5900fc2c486a70e526baeda26cb0c3e"/></dir><file name="Groupprice.php" hash="3786eb7d502bd0b3a17f0f6f80e82dce"/><file name="Media.php" hash="65e6c1cbaa29a18f6aefa3fffdca8a75"/><file name="Msrp.php" hash="c7d44ca4f1ea3794cb19154bc2bc9e9a"/><file name="Price.php" hash="141048adfd0a2e00c4df780bec708c5b"/><file name="Recurring.php" hash="097c0474a762c4cf7cb87b5b0e4d048e"/><file name="Sku.php" hash="54a49ebfe99905992c11d6e193cbfcb8"/><dir name="Startdate"><file name="Specialprice.php" hash="0bb04fa551a461658cdfeea5c783be81"/></dir><file name="Startdate.php" hash="0ad91d8bccbe9dc867ccea9f99d0fd2e"/><file name="Tierprice.php" hash="3681dc3533c8604368a349c68ac68f1b"/><file name="Urlkey.php" hash="2e29bcde62d97ad85f8be84361b3e343"/></dir><dir name="Frontend"><file name="Image.php" hash="290245ae6814aebe9e6ef535973841f5"/></dir><file name="Group.php" hash="0d5a1d1d89c2d6a1055d77db9872ea6b"/><dir name="Media"><dir name="Api"><file name="V2.php" hash="133a39fb7e1107ef9fa81a0543a3e8dd"/></dir><file name="Api.php" hash="49913c934aa085481b744d7333fe343b"/></dir><dir name="Set"><dir name="Api"><file name="V2.php" hash="15517f2009ed3c7d72af842619926088"/></dir><file name="Api.php" hash="28959aef8dffec2ccc252a0f39660e38"/></dir><dir name="Source"><file name="Boolean.php" hash="72523d6f15bb4b7a5ddd8fb235f046bd"/><file name="Countryofmanufacture.php" hash="aadda3679470302577acd9f724d08ad0"/><file name="Inputtype.php" hash="15f7e59849a0ac4977e939caa3c4465a"/><file name="Layout.php" hash="c559a06df151d3d9c452a228f29876fc"/><dir name="Msrp"><dir name="Type"><file name="Enabled.php" hash="de117cb62373580b321199a446b804b6"/><file name="Price.php" hash="c8ee83148e929926333e11d838482b5e"/></dir><file name="Type.php" hash="5d6016b1c16da153676b7c0e4a081464"/></dir></dir><dir name="Tierprice"><dir name="Api"><file name="V2.php" hash="11ad5b869f9cb14fb0686f47b1680f08"/></dir><file name="Api.php" hash="94a5c06286100b29190c34655178bd33"/></dir></dir><dir name="Compare"><file name="Item.php" hash="1770a04bfd6b7663bb99e37904a91c13"/><file name="List.php" hash="72668aa9d697d58b18fb18191effd38f"/></dir><dir name="Condition"><file name="Interface.php" hash="f2cf66045ea9dd61986b758342556233"/></dir><file name="Condition.php" hash="19cd56bf3f2550ed01292cc341c7d6d0"/><dir name="Configuration"><dir name="Item"><file name="Interface.php" hash="0f23070446e06334285c197372c35b7d"/><dir name="Option"><file name="Interface.php" hash="c66bdfbe8f13e7a5edad0672275bee2c"/></dir><file name="Option.php" hash="ee7272d03f6afc6e9449d6e474f37b11"/></dir></dir><dir name="Flat"><file name="Flag.php" hash="363aded09ba741942b0aacb3d3a07c27"/><file name="Indexer.php" hash="0b3c9e5fed4229a33b5641075e637517"/><file name="Observer.php" hash="d5662401baa5cde6c28f01d141294bc7"/></dir><file name="Image.php" hash="baec4a63b96bbbf5e14e455dc2e2d015"/><dir name="Indexer"><file name="Eav.php" hash="e47e464e1023c564e911ab1961a0b11f"/><file name="Flat.php" hash="e88b212e14303f5869321e95dda2999e"/><file name="Price.php" hash="eebb7689c64c15b55a0cd5dc37a5d276"/></dir><dir name="Link"><dir name="Api"><file name="V2.php" hash="477152eaccdc7de5a464e56dabbb3612"/></dir><file name="Api.php" hash="0908690809e366ca32a85eccc39424ba"/></dir><file name="Link.php" hash="aeb02bfb03bb74c369e081e3ee0d8af2"/><dir name="Media"><file name="Config.php" hash="099a406b5674248b233f09f243a2920a"/></dir><dir name="Option"><dir name="Api"><file name="V2.php" hash="14bb5161d6a2a298d435f516798ede69"/></dir><file name="Api.php" hash="befcfd818c890847fd991db908f337bc"/><file name="Observer.php" hash="4356352cea7f0cf6aa42df08ae2f90ab"/><dir name="Type"><file name="Date.php" hash="f58c2ebf294cab03940eca55c4e84490"/><file name="Default.php" hash="d30754bfd2505dc7b7c2fa088dc4115c"/><file name="File.php" hash="6352b854844cdcfa25cf6f43dff7d54c"/><file name="Select.php" hash="9555af869c9cda85d96be06ce4ea8c88"/><file name="Text.php" hash="3343457af57c576140ab52c759de1d57"/></dir><dir name="Value"><dir name="Api"><file name="V2.php" hash="3939065d0e21ab3d7f91673be42280b7"/></dir><file name="Api.php" hash="0b85d0ce714b5acffa1e428c2d8aed58"/></dir><file name="Value.php" hash="4e14b90cc585e7a5b691625135dbd028"/></dir><file name="Option.php" hash="eb7598408500873cb7e55c9eca535b38"/><file name="Status.php" hash="e848573b6f8f57f01053330d20b2bcdb"/><dir name="Type"><file name="Abstract.php" hash="456ddf2b2a03e14e81e3e0a683119e4c"/><dir name="Api"><file name="V2.php" hash="b6707f76e85bc688dc5ba8f60dc10d3b"/></dir><file name="Api.php" hash="e42bfe85d504d4b9dd00b4b64b8fecb0"/><dir name="Configurable"><file name="Attribute.php" hash="b8ed3e9057b253b0f344846b188509d2"/><file name="Price.php" hash="1802e8c7a74d5795d125a27d1e3a53a4"/></dir><file name="Configurable.php" hash="0ba0e65168d5af4647b9fe6da254e39e"/><dir name="Grouped"><file name="Price.php" hash="d1afc84f82d025db921f5d4ce1b7e32b"/></dir><file name="Grouped.php" hash="9d5c08c0e094dcacedc542afa334d98b"/><file name="Price.php" hash="85eddbc0df0b45a54e5cfbb801b9a010"/><file name="Simple.php" hash="e4a0cefc389b7da8509a9b17b4c2ba09"/><file name="Virtual.php" hash="89d8e7e2b763427055e3da933a172e88"/></dir><file name="Type.php" hash="54d62b5d5c8d98f279443906360247ba"/><file name="Url.php" hash="9430be8c25239582d3aea22711db6720"/><file name="Visibility.php" hash="3d4d497257c9f3335dac07b41cb4c69d"/><file name="Website.php" hash="b65aaa5099f357f5aa688efb8a0823b4"/></dir><file name="Product.php" hash="8c1eca1931764491e74f1d15c735df1f"/><dir name="Resource"><file name="Abstract.php" hash="c14958ef6804679c24703aba82434753"/><file name="Attribute.php" hash="4b8177eb1f1e7241eba5e70806beddc7"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="3ffbcb599ae748665619ecb1bd4e32de"/><dir name="Frontend"><file name="Image.php" hash="265bcb0baebcc805a992d9e92a105c98"/></dir><dir name="Source"><file name="Layout.php" hash="8a605bb387b98c83eb8370714bc536de"/><file name="Mode.php" hash="2f54f5b1302a21f362e7f3776c1ab10b"/><file name="Page.php" hash="3f583421a6c6a90fcfded71ac86b1711"/></dir></dir><file name="Collection.php" hash="60ee6565b57ce712723d4e41a827dede"/><dir name="Flat"><file name="Collection.php" hash="c8dd70661951f7fd60a61fd08b1247fc"/></dir><file name="Flat.php" hash="5b2c10a35f424b8168dd1b2794f1dfff"/><dir name="Indexer"><file name="Product.php" hash="fb9f9cf67f670d287ff49a762b91fa3e"/></dir><file name="Tree.php" hash="76ddcd3417b6ec0b62e0b175933217e0"/></dir><file name="Category.php" hash="d5be53b29b16c8ae073b482daa66ef4d"/><dir name="Collection"><file name="Abstract.php" hash="f871c02ea4d88638f637eb24b790b3d5"/></dir><file name="Config.php" hash="3b6571774cadf96433902cd54297a9d6"/><dir name="Eav"><file name="Attribute.php" hash="e92cbf5f90282670c86bcedd005846ea"/><dir name="Mysql4"><file name="Abstract.php" hash="2a367c043fbc2858adb01c6c4ea2ff9e"/><file name="Attribute.php" hash="b2344f0813ac67e3d4550087a20ad2ae"/><dir name="Category"><dir name="Attribute"><file name="Collection.php" hash="bd7da78fe2526ae9ecf57eec773092f0"/><dir name="Frontend"><file name="Image.php" hash="592591274fd4dd36f1c101a40d4b2951"/></dir><dir name="Source"><file name="Layout.php" hash="645778015cea4f06dff49c5726502f4b"/><file name="Mode.php" hash="96bcbb702e35ecf20f03b12ebf8042d5"/><file name="Page.php" hash="5e5193c362e2fb605d7128c3f2894ac2"/></dir></dir><file name="Collection.php" hash="e3fe15e20c006b16c9aa38caa17caa95"/><dir name="Flat"><file name="Collection.php" hash="847dff2c53f375efc6107a5044afbd1e"/></dir><file name="Flat.php" hash="040ba88e64f19013f85b66834cf0f5f8"/><dir name="Indexer"><file name="Product.php" hash="33642d91c512107fb37252f6e97408df"/></dir><file name="Tree.php" hash="6115a020dc6913f3dfaf226601247c80"/></dir><file name="Category.php" hash="79029baf7c325430171bf30886a5caa5"/><dir name="Collection"><file name="Abstract.php" hash="124dfabd4981973f07975154bafea8d0"/></dir><file name="Config.php" hash="9fe560aa88aabe6f9fbe03b68b4085ea"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="ccbf9d48d22c7f077054e95b3d2042cf"/><file name="Decimal.php" hash="0d9a04b5a445d15d6b7b03a7febcb4be"/><file name="Price.php" hash="59d45ca47c02f4d1ee5860923d5c96d1"/></dir></dir><dir name="Product"><file name="Action.php" hash="0bb6f6cd561b111392302f58de49b7b0"/><dir name="Attribute"><dir name="Backend"><file name="Image.php" hash="b2ff2e77ca0a5c1b96e2b0ea7913195d"/><file name="Media.php" hash="08eab44f2071f37ed4a17771014d18a7"/><file name="Tierprice.php" hash="d8e1f29c9aded8a2f503e1e05f0f3508"/><file name="Urlkey.php" hash="f4a2a06d66828a9425032ff779971546"/></dir><file name="Collection.php" hash="42d92267179369ca1b53a04769202de5"/><dir name="Frontend"><file name="Image.php" hash="9ff5fc06d6bb7367283c7d4254d792f6"/><file name="Tierprice.php" hash="15c00b90689a29f9a011c9f485e49ddd"/></dir></dir><file name="Collection.php" hash="b79fc090c34b6fd44c9cf6ea9cbd4883"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="8ef3865a4184e44a79ae2e266135a6ab"/></dir><file name="Item.php" hash="3a11128e27a6e042c859fd9870b12138"/></dir><dir name="Flat"><file name="Indexer.php" hash="de2ed76c939ee2bdb9eb184176a8e604"/></dir><file name="Flat.php" hash="699390b439b8db9bde5104d2a59009da"/><dir name="Indexer"><file name="Abstract.php" hash="bc190cb0183bd1f7db0ac4c2e3cd182d"/><dir name="Eav"><file name="Abstract.php" hash="1f3bdac32c138ad8c5a71fad5f655eba"/><file name="Decimal.php" hash="8418e2274ff77522e8caa393339acf61"/><file name="Source.php" hash="956a03b9a4cb0602f28cb06373d41e82"/></dir><file name="Eav.php" hash="9dbfa6685d22718fd6dd81ac9112dd34"/><dir name="Price"><file name="Configurable.php" hash="460c5542704c3b11741821ff704d4fcc"/><file name="Default.php" hash="c5edd3e077b00463b3cbbaefad1ba6a8"/><file name="Grouped.php" hash="077cb723a265b1a5c43eeaa1b601e1a6"/><file name="Interface.php" hash="3f4c53d917ec9381894358b8822d806d"/></dir><file name="Price.php" hash="3fc351998bdaba729be4678a78a0da85"/></dir><dir name="Link"><file name="Collection.php" hash="34fe71afca447379ed7513536fecd642"/><dir name="Product"><file name="Collection.php" hash="853c7788c08dcf878e2607a555685122"/></dir></dir><file name="Link.php" hash="14758eb79f27b954abb80ed90a101a3e"/><dir name="Option"><file name="Collection.php" hash="0a201c7e6fb601f98e9f9cca226358e9"/><dir name="Value"><file name="Collection.php" hash="86aa68a240301b088861ed13dc8381f0"/></dir><file name="Value.php" hash="82d41979c3abf45111e1dd2c56a4b001"/></dir><file name="Option.php" hash="b3bc9c0b3ab001abf97628fb2d5dbf96"/><file name="Relation.php" hash="34958c4dacac719d88f9e2cdfdb8b136"/><file name="Status.php" hash="1ee8129ba6198845a4022cb0a23e1b60"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="9b7f72984109f13c28cf85a68b319bd9"/></dir><file name="Attribute.php" hash="e2caafaf5f244802e171ee2ed1ff7bbf"/><dir name="Product"><file name="Collection.php" hash="db3d68e3ebf537cd23158e9292d3d575"/></dir></dir><file name="Configurable.php" hash="6dde68202d2dfd1cd0cc00548b7a1985"/></dir><file name="Website.php" hash="cc737b50d6e2e43e14b81ed1746e9b3a"/></dir><file name="Product.php" hash="4151845a9d0686def340b920e098f741"/><dir name="Sendfriend"><file name="Collection.php" hash="db2654b8b3538dc570f4411d4735131e"/></dir><file name="Sendfriend.php" hash="0525ce13a3a3a10d7171fb8622dfd48d"/><file name="Setup.php" hash="3e1d02f8e0c571a19598f9d98ad84bba"/><file name="Url.php" hash="56970705a722b52eca45df8ae3a066d6"/></dir></dir><dir name="Helper"><file name="Mysql4.php" hash="346aed24f42fc8cb87edb7140638663f"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="9dad377ec4098111bc3db812204ff080"/><file name="Decimal.php" hash="749ff82a37683e09b24c65dcf701402b"/><file name="Price.php" hash="310aab644b6600746d0c27c6a01403ac"/></dir></dir><dir name="Product"><file name="Action.php" hash="298bd0d4c878a4c20ef1e38055302b53"/><dir name="Attribute"><dir name="Backend"><dir name="Groupprice"><file name="Abstract.php" hash="e14702c7892e3bafd6a7d8b1ba361b51"/></dir><file name="Groupprice.php" hash="646caeb2f18916e63c1432f1af1708e0"/><file name="Image.php" hash="ff506a149dd3f4e6bf3ea120d3473170"/><file name="Media.php" hash="01fafee272101d93242d0e574a32481a"/><file name="Tierprice.php" hash="b328e4cde490e74a3296882570c0ed6b"/><file name="Urlkey.php" hash="3fbc5b079cfc88a46e2e45a589182041"/></dir><file name="Collection.php" hash="63fdcf9337942f1dca816ea76dc35fe5"/><dir name="Frontend"><file name="Image.php" hash="22810c5cad61e224f0fc6881bc88fae3"/><file name="Tierprice.php" hash="04ea1ae5b17fc1a388859a0c4b9cbdaf"/></dir></dir><file name="Collection.php" hash="f1cd791dd63e491fce2dfdd13b64b82a"/><dir name="Compare"><dir name="Item"><file name="Collection.php" hash="4fb51b54810df997353844058e8741b9"/></dir><file name="Item.php" hash="b744e1f4b3ad4b448e41162746c3dfe3"/></dir><dir name="Flat"><file name="Indexer.php" hash="d23c69dd71584b02c83cd997b390dfb3"/></dir><file name="Flat.php" hash="26e93d868615c55fb33db2213db4286a"/><dir name="Indexer"><file name="Abstract.php" hash="b51e95b7b0f89be7859b20e0c439d6c1"/><dir name="Eav"><file name="Abstract.php" hash="a7de365b3c24f7925d0aff2ded37f403"/><file name="Decimal.php" hash="8bca02dc0329c702b965f05f5a9949cb"/><file name="Source.php" hash="b207472624ad4d67f9f2a88e6e2ad2e6"/></dir><file name="Eav.php" hash="f5e66db5984ed89d7ff6531dd30633f3"/><dir name="Price"><file name="Configurable.php" hash="c0a92825df74de40aadab166763d6fc8"/><file name="Default.php" hash="3df089b3b5116fb4db829dc94ac66fd4"/><file name="Grouped.php" hash="ff69c8dc1428f1ed620843acfaaa5121"/><file name="Interface.php" hash="ec19f8d573eca3c7dcd43a5c33f98f4e"/></dir><file name="Price.php" hash="2c4385289d5a45a8a66ab41472b64754"/></dir><dir name="Link"><file name="Collection.php" hash="c0983cdfd3183129078b302021e57587"/><dir name="Product"><file name="Collection.php" hash="ea9ec18e1ba474635dde20f245f90430"/></dir></dir><file name="Link.php" hash="7dbac8c8fa2cc623f4d50aceb27e0e00"/><dir name="Option"><file name="Collection.php" hash="de9703a538cfe61ec3b5bfe0ddef228a"/><dir name="Value"><file name="Collection.php" hash="cf7203a390fe7bcdd2d80658ea638f8b"/></dir><file name="Value.php" hash="6e12f40c2708897a49aae723a2ff19d9"/></dir><file name="Option.php" hash="75fd5d228bbc80fd97e12c4d0d9622b3"/><file name="Relation.php" hash="46966dfd38f5d80d22ffe0ff9e43c967"/><file name="Status.php" hash="e77d71b99b3e29da963a7f76600f10ea"/><dir name="Type"><dir name="Configurable"><dir name="Attribute"><file name="Collection.php" hash="bd087f24c45cb093d8d536ea05c6e92c"/></dir><file name="Attribute.php" hash="2f2399997b9b922c2ea9f5ada87ff958"/><dir name="Product"><file name="Collection.php" hash="d24bba40636bf969f73e20b407dab32c"/></dir></dir><file name="Configurable.php" hash="a0ab436c28d58783caa04224c1f5d3bf"/></dir><file name="Website.php" hash="ae55f3449cfef9a583d3a0e2d43f2cb5"/></dir><file name="Product.php" hash="d8d540dbeca26d6dd3acdfc26302ac41"/><file name="Setup.php" hash="a9aceb3a22800559189a82f3d644d6e1"/><file name="Url.php" hash="fee84f8fd827c4b523c8bc72f1de704b"/></dir><file name="Session.php" hash="d215af2e51c77cd0eb48d01886d97c67"/><dir name="System"><dir name="Config"><dir name="Backend"><dir name="Catalog"><dir name="Category"><file name="Flat.php" hash="5e7c93fe883ca86ae471ec9533b92488"/></dir><dir name="Product"><file name="Flat.php" hash="be6906d997d57412dc0f0678fed1fcda"/></dir><dir name="Url"><dir name="Rewrite"><file name="Suffix.php" hash="dc19187f7b9027e075e69ad5828bca08"/></dir></dir></dir></dir></dir></dir><dir name="Template"><file name="Filter.php" hash="be97244f623000eba021d31da010f457"/></dir><file name="Url.php" hash="b9cc8fa3476c3028ee3fd90852aa3050"/></dir><dir name="controllers"><file name="CategoryController.php" hash="0b623f4ee9d8e885aad13d0f23f13a30"/><file name="IndexController.php" hash="805f36221033bcbd93eb3121d0d0948e"/><dir name="Product"><file name="CompareController.php" hash="86e968a1afb955a34c8bcc2e98d08525"/></dir><file name="ProductController.php" hash="e14a5e084e5e2f024c5fd3b5477c906c"/><dir name="Seo"><file name="SitemapController.php" hash="34d2c078cdb514e676a60691d607e15d"/></dir></dir><dir name="data"><dir name="catalog_setup"><file name="data-install-1.6.0.0.php" hash="ef9ebc687f8cc23de608e3eec94232cc"/><file name="data-upgrade-1.6.0.0.12-1.6.0.0.13.php" hash="d472917c63d90778ca89350d7232ee13"/><file name="data-upgrade-1.6.0.0.13-1.6.0.0.14.php" hash="8212a73ea36cb390312bdb382ec6f408"/><file name="data-upgrade-1.6.0.0.19.1.3-1.6.0.0.19.1.4.php" hash="5f60b06746ecaaa74f24ebc376fc0f38"/><file name="data-upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="d369491d2e0204a1708d8a8e0212be93"/><file name="data-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="8717445601b14a3f806bb161fb596a4f"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fd5a88df31874c873ddc47fd12128483"/><file name="api.xml" hash="61f1a48867bbfafb52e53a29b5c3d694"/><file name="api2.xml" hash="013a076022ddbf3fea4a0742d5b8bc8c"/><file name="config.xml" hash="0f41603c3f745b50d2a0fb4de8d0a546"/><file name="convert.xml" hash="8d8f7eba4c23dc6873132c771d46af97"/><file name="system.xml" hash="c68005c02276e6b02fcee376373c9248"/><file name="widget.xml" hash="772ee5617954b3a85519bd64bd25abdc"/><file name="wsdl.xml" hash="fa198392d766134085b3c2ec1be4a0e9"/><file name="wsi.xml" hash="0acfd65c613ccb83404317500078a85d"/></dir><dir name="sql"><dir name="catalog_setup"><file name="install-1.6.0.0.php" hash="c29963f106b44ac2bedf0ef43b16caab"/><file name="mysql4-data-upgrade-0.7.57-0.7.58.php" hash="9c5663631e26bc0dbae1ea7f31d2ee86"/><file name="mysql4-data-upgrade-0.7.63-0.7.64.php" hash="6073444dda366a4cb50d3b4704bbb1d5"/><file name="mysql4-data-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="fdf01e58ffaf834d4761675e99ba5b88"/><file name="mysql4-data-upgrade-1.4.0.0.42-1.4.0.0.43.php" hash="466304c2f961b3dbcd2606fc02cc8087"/><file name="mysql4-install-0.7.0.php" hash="a6b88eeac8ea791e1c6b50be6a2bdcff"/><file name="mysql4-install-1.4.0.0.0.php" hash="d4e60629ae2494d3d7d8db7424e4f463"/><file name="mysql4-upgrade-0.6.40-0.7.0.php" hash="507edb127b940c5b9c85dc5bfdd9ee30"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2f6b873ea84bac96da7be4905fe9c17f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f43a60fb17d36c541e08b0ad92d146da"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dfc471e252d3995a7ef491d1399d9ffc"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="bc84e63dd439f8a424ef9e6d8ca29adb"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="ea6b851a464cb7005f0798c17448a5e7"/><file name="mysql4-upgrade-0.7.16-0.7.17.php" hash="b680eced0513fa6d31999995dc431511"/><file name="mysql4-upgrade-0.7.17-0.7.18.php" hash="5677f19bba0d4e8cfa1f88363081e7af"/><file name="mysql4-upgrade-0.7.18-0.7.19.php" hash="7d624e6c993855ad8fba5f3898429401"/><file name="mysql4-upgrade-0.7.19-0.7.20.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="f9d888899433993fedac11a5ae62a2bb"/><file name="mysql4-upgrade-0.7.20-0.7.21.php" hash="5d8ff6a9614259de0da5aa89ab3f0c06"/><file name="mysql4-upgrade-0.7.21-0.7.22.php" hash="a8063991dd0567f63c169893210d04ec"/><file name="mysql4-upgrade-0.7.22-0.7.23.php" hash="d89516b96caced26119cf3a3f14442b7"/><file name="mysql4-upgrade-0.7.23-0.7.24.php" hash="8b96b8f483d5c21b42dbdf68ecf6c2f2"/><file name="mysql4-upgrade-0.7.24-0.7.25.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.25-0.7.26.php" hash="04170047fcd3b7cf5bb9cb91978fbbe3"/><file name="mysql4-upgrade-0.7.26-0.7.27.php" hash="083503e821d19cfab3ca9d97bbbbaa72"/><file name="mysql4-upgrade-0.7.27-0.7.28.php" hash="64cb2325781d72a135aa2e5744e012e5"/><file name="mysql4-upgrade-0.7.28-0.7.29.php" hash="460f9b2de5477af5ec4c36ca2791d530"/><file name="mysql4-upgrade-0.7.29-0.7.30.php" hash="908ca45d436735f8d498de0d28c5a092"/><file name="mysql4-upgrade-0.7.30-0.7.31.php" hash="085e3ad264455870e6b57b135b10860c"/><file name="mysql4-upgrade-0.7.31-0.7.32.php" hash="25dbc8dc2e32d91e394ed76f2e68b94c"/><file name="mysql4-upgrade-0.7.32-0.7.33.php" hash="6c050648205a2971087c3822fa10f99a"/><file name="mysql4-upgrade-0.7.33-0.7.34.php" hash="53bfad70ff24d6227c2a3e4f831513e3"/><file name="mysql4-upgrade-0.7.34-0.7.35.php" hash="0bf51a7f95d6e11f5244bac7b4b7ce9c"/><file name="mysql4-upgrade-0.7.35-0.7.36.php" hash="8b01c971f3a27f7b49576aa8b7d4ddcb"/><file name="mysql4-upgrade-0.7.36-0.7.37.php" hash="09c848c52e1e27cd105e3cfb107a24b2"/><file name="mysql4-upgrade-0.7.37-0.7.38.php" hash="1c27b73c04e636200f7c8e388fec68c8"/><file name="mysql4-upgrade-0.7.38-0.7.39.php" hash="6c573296430a1e2ccdfe596ced83b201"/><file name="mysql4-upgrade-0.7.39-0.7.40.php" hash="c337c33147016060b3ff88c8dc415da4"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="e236771503e6d160a30a216bf7e77b43"/><file name="mysql4-upgrade-0.7.40-0.7.41.php" hash="8e594a691237dd91fc12635476d38fee"/><file name="mysql4-upgrade-0.7.41-0.7.42.php" hash="1b8378086638dba3520f1044d8352485"/><file name="mysql4-upgrade-0.7.43-0.7.44.php" hash="f824722e979b87d55941ad6d6d828452"/><file name="mysql4-upgrade-0.7.44-0.7.45.php" hash="a03e8d35ed5bb34226075266b395dbe5"/><file name="mysql4-upgrade-0.7.45-0.7.46.php" hash="fb4ebc451e162848f9897f94772862b4"/><file name="mysql4-upgrade-0.7.46-0.7.47.php" hash="b0ee6aa0fe5a6b836e91e2c4d03f4f2b"/><file name="mysql4-upgrade-0.7.47-0.7.48.php" hash="87aa57f14078c57fc1a8da34e314e347"/><file name="mysql4-upgrade-0.7.48-0.7.49.php" hash="6d76557d041bf75e5bfc306a2bb9f3ed"/><file name="mysql4-upgrade-0.7.49-0.7.50.php" hash="07d744ff031c377e2728ecaba6009629"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="9d946faeab0c58e3f085609032515478"/><file name="mysql4-upgrade-0.7.50-0.7.51.php" hash="7f9260d51a63a0a8f3c5192f1db14d0b"/><file name="mysql4-upgrade-0.7.51-0.7.52.php" hash="2c18d6c66df05f3b4207f7c00854cf66"/><file name="mysql4-upgrade-0.7.52-0.7.53.php" hash="5a1008b25157ec584c5c881c3c7e154d"/><file name="mysql4-upgrade-0.7.53-0.7.54.php" hash="15ff250c95b87120a83d90a062f73a5a"/><file name="mysql4-upgrade-0.7.54-0.7.55.php" hash="719516da1f701c670f856f60f98860cf"/><file name="mysql4-upgrade-0.7.55-0.7.56.php" hash="c771a19fff3b61373ce76646a701bc47"/><file name="mysql4-upgrade-0.7.56-0.7.57.php" hash="490d8c1cb40c3045dbe7484bafa2b1ba"/><file name="mysql4-upgrade-0.7.57-0.7.58.php" hash="9a0d6890063532aad3a0eb27e32fc622"/><file name="mysql4-upgrade-0.7.58-0.7.59.php" hash="76025781953b54f5316084857594254c"/><file name="mysql4-upgrade-0.7.59-0.7.60.php" hash="d74eeb502951b3f401813795be8c7a60"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="3340972bf2f63ecc5cb8a5330fa1525b"/><file name="mysql4-upgrade-0.7.60-0.7.61.php" hash="88de24828d60913d63ce0c2f76315a3d"/><file name="mysql4-upgrade-0.7.61-0.7.62.php" hash="06aae2ea1d872fa83f0121324aa02400"/><file name="mysql4-upgrade-0.7.62-0.7.63.php" hash="f7ca5162b321dd64887c9d245eeed643"/><file name="mysql4-upgrade-0.7.63-0.7.64.php" hash="9e19c27309b19b275ca0bee0a4790476"/><file name="mysql4-upgrade-0.7.64-0.7.65.php" hash="979fb613a8ec5695ed2e6f615616d169"/><file name="mysql4-upgrade-0.7.65-0.7.66.php" hash="dc64aa0fa4c4198100948dceee48f96d"/><file name="mysql4-upgrade-0.7.66-0.7.67.php" hash="86a3c5fd7a06048cda04cdad7a6e801d"/><file name="mysql4-upgrade-0.7.67-0.7.68.php" hash="f2afb3c2630946476346958e29d9e70e"/><file name="mysql4-upgrade-0.7.68-0.7.69.php" hash="89b9d73c5b6c625ece67693ccd498ce7"/><file name="mysql4-upgrade-0.7.69-0.7.70.php" hash="a0548013b1718f68e9ce15fcf5d38408"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="79e710442cb653908c95b585829abfaf"/><file name="mysql4-upgrade-0.7.70-0.7.71.php" hash="e767f97578e42fc4a32162f58d9b2e4f"/><file name="mysql4-upgrade-0.7.71-0.7.72.php" hash="eeff783e2e2000befd14b9340ba28a32"/><file name="mysql4-upgrade-0.7.72-0.7.73.php" hash="419232e5dce501a80c5dc2a66a42577b"/><file name="mysql4-upgrade-0.7.73-1.4.0.0.0.php" hash="8b6172c12f58ce3ef1a16bf35ee31cdc"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="623853171877cf7085d6f3abcc49673f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="20555dcf3e6a01e408b1cb1c56957f23"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="5aa11d1c55bc3cd63db6c2cd157cd71d"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="87eb69de3122c4d90935518fe8868749"/><file name="mysql4-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="a3f9c9b41fb20c258248f98bb9e1ec2f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="f18e34961d0277f9ae9875075c2e4514"/><file name="mysql4-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="9a2dc72bb5b00912af39399d53021d21"/><file name="mysql4-upgrade-1.4.0.0.14-1.4.0.0.15.php" hash="de27b4f0ddc37e5cd856c66f041479e6"/><file name="mysql4-upgrade-1.4.0.0.15-1.4.0.0.16.php" hash="b1eb1bc037284300f4b7280c03eb241c"/><file name="mysql4-upgrade-1.4.0.0.16-1.4.0.0.17.php" hash="5651974d4eb2bae3c27be5cd312cfbbe"/><file name="mysql4-upgrade-1.4.0.0.17-1.4.0.0.18.php" hash="660ec00a2013d97bc10851ef4b27e940"/><file name="mysql4-upgrade-1.4.0.0.18-1.4.0.0.19.php" hash="dae45d8263ea6f26b98d6ac49a08e19e"/><file name="mysql4-upgrade-1.4.0.0.19-1.4.0.0.20.php" hash="79c4658fa552dfaeda70ba030a3642b2"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="593097cd07e2a4806d832c85fc735706"/><file name="mysql4-upgrade-1.4.0.0.20-1.4.0.0.21.php" hash="235e9a7c3ebe5ea369584b49e86276ef"/><file name="mysql4-upgrade-1.4.0.0.21-1.4.0.0.22.php" hash="677245c0b3379140dffede0d209deee5"/><file name="mysql4-upgrade-1.4.0.0.22-1.4.0.0.23.php" hash="841015edcc5f636391541fd252463c50"/><file name="mysql4-upgrade-1.4.0.0.23-1.4.0.0.24.php" hash="6504d290e95977304959211ac7bfc0c4"/><file name="mysql4-upgrade-1.4.0.0.24-1.4.0.0.25.php" hash="e83e00bed962a768af6ffc6906bf6c0e"/><file name="mysql4-upgrade-1.4.0.0.25-1.4.0.0.26.php" hash="e0e38aa2816abd6159b33717dc246e97"/><file name="mysql4-upgrade-1.4.0.0.26-1.4.0.0.27.php" hash="f7d17fca52fb06de66f430900fee2c13"/><file name="mysql4-upgrade-1.4.0.0.27-1.4.0.0.28.php" hash="6084b618f9a2d7d69e2e2e91f2e1f55d"/><file name="mysql4-upgrade-1.4.0.0.28-1.4.0.0.29.php" hash="a69471d54bede4e5afed8ccae51b8a9c"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="a7c535e680a7c9c623094e54f514b58f"/><file name="mysql4-upgrade-1.4.0.0.30-1.4.0.0.31.php" hash="2f221443dffe6cfd32ea64ecda52ce2f"/><file name="mysql4-upgrade-1.4.0.0.31-1.4.0.0.32.php" hash="d64fc6dd5225c10dd4e36bf298aa4d7a"/><file name="mysql4-upgrade-1.4.0.0.32-1.4.0.0.33.php" hash="d1fe2d8afb82cf468657ddda5389aa88"/><file name="mysql4-upgrade-1.4.0.0.33-1.4.0.0.34.php" hash="cf0e6b3578ad191f76157c0132d03230"/><file name="mysql4-upgrade-1.4.0.0.34-1.4.0.0.35.php" hash="9717a718577395f0e0646fcffeb7f6da"/><file name="mysql4-upgrade-1.4.0.0.35-1.4.0.0.36.php" hash="551b8c6cdd768e72050f686f267c9ebc"/><file name="mysql4-upgrade-1.4.0.0.36-1.4.0.0.37.php" hash="39a95ef491d0af85fa873fc53bc0a591"/><file name="mysql4-upgrade-1.4.0.0.37-1.4.0.0.38.php" hash="d8f9fa201cb8bee1872c01c5364710e7"/><file name="mysql4-upgrade-1.4.0.0.38-1.4.0.0.39.php" hash="3da4c8953eebd0faa442fe07ea3f94f6"/><file name="mysql4-upgrade-1.4.0.0.39-1.4.0.0.40.php" hash="8269869aaf91ae34cfdb2b6f2f6f4545"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="033cc6f1eb844eb2aca8bdb4ac2d7901"/><file name="mysql4-upgrade-1.4.0.0.40-1.4.0.0.41.php" hash="c123b4fd1db3e8638d748613d0af8138"/><file name="mysql4-upgrade-1.4.0.0.41-1.4.0.0.42.php" hash="fba18ca14ea477338ed50c1beec34bcd"/><file name="mysql4-upgrade-1.4.0.0.43-1.4.0.0.44.php" hash="e8fc42ea638f58c7221a19b49c9cf9ab"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="b80203909773a1f38c35383a983b3273"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="b41a118ff245764def690665767cca24"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="2ece267357c4d9440e3402c3f0c8b19b"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="e6580f466b4567f9db9c69ce4d19be6a"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="b65d059cd51c7d188ffa9bacff3d978a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="375eecb3c1d1378633edf5b674e14da6"/><file name="mysql4-upgrade-1.6.0.0.8-1.6.0.0.9.php" hash="7c81d529fdcbfeb15e293ce059c0cbca"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="077527314f082634ae92550d915e543f"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="9f2bacade9c4d2ad1a8542cac36097c4"/><file name="upgrade-1.6.0.0.10-1.6.0.0.11.php" hash="e7529d1f8a30b456f6577ff8b3b46245"/><file name="upgrade-1.6.0.0.11-1.6.0.0.12.php" hash="8814c53ea7fc2e5a15b96a4f2c15a391"/><file name="upgrade-1.6.0.0.14-1.6.0.0.15.php" hash="dc9ac4700806bdc55bd4ffcd5c22a49a"/><file name="upgrade-1.6.0.0.15-1.6.0.0.18.php" hash="d39d85f7ea7f2975dad11e467b8bba7a"/><file name="upgrade-1.6.0.0.18-1.6.0.0.19.php" hash="5e06c46ebebd369a3178b00603f0bc18"/><file name="upgrade-1.6.0.0.19.1.1-1.6.0.0.19.1.2.php" hash="7d10833e5b4f9b540ddf4df06dbf63fb"/><file name="upgrade-1.6.0.0.19.1.2-1.6.0.0.19.1.3.php" hash="ce8eb57226d3b66fda8ff9cace5fb8c9"/><file name="upgrade-1.6.0.0.19.1.4-1.6.0.0.19.1.5.php" hash="ad98088ce7ecb304e78e7e4c2163fe33"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="a4f70ae360f99126e6b25e166431e337"/><file name="upgrade-1.6.0.0.3-1.6.0.0.4.php" hash="e0ad21122b4cee55e0f4c8b5c44d737b"/><file name="upgrade-1.6.0.0.4-1.6.0.0.5.php" hash="1cbb44723229355c50f2202fab455931"/><file name="upgrade-1.6.0.0.5-1.6.0.0.6.php" hash="e78ecce5cfd76b13dbd7ef5d9f9735e3"/><file name="upgrade-1.6.0.0.6-1.6.0.0.7.php" hash="5f4e31a57366b12432190b0dbdc0a68c"/><file name="upgrade-1.6.0.0.7-1.6.0.0.8.php" hash="e79d5e53a7a4c25497eb3bfdda46eb97"/><file name="upgrade-1.6.0.0.9-1.6.0.0.10.php" hash="ce5b3dbc98219a2c0da94040da590f51"/></dir></dir></dir><dir name="CatalogIndex"><dir name="Model"><file name="Aggregation.php" hash="9c6f7998d76d1bca362e089175a93ae2"/><file name="Attribute.php" hash="78d663d4ea9f77754c2c3560d0b020e1"/><dir name="Catalog"><dir name="Index"><file name="Flag.php" hash="9524e2814fdeca550e656b6733338f65"/><dir name="Kill"><file name="Flag.php" hash="5a9339464929555f00c31e9ecaf098aa"/></dir></dir></dir><dir name="Data"><file name="Abstract.php" hash="b9ce96f710806d292935a8db74af86ff"/><file name="Configurable.php" hash="eee28753c670a9c2379b39f0234d427e"/><file name="Grouped.php" hash="bb07795d092a9ac2c63ff0c29e76b729"/><file name="Simple.php" hash="f007617c31143387958a8604e3f0870e"/><file name="Virtual.php" hash="4aca3ebe694553e66aa6e3ea0682cda9"/></dir><dir name="Indexer"><file name="Abstract.php" hash="61295f02872b473935c13c0aca969d47"/><file name="Eav.php" hash="9085f089b3882a86f4f847f2abb5caad"/><file name="Interface.php" hash="6c71d4648ba7201f7987022cdfce3685"/><file name="Minimalprice.php" hash="6decf39ab3208edce2543e75892ac265"/><file name="Price.php" hash="95c1e4e340c4caa61dd8d2468c082080"/><file name="Tierprice.php" hash="47dcfa2ab722cbe136b770f70d6edef6"/></dir><file name="Indexer.php" hash="56c31bb712bbe66591c98161de5e38e7"/><dir name="Mysql4"><file name="Abstract.php" hash="6e0f0fe11a1ce650c3e10a23a0d945e4"/><file name="Aggregation.php" hash="76f46435204ca54d4591ab2a0c616cbb"/><file name="Attribute.php" hash="a58cd34ef532d852bed7b9d4ad1b9771"/><dir name="Data"><file name="Abstract.php" hash="41bc6267ada02fa6fe8ec615ec3ebb3f"/><file name="Configurable.php" hash="4577c89b879e8f99bedc4465fb9661f3"/><file name="Grouped.php" hash="a6884d4b81b61a067b1e505dbfc93a19"/></dir><dir name="Indexer"><file name="Abstract.php" hash="d3a9da75a16656171c18bb86fa33fab5"/><file name="Eav.php" hash="1d0f16eebd4ce5b824e1ae1eda2cfc15"/><file name="Minimalprice.php" hash="064cc6452df17680b1512dbfc226c141"/><file name="Price.php" hash="3c6e97db8d77933ca4defea0b51d6e91"/></dir><file name="Indexer.php" hash="5898b1893183208da157dc36abf37cba"/><file name="Price.php" hash="74b8fa8fba67d2def8524a1dd460e1c1"/><file name="Retreiver.php" hash="df8626625cbcbd70a168d8d0176fa097"/><file name="Setup.php" hash="06f2b09a62a2ede2972d82217c12fa36"/></dir><file name="Observer.php" hash="323541f9c7627005c1097bae4745eaaa"/><file name="Price.php" hash="59d2c099a753e4bfc63a3dbc38182a4e"/><dir name="Resource"><file name="Abstract.php" hash="841e8054f863bb931a77ee7566252c2e"/><file name="Aggregation.php" hash="3ffea2e0c7fde3c001db5b39ebfa9f0b"/><file name="Attribute.php" hash="7dfb03a93545bbc0f3dfc764be9d7f8d"/><dir name="Data"><file name="Abstract.php" hash="835008239d9b91c16a2d972aa0f59568"/><file name="Configurable.php" hash="7ab1340e4d655b92110de56727b3baa1"/><file name="Grouped.php" hash="94e47080c8f6d107791271c21c88710b"/></dir><dir name="Indexer"><file name="Abstract.php" hash="ed70e8d2d098dab0aa3e69987a6eb43a"/><file name="Eav.php" hash="31a975aef9ba4b6342eaee5c807f3e65"/><file name="Minimalprice.php" hash="6eb6e4b3fb2fa545f2d038ccf0cadc0a"/><file name="Price.php" hash="064d4f9ae150af92c167e2f87bacac54"/></dir><file name="Indexer.php" hash="2cc939178ff4282eec7626cdba5f1c04"/><file name="Price.php" hash="92c794f7efea76b7743824653c1af1be"/><file name="Retreiver.php" hash="2c957b00ad7ce5a6b95edd019edb6d66"/><file name="Setup.php" hash="5554288996af6894c7775b145ffc5bf6"/></dir><file name="Retreiver.php" hash="1df136bf73b17d8359282db267f82c4f"/></dir><dir name="etc"><file name="config.xml" hash="c656807d07ca63f6559c2c16433a30e4"/></dir><dir name="sql"><dir name="catalogindex_setup"><file name="install-1.6.0.0.php" hash="97c3e10d65e4659926d6b421c1176ffc"/><file name="mysql4-install-0.7.0.php" hash="abc5d0a60e6aab9d45381283f81135fa"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="2fe9002754d7040b3d81232775aeaaf3"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="3eea917118c05a18058a1cd8a4ba4bf1"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b6d8864d8dfd8c7ee3a02b8aa302e871"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="44255be8ed6d405d4fb46437834fd5bd"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="84481ab5908352b47ee67f8e567fdd51"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="31cb140799cbfdea28fd5664dbd20ebb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="4d6dacf7add59599453c62b2030f8a19"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="941ce43d345e02a8e2063372f668aee4"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="af882140c001d15fd714561a4edeba4a"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="ca365f245bb6431d707cb6b4191875ce"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="713fb9108b9cc1a693beb46c4bc0f70d"/></dir></dir></dir><dir name="CatalogInventory"><dir name="Block"><dir name="Adminhtml"><dir name="Form"><dir name="Field"><file name="Customergroup.php" hash="2e9c0b96002b64f4f7162bd226d8f272"/><file name="Minsaleqty.php" hash="f8e25f0b5e7963d56340bfedfe36568a"/></dir></dir></dir><file name="Qtyincrements.php" hash="2e8244667132250bac8df2261776922d"/><dir name="Stockqty"><file name="Abstract.php" hash="8e2e0ade0a0da53c6b35222dc09c071a"/><file name="Composite.php" hash="abf260fa1ed8bc927c5d8c3cc96ddc6c"/><file name="Default.php" hash="a9faf85cce3e6e55e3f6e4c6238cd500"/><dir name="Type"><file name="Configurable.php" hash="9e70eb26e469c140f8284f1e5ba40567"/><file name="Grouped.php" hash="e417d1c1e33593a0716fa13c08532b47"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="e0445a47c24084f278d63fd06637cd64"/><file name="Minsaleqty.php" hash="1d5f6decd8444784b18259933d81bb70"/></dir><dir name="Model"><dir name="Api2"><dir name="Stock"><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="7a23ef28d5a0af8bfc560a0676b2a085"/></dir></dir><file name="Rest.php" hash="ba30f908399b6f74e8b0a7002d7a58ee"/><dir name="Validator"><file name="Item.php" hash="b4c1717c1e68a85e311b5824785578b2"/></dir></dir><file name="Item.php" hash="aa104a6ad7fcd8bbb5525d2b06da44b9"/></dir></dir><dir name="Indexer"><file name="Stock.php" hash="335ec51bc643daed577dfb2ba8bf6b46"/></dir><dir name="Mysql4"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="4473b479ce9ba081ed544e1b8f0b7309"/><file name="Default.php" hash="9ca91a40962bd6c477c078a630e13ab9"/><file name="Grouped.php" hash="8b101ec046557860d6f105ae41e1522e"/><file name="Interface.php" hash="326e696ddeacaf4276cbaab8a4182dec"/></dir><file name="Stock.php" hash="71d81a2696bacfc9c0dd6424ab85ab16"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="a38578f9783e2a4ac28c4e805abe2636"/></dir><file name="Item.php" hash="2cfd2de320892d92e7c8a292b56d78bb"/><file name="Status.php" hash="e08210b68acf2bffd5f42f13fc3e5664"/></dir><file name="Stock.php" hash="182adcece403f3ef3bd7dce42eac8d87"/></dir><file name="Observer.php" hash="020a068947260bb45ec1d78060aa5fef"/><dir name="Resource"><dir name="Indexer"><dir name="Stock"><file name="Configurable.php" hash="ccea699212cff2126272bb083c5d263d"/><file name="Default.php" hash="8149b5c0bf67e786f7578dbb9deab3e6"/><file name="Grouped.php" hash="536e6f1a82a87fc585c12ef19dea0cf8"/><file name="Interface.php" hash="8618058d3e32ebd241f70cc2d2e2b724"/></dir><file name="Stock.php" hash="61375ad597c7aba54135ec211b1a82f0"/></dir><dir name="Stock"><dir name="Item"><file name="Collection.php" hash="869c034146c234b9903de6a77daad195"/></dir><file name="Item.php" hash="cd33d89bd9b106404390c13e45e59e1c"/><file name="Status.php" hash="3779311bafda42361e4914457843fe0d"/></dir><file name="Stock.php" hash="6b27005eed460abb8024062ab5689627"/></dir><dir name="Source"><file name="Backorders.php" hash="52bfd816b598f674af9246a386e853d0"/><file name="Stock.php" hash="8f989c3a9c2bfad7024c2972660b6230"/></dir><dir name="Stock"><dir name="Item"><dir name="Api"><file name="V2.php" hash="11906267f8825815d908e8dc4da2d5f7"/></dir><file name="Api.php" hash="ee5f50879277fbfb25fef1cd765fbec4"/></dir><file name="Item.php" hash="b1cd47179773a36d88e1cbbddcf35f08"/><file name="Status.php" hash="7bbd47e4e0f67216aa713490ba8f1325"/></dir><file name="Stock.php" hash="d855ca5b36d285f8a17ea50a6505b3ef"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Minqty.php" hash="4014d544cb255499a02e567d4996903d"/><file name="Minsaleqty.php" hash="fdece014d82645ec760f206ff7df57d7"/><file name="Qtyincrements.php" hash="285280b282792966c9a0f6ff1021a4a0"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="1df150f6a6a441a5e7cbda8e585700f6"/><file name="api.xml" hash="e7091001f41aad0123d9b497de699ad9"/><file name="api2.xml" hash="cb0a1352c87cfc41d300433cdc751543"/><file name="config.xml" hash="bb99649315278ff3c9ab14c42e4da6b3"/><file name="system.xml" hash="e82c936b49b723bfaf7708955302f31e"/><file name="wsdl.xml" hash="cfad5924eb32b8fb7ccf79309e5966df"/><file name="wsi.xml" hash="ec7bdd8cb2bc5dd12c0a4d865fe3d313"/></dir><dir name="sql"><dir name="cataloginventory_setup"><file name="install-1.6.0.0.php" hash="c58fbf677912982192f8ba6f92da98a8"/><file name="mysql4-install-0.7.0.php" hash="c14adc7fd17314f606dd025e5a3596ab"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8bc1263072589be9aad31acec946d7d2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9ccd6c185ac8c4711b0dd2f23b41ee27"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a9b3620418d2989d776b7331c57f2662"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="b4ce29815129ac4a20e3c90c2e79c21a"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b6d74e91f068732e6d22ab91676c1f4a"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="643fe882b5ab42a56116119e424d0c63"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="e7b0e938da066210c9ebf4245ab58490"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="aa4b8366d8fa8eea648a025e99a8ad7a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="80990b2e6d3614b02bfbd1d937d34d5a"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.0.1.php" hash="9658089831fd4d840ce4db56aed83b23"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="89d03a9fa5a570b3313142496c6aa615"/></dir></dir></dir><dir name="CatalogRule"><dir name="Helper"><file name="Data.php" hash="02fd668b6fac397272a825c3541da418"/></dir><dir name="Model"><dir name="Action"><dir name="Index"><dir name="Refresh"><file name="Row.php" hash="93b092e341b065a9bb317e12444c5bb2"/></dir><file name="Refresh.php" hash="0e568cce6cda87c03d340c870d0b1785"/></dir></dir><file name="Flag.php" hash="06cd7f3695868ca1179c714c21cf5940"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="386d62b6e7b73f4b6b9c3b02cf74d88c"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="129382f3131c13a18283adbfeb62c2a8"/></dir><file name="Price.php" hash="429bbac7f001786a730fcb4952cd08ed"/></dir></dir><file name="Rule.php" hash="f5d715c0ef2b3131f17f0b3b58b57c9b"/></dir><file name="Observer.php" hash="a4f5c653cf6ea08d438ed6cb7ab01815"/><dir name="Resource"><dir name="Rule"><file name="Collection.php" hash="e68a7c7f5f2c30135292dfec6a9ba1c7"/><dir name="Product"><dir name="Price"><file name="Collection.php" hash="24b6c52ec0ae8e4a77aa026afeba33eb"/></dir><file name="Price.php" hash="dbb69f5dc27ba7ac2906dfeef83058bc"/></dir></dir><file name="Rule.php" hash="333901cbed42699ed619591aefa54d3a"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="9f1535a506b3572ef624fb1fb6728420"/><file name="Product.php" hash="5ec3f6ce240e4a566df9c8f986952482"/></dir><dir name="Condition"><file name="Combine.php" hash="e5ee0060b291073742ccd8117e063dfa"/><file name="Product.php" hash="ad29e318311505376d6107505ce3ddf1"/></dir><dir name="Product"><file name="Price.php" hash="2c10f93fffed8412ee293593ee921f51"/></dir></dir><file name="Rule.php" hash="bb269632d99431ba30af6495afcf0a83"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c6b223bf5a5652ab22611116c8c657e2"/><file name="config.xml" hash="9d73f646bfdbb6cc8c5bd138193d7f5a"/></dir><dir name="sql"><dir name="catalogrule_setup"><file name="install-1.6.0.0.php" hash="f332d718d7bd99d71d0f082665693ecc"/><file name="mysql4-install-0.7.0.php" hash="76d2ed479091e930a6d38ee4352bd7f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="52b4d6b4f74ad67eb2bd2f55dd01d687"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="881908a6f1cb2168d75faec9c12386a4"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="7b46efbd5570db930a2c48c48d6e1d42"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="66928483f1f7b1998478515ccc51c5e8"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="de0d78cebca0488b813b3a2cd87446ff"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="e0a6bffa1b75781d635af98ab71d55ff"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b9dd39d53f3640cc1a3353db14b55184"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="c1a0379e645058c2ce17e82d085bd8dd"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2d8f52da58d3aa7c880c973253d79910"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="31c2d3d59471a95b3e76c7565badd1c8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="2a4f997d4154ba7eea0bd70341361870"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="b960a4dd01fa9fd52b6cc7a69182cf84"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="aa53e808b061f65ee9e96ab5dd4669d1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c12a6c50ab346177340f211130e35c5e"/></dir></dir></dir><dir name="CatalogSearch"><dir name="Block"><dir name="Advanced"><file name="Form.php" hash="e09857306805f17d7eab766db1a311b3"/><file name="Result.php" hash="3b276615955ba0b3f0e7aac91000be10"/></dir><file name="Autocomplete.php" hash="47bb6c0ee66fe844396761c32b7e0fd2"/><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="d61b49dfd69ac4911df3164b28c253c9"/></dir></dir><file name="Layer.php" hash="c184ba0c66101349863cf4ece22fecaa"/><file name="Result.php" hash="744bd500ea0a539689dfdc90a010928c"/><file name="Term.php" hash="dcaed98a36ce41a8aa772aaa2fe579a7"/></dir><dir name="Helper"><file name="Data.php" hash="21e8df110a7815488a32d826288a1779"/></dir><dir name="Model"><file name="Advanced.php" hash="68f1e6b7ae6d58b7c7dfffe451c12468"/><dir name="Fulltext"><file name="Observer.php" hash="55bb856408b532a5a2fcbe5d72ec7e5b"/></dir><file name="Fulltext.php" hash="7f979ca22146216bc5e79f54146c6307"/><dir name="Indexer"><file name="Fulltext.php" hash="37a36fa4fc2c5644590984c97b292c48"/></dir><dir name="Layer"><dir name="Filter"><file name="Attribute.php" hash="51fdc45bc9d7b73240e5912c96318e53"/></dir></dir><file name="Layer.php" hash="dc75dfbfb1d4500419fe2e920a9a197d"/><dir name="Mysql4"><dir name="Advanced"><file name="Collection.php" hash="93472c5b0519e8a32716607f44e2e931"/></dir><file name="Advanced.php" hash="91b392b7e91171e513edaaa7bf9daaa6"/><dir name="Fulltext"><file name="Collection.php" hash="64a3d6b2222856b359fc590e0f9123f7"/><file name="Engine.php" hash="02c44612ab356054281fdc57c8bf4f43"/></dir><file name="Fulltext.php" hash="5306ad7e0a51b62b4a196d12567a85fb"/><dir name="Indexer"><file name="Fulltext.php" hash="17ca5374bbfdc866c2042539413fd1a1"/></dir><dir name="Query"><file name="Collection.php" hash="2d199f6a7a59dd72431361882e2e3bdb"/></dir><file name="Query.php" hash="c50ba30123a9097da433d6477734aefa"/><dir name="Search"><file name="Collection.php" hash="3082b50e38e1316290f02d44cb7bea09"/></dir></dir><file name="Query.php" hash="3c554833d0d6d9ff28249413ec69c95a"/><dir name="Resource"><dir name="Advanced"><file name="Collection.php" hash="367e28f0b01e481639f9080af2103273"/></dir><file name="Advanced.php" hash="499d0194d4398b6112fe4728b4574d08"/><dir name="Fulltext"><file name="Collection.php" hash="c1aa738ba2762c740bafd30b91541811"/><file name="Engine.php" hash="f4ff7fb0fef054d0b9e07fc8d6a7a4f1"/></dir><file name="Fulltext.php" hash="49e4c0eaeec47644808638c06acfc79e"/><dir name="Helper"><file name="Mysql4.php" hash="d842b9fb5472821c9ab907e59d91aebf"/></dir><dir name="Indexer"><file name="Fulltext.php" hash="4904abfa5a1b521ac3cf6dba2e634de6"/></dir><dir name="Query"><file name="Collection.php" hash="423c3688bdd152ee2a3fd3b4edecfaa8"/></dir><file name="Query.php" hash="72c2d37cddee2a7324d11aefd52f14be"/><dir name="Search"><file name="Collection.php" hash="66208450247763e5966249f23686703d"/></dir></dir><file name="Session.php" hash="3745505f98b1a5048a6b7a9d8b6c4f6d"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Sitemap.php" hash="fa4e835f1e0cf01dbf1ac83f55b37b7f"/></dir></dir></dir></dir><dir name="controllers"><file name="AdvancedController.php" hash="23d18bbefe8d5adfdc9b9b55e733b273"/><file name="AjaxController.php" hash="2fdba8218e3c8a6459be9811df8ddc9a"/><file name="ResultController.php" hash="f426aec253d9637a23166d8b68ea7476"/><file name="TermController.php" hash="8e7c5c0c561a20e576a9bf92609f51b3"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c4ec08c32f76b59392eb05422a7aea0a"/><file name="config.xml" hash="a8ea307b4b0a8d243a562b722d5f6cc8"/><file name="system.xml" hash="11d073698075bd1d34bcad7b97ece881"/></dir><dir name="sql"><dir name="catalogsearch_setup"><file name="install-1.6.0.0.php" hash="5167ffecb4d0816729fa55ecfb031f6e"/><file name="mysql4-install-0.7.0.php" hash="60a67b21cf81c144a73b675c38b448dd"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f60f5ca4dfe09e5cb4542661ca100f58"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="933ff654bec558c06154bf4a94361e50"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ef06fdabc135f31e09f5d9d352afdb4b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b3d2a1b9f232e07ec18eef4eb73663ce"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="86d5358977b644d0cfcbffe3a2af2b5f"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="a69f6e028a210cacd6c25cb9da90f40a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="9558e9c0922c08180ca20bdc32bbb002"/><file name="upgrade-1.6.0.0-1.8.2.0.php" hash="8f960ea56b711026613027837ca2fe44"/></dir></dir></dir><dir name="Checkout"><dir name="Block"><file name="Agreements.php" hash="6c419b6e50cadacc1e3683175f78a52e"/><dir name="Cart"><file name="Abstract.php" hash="79ea3265df399c9d5aa26205b25029a8"/><file name="Coupon.php" hash="5ff10b062d60e48654a97a764cf9eebe"/><file name="Crosssell.php" hash="72f9367a7ca7afebcef1717958b3e2f8"/><dir name="Item"><file name="Configure.php" hash="122317fd9233a58f8431f5aa8fe6c6b3"/><dir name="Renderer"><file name="Configurable.php" hash="0499106074c07c07911e02bdabc28562"/><file name="Grouped.php" hash="7dc9b801b73e502eed94f688e56aa8f6"/></dir><file name="Renderer.php" hash="b115b174d92e3b9c89712be5fb1ddd25"/></dir><file name="Minicart.php" hash="baa802262a3d62eb9f5e9b9a6b575666"/><file name="Shipping.php" hash="98375067aecfbbd314a49b01703f35fc"/><file name="Sidebar.php" hash="eae9e0946e0ed91cb983d2cf3d8ff413"/><file name="Totals.php" hash="278079d9f15c7fb26a96d4eafbc2457d"/></dir><file name="Cart.php" hash="8927a89d17a7c5450a297f2fcd2f4d63"/><file name="Links.php" hash="5af955b92e6909a8037d3b2bfe3299d0"/><dir name="Multishipping"><file name="Abstract.php" hash="13eed75a648bc53d3f9cab30fa886d1a"/><dir name="Address"><file name="Select.php" hash="c1d42e9a074f1aae15e7cc8d2438958c"/></dir><file name="Addresses.php" hash="01bd295d52c0efd3d25c85eb70224b64"/><dir name="Billing"><file name="Items.php" hash="439e1c39eb8f0ff590855619ee0b487c"/></dir><file name="Billing.php" hash="cd0ce4f01da14b9db765b0e1a8b73939"/><file name="Link.php" hash="fd48a3860b89af8fa1fff0b6e8ee635d"/><file name="Overview.php" hash="c466ea1a4704fd3eb239d29bc18426c6"/><dir name="Payment"><file name="Info.php" hash="f3c621bf82891c1526e033658861985c"/></dir><file name="Shipping.php" hash="ed6224c3de5545061118a46eb26f323d"/><file name="State.php" hash="2d44a4589b51b51717d7388c1f089060"/><file name="Success.php" hash="fbfacb807fdcafd4303c876e95cf44c5"/></dir><dir name="Onepage"><file name="Abstract.php" hash="6636e2a60c4333b67476c1ab73470e42"/><file name="Billing.php" hash="6895de8b90b2ebfa0fd45c36b9d62a60"/><file name="Failure.php" hash="fd9d92089ff78b9c1bdd9c550b1b0beb"/><file name="Link.php" hash="244a96a744397a83e0adc48755462ec5"/><file name="Login.php" hash="acfdf55652b1b6216f948f9264107721"/><dir name="Payment"><file name="Info.php" hash="4c949f134995bfc85af1aaa1408d30af"/><file name="Methods.php" hash="e7e382062e415ee142eb874f3d7982de"/></dir><file name="Payment.php" hash="33174e1083b18f0ffd8b01193e346479"/><file name="Progress.php" hash="e3fd23946ed8dea075237cedad3504b9"/><dir name="Review"><file name="Info.php" hash="cbe8a8c5c7dda76be20018f22ddea285"/></dir><file name="Review.php" hash="01938f8f5d45925b4b6deafc95ef81ea"/><dir name="Shipping"><dir name="Method"><file name="Additional.php" hash="2e827ccaa46ad3f571dbe055da2d9d4a"/><file name="Available.php" hash="3b091336ac70c22a1f5c4254468e838f"/></dir><file name="Method.php" hash="fc1c37cd94b51f12a05ea5b34a505cd1"/></dir><file name="Shipping.php" hash="8bce6afd8592e02fa26e7838653fd2e5"/><file name="Success.php" hash="15215ffcbb27b211983f6729f16808e9"/></dir><file name="Onepage.php" hash="9c055da8dac9e6768e11410a5af1b111"/><file name="Success.php" hash="934b486b48e29808a83ce46548085f9f"/><dir name="Total"><file name="Default.php" hash="ac18f91a451a3b0e5f3534b8d331d801"/><file name="Nominal.php" hash="c680791504238741fbfda82bd3e529ae"/><file name="Tax.php" hash="c167aba9ce6886e0e039b299f02e266d"/></dir></dir><dir name="Controller"><file name="Action.php" hash="0b6b8223ff9fa50cce71a981b81a1e69"/></dir><file name="Exception.php" hash="8843b4d4cb6c2300c7eb41f25c36fbf4"/><dir name="Helper"><file name="Cart.php" hash="88c7a664f4b6235169238a1449a7cb37"/><file name="Data.php" hash="6dff22121e836f64f4495df89178514e"/><file name="Url.php" hash="aa56ee90a07fbe7011a7c0108ea8757f"/></dir><dir name="Model"><file name="Agreement.php" hash="3f041873a16711d3187093f99c0157de"/><dir name="Api"><dir name="Resource"><file name="Customer.php" hash="01695dd8fbf9dcb04e58452b7cb8dc4e"/><file name="Product.php" hash="60c82ea66b3307ada9629cfeb3085a70"/></dir><file name="Resource.php" hash="e9318ac0ccea53931bf3e1820440ad82"/></dir><dir name="Cart"><dir name="Api"><file name="V2.php" hash="8ed31090d4343e10f32096dfa8be5921"/></dir><file name="Api.php" hash="10c6022b2e4d543eeb176280d2fe9adf"/><dir name="Coupon"><dir name="Api"><file name="V2.php" hash="37e5b83cc1885403394b925d2f1811a8"/></dir><file name="Api.php" hash="248dab0865f6f11b33675ecf4d49aca0"/></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="437058c8e011f4451cd24092a687e1e3"/></dir><file name="Api.php" hash="4ab20a22e0e0cae84a8bbf7504230e3d"/></dir><file name="Interface.php" hash="90a82b74a7125491fbcf209f7253ee33"/><dir name="Payment"><dir name="Api"><file name="V2.php" hash="dfdd088a3c9cd8e0eadffe3478169bba"/></dir><file name="Api.php" hash="e061f0a8eafb776dfc9278c4e1bf194b"/></dir><dir name="Product"><dir name="Api"><file name="V2.php" hash="69b1b20f8507a6e1d49e60a6d6624552"/></dir><file name="Api.php" hash="4cd63af3cf6aebc8ab92a9870e256fa0"/></dir><dir name="Shipping"><dir name="Api"><file name="V2.php" hash="9745eccad000d73a39bdc942b078db6f"/></dir><file name="Api.php" hash="3beb01b7eb467504151f4930e3786f1a"/></dir></dir><file name="Cart.php" hash="39d64fd85416c389b8898fce0aa122fa"/><dir name="Config"><dir name="Source"><dir name="Cart"><file name="Summary.php" hash="a7de12a6e7bada6ee07ca7b420dfcc93"/></dir></dir></dir><dir name="Mysql4"><dir name="Agreement"><file name="Collection.php" hash="630bc38c5b7dd4282a8e5fc40b8dd82b"/></dir><file name="Agreement.php" hash="8b84786b700b9a3b1571ed60d200c1fc"/><file name="Cart.php" hash="a9c3c664819226cc6b991396dfe9da61"/><file name="Setup.php" hash="853da7adb3c0f2601cea42422b3c8615"/></dir><file name="Observer.php" hash="23f1b13f2ff512aa176127da47bc59ca"/><dir name="Resource"><dir name="Agreement"><file name="Collection.php" hash="d382c3cb681caf3595e8f1e74333afcc"/></dir><file name="Agreement.php" hash="76b6db40df8585da3f36316d560f52e9"/><file name="Cart.php" hash="b9bcb03fa78ac8e853c4e7a2f25bc8dc"/><file name="Setup.php" hash="d52f8c44ff0a18ce90186d998b5a1299"/></dir><file name="Session.php" hash="dc1be0477711dfa09c90be1f20f8c601"/><dir name="Type"><file name="Abstract.php" hash="876431c28c3e06020a1b0fc87e5280fa"/><dir name="Multishipping"><file name="State.php" hash="f22eb108e021c5654d6c956441c67836"/></dir><file name="Multishipping.php" hash="d7df9388663a58ed18d14eab796b5a77"/><file name="Onepage.php" hash="7623296ec5eca56b6b5ce5eedf96a9a2"/></dir></dir><dir name="controllers"><file name="CartController.php" hash="d8d9bba5baadb115ad53523d945b4306"/><file name="IndexController.php" hash="c27bcd873c8bd5608ab90ae78d200f96"/><dir name="Multishipping"><file name="AddressController.php" hash="c961a9cd3de294783ed7d41726430465"/></dir><file name="MultishippingController.php" hash="291fe953a99e782bd123ce1b3e88fa0e"/><file name="OnepageController.php" hash="beb35cb2289d5af3ea0cf33aa2ac673e"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3bd25edd429a1761399ce2f33926dbe0"/><file name="api.xml" hash="56f66248a45024499270e622af0b101d"/><file name="config.xml" hash="9d6e4eb2e746a7341535136d3891b01a"/><file name="jstranslator.xml" hash="c70d5f292b4e369d7c378346dbc05416"/><file name="system.xml" hash="f6f67fbccdc6a8223f22d0f2d94a1d91"/><file name="wsdl.xml" hash="9a10e25803e84713f5031a168dd0c624"/><file name="wsi.xml" hash="2567bee4ef18e1b426c700ce66c3bcb1"/></dir><dir name="sql"><dir name="checkout_setup"><file name="install-1.6.0.0.php" hash="bacfdd2c8ccb82057efca72250758a93"/><file name="mysql4-install-0.9.1.php" hash="7f40a79587cd339e871165bb4e8b38bc"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="0fae593af23654670a9a60e1ec93d7df"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="4f9a3d70f56c78478f5d1cc73b3ac918"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="96777089267f69ce0ece1f0b85b79a84"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="ad23b08fb3a6253b679846d7e2d9a877"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="4689dea6d535aca2681d91050aaf700c"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="feadb7e5160ff33b7d4b595c5594039f"/></dir></dir></dir><dir name="Cms"><dir name="Block"><file name="Block.php" hash="08baae8f852b0eb7ceb7f00703f90349"/><file name="Page.php" hash="d3893bc1dc3df63c65c3d8e3eee596d7"/><dir name="Widget"><file name="Block.php" hash="2d29800146e6e32e75a00ea9d8663bc8"/><dir name="Page"><file name="Link.php" hash="c8d6ab51cd313b3b2bbade08f8981727"/></dir></dir></dir><dir name="Controller"><file name="Router.php" hash="6a8e1f13e9da08ef8fd7364712a5dc8c"/></dir><dir name="Helper"><file name="Data.php" hash="0d6d4f0b162a64605f110364499a7300"/><file name="Page.php" hash="e514993ac654fb8ac5bdd16f5476dab4"/><dir name="Wysiwyg"><file name="Images.php" hash="d38e6d1abbc0c30c7b9d556508aa68cc"/></dir></dir><dir name="Model"><dir name="Adminhtml"><dir name="Template"><file name="Filter.php" hash="23efebd6cd5e478ae573167f90f7e45d"/></dir></dir><file name="Block.php" hash="2510ee77473f2dfe1b70dffdb6c71ea5"/><dir name="Mysql4"><dir name="Block"><file name="Collection.php" hash="56f951c0fccd6f8f4217e48a0dc34e1e"/></dir><file name="Block.php" hash="c8e3e5c7817f2d9580092197b222e795"/><dir name="Page"><file name="Collection.php" hash="f8455b1b345414ae2233229e6e89ba21"/><file name="Service.php" hash="52cda9bdbc67bed0ad890ebc4253e044"/></dir><file name="Page.php" hash="57bbae6d1da3f3fbcae2e974dd24870e"/></dir><file name="Observer.php" hash="7c0841e97b147871d78ae5d4eacbf365"/><file name="Page.php" hash="cd5813f33a28df24d2a871176ef6a872"/><dir name="Resource"><dir name="Block"><file name="Collection.php" hash="6ceb057a593d25ff06064a6649039b32"/></dir><file name="Block.php" hash="40f9938bd66ad36f46899c78ef6a8b95"/><dir name="Page"><file name="Collection.php" hash="ef32535a56be83dfadbbd6d31b438353"/><file name="Service.php" hash="7cf9b5d216081a22cedfd6e203c5ec6e"/></dir><file name="Page.php" hash="3991ad97fd44ec669410b11d392eece0"/></dir><dir name="Template"><file name="Filter.php" hash="5d27b599aca8a35f85ec6d19f338bbe6"/></dir><dir name="Wysiwyg"><file name="Config.php" hash="00afd10e12044b11afd492213c477c76"/><dir name="Images"><dir name="Storage"><file name="Collection.php" hash="b6e877870e17351df738be1dff5cd856"/></dir><file name="Storage.php" hash="0c179d8ef5099f7bbd66ae62175efccb"/></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="f872d2a6efeee3d405e5cc633481a6d3"/><file name="PageController.php" hash="0e0257f9133bbf7773508f0c5eba6e93"/></dir><dir name="data"><dir name="cms_setup"><file name="data-install-1.6.0.0.php" hash="a2524a24696ccc0c0051abc687b3b63d"/><file name="data-upgrade-1.6.0.0.0-1.6.0.0.1.php" hash="aa16ad74a468113741303f3a9b992efb"/><file name="data-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="364a7d774dc5f46ff84716a32374ae94"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5fdb8a794aa9c661491b77ba99c62eb5"/><file name="config.xml" hash="bfcfa1d954915d7ec2e0545af9d80dd9"/><file name="system.xml" hash="568f4eb1982d6c4dd32b25dfd3083ed8"/><file name="widget.xml" hash="fb79ba2126ba0c725eb1813dff174fb7"/></dir><dir name="sql"><dir name="cms_setup"><file name="install-1.6.0.0.php" hash="11ceea6c6c0d695d822096571fab4b9f"/><file name="mysql4-install-0.7.0.php" hash="5ebbb4e38de419a58f3d1a06d6381f93"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="76beaae155c65796e580e922fc10cdb2"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="5c7e65d4b2faac184097691e77e46b57"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="9df2ea203d9aeea43a6d450a1b403780"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="6aed180669f3c7751b58b6c6aac430b1"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="9e55629d9f9b47d682a17058997246e2"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="775f2b5b185dea356844293e9f732e97"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d6fcd1a5949c041035954a1604828f50"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="408cb50d7a9878fb017069d30a65170b"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="e91389aa6444e2d56be0925897709f6c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="14a5a61c8214ce5dd7d47f8cf3744edb"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="929a4d0435d84c06fd662ae80bf09b52"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="eb09203a1d3c74197beb5d52cf1eb794"/></dir></dir></dir><dir name="ConfigurableSwatches"><dir name="Block"><dir name="Catalog"><dir name="Layer"><dir name="State"><file name="Swatch.php" hash="6887e2af0be94e3cd1a7ae5ed7cf136a"/></dir></dir><dir name="Media"><dir name="Js"><file name="Abstract.php" hash="0efe6efa7f3b10f969d394786ec07ae0"/><file name="List.php" hash="610da3f155d02eefcb92a0a5148b62f8"/><file name="Product.php" hash="a21153887e119a79084a16ba05685ba0"/></dir></dir><dir name="Product"><dir name="List"><file name="Price.php" hash="9f444e14b4d91046919ba561aea953a7"/></dir><dir name="View"><dir name="Type"><dir name="Configurable"><file name="Swatches.php" hash="f2f57c18a3a8e3e28fe113ef4a040440"/></dir></dir></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="6e2e74df24270f8d2439248af8e1f6f2"/><dir name="List"><file name="Price.php" hash="07f06e13d39df55fb6ea4b4061b51530"/></dir><file name="Mediafallback.php" hash="49a9b43961336e4a559824d03ec80f2c"/><file name="Productimg.php" hash="2f54dbbd264875d55145002411a124a2"/><file name="Productlist.php" hash="b0a644f9a7696db14c44efcbaff2d325"/><file name="Swatchdimensions.php" hash="05e4dcd9530b050cd7b58496141bfef9"/></dir><dir name="Model"><file name="Observer.php" hash="8a14785bd5cd4a97238dd4eec5a70841"/><dir name="Resource"><dir name="Catalog"><dir name="Product"><dir name="Attribute"><dir name="Super"><file name="Collection.php" hash="cc8383320165c4b86b4d69dbb9dd9c80"/></dir></dir><dir name="Type"><dir name="Configurable"><dir name="Product"><file name="Collection.php" hash="a57bde9ef68e3e132bee8277ea2a1350"/></dir></dir><file name="Configurable.php" hash="9e962b8ce86d7759a98dee78ad695d21"/></dir></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><dir name="Catalog"><dir name="Product"><dir name="Configattribute"><file name="Select.php" hash="e62adfcf184e9a2122f1a19040dc21c3"/></dir><file name="Configattribute.php" hash="16aac641aaac0d4414bc6c184b39c9b4"/></dir></dir></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="89988fe030e4c09d2026f1bbf7660af9"/><file name="config.xml" hash="cfa742589e8e8ed4bd58fc3f79ead76e"/><file name="jstranslator.xml" hash="969a61359c6f119aad145803bd2a8c8b"/><file name="system.xml" hash="45153613a10f66eb03200863329f2a66"/></dir></dir><dir name="Connect"><dir name="Block"><dir name="Adminhtml"><dir name="Extension"><dir name="Custom"><dir name="Edit"><file name="Form.php" hash="76b93302a318c93964500d94b58ea4b9"/><dir name="Tab"><file name="Abstract.php" hash="17596eeb6b89b1224c4e231db7bf1d99"/><file name="Authors.php" hash="04a6a4f80bf35b812b94c2e1e968f447"/><file name="Contents.php" hash="e413c95985acb90a4b95fc9a07daa4e2"/><file name="Depends.php" hash="0d76887da37383555abed6e1864c29f5"/><file name="Grid.php" hash="e697766b63ee61b93a43cef718b4983b"/><file name="Load.php" hash="ebc124649980545035a84844a2ec26cb"/><file name="Local.php" hash="811fc83e338d7253c9b01cf0b42ddc68"/><file name="Package.php" hash="c104894bd8051f2bb116226cd13eb8d7"/><file name="Release.php" hash="72da8682ba77a0390283af960e0f6382"/></dir><file name="Tabs.php" hash="dc98a95db0627f6ea68098951ac62a0a"/></dir><file name="Edit.php" hash="065ab68977dea45f03106f9888b3163b"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="775c24dc230dd16d7c45d5aab8f8bc5f"/></dir><dir name="Model"><dir name="Extension"><file name="Collection.php" hash="7ba1af3c40d1c9178a2441087b552c9a"/></dir><file name="Extension.php" hash="4ec228deb98a7c0f73a053785b2e7baa"/><file name="Session.php" hash="83b7c65b6e95aa98be31fcf73c59c11b"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Extension"><file name="CustomController.php" hash="25b2c303170316f51ade98f9ed296771"/><file name="LocalController.php" hash="45c2e963cbf6971e79f7236f37b465e8"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="65d57a497ee09c0f55889a464e9e8ae2"/><file name="config.xml" hash="ea7d1fb7798ba51608b4b423baa769ec"/></dir></dir><dir name="Contacts"><dir name="Helper"><file name="Data.php" hash="01fd76d3de097833859238af70268c7f"/></dir><dir name="Model"><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="972d0ea115f2e748ff5ed306d2f86d93"/></dir></dir></dir></dir><dir name="controllers"><file name="IndexController.php" hash="ad53ddc28af4e5f60402bde2187d14cc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="5a5412d8cd4ba0577b53483384304464"/><file name="config.xml" hash="d73ab097d6502eccb1d5b2d177a75ca6"/><file name="system.xml" hash="e675da38d1a140774e10e5eefcfce547"/></dir><dir name="sql"><dir name="contacts_setup"><file name="install-1.6.0.0.php" hash="89d25bebd151554fe3bbe3aa7c0dc919"/><file name="mysql4-install-0.7.1.php" hash="da95f978021d0b072b68dcd96b48e56e"/><file name="mysql4-install-0.8.0.php" hash="5cd7480fc89bd86f98ccaee703046616"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f65d6c63a1f7d8304809352e6b283c10"/></dir></dir></dir><dir name="Core"><dir name="Block"><file name="Abstract.php" hash="181c69bec880b301cf2a8f420bb29351"/><file name="Flush.php" hash="fd9dfb94528913c62cc7a4d7e5a1a517"/><dir name="Html"><file name="Calendar.php" hash="b101ca0e43d1dbc4e6880337bf01f083"/><file name="Date.php" hash="55f39c51369070b92407c353b450dd83"/><file name="Link.php" hash="52008b8eee4025fa3ce89afff820dab4"/><file name="Select.php" hash="94d45ec931414b391f8627fa79105a68"/></dir><file name="Messages.php" hash="b99feba6519e2e9a7f1392b19a852f05"/><file name="Profiler.php" hash="be9cad609a54f5a54858238aae217a92"/><dir name="Store"><file name="Switcher.php" hash="19f7c757077689e92c5072a24f843bee"/></dir><dir name="Template"><file name="Facade.php" hash="3b0217c0329aa8ce65805d794f97f0db"/><file name="Smarty.php" hash="3952590ec21561a967bc7ae4093e41a4"/><file name="Zend.php" hash="df09e4fa347b60978eea94bbf85070c4"/></dir><file name="Template.php" hash="6000e614c2e4f2dfa51c56feba11737a"/><dir name="Text"><dir name="List"><file name="Item.php" hash="1217b54e7a673f5362b93b801e8e47ec"/><file name="Link.php" hash="d2c7b7093cd7e73d1477ac9586ad630c"/></dir><file name="List.php" hash="4fd2bc96e9c37feb598eac4c4588eb8a"/><dir name="Tag"><dir name="Css"><file name="Admin.php" hash="f489191668ee974a3cd58249114c23a8"/></dir><file name="Css.php" hash="2df8967b6fb12467d2089156838d5744"/><file name="Debug.php" hash="45464fa97f1073305a54091c888c6595"/><file name="Js.php" hash="c2c209a6fe743d0a1e23c064b0da7f74"/><file name="Meta.php" hash="4be5ce7d98b752f78ce557e4615e09a4"/></dir><file name="Tag.php" hash="91fb5ed6bc5c86d81a164222dbe252a3"/></dir><file name="Text.php" hash="107c848b8a1445b448b0fb700b1f9a48"/></dir><dir name="Controller"><dir name="Front"><file name="Action.php" hash="68f128fb1eeac96a88ccadc9e6266031"/><file name="Router.php" hash="c2a39b4e6b0522a85e1e3c933379da10"/></dir><dir name="Request"><file name="Http.php" hash="9630c120fa5e6c9bb40dd834510e7394"/></dir><dir name="Response"><file name="Http.php" hash="611b9c20b0db52fafe10d982d1190729"/></dir><dir name="Varien"><file name="Action.php" hash="60099b82349b2d1a4f6b9c3e5b45164d"/><file name="Exception.php" hash="d61c714f6177c3113637e37492ae861f"/><file name="Front.php" hash="93246cc98978f42489f3b54085d3b6cd"/><dir name="Router"><file name="Abstract.php" hash="4e55cf4f93c0bf9511b39b5a58bfc125"/><file name="Admin.php" hash="77c9d603cd241af6979d42bf18aa569d"/><file name="Default.php" hash="3efe36835a5671227ede3b2995b3ee27"/><file name="Standard.php" hash="abf493b56ab8ecb0cdd377e282481e5d"/></dir></dir></dir><file name="Exception.php" hash="31ca7f9b564737aa0d9e44c40f8ae884"/><dir name="Helper"><file name="Abstract.php" hash="797b2055cb15cae1f1f1533628fd2f97"/><file name="Array.php" hash="9f4a32af761a5183a2382967143bdb73"/><file name="Cookie.php" hash="1a7137d6315a204839964ca6ad14444d"/><file name="Data.php" hash="c519d5eebc5f7d815613d69c2a2d23ea"/><dir name="File"><dir name="Storage"><file name="Database.php" hash="ed127be92b1accf150d16fccd36ef1c4"/></dir><file name="Storage.php" hash="03de906d7c74b5fbda3fba390e3d4466"/></dir><file name="Hint.php" hash="0a54b2a389f46b52e0e2ced66baa6583"/><file name="Http.php" hash="989506e44c5de4c5c38a5383989d59cd"/><file name="Js.php" hash="2a387f8aeeac68c505f7843151987dce"/><file name="String.php" hash="07ac63bfbea05a210fcf632d999adeaa"/><file name="Translate.php" hash="c96c535de4a30db514a0a611af6ef9d8"/><file name="UnserializeArray.php" hash="b14f0cf9a2676961650828bfbd52992c"/><dir name="Url"><file name="Rewrite.php" hash="1bef9c0835550ea3839306a23412b1ad"/></dir><file name="Url.php" hash="d0c40c0c2d5604d182c854c9adc32f4b"/></dir><dir name="Model"><file name="Abstract.php" hash="d1d1d3a5d98f1d740c11c28a504c42fd"/><dir name="App"><file name="Area.php" hash="ebc16a577260811a2a6a18af0076d974"/><file name="Emulation.php" hash="02c3d17d61e3cb4226b8529ca509328e"/></dir><file name="App.php" hash="e097bb0f10878f0fa813689889d28484"/><file name="Cache.php" hash="6b4502cb8f596f2c04b7e96416fd5ff5"/><file name="Calculator.php" hash="f7565ced7f75b5c0f38ca290ef4f6190"/><dir name="Config"><file name="Base.php" hash="3fd453d91eda0ee62b6d7d93780701e6"/><file name="Data.php" hash="a47121f002b901587af61db6672be643"/><file name="Element.php" hash="c9c49041d51f363957c63936c090b6da"/><file name="Options.php" hash="e582e00cf08bfe118d794fa86e592b88"/><file name="System.php" hash="c61e23bbeb5ceda5a6025e38bad1bbcf"/></dir><file name="Config.php" hash="5e214b2eb530121c0c984667ce7ee2f4"/><file name="Convert.php" hash="34cd7dc75bb4f0346c9bab88fb7f7d86"/><file name="Cookie.php" hash="29b5db1b3a93728e4686346ba0b0f93c"/><file name="Date.php" hash="dede2548cb32308a2a0a8a16b2bae1da"/><dir name="Design"><file name="Config.php" hash="df530eedf1f6feff7be7b637cb6813c2"/><file name="Fallback.php" hash="80bc720dcec5afcaf344c56058d2e7f3"/><file name="Package.php" hash="d3837c2fd5ae6f64cd15b80a940f15ed"/><dir name="Source"><file name="Apply.php" hash="47ba9fc0c45be610f95155e1ad6ef008"/><file name="Design.php" hash="9fc458c26da1d90754ed12477c99359a"/></dir></dir><file name="Design.php" hash="462b080e4d548675a0f765337c5da43b"/><file name="Domainpolicy.php" hash="6608467e7879164bf85e027b2a03bca6"/><dir name="Email"><file name="Info.php" hash="3a164cb67d10f6d04038f245fb55bccf"/><file name="Queue.php" hash="42e7e6abdfecf376752734d6e49d8111"/><dir name="Template"><file name="Abstract.php" hash="e358142e556d0cced3cc84b2a8f5f2f8"/><file name="Filter.php" hash="a8a28ee83e13fd2f3d0b196978bb9898"/><file name="Mailer.php" hash="6681e7b42df3281bfa7a8ee42b69c947"/></dir><file name="Template.php" hash="66676699de617c412441c3c28b9d8728"/><file name="Transport.php" hash="e4c9a71e9438e593ac59b8853d7501be"/></dir><file name="Email.php" hash="d807c53107619aac70f6be138daa693f"/><file name="Encryption.php" hash="cc2f535836d47868164b7b19a555fef3"/><file name="Factory.php" hash="a8329d328de0e5855513523407f7c146"/><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="7f70c39ebae0b69dd85f296375ba97d3"/><dir name="Database"><file name="Abstract.php" hash="8e02a5de6c912c8e7df8a4d56e6e3103"/></dir><file name="Database.php" hash="2e18119f9ce7fee1fb4cce71694d907c"/><dir name="Directory"><file name="Database.php" hash="12f974b3a4d9d5c2719e295358b6a381"/></dir><file name="File.php" hash="64f5cf70b7b2aac04ad2010e7726b2c0"/><file name="Flag.php" hash="fe629937cabf35ce797aa77a14534ec1"/></dir><file name="Storage.php" hash="1ee69792044faf29817a8555ab67fb40"/><file name="Uploader.php" hash="3d154fcb91174e16eeb04a229c6b6639"/><dir name="Validator"><file name="AvailablePath.php" hash="53407a699db7fc97c5a9f34eaf707e10"/><file name="Image.php" hash="b7fbcf231010f66273d3c907812f3050"/><file name="NotProtectedExtension.php" hash="14fae5d50b74784c586b54f2a91237e1"/><file name="StreamWrapper.php" hash="2966e45d4b779b006ff65afdc3d29fcb"/></dir></dir><file name="Flag.php" hash="5e9df0d7f21ec7ce6ad19a53f7273803"/><dir name="Input"><dir name="Filter"><file name="MaliciousCode.php" hash="9b87d312b7ad9882a418d58125280965"/></dir><file name="Filter.php" hash="527a8a30797a1451733d65666133510e"/></dir><file name="Language.php" hash="abe5b5349861e6eaba496c3418bf16ca"/><dir name="Layout"><file name="Data.php" hash="e353c25b8d41255b2b8f9333275d8a13"/><file name="Element.php" hash="9a1e14e44df962409655e23b8060c98f"/><file name="Update.php" hash="f5a5bd60a84b2215dbb53b32d0c6c70b"/></dir><file name="Layout.php" hash="f1a76bd7d8336aeb1e76075e0442b935"/><dir name="Locale"><file name="Config.php" hash="e297164e06185ca680c803e0226d66c1"/></dir><file name="Locale.php" hash="8cf95e8203a74b64f23ad5c3e98f45d9"/><dir name="Log"><file name="Adapter.php" hash="98ef08e1a2a2723107837369f2165f76"/></dir><file name="Logger.php" hash="763bd3ccd88755a381947852e2350f2e"/><dir name="Magento"><dir name="Api"><file name="V2.php" hash="8f482feb38b1cafca515884de54a950a"/></dir><file name="Api.php" hash="e4be9316b6bfc9f4b8e68aa5b9ef12dd"/></dir><dir name="Message"><file name="Abstract.php" hash="fce642f36593d58b30f9ee3be80c513a"/><file name="Collection.php" hash="88b98cebed98b1f99353152dd7f865ef"/><file name="Error.php" hash="655977a157fa50eb6b07b22f42c345bb"/><file name="Notice.php" hash="052f54af4d7689e6d22c07967138120b"/><file name="Success.php" hash="bffa6f6ebbe3d2de083d65a92884c671"/><file name="Warning.php" hash="32187b6734b82698bda722bfa4115db0"/></dir><file name="Message.php" hash="a95aa9f4a4b22d55849fb2402bcd3aae"/><dir name="Mysql4"><file name="Abstract.php" hash="3708704fae412a0d0247baf0224d1161"/><file name="Cache.php" hash="92c14ffee30326af3bc50a210ebded97"/><dir name="Collection"><file name="Abstract.php" hash="a7e6de8d9f759290881c80edac3b8b72"/></dir><dir name="Config"><dir name="Data"><file name="Collection.php" hash="f7dbe731a1f625a31603757c7300c8d2"/></dir><file name="Data.php" hash="130ed53184c7668ebf31e608294e091f"/></dir><file name="Config.php" hash="a3bf729bf497a384cbaeed34e6bac4b7"/><dir name="Design"><file name="Collection.php" hash="f7f10b12ebbfa86c1862b810ce6d93b6"/><dir name="Package"><file name="Collection.php" hash="b532dbace0f1a4275d73187bb183a4ec"/></dir><dir name="Theme"><file name="Collection.php" hash="c4ff4e160777903e9209130bd154167f"/></dir></dir><file name="Design.php" hash="3490465970f3eb4a00f5ce6278d6f6a1"/><dir name="Email"><dir name="Template"><file name="Collection.php" hash="05749d1d7446e51f63aa1faf663facdc"/></dir><file name="Template.php" hash="1ac03cd7ac86fbb73ae894de71c36fae"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="2a989b8aa3a1e2e880462ea9989a6f0f"/><file name="Database.php" hash="0645555755d39ca151ac4032506cf2e8"/><dir name="Directory"><file name="Database.php" hash="2210f93caf12401dc5f47d7ce46e1fd3"/></dir><file name="File.php" hash="772017c5419250a352d2841d09f8373c"/></dir></dir><file name="Flag.php" hash="94715a36f09bce0bed6ebe085285edb9"/><dir name="Language"><file name="Collection.php" hash="7f83183231ae71e38ec69209e583c127"/></dir><file name="Language.php" hash="db9c590813fe4c7da288b204269b3c88"/><file name="Layout.php" hash="9e3cb41d4c53be096099c997911175ea"/><file name="Resource.php" hash="843d7527e3908b9759bb16365e5e0bf3"/><file name="Session.php" hash="1a890927d43bdbae50314318d3117ffa"/><dir name="Store"><file name="Collection.php" hash="d425d0315f5a1977c5b6d6070f3d1a92"/><dir name="Group"><file name="Collection.php" hash="9113b6a4c8f90dd47b4886f7ca622586"/></dir><file name="Group.php" hash="8db5d7091ef1df0e95cb7674ce95a88f"/></dir><file name="Store.php" hash="d3ae0021d42acfd6a46af7059a67e65a"/><dir name="Translate"><file name="String.php" hash="61f98800fdea35f632ffe0d28c081f8d"/></dir><file name="Translate.php" hash="ecbe50a6490ae1c6381411fa149d4fd3"/><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="2aefce4731631e9465d0d23a19c779a3"/></dir><file name="Rewrite.php" hash="f349ed01f4fcdcd48dbd74bb13272315"/></dir><dir name="Variable"><file name="Collection.php" hash="199eca9e1659bfbcaa6c9460755f6b82"/></dir><file name="Variable.php" hash="d9262e41a163dd0c55fed55d3c6d7f8f"/><dir name="Website"><file name="Collection.php" hash="2a587a71bd36b68a77a4c8f02e2c2fcc"/></dir><file name="Website.php" hash="88ad625c889346e4cfe7c59e41233934"/></dir><file name="Observer.php" hash="e6a7f638f832df1e51f5e64feea6d6c3"/><dir name="Resource"><file name="Abstract.php" hash="1caae9c8430ec6ce0c13606335894edc"/><file name="Cache.php" hash="48a7128434d90edd49485e90768c828e"/><dir name="Config"><dir name="Data"><file name="Collection.php" hash="cb889be83198c5b528e24316371d1883"/></dir><file name="Data.php" hash="639c91e3346b8a93cc361a942ccd5d14"/></dir><file name="Config.php" hash="bac269b45f33fce05eff8adcb63fb7ef"/><dir name="Db"><file name="Abstract.php" hash="192eb8200dc8a6a6c784cc5c57355457"/><dir name="Collection"><file name="Abstract.php" hash="bdcadbc916bfd95ef1a445803829aa35"/></dir></dir><dir name="Design"><file name="Collection.php" hash="d010ab011ac9e2d1ae73d9ea15dffdf2"/><dir name="Package"><file name="Collection.php" hash="b46bd0681a1468c4413aa917d10063ac"/></dir></dir><file name="Design.php" hash="f078ea6fed695c8f9f07468389001106"/><dir name="Email"><dir name="Queue"><file name="Collection.php" hash="8ae181824d19be3dd8d0e72279bf0d69"/></dir><file name="Queue.php" hash="a6a50894a43ce7189f14e1e7b4840ead"/><dir name="Template"><file name="Collection.php" hash="ca9653326c602a71e0a93c076e5e35b8"/></dir><file name="Template.php" hash="6ed0dee792b3bdfbe6531166d42b91b4"/></dir><dir name="Entity"><file name="Abstract.php" hash="c9e0bb6aa889ca36e2eaae296396a02e"/><file name="Table.php" hash="c06c09b2a03bcbbfd186c9aa98a634de"/></dir><dir name="File"><dir name="Storage"><file name="Abstract.php" hash="4d12a1ee3a12b35a1fd908588d207bd2"/><file name="Database.php" hash="770ed506ed0a2d82f4897b4a287ae694"/><dir name="Directory"><file name="Database.php" hash="7703449b22f643da8dd43712955fa6b3"/></dir><file name="File.php" hash="40d79daa54798cb4f810cf7e2a524728"/></dir></dir><file name="Flag.php" hash="82bc20374f8864d49b7293c1dc70a4f5"/><dir name="Helper"><file name="Abstract.php" hash="78e15036317fe2f704427e748e488696"/><file name="Mysql4.php" hash="555297623b7312cb4a5ee74014dcb33e"/></dir><file name="Iterator.php" hash="ec070c942fc8f7a67f4e26e5fcd08d66"/><dir name="Language"><file name="Collection.php" hash="50cf8598e78404829ad72d63c8388c66"/></dir><file name="Language.php" hash="7e23e3443583f40c7e3415d92a35730d"/><file name="Layout.php" hash="e8f6aeb0ba21e41d5067b4cb856dde9d"/><file name="Resource.php" hash="3eb9eedef05d21d0cc6c4e97142d1d9d"/><file name="Session.php" hash="88318f7f71df8fd9d82fd8b24ab7abed"/><dir name="Setup"><dir name="Query"><file name="Modifier.php" hash="813bd2670a0d73708b09ea92bbb9be86"/></dir></dir><file name="Setup.php" hash="4139a2d32143a8550f87ff50435e75a3"/><dir name="Store"><file name="Collection.php" hash="3320d22e0d1333d614ad290e0525d53e"/><dir name="Group"><file name="Collection.php" hash="1ac2b4c1de5e1903c26f4e3785e4e937"/></dir><file name="Group.php" hash="42e813bcbaf698881e1bf5a27c59f39e"/></dir><file name="Store.php" hash="fa3bf05b568294e02a6fe4c1c27cb9f8"/><file name="Transaction.php" hash="08fa1309658be97145d36d6f246d3775"/><dir name="Translate"><file name="String.php" hash="a2cb79ab5c6bc58a1d9f06b173c9b60c"/></dir><file name="Translate.php" hash="9a1a8fed6527f816b1b5eace64212c81"/><dir name="Type"><file name="Abstract.php" hash="5223eadca84d77cb2596c2776cb6d65b"/><dir name="Db"><dir name="Mysqli"><file name="Setup.php" hash="3fea549d4e4f8b68f0e576f6a12d17ce"/></dir><file name="Mysqli.php" hash="96292453517efdd07547eb8407d5f1dc"/><dir name="Pdo"><file name="Mysql.php" hash="c0ac5cf999e1d553f90c37e00e36e3de"/></dir></dir><file name="Db.php" hash="25034f3d1ae6ad136e39fae5d01ce0a4"/></dir><dir name="Url"><dir name="Rewrite"><file name="Collection.php" hash="f8da7eb03c8fb8f83283e6314cd3c1c8"/></dir><file name="Rewrite.php" hash="fe8475fd925996ae8ab39258c85a53de"/></dir><dir name="Variable"><file name="Collection.php" hash="401b5e614ae732c5678a04a2b98879c9"/></dir><file name="Variable.php" hash="f84b3387796b375a8bf33c136d381dde"/><dir name="Website"><file name="Collection.php" hash="4ced4ca90dea76629bbc53f216421181"/></dir><file name="Website.php" hash="3521e6bba1c4688bc47d53f794cbebdb"/></dir><file name="Resource.php" hash="e7e6cf7f40b1a7c38a30e4cc0744b249"/><dir name="Session"><dir name="Abstract"><file name="Varien.php" hash="569c98dddeae79ca1cf6af5ae6de8a39"/><file name="Zend.php" hash="cfe635669d5b999b71fc6a2c0430158c"/></dir><file name="Abstract.php" hash="979ddef17c114d7f3f9b4ab43764381a"/><file name="Exception.php" hash="985b0f518cdeaa693ed2487bf0f6bc71"/></dir><file name="Session.php" hash="5290571c529b366f4932afdecc6aee34"/><dir name="Source"><dir name="Email"><file name="Variables.php" hash="9acd0ca901919230f0b04c6d37da62ee"/></dir></dir><dir name="Store"><dir name="Api"><file name="V2.php" hash="44da778a107458327526e71820b7b1ff"/></dir><file name="Api.php" hash="7fd2194a6736267ddf6990d01277433f"/><file name="Exception.php" hash="563bbd8d7ac0a433a77a456763c4c3e0"/><file name="Group.php" hash="1902252843de7b5774a4e81326e2fdad"/><file name="Observer.php" hash="63819493bcf83ad8e8ca370ca7f6aced"/></dir><file name="Store.php" hash="34c99c0b6717f26712d299e1a869a752"/><file name="Template.php" hash="fccd27ce17f7aa0afbcd52403221b342"/><dir name="Translate"><file name="Expr.php" hash="e9d7462a5fb8e7a393d5f54797d49235"/><file name="Inline.php" hash="e93b3c785268564f9c4c8407b20a3a10"/><file name="String.php" hash="0adb95a97362072d6e8ea38583887b59"/></dir><file name="Translate.php" hash="bc3e61e7886c80e4a27657083b7d73b3"/><dir name="Url"><dir name="Rewrite"><file name="Interface.php" hash="2e681780b29fb80c8240c56c87f3d067"/><file name="Request.php" hash="5df0865b6561e78521ed01ac6b7d57c6"/></dir><file name="Rewrite.php" hash="a3390b9c5c1475415d8c5a274eba51ac"/><file name="Validator.php" hash="e3f18c399f4cc29dc71ec4b6bf79490f"/></dir><file name="Url.php" hash="12dfc1a9d4e7ed0958fd543a10d0295a"/><dir name="Variable"><file name="Config.php" hash="294323396e9d0cadc983c976033b2735"/><file name="Observer.php" hash="f202b59b429f4f2d02cb650f130e4258"/></dir><file name="Variable.php" hash="0e14c7251900724becb45597711ca75b"/><file name="Website.php" hash="4a6f6a97f9522c03590bb28e140f9885"/></dir><dir name="controllers"><file name="AjaxController.php" hash="a08f8290380cf11cf83500ca24bae20c"/><file name="IndexController.php" hash="f9ef6110cbc8a9666098fbef0e8e754b"/></dir><dir name="etc"><file name="api.xml" hash="86293f2f531b7a6ddf9bacc685c4fc5e"/><file name="config.xml" hash="db29a25854bf300dec47d9cccad00ab8"/><file name="jstranslator.xml" hash="b200108bfac41b69ee844c2bee267ec8"/><file name="system.xml" hash="99fadc897cd072625871d0a04231eada"/><file name="wsdl.xml" hash="79501d6ccf39846b5dd551e85880dcb8"/><file name="wsi.xml" hash="31fa195d527181c946019bcd44d819d6"/></dir><file name="functions.php" hash="be323071dc9038ba621e2a03a05e2d08"/><dir name="sql"><dir name="core_setup"><file name="install-1.6.0.0.php" hash="99c037a0a1ac60718cd61bb66f2ce9b9"/><file name="mysql4-data-upgrade-1.6.0.2-1.6.0.3.php" hash="ab507b796172a81e53f7dea055f5747f"/><file name="mysql4-install-0.7.0.php" hash="5c744d9ec05924ba2a05443fc797c614"/><file name="mysql4-install-0.8.0.php" hash="d7eb01be2a8ae5c212a48e000cd0f2b3"/><file name="mysql4-upgrade-0.6.26-0.7.0.php" hash="4f20726fa1cf4822a6a8915dd427af4b"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="a21956c396c1b967ede3ad976cfdf448"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="64a85f90819585aaaf7c5cbdf5ac9cf5"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="476423c81b0e11428d206f5a736bce3d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="337139e7657a6d1e7ef9fccddc23553d"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="57780327ffe3eba191534854bad676de"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b0f5f9f49140980d21565993f622ae81"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d4614e187cc7a85654ced0176b5688f3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="fe2ea548791820ac5c1801695b0f75ef"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="f42d281fce5121d5f411e6611c71e38c"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="0cfe8f124a171dd82663efad6127e14c"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="299207679a44c8d5ea8ac5754f8de98b"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="6fcd0f93e0d91905c073605aba88940b"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="4dbb9443f34a75b9f421b7b818446043"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="0de67179defca183bfb0b1c611a39887"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="a98d5c510f9e19ee903e957bf7eb3202"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="48eb471e3d57c8bd4c8e7f4c38d49d57"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="0d8dbd126c7140043695ceb63037324e"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="600c23395322527f7a0b9bf6955d72c1"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="f6830aa69a99fb2bf5c3e92f4cffcdf9"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="0fe329675e0340210bfe2a6fb4066377"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="1742e2c0c393bdb449636e2fbb35dcd2"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="ba27150f507d3def66478fb1be8a6f80"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="d43d803598bc07a5cc3622d7c4046efc"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="8050654374a57af43bd12d16fd5c8146"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="9fe12edd3f5a54bce363fb5c7c3a23a8"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="cb8112cd37d71d62e673e816623d1a9a"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="a57334d7c2206e31b7db077748949d43"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="69372713f802f2aa756d6c4e3b25706e"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="e82b56e0531638a1ccce30bc12cf6aa5"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="e8497ce884a5a14dacb68d6988e6db61"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="a825fb80da1068e176efc6559f8e3183"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="37d085e478c96b39c697b3b40506ae87"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="5cfd483b04eaccba4a2d509432c190bb"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="c9e92c9d8305a03222ab7562ea8ce2f9"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="38c349fc77a280f0d3ffedad22cc6d47"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="0ba1f78f11cf2d2cd2739cdd580def92"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7893e14572c2a1c90ef2a32b983b76bc"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="3688343c162f029654b67cfbc2387024"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="7cf54034cb33d05f707cd9db126a300b"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="de7f2c22f6094821ddcde05aee42933d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="015a4339c6e0d045fc73ed7864246a45"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="af573097ec2ebe58f82d4f4333bbc91a"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="d1a38f6c8e9d71dd44842a77cfdc378f"/></dir></dir></dir><dir name="Cron"><file name="Exception.php" hash="cf1dfad3794259101456ab530c5db5a4"/><dir name="Helper"><file name="Data.php" hash="27e5fd603d4ca44ff134f01c2204cd38"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Schedule"><file name="Collection.php" hash="82f4b5c141920cae628956674651e686"/></dir><file name="Schedule.php" hash="68a1f1d41f2881f5710794b74bc5fa4f"/></dir><file name="Observer.php" hash="ba0660d83c9189ba3f86b79d58a37b73"/><dir name="Resource"><dir name="Schedule"><file name="Collection.php" hash="1c4d160bf611d9e5d2ae329e718a5016"/></dir><file name="Schedule.php" hash="70b7a234326eb5f4a437d9c83c941a35"/></dir><file name="Schedule.php" hash="5af32d2624ad82e95d7ba0aaaeb69404"/></dir><dir name="etc"><file name="config.xml" hash="7f3d40612a48d9d5ff88aaa180db864d"/><file name="system.xml" hash="cf72373326f9de8c29898d577dec01ba"/></dir><dir name="sql"><dir name="cron_setup"><file name="install-1.6.0.0.php" hash="e880af79df0e64a24f25b9b6ca5a0a06"/><file name="mysql4-install-0.7.0.php" hash="f2fef9a649061718fced001da2d17ff6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="237886cabfccaf58b4baf26dc7d8173d"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="6dd37c019fd015568fb404635e8fa3de"/></dir></dir></dir><dir name="CurrencySymbol"><dir name="Block"><dir name="Adminhtml"><dir name="System"><file name="Currencysymbol.php" hash="180872bd15491de4d7243f518637cc27"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="2268459f3c43056d7fd35adb8dfb2497"/></dir><dir name="Model"><file name="Observer.php" hash="844f97fd2d98a7a93c235421c7286567"/><dir name="System"><file name="Currencysymbol.php" hash="6d57b47c450552d61d4d694e83640599"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="System"><file name="CurrencysymbolController.php" hash="0e2e34ce111da77949ddb67b21fb433a"/></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="e3b17991058dae47d0e9ff06418c3c01"/><file name="config.xml" hash="ea98c18686306119b6b936c5bb0d4b99"/></dir></dir><dir name="Customer"><dir name="Block"><dir name="Account"><file name="Changeforgotten.php" hash="8b663124bc516f05a5b6319db495e29e"/><dir name="Dashboard"><file name="Address.php" hash="aac0afce3651c4d72c76e28c43892ee7"/><file name="Block.php" hash="c956121184fb8d2f1ca3214293a86832"/><file name="Hello.php" hash="7fb0384b0f53cfe0eab7477130c036a6"/><file name="Info.php" hash="777950ea83313c7ccb2df5a632d95d79"/><file name="Newsletter.php" hash="fec02bad0bdb8016810da2f75d7af4e8"/><file name="Sidebar.php" hash="612e6c9109efddfcf09efab2bf19ad87"/></dir><file name="Dashboard.php" hash="669ca917a411643f2df70dedf77c7a03"/><file name="Forgotpassword.php" hash="4d4bb6faed3d7be132c6de8ba097d79c"/><file name="Navigation.php" hash="7814958a2f1504e592f60b94286fca91"/><file name="Resetpassword.php" hash="09f6699b3e8a5cfd801d9fce6be6caa4"/></dir><file name="Account.php" hash="43490efe5663f8252b0890dd67153725"/><dir name="Address"><file name="Book.php" hash="8dd1a6365d2cee386fa50f2bd9b67f95"/><file name="Edit.php" hash="93184bd1536389b9027bdc3b85738d87"/><dir name="Renderer"><file name="Default.php" hash="ffee9ef9dcf06f89ff6fa37881a09f5e"/><file name="Interface.php" hash="c3d67cdcde0d581ec8a884ae41320b9c"/></dir></dir><dir name="Form"><file name="Edit.php" hash="9681856afa02438569c99c4a39c71efe"/><file name="Login.php" hash="2f136fe58a89cddfdcae1c8a20374eb8"/><file name="Register.php" hash="dc2c0b46dba1b9d697e86f920f4b2b03"/></dir><file name="Newsletter.php" hash="4bbfc9637bcfd47df22a24d0ac332198"/><dir name="Widget"><file name="Abstract.php" hash="82d02521c1c154986f99a7cd5cc595bb"/><file name="Dob.php" hash="08eff27d1c12a2bdea2f02bb1beb9956"/><file name="Gender.php" hash="69ba0733ec5825d9c84aa2bd36518242"/><file name="Name.php" hash="2fe99449c98c4831c81499a996955bdc"/><file name="Taxvat.php" hash="f6a34e678cce8e9db4337a171e1eb5c1"/></dir></dir><file name="Exception.php" hash="84ed4a7311c3b067f5a9a2b4ebaf2701"/><dir name="Helper"><file name="Address.php" hash="b7d0e116bd13ee4040e4a3e7d7e10f54"/><file name="Data.php" hash="8b5c4cbf10617330771fb0179c3328a6"/></dir><dir name="Model"><dir name="Address"><file name="Abstract.php" hash="fa80923d3d564b19d139c8217d52c4db"/><dir name="Api"><file name="V2.php" hash="5264e405138723779708a01e0ad3a953"/></dir><file name="Api.php" hash="c625c51f21aebed93b312016d255a325"/><file name="Config.php" hash="81e4c387f3c84c6bbd6eeb85c6bb6415"/></dir><file name="Address.php" hash="4e2bdc078893483df4368f90ad9069ce"/><dir name="Api"><file name="Resource.php" hash="88a0a4742fcb4b506e0fe0bad02fbf42"/></dir><dir name="Api2"><dir name="Customer"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="6f3addc32e6948ff8b1427d8a5edfc6c"/></dir><dir name="Customer"><file name="V1.php" hash="ee1fa714d1b0d4c0089cdc8b78536901"/></dir></dir><file name="Rest.php" hash="dd7c4ad62e07cc33093b1825c91dc32f"/><file name="Validator.php" hash="68549f28fa41a68a9212ddb19c1e11cd"/></dir><file name="Address.php" hash="7763734d86e3092e92066cdecde510a3"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="df8b83b4419c9d7b00176578de386f3b"/></dir><dir name="Customer"><file name="V1.php" hash="15773c1ca13ed447f1734e30151d0aa7"/></dir></dir><file name="Rest.php" hash="13687d1d31f233b15bdd487a13e1c766"/></dir><file name="Customer.php" hash="075e0124ec757065f5343d92b66c74db"/></dir><dir name="Attribute"><dir name="Backend"><dir name="Data"><file name="Boolean.php" hash="432dd89c3a7c292b09f374d233ee88e8"/></dir></dir><dir name="Data"><file name="Abstract.php" hash="ce5306f1e0a22d3dcd993e5220fbb7ac"/><file name="Boolean.php" hash="f757034441c95c0c30917147e3899d7a"/><file name="Date.php" hash="c977b4c1e25a829d9dd2b56afb7e1ead"/><file name="File.php" hash="cff1562f1f09a1f77f446c15e9441405"/><file name="Hidden.php" hash="3d2815af68515718683db2cb2e2973ba"/><file name="Image.php" hash="65edcc06c39664fb4d244bd484543083"/><file name="Multiline.php" hash="6b16093b04c6724d52d294d8a7fda5a2"/><file name="Multiselect.php" hash="219e0b4179d1ff3fec774a53f8f9af34"/><file name="Postcode.php" hash="ba6c2c9e682d8720d7cfe3ec50177a42"/><file name="Select.php" hash="5e80c9f0c60d9173634b5fa0f287e328"/><file name="Text.php" hash="19c74a8d13af4e7a4862c4b89f954e27"/><file name="Textarea.php" hash="d4b77360bae2a6a748cf27367ea83d24"/></dir><file name="Data.php" hash="b02ad271accfaee388a7ad3bb222f09f"/></dir><file name="Attribute.php" hash="83f08943bca6efc1081de3af6d51d73d"/><dir name="Config"><file name="Share.php" hash="611a68be66eb8da9af205150c54e9fea"/></dir><dir name="Convert"><dir name="Adapter"><file name="Customer.php" hash="e803d6cb098208d70b601fc5593cde91"/></dir><dir name="Parser"><file name="Customer.php" hash="9d4b84d66f8d8b81ed939118a33be002"/></dir></dir><dir name="Customer"><dir name="Api"><file name="V2.php" hash="b9bef0e5e64fa1bd9e390c99f3942281"/></dir><file name="Api.php" hash="167a33181ce2964937d5e7e73b9894d8"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="89c52c1b2f0bd8484df39ea7acb46b7b"/><file name="Password.php" hash="d3986a064f7d4cfefe4ff68332698665"/><file name="Shipping.php" hash="06ab66f794689e099ee95692283c12ce"/><file name="Store.php" hash="b0ef14e8531d2257a2b9de8fd180898d"/><file name="Website.php" hash="901f05d219245cb98170965bf8b014d7"/></dir><dir name="Source"><file name="Group.php" hash="0553e3010d7141c267a8749dcf4c1b39"/><file name="Store.php" hash="aec62dac295af5b5dd732c6ac1959764"/><file name="Website.php" hash="808118f1f0e66be0957876dbe8e9e57c"/></dir></dir></dir><file name="Customer.php" hash="9abb92d3d08028b277fda5db64f6bbbc"/><dir name="Entity"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="3662b45a02a564d622f1b570ab7aa2e9"/><file name="Street.php" hash="3d8358dbf971673582d68d977b2772af"/></dir><file name="Collection.php" hash="9b4b6effc2a69a7997605e3bd1bd9870"/><dir name="Source"><file name="Country.php" hash="681cded02921d688127cd30abab8efe3"/><file name="Region.php" hash="d6f544d7b9377c54b3e4f7546a3b2b38"/></dir></dir><file name="Collection.php" hash="bd986a57656ef8a1a39d9c66b927e451"/></dir><file name="Address.php" hash="8617ad0449bf5fa8eb64c37a08f6834a"/><dir name="Attribute"><file name="Collection.php" hash="b0d588d2382b7790638831b94ed26bfc"/></dir><file name="Attribute.php" hash="70d04a5d91848027fc7524f8abdc23de"/><dir name="Customer"><file name="Collection.php" hash="aa16d5336085baa3ba3eb2c1d312b7df"/></dir><file name="Customer.php" hash="f5d7eb3738e07eb83a334b2d4a4301c0"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="a7d64fa72682061c7e53586e866c7d9c"/></dir><file name="Attribute.php" hash="b02dec4db5d7fdc34d380f46793e47c6"/></dir><dir name="Group"><file name="Collection.php" hash="09b632cea0cf63a7340d570d7fc870a3"/></dir><file name="Group.php" hash="5546c3f3f4e4e576c99704a159181eb5"/><file name="Setup.php" hash="26ee35b14c5bc8cbd73cce9162aba1f4"/><dir name="Wishlist"><file name="Collection.php" hash="72b17e5c6b622a67428b49159d192676"/></dir></dir><file name="Flowpassword.php" hash="b37572d121efa8f7f5a6145220099c16"/><file name="Form.php" hash="5d6109e111b3246bdfa4fbae2eee62a3"/><dir name="Group"><dir name="Api"><file name="V2.php" hash="e41ba19167609e178625c837ffadcc0d"/></dir><file name="Api.php" hash="910ce41663a3aa1eb1bc5dec47f75c36"/></dir><file name="Group.php" hash="3434803d8e2a377e825534383e8827c7"/><file name="Observer.php" hash="8f3ad14644722c03bd6bfadd85f1a936"/><dir name="Resource"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Region.php" hash="2480c7ff5479486acdc71d5c4041e5fb"/><file name="Street.php" hash="5df083ea021e34bfabaf561726310e56"/></dir><file name="Collection.php" hash="3407e94f14ea73174dee4ee51b1759fe"/><dir name="Source"><file name="Country.php" hash="8c31116b4df92372cb202bf015dcf110"/><file name="Region.php" hash="c8816ccc18de38c74aac9a0ee0fc736f"/></dir></dir><file name="Collection.php" hash="382ffc3ece33f6d97cbab480e876e4ad"/></dir><file name="Address.php" hash="47ea3ba9064ab22f183e7fa309ebac6b"/><dir name="Attribute"><file name="Collection.php" hash="dc11746c5e719d05443ab6abfc158f62"/></dir><file name="Attribute.php" hash="a6e8657bccc9b73bac42927538cd4cb7"/><dir name="Customer"><file name="Collection.php" hash="88d5a0089a3fa9f9d6f10ff7aa45e18a"/></dir><file name="Customer.php" hash="cc0f7b29dc56a062795a42cc0085e5e4"/><dir name="Flowpassword"><file name="Collection.php" hash="ef19c2c10862f6e5362184291436e5af"/></dir><file name="Flowpassword.php" hash="968e8244a0c27d8c67a2569f655ecb0d"/><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="9315c60166317f2ef4c5a8105d5741c5"/></dir><file name="Attribute.php" hash="160eef2ee2908ef291e4ebe34f1f15cc"/></dir><dir name="Group"><file name="Collection.php" hash="9db3838edca76b5984f6b8ee7a32c66c"/></dir><file name="Group.php" hash="d7eae76b439b0dfa8c07557f3cba28d9"/><file name="Setup.php" hash="a271ee2dfeea1fdd49d24faacfc6cbe4"/><dir name="Wishlist"><file name="Collection.php" hash="63dfa1eef06f3064f6f8321ddf4a8654"/></dir></dir><file name="Session.php" hash="19447307e588272469dff208c75ad4ab"/></dir><dir name="controllers"><file name="AccountController.php" hash="efc462f991abe87c53cbcb265def3a42"/><file name="AddressController.php" hash="f9b92db500258202d88fe74b567e43cc"/><file name="ReviewController.php" hash="b4220956b1abdb7d143ce458d1b72fe5"/></dir><dir name="data"><dir name="customer_setup"><file name="data-upgrade-1.6.2.0.2-1.6.2.0.3.php" hash="af7950ce248f9a9017052f7e1de00ac5"/><file name="data-upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="28ead7be0a5853812b0d0c5e57968990"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="692e9ed764e5480a906b6c5819113acb"/><file name="api.xml" hash="e7cf0b9531cdef20c4898881e22d9988"/><file name="api2.xml" hash="6156af439bc63e66ca40cf2a26080640"/><file name="config.xml" hash="2b831a3d541c36c78dabf3cfaafd2aef"/><file name="system.xml" hash="0f3ff65c4195a6bcfa2720f6d15f0faf"/><file name="wsdl.xml" hash="b31ebf1de4a58469781b383f455991f5"/><file name="wsi.xml" hash="4c81aee30c525677be5c38e078b98408"/></dir><dir name="sql"><dir name="customer_setup"><file name="install-1.6.0.0.php" hash="8b5aa8cc89e2641c6853319b9546675e"/><file name="mysql4-data-upgrade-1.4.0.0.11-1.4.0.0.12.php" hash="4872ec3fc02eb5eb00f103700aa77041"/><file name="mysql4-data-upgrade-1.4.0.0.13-1.4.0.0.14.php" hash="28a7c7051a1bcd86dc8309b852ea8c29"/><file name="mysql4-data-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="5ffb0490d8258a783e7ac941286d048b"/><file name="mysql4-data-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="f8c846cdbe95a76586d1ce92064015dc"/><file name="mysql4-install-0.7.0.php" hash="cd96a8f93ad9e49f55db79733320975d"/><file name="mysql4-install-0.8.0.php" hash="aa7e8a1483150b61f53a5d7c1578d6c2"/><file name="mysql4-install-1.4.0.0.0.php" hash="6a6c0b7b9460e1fb4c536a2aa0b2f5e5"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="3e2055145079f629026415a460010553"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f2cbbb1b7ec6902b75a9955e6abb0610"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="b85fc366d0e7d0e087ddaf00f0705ff3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="35525103f1307dac9df768192fd2e9d9"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="37a2056b43079d14d0128e60566f8c52"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="3285eea05014e0c9b320e70e23de2ea9"/><file name="mysql4-upgrade-0.8.12-1.4.0.0.0.php" hash="d6feb52da70cb181bdddc8f33e1a16d1"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="4c7cf47f2f0324e2fa56ea6074e7eebf"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="46cf00d3651186a07a4129c23670c581"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="80d616f36e92d58504a08574115177a9"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="64fd262a2923be67f079266d36168a69"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="b52810769b33bdd85dd2efe64e4b3e56"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="4f5c33afe8389600c49ac4830de89ddb"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="62243eccbc11be32cf0c6627404bf5c5"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="0cdad1e573d83ddfa65de2e8bb1ca548"/><file name="mysql4-upgrade-1.4.0.0.10-1.4.0.0.11.php" hash="7950a9f2a7dacf4e4c485f403ef1f43f"/><file name="mysql4-upgrade-1.4.0.0.12-1.4.0.0.13.php" hash="8fbc3cf7e2c7c9f0479c7a9733174f68"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="1fbc98105825cd6e2a74ad876693abde"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="3f4745fc93d60c54d0786994fed3c4d9"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="2aba57c96240a0d360c1592e0e1aef74"/><file name="mysql4-upgrade-1.4.0.0.6-1.4.0.0.7.php" hash="aedd52a3f2cc4cfe9425cc4603a712ca"/><file name="mysql4-upgrade-1.4.0.0.7-1.4.0.0.8.php" hash="a049b659f24e9ffee7a567dc02a49e64"/><file name="mysql4-upgrade-1.4.0.0.8-1.4.0.0.9.php" hash="8ffd9139acb5c755e97d3d6541ad6700"/><file name="mysql4-upgrade-1.4.0.0.9-1.4.0.0.10.php" hash="be0bbb074cd8e0a3a32f984ec7bd0a40"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f176af847c112f0928b51cc3083729c8"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="fdd18814b345085bf323079bb855573a"/><file name="upgrade-1.6.1.0-1.6.2.0.php" hash="84a048767e0b1123ce58fa66c9323963"/><file name="upgrade-1.6.2.0-1.6.2.0.1.php" hash="dd06b50b358acf47a2dc7b8cbf14637f"/><file name="upgrade-1.6.2.0.1-1.6.2.0.2.php" hash="d2ce3d712996dbe1f3ba7c282060d44c"/><file name="upgrade-1.6.2.0.3-1.6.2.0.4.php" hash="6bb3b5b87199ed5d39609dddd5ba9bfa"/><file name="upgrade-1.6.2.0.4-1.6.2.0.5.php" hash="26b3352e206d19a1d317014b66a966a6"/><file name="upgrade-1.6.2.0.5-1.6.2.0.6.php" hash="18abac53655791f7eb8bb296463998c7"/><file name="upgrade-1.6.2.0.6-1.6.2.0.7.php" hash="97804c97f4ab9d2ae87c39f85c16aa0f"/></dir></dir></dir><dir name="Dataflow"><dir name="Helper"><file name="Data.php" hash="e08ebbc2fd4e1d69f37837bd6879e617"/></dir><dir name="Model"><dir name="Batch"><file name="Abstract.php" hash="7fdc20cf4337b2e8e6ec98996355851e"/><file name="Export.php" hash="44de5ec437a2e8f8962a30f6a0aa7fbf"/><file name="Import.php" hash="438a63fba93182fbb849695e7f14ec9c"/><file name="Io.php" hash="b5faecc9e049d11969ef6888e847301b"/></dir><file name="Batch.php" hash="14e83b5b30bede8dae90cfb6444bd09e"/><dir name="Convert"><dir name="Action"><file name="Abstract.php" hash="9a037b33e482074fa3d913e478597727"/><file name="Interface.php" hash="5451a3ae2d36340211f5db410cfbd618"/></dir><file name="Action.php" hash="133f901570f109f9af35ab17a7a7bf2c"/><dir name="Adapter"><file name="Abstract.php" hash="51fd62ea51d6e990429d3fdc6e870c6f"/><dir name="Db"><file name="Table.php" hash="a4f0bed5a537c6dd4f04a1875a3e5f29"/></dir><dir name="Http"><file name="Curl.php" hash="c62a57836e8e36d04621c2ec4f41adbc"/></dir><file name="Http.php" hash="6fed3d72666b24902601a4ce5b2478cb"/><file name="Interface.php" hash="d2f28a724dd13c880372397ead2416f7"/><file name="Io.php" hash="62e2beb0db33f5845d6221428d144325"/><file name="Soap.php" hash="1cb9b54a4968108f511e86da5c30b5b7"/><file name="Std.php" hash="5c9c797d238d5731484fed2669c4320f"/><dir name="Zend"><file name="Cache.php" hash="cb121f8c7129317b181b80dda9946fc9"/><file name="Db.php" hash="457dd7726d2a30ec193ed8f4e7116031"/></dir></dir><dir name="Container"><file name="Abstract.php" hash="03d6e312e776303d9cf1dc8de1c77478"/><file name="Collection.php" hash="52edd435007eab55dd6c44b61cdd9841"/><file name="Generic.php" hash="2dcbb8dac8a4d8d68157d8c742f74b2f"/><file name="Interface.php" hash="99565c4df1b032f1276db130f99cb723"/></dir><file name="Exception.php" hash="076118f579fded6e5ee39631c8a74505"/><dir name="Iterator"><dir name="File"><file name="Csv.php" hash="e8d574afc2c3bdf922eea8387ea68b06"/></dir><file name="Http.php" hash="80d1c7d31b2641cef4d9b81dca74b07b"/><file name="Interface.php" hash="8a2e0ea004e8ec1c10163f73f96374bf"/></dir><file name="Iterator.php" hash="54bdd6114b22be7319333103fa3e8c76"/><dir name="Mapper"><file name="Abstract.php" hash="93ae0b13a5352a620825298c5ed66c05"/><file name="Column.php" hash="f392976ef13863f5f32f04a09ab6aba5"/><file name="Interface.php" hash="0437e7aacc6b135b6ae383b463616287"/></dir><dir name="Parser"><file name="Abstract.php" hash="3236fe8798302c48929726e03e141ecb"/><file name="Csv.php" hash="949f7e32e0199ea94577f670e273f1df"/><file name="Interface.php" hash="dd7760a2cf2b5e49ef67990189647ab7"/><file name="Serialize.php" hash="ae87fb54224bfddafd7efd95c87d9066"/><dir name="Xml"><file name="Excel.php" hash="cc4a18db41565711ec48b471ac7c55d6"/></dir></dir><dir name="Profile"><file name="Abstract.php" hash="0ddcfa647231d5e2a0d9fdfcb54419e6"/><file name="Collection.php" hash="406521382cf7603b8054c6ef4131fb72"/><file name="Interface.php" hash="a0a9fba52399f7946b7743d8011c3ebf"/></dir><file name="Profile.php" hash="834a4d150f1597dbdc251db0ef543e14"/><dir name="Validator"><file name="Abstract.php" hash="e765aea7e8f5193277899c5418a7578c"/><file name="Column.php" hash="1a5b7cffadecce6e2c687ad6e1606e57"/><file name="Dryrun.php" hash="edb950b748d40593f34594db0911715b"/><file name="Interface.php" hash="86f42e70518c14452d499c1d73884a1c"/></dir></dir><file name="Convert.php" hash="e125ca51eb5ea388a4226984e077bb55"/><file name="Import.php" hash="8838b197445f884cd96d210057768a6c"/><dir name="Mysql4"><dir name="Batch"><file name="Abstract.php" hash="2b6f51758706c99b5f5694c4bf59400b"/><file name="Collection.php" hash="6d31df66ebb4c838e937ced0950add33"/><file name="Export.php" hash="14e075cd437463318c4918c87d51f142"/><file name="Import.php" hash="6d7a15cc0ee4750440e27169f1458165"/></dir><file name="Batch.php" hash="8c72af2813e71735947b59224512fd7a"/><file name="Catalogold.php" hash="24ed373e2153ac1553a8f5213d1cb3db"/><dir name="Import"><file name="Collection.php" hash="931767370c3cd538c2d61137ef81c270"/></dir><file name="Import.php" hash="b1845aa3d075528f559e4278c0545c90"/><dir name="Profile"><file name="Collection.php" hash="667d27ab098a1cc0d7b63add7f846bee"/><dir name="History"><file name="Collection.php" hash="561468d39bea85e329273488cfd2e25c"/></dir><file name="History.php" hash="a671fb7398cc9013b5679924a9576121"/></dir><file name="Profile.php" hash="423f9c09e862da840aff3c1045671760"/><file name="Session.php" hash="9f2de6e0336f990f406c314f848d80d1"/></dir><dir name="Profile"><file name="History.php" hash="952111190cf3cf31c4a293ff30a42a1a"/></dir><file name="Profile.php" hash="d6f8175d00db20f1d44690a467d56a18"/><dir name="Resource"><dir name="Batch"><file name="Abstract.php" hash="adf8bd1d47bfb44429d1f22557e09c4c"/><file name="Collection.php" hash="a107007ee0f2e1d33a075b2042cac37f"/><file name="Export.php" hash="6de19c09e9b2cdfb339477eab9536cc7"/><file name="Import.php" hash="8b2ecc68b077493284aa7ea723b1f202"/></dir><file name="Batch.php" hash="31fa2a981414ba9cbb1d36d9fce80ac8"/><dir name="Import"><file name="Collection.php" hash="bc29b52fd643bba0973be87265fd32ed"/></dir><file name="Import.php" hash="cd5b7cd2631393c4606fae225ba5fdef"/><dir name="Profile"><file name="Collection.php" hash="c4d4a9004563e08fd051316dad4695ce"/><dir name="History"><file name="Collection.php" hash="2f30f6a4d76e22bffa55cc493b01cd29"/></dir><file name="History.php" hash="b7aebcdd049fb2be0481f25a058e592c"/></dir><file name="Profile.php" hash="b12abc950a618c3239ffd0b087fafb89"/><file name="Session.php" hash="24cba703ea2a3899f1ceaec111445da2"/></dir><dir name="Session"><dir name="Adapter"><file name="Http.php" hash="c3992d945b4f9e2cf948827ef4b97675"/></dir><dir name="Parser"><file name="Csv.php" hash="165232a998562cb26a5a5664c0ca06ba"/></dir></dir><file name="Session.php" hash="8bae06d98900fb274e96676edc00df20"/></dir><dir name="data"><dir name="dataflow_setup"><file name="data-install-1.6.0.0.php" hash="e8a25ff1d524d64663da553ac0bbe530"/></dir></dir><dir name="etc"><file name="config.xml" hash="d8bf8f4863632692e44a1ee692bb7874"/></dir><dir name="sql"><dir name="dataflow_setup"><file name="install-1.6.0.0.php" hash="d97858ba4c95f9baca0091f37df58654"/><file name="mysql4-install-0.7.0.php" hash="e6a1202a88b8be57424e537535bd8546"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="b031906d286d82ec0d22c3c00438a387"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9e7d95b914f360a1a342f7364886ed61"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0399490704f187860be377f3eca679d4"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="84740102452a11d71c2e94790d8c94e1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="8041c24d939a69eccc8da15b2a27b175"/></dir></dir></dir><dir name="Directory"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Currency"><file name="Base.php" hash="dcb443aff27519bec9c0fb1eadebddb4"/></dir><dir name="Region"><file name="Updater.php" hash="84e993fa8725770c162375474f6162fc"/></dir></dir></dir><file name="Currency.php" hash="a209e62973d545d82a06c3d37c3b2494"/><file name="Data.php" hash="814cd0a83516e4040436918d176e6b73"/></dir><file name="Exception.php" hash="ffe766fa980bcff2159ee53263c01805"/><dir name="Helper"><file name="Data.php" hash="339c9514b741d43f50db4f7a3a18353e"/><file name="Url.php" hash="67ccb2a02f260665556beb8946de1be7"/></dir><dir name="Model"><dir name="Country"><dir name="Api"><file name="V2.php" hash="f1f135eb3faa33d17f66ec80daa125a8"/></dir><file name="Api.php" hash="3ee2f9ed300a8728203243e70b1bce82"/><file name="Format.php" hash="f2f2ad752bcba7dc3297bf101157e8e0"/></dir><file name="Country.php" hash="e0e56529d3f42681f39f2d550c12d71b"/><dir name="Currency"><file name="Filter.php" hash="f70bbe7b70f72e3eba142ef51a2f53e6"/><dir name="Import"><file name="Abstract.php" hash="9438914132e0315803cf7411034a9f57"/><file name="Webservicex.php" hash="2c0f90fa66b24589ee74f3c67649a40f"/></dir></dir><file name="Currency.php" hash="53fbd10d7e037604c4b68b0afca9eb3a"/><dir name="Mysql4"><dir name="Country"><file name="Collection.php" hash="0d944c0a19c1a348d3ff86809697a289"/><dir name="Format"><file name="Collection.php" hash="b82c10c3e3bf81b493ffbab4dca55013"/></dir><file name="Format.php" hash="30e47385420534e5fcf5c5494ed50e4f"/></dir><file name="Country.php" hash="1fd1f772fdb465235910ff7b4db1573c"/><dir name="Currency"><file name="Collection.php" hash="53291e3cf2239398b21fb65843b9e8c4"/></dir><file name="Currency.php" hash="7e14f08f128342f007f48546924a0bd5"/><dir name="Region"><file name="Collection.php" hash="471cfe58eefc3b8051b3cfd8a53cbb6d"/></dir><file name="Region.php" hash="4b79281b66b206439339f899e008800d"/></dir><file name="Observer.php" hash="b6b3d68e879e2c2f4c9d1d28453dc7e7"/><dir name="Region"><dir name="Api"><file name="V2.php" hash="a741b57fb273d9b2e8ce4c7ea72eacef"/></dir><file name="Api.php" hash="281487c558f2a3dddb36958063951cf8"/></dir><file name="Region.php" hash="0d87c99bd12fc091889fce254c77e04c"/><dir name="Resource"><dir name="Country"><file name="Collection.php" hash="972013305c612d9c523559de14fd93d1"/><dir name="Format"><file name="Collection.php" hash="901c10028b32a68a938458b299355945"/></dir><file name="Format.php" hash="f39efabaf3ebdb0c45870b2a8b58333a"/></dir><file name="Country.php" hash="c29b853734688ee76e3745b1883336e5"/><dir name="Currency"><file name="Collection.php" hash="b7a063492f8b0521a0bb6f00ad06464b"/></dir><file name="Currency.php" hash="717ac0dfd9e752ec0c3737fe24fbe239"/><dir name="Region"><file name="Collection.php" hash="f75aac9e2cffc3d608977516f85e5de5"/></dir><file name="Region.php" hash="aa6161845be2b0c5d01d95b97aa236df"/></dir></dir><dir name="controllers"><file name="CurrencyController.php" hash="598938459dedac62bfb4195a2242fd8f"/></dir><dir name="data"><dir name="directory_setup"><file name="data-install-1.6.0.0.php" hash="66a3d2eaa39070958ca9809798102c3d"/><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="354710cadd7abd6dc5a10a2f6842b190"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="3207bee7088f4c11f6c57f2f9bb173dd"/></dir></dir><dir name="etc"><file name="api.xml" hash="78c8bdd46e7a897a74f6455ee688f419"/><file name="config.xml" hash="0ee1b74bccf3c7bba0cfad8326c6193b"/><file name="system.xml" hash="e7ced71e07c4449402bbeded8860a5db"/><file name="wsdl.xml" hash="cc488b81c0eae648a0ee360d6e2d9960"/><file name="wsi.xml" hash="66de37cc17e24c0c66f74c52e2df616e"/></dir><dir name="sql"><dir name="directory_setup"><file name="install-1.6.0.0.php" hash="97df790b958ebbedcba5764fe4dd1011"/><file name="mysql4-install-0.7.0.php" hash="a87b5313783e11a0dd0f0cf8be739ea9"/><file name="mysql4-install-0.8.0.php" hash="ecec00ae456029ca8822f18a20e42e47"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6c70b08a6df461765456c2ac2f026fcf"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0c0e79dfc15370c558cbbabc0d1f8b9b"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="49fd5e3faf9bf452bfa8b7ebe100f346"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="a19b84e51cbc261efec34caaa6f2df7b"/><file name="mysql4-upgrade-0.8.10-0.8.11.php" hash="e328f0f70c75b98ae002d51b4ea991d9"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="2fc37e8f57d83e61a8e2c79a66c26e4f"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="60e3b937063bfb51a4372641c1e7c2b8"/><file name="mysql4-upgrade-0.8.4-0.8.5.php" hash="85297cb10426b170b0d19d2bac8fdc25"/><file name="mysql4-upgrade-0.8.5-0.8.6.php" hash="1dc8216499faf835c7ed62970336fa04"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="39387527f2128086ef2400517a125591"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="8d899b7db31e1e8503d1e3e4ef688a15"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="bd555e1bdf284e094aa80ddac5406049"/><file name="mysql4-upgrade-0.8.9-0.8.10.php" hash="2ab87429050aac0a4df755873cb9b189"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="83bfdf5ef0248ece192862d9c92ddabb"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="2c8baba0cbab3ead3938c8448adf9138"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="572730242d7420bd723f775e67ec9c3e"/></dir></dir></dir><dir name="Downloadable"><dir name="Block"><dir name="Adminhtml"><dir name="Catalog"><dir name="Product"><dir name="Composite"><dir name="Fieldset"><file name="Downloadable.php" hash="5544e55e911f0d9603563313d8a5ba88"/></dir></dir><dir name="Edit"><dir name="Tab"><dir name="Downloadable"><file name="Links.php" hash="5464679fcaef509dba28069874a27e77"/><file name="Samples.php" hash="436ec7541c855576c7db3af0742e6e51"/></dir><file name="Downloadable.php" hash="717fb4bed3c4d7469ee3789cc7ffbb40"/></dir></dir></dir></dir><dir name="Sales"><dir name="Items"><dir name="Column"><dir name="Downloadable"><file name="Name.php" hash="08465b9e4605219116e890219740bc9f"/></dir></dir></dir></dir></dir><dir name="Catalog"><dir name="Product"><file name="Links.php" hash="dc4eb48f451ba86bb70139315b481c05"/><file name="Samples.php" hash="6078e472cabebeb0cdc4a3a357034bf7"/><dir name="View"><file name="Type.php" hash="e68a8cf189a41520d5f0ad72dff79e9f"/></dir></dir></dir><dir name="Checkout"><dir name="Cart"><dir name="Item"><file name="Renderer.php" hash="5cc371580b1e272048c7a21340a3c708"/></dir></dir><file name="Success.php" hash="df0d8053cc9b3a78dcc97e8897d856ad"/></dir><dir name="Customer"><dir name="Products"><file name="List.php" hash="623c68e1145d21ec434ee61cbdc2a2eb"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Email"><dir name="Items"><file name="Downloadable.php" hash="e01c820dd9d434855510c3eb75e566c7"/><dir name="Order"><file name="Downloadable.php" hash="11f1993afc36f2382f9115178fc5d821"/></dir></dir></dir><dir name="Item"><dir name="Renderer"><file name="Downloadable.php" hash="d922d37364e371d75723b7a7ea2597ef"/></dir></dir></dir></dir></dir><dir name="Helper"><dir name="Catalog"><dir name="Product"><file name="Configuration.php" hash="cef93d38c9bf07a97c29b47db1cdbdca"/></dir></dir><file name="Data.php" hash="cce44b4432c3a168625e7e57932b18d9"/><file name="Download.php" hash="f9f893a3aae7ae404efb0c1543df2ff5"/><file name="File.php" hash="b288bd80241f90020a9fb606c572cd6a"/></dir><dir name="Model"><dir name="CatalogIndex"><dir name="Data"><file name="Downloadable.php" hash="106ce95f23424fec86b33737bc66ad6e"/></dir></dir><dir name="Link"><dir name="Api"><file name="Uploader.php" hash="6b4ff7b40832964c7beacea27513f349"/><file name="V2.php" hash="c4cc027f7ee0d8fcc4e850e55ff90652"/><file name="Validator.php" hash="64c1aa175dd35795f3d2e34efa349b29"/></dir><file name="Api.php" hash="c60626720f452220954577fec210e2a4"/><dir name="Purchased"><file name="Item.php" hash="1c448bd68d1307b8835a6033762d32a0"/></dir><file name="Purchased.php" hash="a7d59c19ef70336d8cc142bbbec8a9cb"/></dir><file name="Link.php" hash="0217b7584fef57c6954c16d6adcaa3b1"/><dir name="Mysql4"><dir name="Indexer"><file name="Price.php" hash="872bec0182625153cda0d1f1bf472c13"/></dir><dir name="Link"><file name="Collection.php" hash="77d4839d3861a3071e6d8396fdcd256d"/><dir name="Purchased"><file name="Collection.php" hash="c0d5586d288467fdaf479b7b0c911b7f"/><dir name="Item"><file name="Collection.php" hash="cf6773d1b912235af2ccdbab5dbb79c9"/></dir><file name="Item.php" hash="76cd2e07c02c2c2c964d7bddf4102aa6"/></dir><file name="Purchased.php" hash="1147feab13010c4719a84f1f767e822e"/></dir><file name="Link.php" hash="f11eaf4cd02f64961e5672751d4a166e"/><dir name="Sample"><file name="Collection.php" hash="fadf9932b2f36dd6813e7ab44b0ac474"/></dir><file name="Sample.php" hash="16e8fc69977438abcd8acdfed3dec4e8"/></dir><file name="Observer.php" hash="dbdb75ba95873d2af9f73636c140a2cb"/><dir name="Product"><file name="Price.php" hash="7ee60315804a76c4ac13a442fa75e546"/><file name="Type.php" hash="20db85d75642ce7fceb7f9354b6f139d"/></dir><dir name="Resource"><dir name="Indexer"><file name="Price.php" hash="ad05b2ed96af42e014e7e9056cd05215"/></dir><dir name="Link"><file name="Collection.php" hash="430a3e0f8cf92d1c2c2f1cf8ca3a22d8"/><dir name="Purchased"><file name="Collection.php" hash="ccdffcce054283303fa2b57f55bb2478"/><dir name="Item"><file name="Collection.php" hash="b72144d20dd7a94c491c484bca5993d2"/></dir><file name="Item.php" hash="1870b346f2c46e5501390aa6fcc6bd7e"/></dir><file name="Purchased.php" hash="e098613b94c59cd7ad0c86d305c4c6e3"/></dir><file name="Link.php" hash="c6f124b3611b837957d2a1b87e495308"/><dir name="Sample"><file name="Collection.php" hash="9e69c792b71ff1b74d4fd774e50ef8ff"/></dir><file name="Sample.php" hash="d40abfd991963a6dcf395d79a6994608"/></dir><dir name="Sales"><dir name="Order"><dir name="Pdf"><dir name="Items"><file name="Abstract.php" hash="d66eb5e3f7cacd8f8f5be7278a700047"/><file name="Creditmemo.php" hash="2c16eefe0e064ecdb82bbcf48ccd9f0f"/><file name="Invoice.php" hash="b49d92df09b7cd688c98368227124c30"/></dir></dir></dir></dir><file name="Sample.php" hash="c0ef89aebd738dd0fb5d0953cbf54aeb"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Contentdisposition.php" hash="17876b9510afa671206c4ba1fdc85ac7"/><file name="Orderitemstatus.php" hash="10912ec89ce9a860dc65577b0ba3afc7"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Downloadable"><file name="FileController.php" hash="a0eb299dc9ef7811ca4c495b29ddddb6"/><dir name="Product"><file name="EditController.php" hash="4ae0fec76ce03173441bfe71f08a0327"/></dir></dir></dir><file name="CustomerController.php" hash="c4fbec7c76733cda3b1b5916a6f73ebf"/><file name="DownloadController.php" hash="3a634e6488460025f202e3ceabfd81f2"/><file name="FileController.php" hash="870f184cd5cd1e2d7cad96b7d05e3bc2"/><dir name="Product"><file name="EditController.php" hash="30c279baf5ffe4a5902015780ad8630c"/></dir></dir><dir name="data"><dir name="downloadable_setup"><file name="data-install-1.6.0.0.php" hash="0856a374d51df586dc44049643d69c97"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="c3d749dddcef5a546dda075abce68322"/><file name="api.xml" hash="2a1e953ddd8fb42c48b0bd9199b16d5f"/><file name="config.xml" hash="f889323cbc6b12cd75f042a6da641de0"/><file name="system.xml" hash="1673c3db704574c12a117cbf51f1d235"/><file name="wsdl.xml" hash="b3935ff3bf7e2ca40ddd304b4c78577f"/><file name="wsi.xml" hash="7eef36b29c2abf88596e63b6a042626d"/></dir><dir name="sql"><dir name="downloadable_setup"><file name="install-1.6.0.0.php" hash="73025eb4881191a625ff8e4d1d4cad1f"/><file name="mysql4-install-0.1.0.php" hash="3f91840c8450bbecc18d9341d6f99e26"/><file name="mysql4-install-1.4.0.0.php" hash="7bcf4612674cdd43767c86d24fc9c91a"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="65cdda44f8abb16f5831193b0a894160"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="2e41ac0d97b013779f8aea4e9c660fee"/><file name="mysql4-upgrade-0.1.10-0.1.11.php" hash="d3fa7bb5ecfb83e0c1c492c895b963d4"/><file name="mysql4-upgrade-0.1.11-0.1.12.php" hash="108af92cb4d9c9e6bdf081789733c1d9"/><file name="mysql4-upgrade-0.1.12-0.1.13.php" hash="020a4ffe85262a22fda6a434a23c9d76"/><file name="mysql4-upgrade-0.1.13-0.1.14.php" hash="148e7cce3138f3880f2b3c66865f70a2"/><file name="mysql4-upgrade-0.1.14-0.1.15.php" hash="23f6349cd7cdb4851518b60c7e429056"/><file name="mysql4-upgrade-0.1.15-0.1.16.php" hash="e00c6062b8353456aa06352dcc1a5e8f"/><file name="mysql4-upgrade-0.1.2-0.1.3.php" hash="dc74191e6087ea0d6a00d6af0c9fc58b"/><file name="mysql4-upgrade-0.1.3-0.1.4.php" hash="540575730433e088edc3dc0cbbe6f943"/><file name="mysql4-upgrade-0.1.4-0.1.5.php" hash="4c2065c26097a369bc666e82dbaff7ae"/><file name="mysql4-upgrade-0.1.5-0.1.6.php" hash="bcdf26984f17320f3a1336b69f99fd94"/><file name="mysql4-upgrade-0.1.6-0.1.7.php" hash="9b026da94cd3b6b45ab968ef3214fd86"/><file name="mysql4-upgrade-0.1.7-0.1.8.php" hash="c440e7df19344e1d439538e5c55da8db"/><file name="mysql4-upgrade-0.1.8-0.1.9.php" hash="b13ea4ce5555f4e0665abe5742cdfe2c"/><file name="mysql4-upgrade-0.1.9-0.1.10.php" hash="fd75df74eca07dd8b6fc2cefe64f4257"/><file name="mysql4-upgrade-1.3.9-1.4.0.0.php" hash="1f9d156b0cbd54eb0eeb2eeae8d24150"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="07e2648baa8a10a806458e82ebbcd0d8"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="1bc757aced95279cd466f815c1285b48"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="4c9892da7cb86c07246592c6f47b8ca5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="27359d8b56d13b44bbeca5eeaa839c2c"/><file name="mysql4-upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="b0b63d81f9e951a28608a5cf35691a9d"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="5a18214628e2734e899e21632229d814"/><file name="upgrade-1.6.0.0.1-1.6.0.0.2.php" hash="3f5a16909ebda690210c9be08dbe1859"/><file name="upgrade-1.6.0.0.2-1.6.0.0.3.php" hash="e807d4c8365f32b0a4aab3d0552cc1a6"/></dir></dir></dir><dir name="Eav"><dir name="Block"><dir name="Adminhtml"><dir name="Attribute"><dir name="Edit"><file name="Js.php" hash="8002101c678b99ac6f8b59eb03d2382b"/><dir name="Main"><file name="Abstract.php" hash="a7a149707b945eca823a2ca098adb59f"/></dir><dir name="Options"><file name="Abstract.php" hash="e0b64d061e2fcd87526641c2ec6f6774"/></dir></dir><dir name="Grid"><file name="Abstract.php" hash="d5c599e249678648d293cb9ed83e2249"/></dir></dir></dir></dir><file name="Exception.php" hash="692892ea4ef5d5e1b6da23cbabe22d38"/><dir name="Helper"><file name="Data.php" hash="469b64a28f1b7ea088989d1d45803204"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><dir name="Inputtype"><file name="Validator.php" hash="47eac458550c8af64457669f0ac3d9f6"/></dir><file name="Inputtype.php" hash="b67a8dbd70de6eb89cdb1479f1387339"/></dir></dir></dir></dir><dir name="Attribute"><dir name="Data"><file name="Abstract.php" hash="18b807dbce7f4e21dfb7d226b481cf48"/><file name="Boolean.php" hash="448ffc80b75e90aec463ba51e050aa48"/><file name="Date.php" hash="7a2cc647db45fbcabc84d98c71ba1940"/><file name="Datetime.php" hash="b7e86e04808abb6740f77da62852d5c0"/><file name="File.php" hash="d4a0899d5d9b3b1daff4eb7e18b584fc"/><file name="Hidden.php" hash="5cabcb3cc942d369d485498abb15a27f"/><file name="Image.php" hash="23813e4f849dd850a42ffb317805ccb2"/><file name="Multiline.php" hash="9e2c79401a1ddf91f7635ca1e891b1d1"/><file name="Multiselect.php" hash="6d3a8e7d0bdadf02122a7c93b7bbff86"/><file name="Select.php" hash="1bb3420d77077d7f4fd1f5eb1b586695"/><file name="Text.php" hash="70ebf479764a19c96d0de26bc6b82485"/><file name="Textarea.php" hash="30f51d262e78a9fab2199555732e009f"/></dir><file name="Data.php" hash="7bdccd4e5d8ee6d29f5c7e4b99bbe561"/></dir><file name="Attribute.php" hash="7b68850f63e3de9fedfb181d44baabf7"/><file name="Config.php" hash="f57eadd2adb757beb19123576734e006"/><dir name="Convert"><dir name="Adapter"><file name="Entity.php" hash="7655752075b807bed3af49cc549faa50"/><file name="Grid.php" hash="ac7a302dc3a2b9c392a440a2db37dc34"/></dir><dir name="Parser"><file name="Abstract.php" hash="1057d89923122d529e273dffcf5f4a0f"/></dir></dir><dir name="Entity"><file name="Abstract.php" hash="8eee99942b9582fa010e040a875d7c1c"/><dir name="Attribute"><file name="Abstract.php" hash="4efa349be932010e7b6cb566de9114c2"/><dir name="Backend"><file name="Abstract.php" hash="9a640786c043cde90f01f6dbb1a35d96"/><file name="Array.php" hash="0a711643fa35be28798dc184c627e700"/><file name="Datetime.php" hash="dde5423ae42ddbf1935ba015f2e1002a"/><file name="Default.php" hash="0d67f3e45c2837cf97cab5ea4332e569"/><file name="Increment.php" hash="27e72f5a631fe9e8317b6e97173fbbad"/><file name="Interface.php" hash="70a21176e2194e7b2494f50954c4b178"/><file name="Serialized.php" hash="1d30c28c6ddb374758a9a189035c3ec2"/><file name="Store.php" hash="f1a93a8001c7b9a943fbe8bda205983f"/><dir name="Time"><file name="Created.php" hash="a7c20601a78ca7dbf51ad0a8847e972f"/><file name="Updated.php" hash="21a98e318fca4efc9d360a5e08990e57"/></dir></dir><file name="Exception.php" hash="794a727bc18b5bd60b349a2a858fef79"/><dir name="Frontend"><file name="Abstract.php" hash="2fad37d0d105191e3e764af900f793cd"/><file name="Datetime.php" hash="9c434461bc5f2b9800a072d040b29465"/><file name="Default.php" hash="991f8adc6ee272e59749753e021fcbfb"/><file name="Interface.php" hash="7f8db3081bac40a4411b219ed4c86b15"/></dir><file name="Group.php" hash="2da22de349ceb7b41b4df05e3e63bfb9"/><file name="Interface.php" hash="cf6e7cdd174f51cfc7f7e62d37aca049"/><file name="Option.php" hash="1a4439116682f14f492d0e155aa5adf5"/><file name="Set.php" hash="67c868057c968a2806890122a9d0bd84"/><dir name="Source"><file name="Abstract.php" hash="4f2f467815b3f475038d60bcbca97c6b"/><file name="Boolean.php" hash="60c477201e65a1dfd8bd6026c92e2905"/><file name="Config.php" hash="2e7a518ddb3c8e61489de5f11620c319"/><file name="Interface.php" hash="5895a4fb491b6d0190ecf2f179a34480"/><file name="Store.php" hash="c3d40f6aacc4977a98261d64f67d170e"/><file name="Table.php" hash="a13af459d41f4e38fca0494f5b0cdd36"/></dir></dir><file name="Attribute.php" hash="e41967fbcb581b0082d9f4ce4ac04f01"/><dir name="Collection"><file name="Abstract.php" hash="abe40e0d6c5f48e82410446329eab621"/></dir><file name="Collection.php" hash="dd3182d0409c9dfef8703a04d05ce6bf"/><dir name="Increment"><file name="Abstract.php" hash="88913be1b543278355276369c687cf2c"/><file name="Alphanum.php" hash="55dd05c0cd441d15e16d44e7824846cc"/><file name="Interface.php" hash="8a3cd897b1d0f8da29cf529362384570"/><file name="Numeric.php" hash="7aaac9e675d0e684fdfb0090a3f86251"/></dir><file name="Interface.php" hash="6492dcc4320e059b4dcfbbef7cd3660f"/><file name="Setup.php" hash="765e2c9b0391ced119e70b51041c6fdb"/><file name="Store.php" hash="9b190b04359b1055cc38f14ec34bf210"/><file name="Type.php" hash="48b9da0b09cea5525ae11e66eeeeecef"/></dir><file name="Entity.php" hash="a43519b11a54664e6f567d6c64cb7566"/><dir name="Form"><file name="Element.php" hash="958c9fe3092b2cb584fb6fd367f65e4d"/><file name="Fieldset.php" hash="9d541ea5e7fa884a5aef36b358f4584e"/><file name="Type.php" hash="297b10819a97e098e398dafce6bf9e2c"/></dir><file name="Form.php" hash="1f3db6caa1e69d6fa7d0270d125b7fa4"/><dir name="Mysql4"><file name="Config.php" hash="88ddce2de8762b473e5f11ee15863ea5"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="f4bad2b7c97aff236c4d59ab9d11d80b"/><dir name="Group"><file name="Collection.php" hash="e5e8ae843ffab0d11e7306ecb3f76d36"/></dir><file name="Group.php" hash="b034badccbbc0e7102f085ac7d788b40"/><dir name="Option"><file name="Collection.php" hash="17e9bb8286b55de90c59cfe7da7d5f7b"/></dir><file name="Option.php" hash="3a058b88276a2fdd8b34cc39c7b66993"/><dir name="Set"><file name="Collection.php" hash="5d5f48626da06576b673c039de164606"/></dir><file name="Set.php" hash="01e30e73fbae7885c6808ee532f15e12"/></dir><file name="Attribute.php" hash="0bc50d42a753a0d38b027ed6e8125cb9"/><file name="Store.php" hash="022bb925298448ce0515c8902c950ae2"/><dir name="Type"><file name="Collection.php" hash="bc9361e0e15cea6007ddd2ff3756e906"/></dir><file name="Type.php" hash="563ecb5bc3160660ee2cd981db54e83f"/></dir><dir name="Form"><dir name="Element"><file name="Collection.php" hash="b5c98a418630ef3df9ab3f94c7b675a0"/></dir><file name="Element.php" hash="c8ad10c8cc7a5871ee92b972111cbabc"/><dir name="Fieldset"><file name="Collection.php" hash="daa73b54fa5aeb8ab5a310f910e64d80"/></dir><file name="Fieldset.php" hash="bc071d0b1c94bdc5a1dcd0a8496f051c"/><dir name="Type"><file name="Collection.php" hash="0196365ca85575c2f188fcf564906647"/></dir><file name="Type.php" hash="8ae370004548e992999bf7d1c5b8bf72"/></dir></dir><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="884adb14175e8728ee1757184d595297"/></dir><file name="Attribute.php" hash="977d832c7bf13354773879120e02a47a"/><file name="Config.php" hash="0c92be60b44d8f3f3872598662b484f0"/><dir name="Entity"><dir name="Attribute"><file name="Collection.php" hash="c5dadd8439567c5ce0bdebfea23a3cb7"/><dir name="Group"><file name="Collection.php" hash="df9ab23eec5d042f5f44019dff458faa"/></dir><file name="Group.php" hash="3d732769aff3b8cc4af392346edb4f6d"/><dir name="Option"><file name="Collection.php" hash="fd5336332f8520dafc0213ef56d46f46"/></dir><file name="Option.php" hash="ef41db5b623b60125f36dd3166a73694"/><dir name="Set"><file name="Collection.php" hash="a218c8eaeb97080247c1f33f6763ce6d"/></dir><file name="Set.php" hash="ce0178c652fe12485b7e93ab22bacd5a"/></dir><file name="Attribute.php" hash="b35cfacaeda83f88f4ffabdcd637e9e3"/><file name="Store.php" hash="c922ae9b3f5ea5dc1cbabda637529252"/><dir name="Type"><file name="Collection.php" hash="f5ac2bd4f51c6a5caf49fb17526474d0"/></dir><file name="Type.php" hash="63c0bca51b1a0022c55fd4991f048981"/></dir><dir name="Form"><dir name="Attribute"><file name="Collection.php" hash="b0ce3e921c386fdc8127a7cf632fc9bf"/></dir><file name="Attribute.php" hash="b3aa3ef3de1bfc985d5b0dff837435c2"/><dir name="Element"><file name="Collection.php" hash="ed90d49ac06f3c6fbb8db1c5e93e70fc"/></dir><file name="Element.php" hash="cc8254b4f9231e1ef8bc62c7961c952f"/><dir name="Fieldset"><file name="Collection.php" hash="25e2bbc43a6a3f717687ab2f02ce3908"/></dir><file name="Fieldset.php" hash="d53c80a906104fe1c027e523230d8693"/><dir name="Type"><file name="Collection.php" hash="bb1bbec0dbabd0d2d1c384b7cd664e51"/></dir><file name="Type.php" hash="2ab9c6d0e36d4df5ad949b9a647b4e19"/></dir><dir name="Helper"><file name="Mysql4.php" hash="640baca7f4fed199db4f3be9229b997a"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="0ce463f61644eee879ef38dcff13de24"/></dir><dir name="sql"><dir name="eav_setup"><file name="install-1.6.0.0.php" hash="bbe35ca1128ad7dfcfce6b549a659920"/><file name="mysql4-install-0.7.0.php" hash="7f785666cb5dc104ba63eb2dbf2c57a2"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ec0c99ae4cbf859972139d00f6e728c1"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="9393b28c723fb6167bd688303cba8059"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="ad12f666f57394e5636bb0ba4379b445"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="89b66b6c969e6dc8bdc12956942c009b"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="f471ae0351ea4f1127b40a299e937881"/><file name="mysql4-upgrade-0.7.13-0.7.14.php" hash="dde737bbb90c59b57dd29cbfad286f32"/><file name="mysql4-upgrade-0.7.14-0.7.15.php" hash="4e210a99ea80498b338a7e533056e627"/><file name="mysql4-upgrade-0.7.15-0.7.16.php" hash="1aed43be7928f84ad7412e2df09eeae3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="a760b5658978091af5a9dfeb5388969b"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="565d7aa6ef731bad0e3c836a5e6a3a21"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d53449b41c1fe3670909ffdbb2d66d30"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="b0497e262a4bc2ceede93bd6ef5cabfb"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="d46637cee88d0cff61ab92a67485c141"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="b9cb4c015ee2e6f7aeb171c7326920cb"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="6784ed5afa90ba51e354e85c24cb4717"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="4929c7c613e6c07343551b83efe1cde5"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="d5402afc2fa0f998be3ac372ea6cfd05"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="cb254f182f6e7c6f47fb2c5508499111"/></dir></dir></dir><dir name="GiftMessage"><dir name="Block"><dir name="Adminhtml"><dir name="Product"><dir name="Helper"><dir name="Form"><file name="Config.php" hash="86d11101a35df5731e8a4dc3a8e3dcab"/></dir></dir></dir><dir name="Sales"><dir name="Order"><dir name="Create"><file name="Form.php" hash="548ab4b117fadee4331d5d00b0b231cf"/><file name="Giftoptions.php" hash="194289650bcccaf4483bfe3fb08ea933"/><file name="Items.php" hash="ef73476667ab8864ce6b65c5c0f3d1ae"/></dir><dir name="View"><file name="Form.php" hash="7b686e304e00f3da4a47c46362ccc5ad"/><file name="Giftoptions.php" hash="6c876c5fcbfc4e8204405b36c97865ec"/><file name="Items.php" hash="b7024780e706585ca268cd2522424946"/></dir></dir></dir></dir><dir name="Message"><file name="Form.php" hash="05dda3c7407fdf1bea7786218d99e529"/><file name="Helper.php" hash="5674ff6321c3b9502799786ad0bc45e9"/><file name="Inline.php" hash="3ea27c962a3bbb24da93694e7c3187af"/></dir></dir><dir name="Helper"><file name="Data.php" hash="bb0cda0f10afc6b6f736387f2a42db5c"/><file name="Message.php" hash="ad71d72f75008e1ae2b478a519cb57af"/><file name="Url.php" hash="e4e08bb1c1beda2657e17f4736b32579"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="f98276d7e1d2b4fe7d3cb742a18de8b2"/></dir><file name="Api.php" hash="26bb46739aee15f2398f2878c1150656"/><dir name="Entity"><dir name="Attribute"><dir name="Backend"><dir name="Boolean"><file name="Config.php" hash="f8f406d90bc9932c7b0e524c6403e465"/></dir></dir><dir name="Source"><dir name="Boolean"><file name="Config.php" hash="1e172c45ecdfe20d430f47e325470a8b"/></dir></dir></dir></dir><file name="Message.php" hash="5dfb4882a1a9b17ace6c4e17e5dae1ac"/><dir name="Mysql4"><dir name="Message"><file name="Collection.php" hash="1fd013a786ec1689feb96cf55fe8640c"/></dir><file name="Message.php" hash="4808d235da64c332355a757e6b2b1484"/><file name="Setup.php" hash="789d8e3ce35e92b8397a047c4dc10d90"/></dir><file name="Observer.php" hash="0e5d615565c62715ab68880aada4b619"/><dir name="Resource"><dir name="Message"><file name="Collection.php" hash="c973909813993d83be31e54742148e39"/></dir><file name="Message.php" hash="a78200d1df9b33523802f1dfd28285d8"/><file name="Setup.php" hash="165848ac03e71df30203c50a7bca0736"/></dir></dir><dir name="controllers"><file name="IndexController.php" hash="c4fdd6ed77fbd0ed2a72dc4d6be5508d"/></dir><dir name="etc"><file name="api.xml" hash="0cd624a5a4b2992eab91bab7db9c1a54"/><file name="config.xml" hash="934f6208ca8ebdb88531557d83c9fab6"/><file name="system.xml" hash="38ddfe6859cffc50f20bb4a0c5f0e808"/><file name="wsdl.xml" hash="b99aaaac0126c6e09a7ba59fa4dbcf30"/><file name="wsi.xml" hash="ab77c7cfecb0f5d6cb7b07c0b5abc1d1"/></dir><dir name="sql"><dir name="giftmessage_setup"><file name="install-1.6.0.0.php" hash="374dd23fc10fb776a6e7f846e5790330"/><file name="mysql4-install-0.7.0.php" hash="d63d56da8d880d297f1599a627e71fb3"/><file name="mysql4-upgrade-0.1.3-0.7.0.php" hash="05728dfb17eae1882e1a61ae3a571201"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5bfa3f68a0c188afcbec03f564f2c19c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="f3c3dcb39ffd2293e252c66677ece0a7"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="cb6e77e20e91cdd2497c91dc6f751c8a"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="ba851bc9df9c5a6a6430e1670116870c"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="d4b64697af7b1b59edeab9120245c546"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="616ecca5d7296f027061084f550936bf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ee1e9039080b7cf8fbbe72a5781b1257"/></dir></dir></dir><dir name="GoogleAnalytics"><dir name="Block"><file name="Ga.php" hash="d2e0e76bf461805d7efa3504ba40778b"/></dir><dir name="Helper"><file name="Data.php" hash="d1e53e2c360d075b464fd9de2c564821"/></dir><dir name="Model"><file name="Observer.php" hash="16fa8e062f7aa80cb58c229d4cc4c27d"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Type.php" hash="27d5bbdac178313b3305c6308cc85565"/></dir></dir></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="7609f9a30ebed87c2cc808090733f522"/><file name="config.xml" hash="09a0c00775ae054bc1f6c2d93c426b47"/><file name="system.xml" hash="850dae8ed5870d335ece5cb8fedc9844"/></dir><dir name="sql"><dir name="googleanalytics_setup"><file name="install-1.6.0.0.php" hash="e484246fe4b335068b52afebc226ae6f"/></dir></dir></dir><dir name="GoogleBase"><dir name="Block"><dir name="Adminhtml"><file name="Captcha.php" hash="8ffb81bcaac1a9364c7dff92029209a0"/><dir name="Items"><file name="Item.php" hash="daf200d9b85bcc045c94d3922c97b247"/><file name="Product.php" hash="7e331a3ca0ca01b963e24772a821daf9"/><dir name="Renderer"><file name="Id.php" hash="1b72b62226dab4a38740f1e76a58252c"/></dir></dir><file name="Items.php" hash="85998c466c9bea59a59fc7ab3b890e6d"/><dir name="Store"><file name="Switcher.php" hash="2286a7c57c5b3c6068a63588bc083e4a"/></dir><dir name="Types"><dir name="Edit"><file name="Attributes.php" hash="ac180cb7663f5cc2e32990f83dad0cbf"/><file name="Form.php" hash="ad97b610567b0d3443f8cae9107ca766"/></dir><file name="Edit.php" hash="498601bd79e9965875f081a4d728750a"/><file name="Grid.php" hash="2acaadd9464546bbec77f5d9815f831f"/><dir name="Renderer"><file name="Country.php" hash="74417b955dac939a295eaa7ae64ce979"/></dir></dir><file name="Types.php" hash="96fc7c42735308df6bdd6f5d400e1afc"/></dir></dir><dir name="Helper"><file name="Data.php" hash="37dc22c51575825470397f02a1497b8a"/></dir><dir name="Model"><file name="Attribute.php" hash="de7147676dc2b9efc9e3b2ebe3f2dfde"/><file name="Config.php" hash="186ad497d6e756dafb7ab1e683c1fddf"/><file name="Item.php" hash="5c34a976ae0bc4979e1c77a3521045ea"/><dir name="Mysql4"><dir name="Attribute"><file name="Collection.php" hash="0ac995159720299072572e59b3f56703"/></dir><file name="Attribute.php" hash="0db990e969d8f15ca0202651b16d869b"/><dir name="Item"><file name="Collection.php" hash="6ab601ff75fbb3c02080067924940893"/></dir><file name="Item.php" hash="65aa28e83d4a2d8f56608db3f8e31765"/><dir name="Type"><file name="Collection.php" hash="acba8831466758db65e6a1a47a7147cb"/></dir><file name="Type.php" hash="0b063bc2ce8d0855771db6e4c0f74d41"/></dir><file name="Observer.php" hash="4ee39b5218f1fed7dbaaa36d9a29db6f"/><dir name="Resource"><dir name="Attribute"><file name="Collection.php" hash="03615a6272451f12f8b43804e99ee5d6"/></dir><file name="Attribute.php" hash="92d0b4aa81e38442e1efb2dbb1d34258"/><dir name="Item"><file name="Collection.php" hash="9dca709ca6c169cd79b7b5ead827a08b"/></dir><file name="Item.php" hash="bfb7069e9a061e2ed5b0e0da2b2d01a0"/><dir name="Type"><file name="Collection.php" hash="64ce489b343309f3f39140a4f4cd7583"/></dir><file name="Type.php" hash="76003cbab0af46881bbd98bb957b66f8"/></dir><dir name="Service"><file name="Feed.php" hash="309cdd632278bb8bc5c29c0e2be1e360"/><file name="Item.php" hash="530d7616fc9ce908de7db459fc322015"/></dir><file name="Service.php" hash="24af7082a46a4932cbe03ed0bd6b6166"/><dir name="Source"><file name="Accounttype.php" hash="ce9af7fa322b94b4ec2e47cc6e6c1ec7"/><file name="Authtype.php" hash="b994b36c46031fedfff7b57f612f55a6"/><file name="Country.php" hash="0203b52aa4a28c0254d65a9b920efda8"/><file name="Statuses.php" hash="22ee2dba81cd494972b1fa7ece5b315b"/></dir><file name="Type.php" hash="76076f761fdfd28d59ff8b5577aabadb"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Googlebase"><file name="ItemsController.php" hash="c6de78715aa3017758bbc536b7afb095"/><file name="SelectionController.php" hash="9dfdedde2800187671c629f47971f2d0"/><file name="TypesController.php" hash="2fe00008ed2b55db767718ab1d5c0103"/></dir></dir><file name="ItemsController.php" hash="ee346770e2d88bcb674115d38e7949cb"/><file name="SelectionController.php" hash="8b96306c9cc7321029936c92737b3ccb"/><file name="TypesController.php" hash="709cecf3c0315f9a9063b31f318692a4"/></dir><dir name="etc"><file name="adminhtml.xml" hash="91b17d231331e23446d66dd5a2ac10b9"/><file name="config.xml" hash="26f5d7d23b12a0ca718d897b2595001e"/><file name="system.xml" hash="f31a03a47863c57e568f032001c6bef9"/></dir><dir name="sql"><dir name="googlebase_setup"><file name="install-1.6.0.0.php" hash="bc2387664571480a407c5182ca69a67d"/><file name="mysql4-install-0.1.0.php" hash="b1f74e7e4dc785db8c4821a7f9853659"/><file name="mysql4-upgrade-0.1.0-0.1.1.php" hash="37f586dcf8833a97e9fe0e992a5cf6cb"/><file name="mysql4-upgrade-0.1.1-0.1.2.php" hash="b060d55e1f64d3f672ff025af945dbc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="60867115973ae9449f221d742b319ae0"/></dir></dir></dir><dir name="GoogleCheckout"><dir name="Model"><file name="Payment.php" hash="982c96bcbfa5311070d550a8f8a1f948"/></dir><dir name="etc"><file name="config.xml" hash="c4d1bccf03be132b9dcb2c6822bf76be"/></dir></dir><dir name="ImportExport"><dir name="Block"><dir name="Adminhtml"><dir name="Export"><dir name="Edit"><file name="Form.php" hash="1d2694e45c6ad541957c42ee3eb1782a"/></dir><file name="Edit.php" hash="0666e8af99efef7ab7761b129ce09442"/><file name="Filter.php" hash="2b0d68c9414048ea234afe4d9d1ce8c6"/></dir><dir name="Import"><dir name="Edit"><file name="Form.php" hash="c47eeda645e5a6b54f7841a5528f8b03"/></dir><file name="Edit.php" hash="ca6507375bc594466a773a1530ee7abf"/><dir name="Frame"><file name="Result.php" hash="0a30864c11e996bdc9c66a0b8280b808"/></dir></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="384c6172dc31bae831d96dd3569df8a8"/></dir><dir name="Model"><file name="Abstract.php" hash="5a230ebd046c2cd899ed245bc79706ef"/><file name="Config.php" hash="435812ed04e558d4a74963b8ab7796ee"/><dir name="Export"><dir name="Adapter"><file name="Abstract.php" hash="414836b6ded4008e9655417472429c1b"/><file name="Csv.php" hash="8f1f89d704be424c63c2e1e44437e224"/></dir><dir name="Entity"><file name="Abstract.php" hash="04a03c5b7fcc6b4849cef58a27b98f0a"/><file name="Customer.php" hash="eb5f630dc3ecfa946626a420046ceedb"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="908f6355594c01b95316e7bd14f1a568"/><file name="Configurable.php" hash="8df99a951ecdaa8ce418a8c147d1dc98"/><file name="Grouped.php" hash="14d26d03645a505f4516e65b65da1d58"/><file name="Simple.php" hash="90901b89f0cb6cfc465333f8f102af2e"/></dir></dir><file name="Product.php" hash="e2ecef0dc27574f76ee24f5bafe3ff31"/></dir></dir><file name="Export.php" hash="19776fb654cfc20955e253b83882a902"/><dir name="Import"><dir name="Adapter"><file name="Abstract.php" hash="28a61f3dd03568c018026619ad87d49c"/><file name="Csv.php" hash="ce14a1f5d90265a12fe0dc10ddf44b87"/></dir><file name="Adapter.php" hash="fd89afe4e1be5fbc2389d31d7a51e5a3"/><dir name="Entity"><file name="Abstract.php" hash="79006dccac27958e000d88020097a5b4"/><dir name="Customer"><file name="Address.php" hash="b8237c9fe5dba6466339393c3b000d08"/></dir><file name="Customer.php" hash="6871e8a4a23051a1e218aace81406d22"/><dir name="Product"><dir name="Type"><file name="Abstract.php" hash="ffe2e9103a1e2693edd6891d3e83d47a"/><file name="Configurable.php" hash="fe9623029e842b6472369433b53d243b"/><file name="Grouped.php" hash="a6e1f3c1f9faa1739de0ac23318b846d"/><file name="Simple.php" hash="3a777da7bab161878964364b415080ac"/></dir></dir><file name="Product.php" hash="0397765d44718b3b4395da27b6d483a7"/></dir><dir name="Proxy"><dir name="Product"><file name="Resource.php" hash="06e6798c23ceb6319383e0120d5a571b"/></dir><file name="Product.php" hash="3050c471b6b0192716ea1cc51b4ef3ce"/></dir><file name="Uploader.php" hash="cc526896e36375ed0321e7fb5a80c9f4"/></dir><file name="Import.php" hash="c6c7206c1ec35924116392b6182e21b0"/><dir name="Mysql4"><dir name="Import"><file name="Data.php" hash="1088760a7325fc7a0e0f26427dfa4e03"/></dir><file name="Setup.php" hash="80bc724ecc0f935c2d5ebee1e3c2ad60"/></dir><dir name="Product"><dir name="Attribute"><dir name="Backend"><file name="Urlkey.php" hash="f9990ba2139c5bc3ec895b7bd339bc24"/></dir></dir></dir><dir name="Resource"><dir name="Helper"><file name="Mysql4.php" hash="4f156d994d5e68ce68dd7d2f95a7fc89"/></dir><dir name="Import"><file name="Data.php" hash="0235fb91f691b156680c160c68837ab2"/></dir><file name="Setup.php" hash="9dc5c3f7624900b8850a6e846f1e4f9f"/></dir><dir name="Source"><dir name="Export"><file name="Entity.php" hash="7eba440adcde3b91c888c21318f72447"/><file name="Format.php" hash="13d3a2ddef316c63a973541b299e3aa5"/></dir><dir name="Import"><file name="Behavior.php" hash="d923c67f2a43f414e9dd40eb13dcd10b"/><file name="Entity.php" hash="0970c1703c08c869269728ff3d2b634a"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ExportController.php" hash="46827924b3eee05f89aabcd67a4163a6"/><file name="ImportController.php" hash="be2058650aa5bb4a70b19665e6c92c86"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="91d91549fa6eed9d051fe0483b72df42"/><file name="config.xml" hash="f136ecdde7858eb0e921dc9689c8f560"/><file name="system.xml" hash="26aee9169d1cecd5def38f997c36d959"/></dir><dir name="sql"><dir name="importexport_setup"><file name="install-1.6.0.0.php" hash="440ecd2e1477d34e5cae67e86dac1b9a"/><file name="mysql4-install-0.1.0.php" hash="429e13933993d2ea22656edcdbf5ef55"/><file name="mysql4-upgrade-1.6.0.1-1.6.0.2.php" hash="c22f7d3f8c739ca64843cf2d45fcd73f"/></dir></dir></dir><dir name="Index"><dir name="Block"><dir name="Adminhtml"><file name="Notifications.php" hash="922e03c645be00419e2d8e5844d062e3"/><dir name="Process"><dir name="Edit"><file name="Form.php" hash="0cdf857a98eb42c9b579667a8678afdb"/><dir name="Tab"><file name="Main.php" hash="331b2a59a8d978f81c5b8a05b72e54ca"/></dir><file name="Tabs.php" hash="de2c47f1acf23d9360772ae00c8a859e"/></dir><file name="Edit.php" hash="ce7d7d368479e54c2b01b77dd3886b1d"/><dir name="Grid"><file name="Massaction.php" hash="aaa57991d6610fb6d00077818d532128"/></dir><file name="Grid.php" hash="f81a407a489b12d8ed8ea9c4b2e434c7"/></dir><file name="Process.php" hash="0a14d84d462e2cb2401ef3819389e7ff"/></dir></dir><file name="Exception.php" hash="a1dbeaf5fefc1d31b558fe93f9f73d1a"/><dir name="Helper"><file name="Data.php" hash="8d867f1179f6b39c5f7acdf175784a92"/></dir><dir name="Model"><file name="Event.php" hash="0f4c9a287f5a8679762952b86b8f8677"/><dir name="Indexer"><file name="Abstract.php" hash="cd9c4708d9a38c4c1afc672d04357030"/></dir><file name="Indexer.php" hash="d5143bacc2a4eaa4f6daf9c5cab5dc86"/><dir name="Lock"><dir name="Storage"><file name="Db.php" hash="0c22416871c8f81efa730ace6d992ac9"/><file name="Interface.php" hash="58327d8efcf1dcda6d5ec9c9c1cc1ac7"/></dir></dir><file name="Lock.php" hash="1c6666fe4cda94096d3668bcb8dfc9a8"/><dir name="Mysql4"><file name="Abstract.php" hash="5f9e45269f0beb215a04b7a5cbd7c01c"/><dir name="Event"><file name="Collection.php" hash="63dc340d2fcd37ec6993c171e6a112a6"/></dir><file name="Event.php" hash="720b92789910ef0c519e9e475b683a06"/><dir name="Process"><file name="Collection.php" hash="20ef6b9356da622286766d7acd1d929c"/></dir><file name="Process.php" hash="785aff05f0ac621b6d9a1a845cb1655e"/><file name="Setup.php" hash="c1ddc6c82badb71770af13c90d0cb812"/></dir><file name="Observer.php" hash="b9886ab72e3bd3db214ef31e464a2f1b"/><file name="Process.php" hash="e8bb4432a50efd682dd9419c0a82ef4c"/><dir name="Resource"><file name="Abstract.php" hash="ac3749b23996a6429c36ca137638ad02"/><dir name="Event"><file name="Collection.php" hash="1b03f9d9680463e2e60358052d8b82f8"/></dir><file name="Event.php" hash="d29ee78ac7d82ac16d32bcb7ef28d881"/><dir name="Helper"><dir name="Lock"><file name="Interface.php" hash="4bc86572aea98f639d4babf2ef538cc4"/></dir><file name="Mysql4.php" hash="ccc14816287dc75db167ca32ff5593cf"/></dir><dir name="Lock"><file name="Resource.php" hash="b2f87d6274785e35c8f06f966bf09f66"/></dir><dir name="Process"><file name="Collection.php" hash="82885a920f616ebbc109ca797efb232b"/></dir><file name="Process.php" hash="192269bd7cd4c37abfb4ee71303e0801"/><file name="Setup.php" hash="1464247cd3a97ccd6647a29262c1dde5"/></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="ProcessController.php" hash="c60849c043f9fb2a8ed433ed63288dc0"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="838e8a8273f5f72317ac60721dfa9b03"/><file name="config.xml" hash="738fe1d9e58823a3ad48dff298540bb5"/></dir><dir name="sql"><dir name="index_setup"><file name="install-1.6.0.0.php" hash="fd7edf27ce1ab3e2d8604e13482c7e75"/><file name="mysql4-install-1.4.0.0.php" hash="73f12feb17accae95d4edef62c916a17"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="fac3d6ccb754170d8a8d7554bb6fa3d6"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="4e1513cafc48d3d1c51e39bad877b88b"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="58861d9d24e1b40f78e4a0e8b6a23839"/></dir></dir></dir><dir name="Install"><dir name="Block"><file name="Abstract.php" hash="2dee98d086c168ab90698e8161f57066"/><file name="Admin.php" hash="efb15900c41ed3f02e39283193d391ee"/><file name="Begin.php" hash="659b15e410b828a97c6dfd9bae429ad2"/><file name="Config.php" hash="99dbd0a1160a5438c1b7ceb10a917d15"/><dir name="Db"><file name="Main.php" hash="5c56f37b937236cecc7cd22b065273b0"/><dir name="Type"><file name="Mysql4.php" hash="c20eb4b3c95316815677d5fbc4884b11"/></dir><file name="Type.php" hash="51040fddc22a85428577619c0b977464"/></dir><file name="Download.php" hash="52051c99cb5c5f99e6012d1f25f66074"/><file name="End.php" hash="16f06df1910ea6c4f49a6aec46ae086f"/><file name="Locale.php" hash="22c2f158faa1a3f13003a0c503faa2d5"/><file name="State.php" hash="24efc1866c5f33f0a0b993bedadbb8a4"/></dir><dir name="Controller"><file name="Action.php" hash="b682d197f541961e81213972c7244013"/><dir name="Router"><file name="Install.php" hash="8f69b3ce427d0fc0dceebd0030577e0d"/></dir></dir><dir name="Helper"><file name="Data.php" hash="9e855f685abce78835481bc484328719"/></dir><dir name="Model"><file name="Config.php" hash="dc4ee654173a7d2ef41e6a93199d70d5"/><dir name="Installer"><file name="Abstract.php" hash="4e0e0c729c308107360de80096e19540"/><file name="Config.php" hash="057a8c084c4476ae13a2d1fcf92c1f12"/><file name="Console.php" hash="f85d1f5d4880c7f4a50c8a98b398fd50"/><file name="Data.php" hash="3d90094a839ba4eadaf686cf2f9b56da"/><dir name="Db"><file name="Abstract.php" hash="1ba6d04a4d72970398883f7253263b17"/><file name="Mysql4.php" hash="e8cbc16eca193558c741eb22ac1c60f8"/></dir><file name="Db.php" hash="b67daec31cea6f3375db1ed7e56e4a7f"/><file name="Env.php" hash="639d6290361f4c1c4d5412229773e4f3"/><file name="Filesystem.php" hash="8b12da553f8a2b883da4bd4e19b7c33e"/><file name="Pear.php" hash="201cb7f98f8c34e96ced050fa828cf87"/></dir><file name="Installer.php" hash="e6e46a2976a552552306dc215ba865c2"/><file name="Observer.php" hash="8e6bffd30e9cb2e8a2eb696cf9ac5a68"/><file name="Session.php" hash="ed74c7aa62da86885edcaf79ca9bed8e"/><file name="Wizard.php" hash="c3489d3ad1292e06af7c3844f310aecf"/></dir><dir name="controllers"><file name="IndexController.php" hash="20e64a56f684c04619511846a99cc400"/><file name="WizardController.php" hash="7a00f69b6de90423d3ab53c9964b1492"/></dir><dir name="etc"><file name="config.xml" hash="fdcd1dd42be74df06a8419d8029023f8"/><file name="install.xml" hash="3d9ab17da44031cdc16c5d93e7b60773"/></dir></dir><dir name="Log"><dir name="Helper"><file name="Data.php" hash="8e1ea37dfdb3eb2127ae32b73117b934"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="System"><dir name="Config"><dir name="Source"><file name="Loglevel.php" hash="6bc16da4c393f8244728accef3152b3e"/></dir></dir></dir></dir><file name="Aggregation.php" hash="10552339d8cb158c9b119bc060a0dbb6"/><file name="Cron.php" hash="f834b2b13b33226ef9da72a88cc5874f"/><file name="Customer.php" hash="702b0517de7e854d1700dd4ee045052b"/><file name="Log.php" hash="d44fe18e726aa473d7a0cbe329222965"/><dir name="Mysql4"><file name="Aggregation.php" hash="559d0acec067d9f127f84fcd34eb9696"/><file name="Customer.php" hash="79fbe550b2e61a2b05770265256ce170"/><file name="Log.php" hash="dda701b3c34ef8ce11d3dc30ac96b75c"/><dir name="Visitor"><file name="Collection.php" hash="8d7620ed8c7aeee03683108eca7617c4"/><dir name="Online"><file name="Collection.php" hash="55fd5d38e12430dfd58daf87f9b72d52"/></dir><file name="Online.php" hash="d7c1ce6bd2ceebc4f3f1b1206c4dc67b"/></dir><file name="Visitor.php" hash="755c2ff87d1df51e12e66fb285087c81"/></dir><dir name="Resource"><file name="Aggregation.php" hash="66ec9a927a8fdd273851cf5842ee477d"/><file name="Customer.php" hash="33684fd547fcfa2051fc3d950fe8173f"/><file name="Log.php" hash="1344865f7b485fff14925a226938d6d8"/><dir name="Visitor"><file name="Collection.php" hash="edd5b89c8bd514761aecd16574e9bc3a"/><dir name="Online"><file name="Collection.php" hash="6a059f3701221bcecc2e14d2689624ae"/></dir><file name="Online.php" hash="0b67cc2b5a714f8d76931574745ddbaa"/></dir><file name="Visitor.php" hash="e0a81fc458bc333f4de45282426b4716"/></dir><dir name="Visitor"><file name="Online.php" hash="f227139761c63b469710a03562dcc5ce"/></dir><file name="Visitor.php" hash="6eef64209506c68e05cac75702b8f09f"/></dir><dir name="data"><dir name="log_setup"><file name="data-install-1.6.0.0.php" hash="3e1982a81ee050ddec1949bb6a893c07"/></dir></dir><dir name="etc"><file name="config.xml" hash="eba13997054a59d8b5c1658c2999a4e3"/><file name="system.xml" hash="e333f423f247ee85fe09df20458fe362"/></dir><dir name="sql"><dir name="log_setup"><file name="install-1.6.0.0.php" hash="dc7295d342fda0d6cbcf4157a197d4ec"/><file name="mysql4-install-0.7.0.php" hash="d575dd42f8c7472d4d8ea8b1d90d8f9a"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="34b5ec712445eb9387594ca1f75fd87f"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="129b7e5e5c06180fd48a218db32c7ea0"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="3a12eac2f81c762507914389c904618d"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b78cb4e596f7f1be79f12b3e746c4db9"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="fd33161e285e2a0c8b3d6b5607f73273"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="6d3b11e2e5a4aa4b41aae94b68384d60"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="7eca6d3b4caf1bdd7372f5ff95039d1f"/><file name="mysql4-upgrade-1.6.0.0-1.6.1.0.php" hash="bce437dd6f47db768f109624c4fb60d2"/><file name="mysql4-upgrade-1.6.1.0-1.6.1.1.php" hash="f8726e38a05a6cc876982e61cce65217"/></dir></dir></dir><dir name="Media"><dir name="Helper"><file name="Data.php" hash="a1f43339bdd5d2955ccec8e961f7d44b"/></dir><dir name="Model"><dir name="File"><file name="Image.php" hash="ef90f58f95934ece51b84add82393dbb"/></dir><dir name="Image"><dir name="Config"><file name="Interface.php" hash="2ec657e2417a814d9865c04ebddd2cdb"/></dir></dir><file name="Image.php" hash="cd22c32eaf0da58d4439c238b06947a1"/></dir><dir name="etc"><file name="config.xml" hash="ae68c69fff953c068f256fc2ed885794"/></dir></dir><dir name="Newsletter"><dir name="Block"><file name="Subscribe.php" hash="28e440fb31532edcc299b24c25fad0b2"/></dir><dir name="Helper"><file name="Data.php" hash="b6883b716785a6ae298ae474923bec8c"/></dir><dir name="Model"><file name="Message.php" hash="1750703765bb9f7376f8cd7afef95bdf"/><dir name="Mysql4"><dir name="Problem"><file name="Collection.php" hash="6de593241173f716441cd525a60b29ac"/></dir><file name="Problem.php" hash="5e980ad89adc06f1a064d88264db41c8"/><dir name="Queue"><file name="Collection.php" hash="560faac4ebac5cbdf08b20ce11419564"/></dir><file name="Queue.php" hash="f7f3bb7fa9173b6e51a6cc726c6c03f5"/><dir name="Subscriber"><file name="Collection.php" hash="f6e8ad8d1f24c2614ea758c7a683511f"/></dir><file name="Subscriber.php" hash="28a84169e8bf4563ee77d9a8795ea864"/><dir name="Template"><file name="Collection.php" hash="1385706b684c75f98c575beb981f2988"/></dir><file name="Template.php" hash="343c97a25be170240522e7cf682dab37"/></dir><file name="Observer.php" hash="34aa358337b40b41e062250a37ada85e"/><file name="Problem.php" hash="b84eab3f567814c02ddffd94224c2a9c"/><file name="Queue.php" hash="130624a59c5c70fde0b59d810a7f1917"/><dir name="Resource"><dir name="Problem"><file name="Collection.php" hash="73d5c8ac0bc852b1797deec496552102"/></dir><file name="Problem.php" hash="bc291b49df5cdabea16ef9ed3061a487"/><dir name="Queue"><file name="Collection.php" hash="245e312c2cd091994ad9f45838632360"/></dir><file name="Queue.php" hash="ea511beb43d47d27a98e3aaeaecc4474"/><dir name="Subscriber"><file name="Collection.php" hash="36c88e4f143f94d5ab8963df2f9cd32f"/></dir><file name="Subscriber.php" hash="e3edbe990f15e0e1893f351a3dbda922"/><dir name="Template"><file name="Collection.php" hash="c5ca290fa43abb9fc4748930b3a9d1bb"/></dir><file name="Template.php" hash="0309012892a386b48535d9a59c6d6b25"/></dir><file name="Session.php" hash="f5eb66ba88eb752da13607d4e031dd01"/><file name="Subscriber.php" hash="81525dee3bbd0db4bf1e584e0e6a1a43"/><dir name="Template"><file name="Filter.php" hash="bde6a148d876981d2a36ff0959f86e89"/></dir><file name="Template.php" hash="2cdca2731d3bef3098acca40bbfc7417"/></dir><dir name="controllers"><file name="ManageController.php" hash="5d567820c8d976ce8defd9b1b0da5206"/><file name="SubscriberController.php" hash="3fc6fdadccd2afa4692f0ab6b1bbd488"/></dir><dir name="data"><dir name="newsletter_setup"><file name="data-upgrade-1.6.0.0-1.6.0.1.php" hash="b7a3d19fbaef5a6fdf37fe71176047df"/><file name="data-upgrade-1.6.0.1-1.6.0.2.php" hash="6c8c4e7d435bb50eddd6e7dbb14249cd"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="fe2493b1ef093e63bb504edc5bd2ccd2"/><file name="config.xml" hash="2c22e3965d2256f71fc152e081e34527"/><file name="system.xml" hash="e37205b0b99e719c7623ffa5258b37bb"/></dir><dir name="sql"><dir name="newsletter_setup"><file name="install-1.6.0.0.php" hash="3c620e075f2a9298d52f36bec4ef92b9"/><file name="mysql4-install-0.7.0.php" hash="e81ce4f738b532d5435bfc8008293b8c"/><file name="mysql4-install-0.8.0.php" hash="bafb7e57fb822c4aca123fa6b9ed5920"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="c054de290c7c5fa3e116aed41eff4f17"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="663667dd1923f3890b855fc691375908"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="848b4eb72c16c4e2ac5cd2e12236b326"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="13ef7177c48460bb04dad80c456837a1"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0367dc658bd286502e97f7b648fd6d04"/></dir></dir></dir><dir name="Oauth"><dir name="Block"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><dir name="Token"><file name="Grid.php" hash="faf7492adfcdb46928d76030eff74f65"/></dir><file name="Token.php" hash="ce4dddfe298fc02b2b381a7c6469092e"/></dir><dir name="Authorize"><file name="Button.php" hash="1c81a60de78cc606e79a1d8be57bb869"/></dir><file name="Authorize.php" hash="8f4665e6545dde37434ed9c10b3645a7"/><dir name="AuthorizedTokens"><file name="Grid.php" hash="cb6f809f97a7bf7d46b932e13aadff99"/></dir><file name="AuthorizedTokens.php" hash="85a9f2d4d7e7d12aa7d6b4eebfe9a0a2"/><dir name="Consumer"><dir name="Edit"><file name="Form.php" hash="26442ba5d70ad3bcee2f2787d3032191"/></dir><file name="Edit.php" hash="69ea6261b2de4c0179720f16d771b81e"/><file name="Grid.php" hash="5295e58ea863f40074ce4c590990118c"/></dir><file name="Consumer.php" hash="2a43bb7b1a6ec96fafa2fb0d2b850993"/></dir></dir><dir name="Authorize"><file name="Abstract.php" hash="3e3aba461e6008ecdd38749558530364"/><file name="Button.php" hash="6dd4651aa52e7094c95ca40aa40fe559"/><file name="ButtonBaseAbstract.php" hash="0d30faefc4fd63c756ce97c699e530d2"/></dir><file name="Authorize.php" hash="12557ebc607496441344055642e1fc89"/><file name="AuthorizeBaseAbstract.php" hash="c7286fab6fad35da2af69251df23c927"/><dir name="Customer"><dir name="Token"><file name="List.php" hash="ab6a503fd7351a57ae0c38ab7cbe1bc7"/></dir></dir></dir><file name="Exception.php" hash="f2cce047a249d5042a8196eb2eb1188b"/><dir name="Helper"><file name="Data.php" hash="3cdfd4b295606df93d44cb6e97b453eb"/></dir><dir name="Model"><dir name="Consumer"><dir name="Validator"><file name="KeyLength.php" hash="41a23ef35ba4f1ecb26430a0b15e90b1"/></dir></dir><file name="Consumer.php" hash="48e78ecd656ce1caf445eb7d07c7fa37"/><file name="Nonce.php" hash="c6fbea1ee4b0853402b34214e5a4e7c2"/><file name="Observer.php" hash="af0fe3ecee5ee39ac6f20a34b162b3ac"/><dir name="Resource"><dir name="Consumer"><file name="Collection.php" hash="6a0ae20a1d9598df8cc13c66ff7857df"/></dir><file name="Consumer.php" hash="71aa68f1f659032f19fed5bd7f16954b"/><dir name="Nonce"><file name="Collection.php" hash="a6145078c6830243e6c35521467de6ff"/></dir><file name="Nonce.php" hash="0c2fc104df8c98ef3bf10a06c82c9e4f"/><file name="Setup.php" hash="664fcc4e6ce0c5de4aada29f49ef283d"/><dir name="Token"><file name="Collection.php" hash="c2c31414bdf93a1bf642de15be611a25"/></dir><file name="Token.php" hash="083a0594d61845cb68e28cc118b7bb17"/></dir><file name="Server.php" hash="9468c0b29cc165fc0ef20cd95d47e6f6"/><file name="Token.php" hash="ee05a1801416a8bb440d3d7c8d004dd6"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Oauth"><dir name="Admin"><file name="TokenController.php" hash="c2435d97eb91f835014d403354354ec6"/></dir><file name="AuthorizeController.php" hash="659b7948384ab393209f296f5be15b43"/><file name="AuthorizedTokensController.php" hash="bb7df560a7595deaeec96ae63a7e9b2b"/><file name="ConsumerController.php" hash="8e3244262dc3a34a89cf54984b2ec74e"/></dir></dir><file name="AuthorizeController.php" hash="9536f67c302706a93b5a844f6826d870"/><dir name="Customer"><file name="TokenController.php" hash="f9f9ed1f0041c5ae518005f2e90e78f6"/></dir><file name="InitiateController.php" hash="7bc4b0605282cfc629011ca094863175"/><file name="TokenController.php" hash="3a734ab905de6197146e7de47376de6f"/></dir><dir name="etc"><file name="adminhtml.xml" hash="c3c51c34ae5979c2e0df148ddbec7113"/><file name="config.xml" hash="446b689f37981498a1dc86f5ab1bb0e3"/><file name="system.xml" hash="38bcf79677c20f5821bf6f54dcfe6297"/></dir><dir name="sql"><dir name="oauth_setup"><file name="install-1.0.0.0.php" hash="7d70d6610ebf50a9782337e6f3d0f5ef"/></dir></dir></dir><dir name="Page"><dir name="Block"><dir name="Html"><file name="Breadcrumbs.php" hash="1fe5ffca8e5b2f2f2b7aa78700217c6c"/><file name="CookieNotice.php" hash="f70b0a12cfccafcaa7125478dbd6a8d9"/><file name="Footer.php" hash="77f2fb87201b33dc34fdb7fae4ffc030"/><file name="Head.php" hash="cb019fb8e30bbd8064c3418f6c291a47"/><file name="Header.php" hash="2cbf7f560f06289367d825e99a784355"/><file name="Notices.php" hash="7782add14339c49bbbfa074baff2bcae"/><file name="Pager.php" hash="e946ed0f6a5deb4021ddd415e3dcada2"/><file name="Toplinks.php" hash="be7cbec75d231b5f40cecc45ce6aced9"/><dir name="Topmenu"><file name="Renderer.php" hash="f6df51661c07d24a2cd45ada7a195c16"/></dir><file name="Topmenu.php" hash="7fa8066846bd784d4da25a7638ff83c9"/><file name="Welcome.php" hash="c588210d17985afdd4b70016862a3f58"/><file name="Wrapper.php" hash="c43925e6af41f952a246d38de7acd924"/></dir><file name="Html.php" hash="ebff82d47412ade15f091533080a8cb0"/><dir name="Js"><file name="Cookie.php" hash="97ad94ecbdfb73f1523169f105148de6"/><file name="Translate.php" hash="5b3273d29f989c8348d93788dcbc4d8b"/></dir><file name="Redirect.php" hash="d8b5ddb87a79497acc2136d117aa4cb8"/><file name="Switch.php" hash="92e0ee78127e737abc1d0de28aa39668"/><dir name="Template"><file name="Container.php" hash="58c4e09110863b559c899e766689db3c"/><dir name="Links"><file name="Block.php" hash="a1fd263db9149683be177f12b3d21403"/></dir><file name="Links.php" hash="d3563e74d4e9be5ca574d26980f87ae3"/></dir></dir><dir name="Helper"><file name="Data.php" hash="643200eb25af3286d89295821ccd215f"/><file name="Html.php" hash="ff435cfd6fa058784e5047bde5059cc0"/><file name="Layout.php" hash="68a7da8957b6bf38391076c6dc1d8b89"/></dir><dir name="Model"><file name="Config.php" hash="d3353eb7388747f28106cc422b7c0178"/><dir name="Source"><file name="Layout.php" hash="f6c47751ce94f1202f51f74240576f16"/></dir></dir><dir name="etc"><file name="config.xml" hash="093b9598b2072c232feaed596cdae921"/><file name="system.xml" hash="b639cd00ba12888b93846adf7b7a06ce"/></dir></dir><dir name="PageCache"><dir name="Block"><dir name="Adminhtml"><dir name="Cache"><file name="Additional.php" hash="980caec50a3cbf58f41da2327a565021"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="3b8e9e8eb1d3c56bcb47f4b3eecdb7cd"/></dir><dir name="Model"><dir name="Control"><file name="Interface.php" hash="fd10161bdb54026cff06db39a4dbb5c2"/><file name="Zend.php" hash="21b1db8392b9f2f3d078705e2ec26ba4"/></dir><file name="Observer.php" hash="537fb8952f611b797e394e4569de1ffa"/><dir name="System"><dir name="Config"><dir name="Source"><file name="Controls.php" hash="ea5031f742689bca2a1b08144ea39cd0"/></dir></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><file name="PageCacheController.php" hash="a4905697051657f96098ec4076fdfe2b"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="97661944ee637ba8e00a6596bdba3969"/><file name="config.xml" hash="c3e7a37ca8c0a930bea08751ad362a2e"/><file name="system.xml" hash="f8301b232c7614412428a0fb526bf5bc"/></dir></dir><dir name="Paygate"><dir name="Block"><dir name="Authorizenet"><dir name="Form"><file name="Cc.php" hash="d657a3be38a02106dde73a4892b0c77e"/></dir><dir name="Info"><file name="Cc.php" hash="378841b3fcda8fbec605b62c3fe7a9c8"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="008e92608958a3a7ac08ade7ad142ccf"/></dir><dir name="Model"><dir name="Authorizenet"><file name="Cards.php" hash="d81581da931610d0e8868b4accb3690b"/><file name="Debug.php" hash="977a9c8240e3f572bbb64d6a6f238b87"/><file name="Request.php" hash="ba5a4763ece9bf688257ce424212b459"/><file name="Result.php" hash="219a7a26b1ebfb4c58da9f287f386d6a"/><dir name="Source"><file name="Cctype.php" hash="93635248391f764267488c9584d9690b"/><file name="PaymentAction.php" hash="7dbc905942c6359af597c5dc9c80094f"/></dir></dir><file name="Authorizenet.php" hash="dba6893ddc37660cc8e1a09a7953130d"/><dir name="Mysql4"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="75ccb15a446e4a32e853f2fcba210ab3"/></dir><file name="Debug.php" hash="71d0f733c94f22dbcb887d64dc27d16a"/></dir></dir><dir name="Resource"><dir name="Authorizenet"><dir name="Debug"><file name="Collection.php" hash="2bbfd8a9516e70297630bb01a52f6f50"/></dir><file name="Debug.php" hash="e21392b38f8cb291d1803ce24400a886"/></dir></dir></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Paygate"><dir name="Authorizenet"><file name="PaymentController.php" hash="267d17f09c387babc09a9b065cd145ca"/></dir></dir></dir><dir name="Authorizenet"><file name="PaymentController.php" hash="7943c655501133002d695e8dd980d62e"/></dir></dir><dir name="etc"><file name="config.xml" hash="e8090f4993067b18e61a600994d704a5"/><file name="system.xml" hash="527cb86df3b94b76e49d5738e93edaf5"/></dir><dir name="sql"><dir name="paygate_setup"><file name="install-1.6.0.0.php" hash="512f727b16737444feae450851679a7e"/><file name="mysql4-data-upgrade-0.7.0-0.7.1.php" hash="bb83ae3d9fc7ade47467ca1fadaab284"/><file name="mysql4-install-0.7.0.php" hash="40b964a9db67dc645b20735a0d69d586"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="6f2857623a2baa373fb4d01d8cdf597d"/></dir></dir></dir><dir name="Payment"><dir name="Block"><dir name="Catalog"><dir name="Product"><dir name="View"><file name="Profile.php" hash="725706ecf3c9f45fa76a43aed9f4fd0e"/></dir></dir></dir><dir name="Form"><file name="Banktransfer.php" hash="a8065e642e9b9d36d7b0ed5f333dc152"/><file name="Cashondelivery.php" hash="a3704a4d200caff8a596736650bae112"/><file name="Cc.php" hash="145d796f6c98a11a230cb4292cb683ea"/><file name="Ccsave.php" hash="c25e2aa496f3665a7d22ebaa0046041e"/><file name="Checkmo.php" hash="0e34baf58c26715ab229e2053736a5c6"/><file name="Container.php" hash="7e93316090e0517da04392d2db08623b"/><file name="Purchaseorder.php" hash="4ee06729fdce364077a746e10ec016ca"/></dir><file name="Form.php" hash="08da59955c049b2a436a92c86c42a71a"/><dir name="Info"><file name="Banktransfer.php" hash="8253079b2a3f295e9212ffd471f1fb8c"/><file name="Cc.php" hash="0bc912ea4a40f5f413f501866900f2b9"/><file name="Ccsave.php" hash="c99aac57be0c839c3761bf63b42f9b63"/><file name="Checkmo.php" hash="bdfa5eb12e51b24dfa520d2ce9df0878"/><file name="Container.php" hash="8b24dd8c3fc825879faaeaddda23bdf6"/><file name="Purchaseorder.php" hash="97c4838b60a46f7a2ae9938b1f02e1c4"/></dir><file name="Info.php" hash="df4007e93b95af8440adca3d7a2f003a"/></dir><file name="Exception.php" hash="2f764ffbd8d0325189157a5166961ce0"/><dir name="Helper"><file name="Data.php" hash="4bba6d904ff25cf084a34bc5e67e9562"/></dir><dir name="Model"><dir name="Billing"><dir name="Agreement"><file name="MethodInterface.php" hash="40affb7dbc6e36c9d412acf3752d49ad"/></dir><file name="AgreementAbstract.php" hash="cb98bd16da8df19373a4e2fb4d695c45"/></dir><file name="Config.php" hash="5e882d7781c0b77ae07556af497a0237"/><dir name="Info"><file name="Exception.php" hash="9e329becc170b4510db0a958b85d9992"/></dir><file name="Info.php" hash="f1a313479034fa1cd9cc4a55c754de07"/><dir name="Method"><file name="Abstract.php" hash="e540ef077370453a0caf0f043bf20ee2"/><file name="Banktransfer.php" hash="2c3cef4f19d6c50cfbcad2417881e506"/><file name="Cashondelivery.php" hash="ba5a710d5848130b9bc853fcb5975387"/><file name="Cc.php" hash="936a4c4e2a4ec708d1f7b9a904955a67"/><file name="Ccsave.php" hash="d23c43b145c29936b4f0270f2bd5461b"/><file name="Checkmo.php" hash="e9e42a8a7e6fac87ba540707b971f721"/><file name="Free.php" hash="dbb00b6ca11ff0b713028460fdb4c7fe"/><file name="Purchaseorder.php" hash="5ac8af393668e8293d99edd49448e5fc"/></dir><file name="Observer.php" hash="60a511f336a4e4929f0d493c35ae8a0c"/><dir name="Paygate"><file name="Request.php" hash="6bc7e8cd45e164af3323eb8555334474"/><file name="Result.php" hash="2e4a62d1d983538db34bce670dec9139"/></dir><dir name="Recurring"><dir name="Profile"><file name="MethodInterface.php" hash="7c3753a6b14e1f405bcdb6e9842cdba6"/></dir><file name="Profile.php" hash="a619cf76b0eb8846919935ed8c644995"/></dir><dir name="Source"><file name="Cctype.php" hash="4aa5f460d8dbd3365a37d5a777833284"/><file name="Invoice.php" hash="94cf713138fce0d1e839aff0f4835640"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2ffac8b147628b2f2a905c7c6863f873"/><file name="config.xml" hash="8088a0540e8f4c16af7cdde7f6114397"/><file name="system.xml" hash="73d212e7b1a6299a5aeb3252036481f8"/></dir><dir name="sql"><dir name="payment_setup"><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="8a85b32c4db60c3f8841f3e4a54b9b95"/></dir></dir></dir><dir name="Paypal"><dir name="Block"><dir name="Adminhtml"><dir name="Settlement"><dir name="Details"><file name="Form.php" hash="6ddcb1cc4019de3b6959bca28115ac36"/></dir><file name="Details.php" hash="7ac366f7c6119905719aec713aec003e"/><dir name="Report"><file name="Grid.php" hash="85f1eaa79a7efedcc68b2b55a2996fb4"/></dir><file name="Report.php" hash="36bb9f80863bb5a1475ea1558c474b27"/></dir><dir name="System"><dir name="Config"><file name="ApiWizard.php" hash="0bc7455b8a819c2d72639ea6bbe37e4c"/><file name="BmlApiWizard.php" hash="090124ca3d6b8a7871676c057abbdcde"/><dir name="Field"><file name="Country.php" hash="4c60e38dd22c3b9fb23e3a0ca9a7cb6a"/><file name="Hidden.php" hash="e069a192a35b54b1bc29f9e8b03b06a1"/><file name="SolutionType.php" hash="889a1b47c5fdfb1a8d56e618afffc83a"/></dir><dir name="Fieldset"><file name="Deprecated.php" hash="01f954b46d2bf35bbcb4181fbdc18a37"/><file name="Expanded.php" hash="5feb995a9b9368a7335645cd659e0069"/><file name="Global.php" hash="2edadea19ce037b63b5b9d5f43e0639a"/><file name="Group.php" hash="10a1bd0c6519d110c1da6cf34f2f3e88"/><file name="Hint.php" hash="1b39b3d40b5602d53ddb83aa96285623"/><file name="Location.php" hash="ba3f315238325790ca09dbfe1f3c98b7"/><file name="PathDependent.php" hash="125f5c38eba04b953f6c770de5794982"/><file name="Payment.php" hash="47d6650b3d19fa72cd0be0799a4bc58c"/><file name="Store.php" hash="f3c73d65c6a3830dd320a252b9719c37"/></dir><dir name="Payflowlink"><file name="Advanced.php" hash="c9504cc07b7e8dd2b53b7732ccea5f37"/><file name="Info.php" hash="452702b941cd07c4604d27744768927f"/></dir></dir></dir></dir><dir name="Bml"><file name="Banners.php" hash="b3eec8eed2340570b3992dc5cc91c3eb"/><file name="Form.php" hash="e18437ec63789b079fcee9da6584a6bf"/></dir><dir name="Express"><file name="Form.php" hash="c638da5fe28a9499e97ae54912b39814"/><dir name="Review"><file name="Billing.php" hash="b5b3816f3de318c64cf64c90f56b8c0e"/><file name="Details.php" hash="93b80e5b28ba63323a3e7f1121e56c26"/><file name="Shipping.php" hash="81ad721a1affbfe1e5e1b149819e9399"/></dir><file name="Review.php" hash="accd58014e0a151ad8b9dfcfaa43a57e"/><file name="Shortcut.php" hash="b0e47e3854c9249353b08634818fe367"/></dir><dir name="Hosted"><dir name="Pro"><file name="Form.php" hash="a5cf9e2d9706c4d51f52ecca876cc51d"/><file name="Iframe.php" hash="a6631c676e7b70c2f3c98e37fb4c7938"/><file name="Info.php" hash="66918e15ea5383ae03982360a7d3395c"/></dir></dir><file name="Iframe.php" hash="d9dbf2ed604febfdc93d7ec861416959"/><file name="Logo.php" hash="c1d496b3c83f9b048fc6a6fec17868b8"/><dir name="Payflow"><dir name="Advanced"><file name="Form.php" hash="a53c2c390019833e86255d468ea00ce5"/><file name="Iframe.php" hash="d004c0ecd462b5bd3aa40e60f0eaa98f"/><file name="Info.php" hash="d8b493ddca4388198d58de4f29928575"/><file name="Review.php" hash="e76212ba90c607a6fb4e8937e15157b1"/></dir><dir name="Link"><file name="Form.php" hash="cd8607afb8baf8e7076414aa80af47b9"/><file name="Iframe.php" hash="9fa8a536ea14470f7edbd6542e345361"/><file name="Info.php" hash="adeb4b8a88c9744ea7e7a135b6cf92e9"/><file name="Review.php" hash="79fe2f6d55f6c77ff499e900b8aae56a"/></dir></dir><dir name="Payment"><file name="Info.php" hash="ff95d5e77f8273c3df147339dc2a809a"/></dir><dir name="Standard"><file name="Form.php" hash="74f3f12f2f645bf65d4c7cbd07b41bb4"/><file name="Redirect.php" hash="29dbaaac7d961dbedb27b22ff50a6fd5"/></dir></dir><dir name="Controller"><dir name="Express"><file name="Abstract.php" hash="200daa8f5bfd9cc60308e1c70b48fdfc"/></dir></dir><file name="Exception.php" hash="fcdfd6d4dac7c1f3bf1fd539eb7f7769"/><dir name="Helper"><file name="Checkout.php" hash="615868ddf2e733a90a1530ca7f76e76a"/><file name="Data.php" hash="8bfe0b91a3782f2a3a2589cbff79c789"/><file name="Hss.php" hash="a214dc03517c059962b4b0ae0b3062d4"/></dir><dir name="Model"><dir name="Api"><file name="Abstract.php" hash="83fa994337a3ea71000be3929819339f"/><file name="Nvp.php" hash="9afffc68e2b7f5b088368cfcf852095d"/><file name="ProcessableException.php" hash="3912a3f9f4916ada603c2903f8195a6b"/><file name="Standard.php" hash="6025fea50bc134ae53d7a7253e40a849"/></dir><file name="Bml.php" hash="c8ef5747ef0e41edff08224c8b09780e"/><file name="Cart.php" hash="606f045a4c3441fc3f2a43127840f9be"/><file name="Cert.php" hash="dec38db38574e00681a0171e2ddcbdf7"/><file name="Config.php" hash="8f8e36240b38e64509ba5c14c774e9d0"/><file name="Direct.php" hash="c2a94320efb7745eee4db1ccc22822f0"/><dir name="Express"><file name="Checkout.php" hash="341134b019a81f5132df773034b11ffa"/></dir><file name="Express.php" hash="bb9d000176a507ee2f8f189e2a0cde1d"/><dir name="Hostedpro"><file name="Request.php" hash="349a1a20f529fa148d557b655618b5b8"/></dir><file name="Hostedpro.php" hash="fc7b44c2d2b7a6b2e16555ca779e3cec"/><file name="Info.php" hash="841b30d7eebbf3df26fe71937243c4e3"/><file name="Ipn.php" hash="992d9a3d7eac13cc92e4006bd82cf6d6"/><dir name="Method"><file name="Agreement.php" hash="024ff9253ccbd340ab4d3e1df3b462ec"/></dir><dir name="Mysql4"><file name="Cert.php" hash="cc765655e8978b4a65343cf307e3fd7b"/><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="57ebccbb3c85463714004f17b5944ffb"/></dir><file name="Row.php" hash="f73aa04ec3103f999023738fb56f3efc"/></dir><file name="Settlement.php" hash="c2a3667e985551055c032ceb3269843f"/></dir><file name="Setup.php" hash="d332223394ea48a9316ece62f9d87c2b"/></dir><file name="Observer.php" hash="921ff85011967dace873135b17c4473d"/><dir name="Payflow"><file name="Request.php" hash="bce9a2a096c7948d82f8b376e2a2a178"/></dir><file name="Payflowadvanced.php" hash="7bb0e3274015050ae2fc9c56057b2cb4"/><file name="Payflowlink.php" hash="a5808cb2562f13ad2430c2150a28e023"/><file name="Payflowpro.php" hash="71d8794bc0c48b63cf31312b1dbef978"/><dir name="Payment"><file name="Transaction.php" hash="fa8636d02751123e68d3907326dc3844"/></dir><file name="Pro.php" hash="4f2c1c4e4175db48b24dfd5d074c78f3"/><dir name="Report"><dir name="Settlement"><file name="Row.php" hash="d6c2cd48c2cc14acd7807ae0ecc075b9"/></dir><file name="Settlement.php" hash="4a116d46a8a412baf390b4f660092e85"/></dir><dir name="Resource"><file name="Cert.php" hash="dc4fee682268206f22c450f11ee77ab6"/><dir name="Payment"><dir name="Transaction"><file name="Collection.php" hash="a738465839e6bc7060399d4ea1018811"/></dir><file name="Transaction.php" hash="fc74fade61f3ed060dfd1908d0f3568c"/></dir><dir name="Report"><dir name="Settlement"><dir name="Row"><file name="Collection.php" hash="b86233296208bf48edf315e76af3841a"/></dir><file name="Row.php" hash="b5f4467774406898083bc0a3b381e4a2"/></dir><file name="Settlement.php" hash="00be4934c8645f49be6dfb2f95c2df6e"/></dir><file name="Setup.php" hash="72ee97eac0bf6dd489e87a90f0739f94"/></dir><file name="Session.php" hash="01e89821d349210313e7601a52163253"/><file name="Standard.php" hash="e64d7379830e18577f72f07c2b1bcbcc"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Cert.php" hash="39dee3020d56b4d99acf2dbaac2d8313"/><file name="Cron.php" hash="b9f70827fcf4a140a0dd93d1a6377f32"/><file name="MerchantCountry.php" hash="d8fc9fa97b38b8e5d6e59a10863903fe"/></dir><dir name="Source"><file name="AuthorizationAmounts.php" hash="0c3a38379dc3cf8d7822a91df9bd2fea"/><file name="BmlPosition.php" hash="df2ad0b79c16fdc21b28442544ca6021"/><file name="BmlSize.php" hash="e80300a818111d09ca8c84a535508516"/><file name="BuyerCountry.php" hash="d897c4000b9d38da67e649b1552120c6"/><file name="FetchingSchedule.php" hash="07344b50f6ca9f10e9be3234d57e8957"/><file name="Logo.php" hash="ae5253ff2eb86d72a9d4a48eefd71516"/><file name="MerchantCountry.php" hash="ef1e498e5aad6a3c0af03a5ed5f4faa8"/><dir name="PaymentActions"><file name="Express.php" hash="bab12455a570699163625c6452458116"/></dir><file name="PaymentActions.php" hash="c2593f853dbab0a41dc5175c020b3d3c"/><file name="RequireBillingAddress.php" hash="b73a2c1762c33aad94c8878bfec02eff"/><file name="UrlMethod.php" hash="52cdf00f20176c80a1c099e5f635a8f2"/><file name="YesnoShortcut.php" hash="cad52eb5e45fe480327631f6272f907e"/></dir></dir></dir></dir><file name="UnavailableException.php" hash="aa39aecb2766d59f98b32030254d34fa"/><dir name="controllers"><dir name="Adminhtml"><dir name="Paypal"><file name="ReportsController.php" hash="5c6bf3de5a00da49b48565f92afedec7"/></dir></dir><file name="BmlController.php" hash="b8b1d029fdd2d73ff389c9a100f30054"/><file name="ExpressController.php" hash="5733d778477b5a08dfd3e64992320f77"/><file name="HostedproController.php" hash="0152fbfc438e30b70c7f647278701d75"/><file name="IpnController.php" hash="563d93416c1482581dee5112ab0aebb1"/><file name="PayflowController.php" hash="1a303bea93bcdd01445e5efc7ea2691b"/><file name="PayflowadvancedController.php" hash="640e848bfe279f7585bb877b9571415a"/><file name="StandardController.php" hash="1e8b7292120096b0b9fb38c94b1e314b"/></dir><dir name="data"><dir name="paypal_setup"><file name="data-install-1.6.0.5.php" hash="31f40b7d79be358edb0a9cc0e9b103db"/><file name="data-upgrade-1.6.0.2-1.6.0.3.php" hash="c42ee4ee4739cb2ea92a422fd0b404fc"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="a8bf81ac635dfd2bd045904a25c64da6"/><file name="data-upgrade-1.6.0.5-1.6.0.6.php" hash="ebee289417ad5f5c222be7b1af256393"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="5d13ccd9736705a6b2eb7f6de4f833c3"/><file name="config.xml" hash="83aaa17324edbd5bef47af753ea350de"/><file name="system.xml" hash="114ca5f13f1da5b517f023e332d03a01"/></dir><dir name="sql"><dir name="paypal_setup"><file name="install-1.6.0.0.php" hash="2090e14614dbdce1ff27be6516bc594c"/><file name="mysql4-install-0.7.0.php" hash="378e4be279f4bbc8d04cbdf861094b21"/><file name="mysql4-install-1.4.0.0.php" hash="14d77731070a888c43bf107f45756d76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="10e54e4c72b929cca1c933fda6f08ada"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="781db6012e61655eb559c282e49601dc"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="bb99253212b7a2593936f557c434b370"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="56e09db439d9d5cfa73e06beffd5fc3a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ab6fa9235bae2eedf82869e288af1b83"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="5ef1829af7dfb20fc92b3dbdcbea82a7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="37589fcebf8a761344345ae9fb7850b4"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="bca45a121f607c44b0f63975db8cbc03"/></dir></dir></dir><dir name="PaypalUk"><dir name="Block"><dir name="Bml"><file name="Form.php" hash="3c0edcbe9705ed2744098b851d3fba7a"/></dir><dir name="Express"><file name="Form.php" hash="d256cb349d523a2321e1597cfab93939"/><file name="Shortcut.php" hash="e69f67262822e930f82394a4f0bbc89c"/></dir></dir><dir name="Helper"><file name="Data.php" hash="90c53b8383f4258113adfc5ef79af65a"/></dir><dir name="Model"><dir name="Api"><dir name="Express"><file name="Nvp.php" hash="651c60d497003cb572dbb69a1eaffa17"/></dir><file name="Nvp.php" hash="4e46dc410d3afb2f18da008e45411d1d"/></dir><file name="Bml.php" hash="1e160b4ef8f118a09d8cb4263f96a01f"/><file name="Direct.php" hash="ccd3c98de05755972fb5d89fa806767a"/><dir name="Express"><file name="Checkout.php" hash="17089c92caeb7c8c6fd3059e0bd1a0a2"/><file name="Pro.php" hash="f0c3e779d8623d4f27706dda66decab4"/></dir><file name="Express.php" hash="7e5fa1857cb0696aa9297ceb0f6546ca"/><file name="Pro.php" hash="e8311225b0d975ef699328964807165f"/><file name="Session.php" hash="21a99ed402af561bbb41f6c62bc4ea3e"/></dir><dir name="controllers"><file name="BmlController.php" hash="7386a0d6715cc32a3f07888f3f42b0d3"/><file name="ExpressController.php" hash="a0e8d1669b5e48b3b038fc1cfd8d8b66"/></dir><dir name="etc"><file name="config.xml" hash="4a88d9c97e7fe9ed8ac729813eb02768"/></dir><dir name="sql"><dir name="paypaluk_setup"><file name="install-1.6.0.0.php" hash="778b39aed49df6932c24b93b90de5374"/><file name="mysql4-install-0.7.0.php" hash="04d22ff231e6052b2a7045ceed56e823"/></dir></dir></dir><dir name="Persistent"><dir name="Block"><dir name="Form"><file name="Remember.php" hash="6938ee73ae4b23175929291352627c1d"/></dir><dir name="Header"><file name="Additional.php" hash="fe21d5ba74ee87c8fd1f078820862459"/></dir></dir><dir name="Helper"><file name="Data.php" hash="74c064583b94e204e3d2a9ebb531e83a"/><file name="Session.php" hash="30ec18375b1721d96e419ba1ae51bfd6"/></dir><dir name="Model"><dir name="Observer"><file name="Session.php" hash="26f1f3914a611968042f33448b29493e"/></dir><file name="Observer.php" hash="9c8fc1d64e5475e7999c9adb951b9227"/><dir name="Persistent"><file name="Config.php" hash="97c699aab82390187319a99d6fd8d397"/></dir><dir name="Resource"><file name="Session.php" hash="73fee31ec3e22f4ef5fe35d8572a8086"/></dir><file name="Session.php" hash="f60ed020730dae8723e95b9a7c4f910e"/></dir><dir name="controllers"><file name="IndexController.php" hash="dbe7fb77826b94758eb83510a3f824d5"/></dir><dir name="etc"><file name="adminhtml.xml" hash="ee4a02d8045e01f972d7a819fcb534df"/><file name="config.xml" hash="1556d41acedff911c7eb7f7984bfdb0c"/><file name="persistent.xml" hash="3b9b7c3c2c765d6c999ce496a1712dce"/><file name="system.xml" hash="a551b1dbfd9b4932f1902233199f388e"/></dir><dir name="sql"><dir name="persistent_setup"><file name="install-1.0.0.0.php" hash="087ca130d306aa6b3ff8213a45f39dfc"/></dir></dir></dir><dir name="Poll"><dir name="Block"><file name="ActivePoll.php" hash="0efc7679648818186af612d4783d656d"/><file name="Poll.php" hash="27d6ea8ad7f802de02180374f9d25f6f"/></dir><dir name="Helper"><file name="Data.php" hash="9ace323d9bbe7107ecf78d55bf368f52"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="fcff690bfd2b25a997d966a3ad215d57"/></dir><file name="Answer.php" hash="5b008cec3bd71a09124ec5122d125a47"/><file name="Collection.php" hash="9abdf28422a7199aa63d51c5ac08b0b8"/><file name="Vote.php" hash="4cc3b62377628d468f70de60c7225838"/></dir><file name="Poll.php" hash="5af07cffe3ab1047d194a88db092bb35"/></dir><dir name="Poll"><file name="Answer.php" hash="9ee53f75ee1cb0730a56bab3ca65b051"/><file name="Vote.php" hash="bdde76ff3dc7fa32a2a34aba8bbf0cee"/></dir><file name="Poll.php" hash="04c789d42b6b6195e760d641869a5c9d"/><dir name="Resource"><dir name="Poll"><dir name="Answer"><file name="Collection.php" hash="ad2c1626fa1a4efb5b6b7cc8f8a87299"/></dir><file name="Answer.php" hash="d54f1545c087c996dc4cc8265935efec"/><file name="Collection.php" hash="1f92a6035921131de16b08c77f16a15d"/><file name="Vote.php" hash="3556ee4ac6bc5c48ec5b46ff3c229a13"/></dir><file name="Poll.php" hash="79cc676bf96e3eea566be1b271155ca1"/></dir></dir><dir name="controllers"><file name="VoteController.php" hash="75a4dc065025244db68fdde35dc27b23"/></dir><dir name="data"><dir name="poll_setup"><file name="data-install-1.6.0.0.php" hash="81bc077023380193b961ae812b755e28"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="bebf784876fa408411acba8347fd07c3"/><file name="config.xml" hash="fbe5e0b634f3890830c99d1e19571fa4"/><file name="system.xml" hash="fee2ec0817191ecc52699b6bef1cf5bc"/></dir><dir name="sql"><dir name="poll_setup"><file name="install-1.6.0.0.php" hash="517679e2f811306884b81b50f1ff9153"/><file name="mysql4-install-0.7.0.php" hash="e7e4bad7b4e74accd4ebb402f2d0aeed"/><file name="mysql4-upgrade-0.6.0-0.6.1.php" hash="58897150966041bfc0e59485b3f03712"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="61d60cfd460cf5bebd9937631fb99985"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0f5c35f33dc93513a5f795502a7256c3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="5d4d2334726cb8f948f6b9ed8ef48405"/></dir></dir></dir><dir name="ProductAlert"><dir name="Block"><dir name="Email"><file name="Abstract.php" hash="d4584e39cf64f1519770dc136c4ed161"/><file name="Price.php" hash="c696a8a63f39e8a52d2e79fdded85022"/><file name="Stock.php" hash="ca4bf9d8aa0e94555fe07717d143ad30"/></dir><file name="Price.php" hash="ebe9e1281e2bdabe74dfb394a0847220"/><dir name="Product"><file name="View.php" hash="eadba6f14baa5ec9809405b19c6df677"/></dir><file name="Stock.php" hash="9fbb5d57defc5b98978cff84db56b362"/></dir><dir name="Helper"><file name="Data.php" hash="41646f457da8ca144d27aaf0a6f92b6c"/></dir><dir name="Model"><file name="Email.php" hash="a9fb2a4d7235b1d68dfcd57b81cfe148"/><dir name="Mysql4"><dir name="Price"><file name="Collection.php" hash="88a48bedb0107bcd757e7aaac39a6f62"/><dir name="Customer"><file name="Collection.php" hash="5943e6821711e0e9e0266e0b415c467c"/></dir></dir><file name="Price.php" hash="a91bce1d6069a5c25e6dbcbd8f9bb8b2"/><dir name="Stock"><file name="Collection.php" hash="e2af3546fff475cde3bb9df4cc5e2578"/><dir name="Customer"><file name="Collection.php" hash="e11445992cd1db1bb3f4935d3c5794b5"/></dir></dir><file name="Stock.php" hash="eebeb5ce217c58b557f10eda30911313"/></dir><file name="Observer.php" hash="d1c3f4359a48e887c91ad80791f7db36"/><file name="Price.php" hash="c96bd123fb217872e6f24fb1414c710a"/><dir name="Resource"><file name="Abstract.php" hash="2544041fe5c5be4af7a084afdfdd228c"/><dir name="Price"><file name="Collection.php" hash="e3cc13eb4fac8731b1da5b82b3adc3b7"/><dir name="Customer"><file name="Collection.php" hash="30a328daac7a1dff800060817b47f299"/></dir></dir><file name="Price.php" hash="ecc8828fb2d20b0d4ab06861c987694a"/><dir name="Stock"><file name="Collection.php" hash="1c5d42dbe9c792490dd89928aca889e4"/><dir name="Customer"><file name="Collection.php" hash="f81d09b722478c8ea10f507bea29e889"/></dir></dir><file name="Stock.php" hash="db05538712e2f718318195ac5a4e69d3"/></dir><file name="Stock.php" hash="3f5bd3faf55a0978fe76958ea5592642"/></dir><dir name="controllers"><file name="AddController.php" hash="967cdb1b04d2c534c222232be1346613"/><file name="UnsubscribeController.php" hash="fd8b03509b6c9ca09ad802504c1994d8"/></dir><dir name="etc"><file name="config.xml" hash="8c76943b68ac296be813ba5fd7249c15"/><file name="system.xml" hash="8b462f95ac48ac5350d3aad9bb3b0324"/></dir><dir name="sql"><dir name="productalert_setup"><file name="install-1.6.0.0.php" hash="0241d37ef70e2a735100a50cd07164af"/><file name="mysql4-install-0.7.0.php" hash="1b86eaa23d5d830e157515c848c2bc66"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="1c2c5e094b3773c400177de03e13fdbd"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="18bbf5de2c4f24dcb6dbfff25ab9db8a"/></dir></dir></dir><dir name="Rating"><dir name="Block"><dir name="Entity"><file name="Detailed.php" hash="c337400133e34ad71b6857e4cb9dc7aa"/></dir></dir><dir name="Helper"><file name="Data.php" hash="aa08b748843d918a4f64801a34fb1155"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Rating"><file name="Collection.php" hash="bf5daff55dfd9638ad4068100e9f9801"/><file name="Entity.php" hash="2b8b613f66fb4f0d194530a2e041f90d"/><dir name="Option"><file name="Collection.php" hash="bc1d8b91473af46272fd5ad54d974072"/><dir name="Vote"><file name="Collection.php" hash="b7a023cb71d55d3bcb1ad4c4f71b1eb4"/></dir><file name="Vote.php" hash="88291cb4df65fb6305440350a1e1d569"/></dir><file name="Option.php" hash="e061db0760437a11256d92612ac599f9"/></dir><file name="Rating.php" hash="3b873eddd0c4d3f94274ba13c76f30bf"/></dir><file name="Observer.php" hash="2b1375aadc070ee4dc237b5ee0bbc626"/><dir name="Rating"><file name="Entity.php" hash="e92cb9b2f7d48d365bd58a2a579bb115"/><dir name="Option"><file name="Vote.php" hash="a7ee8de255dd46e91c1aa2d412cb4b22"/></dir><file name="Option.php" hash="c1b61fdc362c81d9a838b301a4307f47"/></dir><file name="Rating.php" hash="53a1e432211ada9a75b7b19016f8e154"/><dir name="Resource"><dir name="Rating"><file name="Collection.php" hash="f5d06f8dbc8a3f5bd10da9c6c6ba3fdc"/><file name="Entity.php" hash="5d7027e01a7c430c159064c74f957502"/><dir name="Option"><file name="Collection.php" hash="f9ac2b03c8abdc7b4728c500948923a9"/><dir name="Vote"><file name="Collection.php" hash="fde61681ae5f8d35e2f6777fb4303e77"/></dir><file name="Vote.php" hash="bf1e516fc97e7266a07cd0cf1f2ef398"/></dir><file name="Option.php" hash="c5072273eb4611d4c7f93873801433f5"/></dir><file name="Rating.php" hash="b67c23b781c0971d2a196d070923a466"/></dir></dir><dir name="data"><dir name="rating_setup"><file name="data-install-1.6.0.0.php" hash="12900433b5a26cbe769bde7ddc66f2e6"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="74579ad431dac104175d33ff02c10822"/><file name="config.xml" hash="2cdae0e1ff2a7e3a63dd7c42805fdb1d"/></dir><dir name="sql"><dir name="rating_setup"><file name="install-1.6.0.0.php" hash="b957611e9c176b0800c472f7d51a73e2"/><file name="mysql4-install-0.7.0.php" hash="a4263d1dacf3e8ea82371fc2aa00288d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="5b2fda173988176fc92e242667b48a76"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0903ea1ed5a6fc1a926dce7d7c0c3a34"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="221a4e86db85c68e5b5e7a3db40f59b3"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="366c0d1c4af6b53d486505665270ad7f"/></dir></dir></dir><dir name="Reports"><dir name="Block"><dir name="Product"><file name="Abstract.php" hash="9381d2f3817997e6b12bf6d1fb59a571"/><file name="Compared.php" hash="9401b0b87c2bcbbffafb8d27bf7160ac"/><file name="Viewed.php" hash="5cc5ea78c4dada735baa33fa470c99f3"/><dir name="Widget"><file name="Compared.php" hash="35b6e1c66895d7e5f972827daf8345cb"/><file name="Viewed.php" hash="e5ec75a90229bc827323e0101ddf1a99"/></dir></dir></dir><file name="Exception.php" hash="608a94b2ffadf371f1b5a92df71441fa"/><dir name="Helper"><file name="Data.php" hash="2808507ba066be921f54fade9f7f7360"/></dir><dir name="Model"><file name="Config.php" hash="8ac452add42e1efa4653842fb351bb06"/><dir name="Event"><file name="Observer.php" hash="38c5a6b2f62648efc5bd900c804f1131"/><file name="Type.php" hash="1bd1bee7108cdf48005b522da3b4e5c1"/></dir><file name="Event.php" hash="b1a4de5241ff78cd457fcfb25cf50b1b"/><file name="Flag.php" hash="74831f5918109873c14eb9bdcef76419"/><dir name="Grouped"><file name="Collection.php" hash="8adb854bcd467bca3afc6a932c61024f"/></dir><dir name="Mysql4"><dir name="Accounts"><file name="Collection.php" hash="6384e2c0b0d981921ec0b04178008278"/></dir><dir name="Coupons"><file name="Collection.php" hash="a8a142a4a3c3b6a34e8938b2cad17c6e"/></dir><dir name="Customer"><file name="Collection.php" hash="41d4be8a6c9daae9f5bb7dea2e4d3137"/><dir name="Orders"><file name="Collection.php" hash="99d08265d68e69bdb7eec18c65fa6ea5"/></dir><dir name="Totals"><file name="Collection.php" hash="e2440c39383c54276dc5122651ece92d"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="10850a1bb4d3106d61a97c35f3e72b35"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="f5a8b4cd57f1cad485ad148902e74a34"/><dir name="Type"><file name="Collection.php" hash="52b034d02ac4fee39387ebf6afa30a16"/></dir><file name="Type.php" hash="4e168e5eb91c2357424e1c59ba48db6f"/></dir><file name="Event.php" hash="f8485c5e772ce4820d914a2d430c598c"/><dir name="Invoiced"><file name="Collection.php" hash="b55329ae04cba3ecc78633ae1666624b"/></dir><dir name="Order"><file name="Collection.php" hash="7c9906ac0c28aca240db23a70d7aaf14"/></dir><dir name="Product"><file name="Collection.php" hash="5e2511ee63229e9c481701d3e8ea81bd"/><dir name="Downloads"><file name="Collection.php" hash="a7a59e694fdd839bd5e7c95f1034ed6d"/></dir><dir name="Index"><file name="Abstract.php" hash="8351ce388ded1083578edd5b61697b30"/><dir name="Collection"><file name="Abstract.php" hash="ec2f7042e58fe0d135e2fc22880006ea"/></dir><dir name="Compared"><file name="Collection.php" hash="95153672ccc9044236c7220e3805f864"/></dir><file name="Compared.php" hash="f9a0ab36e1d389b869057426ce5757a6"/><dir name="Viewed"><file name="Collection.php" hash="f84f3c7fb46a5976a1e676355efd41f8"/></dir><file name="Viewed.php" hash="ee216881da4db2c3e0578768749240b3"/></dir><dir name="Lowstock"><file name="Collection.php" hash="129cda12e29ee74730dcd9f00f280309"/></dir><dir name="Ordered"><file name="Collection.php" hash="8a04b617e9c1a99aa5e632044079f1f8"/></dir><dir name="Sold"><file name="Collection.php" hash="2423be35980f9f6ee1684a6c52862a83"/></dir><dir name="Viewed"><file name="Collection.php" hash="7a65fa98452f67e8ead531b27c4ec7c7"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="4f412c1b59c80f980c2758b04800aaa9"/></dir><dir name="Refunded"><file name="Collection.php" hash="272cc7c309b60ced27a8bf05e4732a21"/></dir><dir name="Report"><file name="Abstract.php" hash="9074336e20298296f48160e7d4e7f88c"/><file name="Collection.php" hash="5981974079e5479aa0eb59977617bdb8"/></dir><dir name="Review"><file name="Collection.php" hash="b19a21cd5373bd77b4508236fc175a63"/><dir name="Customer"><file name="Collection.php" hash="9c7cced8de4d055915d4d94bd5a86571"/></dir><dir name="Product"><file name="Collection.php" hash="b84410ab5000133b9bf3b9e819993641"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="5bc46c5198f98b78d50da2387c58b368"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="5d45215574659235c1e54b01fffec62c"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="7df40ab2b4df1591c691e1eee5ffafb1"/><dir name="Customer"><file name="Collection.php" hash="08398ac0f332002c23d326ec580e2a05"/></dir><dir name="Product"><file name="Collection.php" hash="911eb9cc4fe1c260a1cb6c2b8f6d1623"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="667d111f18687a46988da9b17290c929"/></dir><dir name="Wishlist"><file name="Collection.php" hash="8e57527ad0cf1166cc7e4559a67ab727"/><dir name="Product"><file name="Collection.php" hash="de66493523d35c12fcd0a3ba31a652b6"/></dir></dir></dir><dir name="Product"><dir name="Index"><file name="Abstract.php" hash="354eaa0207964474411899338d9b9585"/><file name="Compared.php" hash="019eb677e0a89b1770cdb5c077330c7d"/><file name="Viewed.php" hash="9095d81fcc6cc892cb67709beac5aeb3"/></dir></dir><file name="Report.php" hash="f5dc6494cff99fb052875b882b702fb5"/><dir name="Resource"><dir name="Accounts"><file name="Collection.php" hash="ac257f532f927cc28943690e7fc8ba6a"/></dir><dir name="Coupons"><file name="Collection.php" hash="5abde4f7b922579e593b868d76c4ca5b"/></dir><dir name="Customer"><file name="Collection.php" hash="ba5e14a4cf75c59ed5baf2099fa2f1d2"/><dir name="Orders"><file name="Collection.php" hash="60dd7f21909c02a2bc1c8d60c6cbf481"/></dir><dir name="Totals"><file name="Collection.php" hash="b91fbcadb349f8762f45a9f8a53547e2"/></dir></dir><dir name="Entity"><dir name="Summary"><dir name="Collection"><file name="Abstract.php" hash="1136c8a67e6a1057b17476d0c7d85966"/></dir></dir></dir><dir name="Event"><file name="Collection.php" hash="ac353d066d90d4c6f25f2e8770e9247d"/><dir name="Type"><file name="Collection.php" hash="8382b58a7462573c16432e0445d76d4b"/></dir><file name="Type.php" hash="3cbccf5eab8cde3bbda74004cefcc618"/></dir><file name="Event.php" hash="0a692a6a09ffc5fdb317d2cff1385291"/><dir name="Helper"><file name="Interface.php" hash="eb1b4518956d271e57dfca77652960ee"/><file name="Mysql4.php" hash="45f718471263a3d85b823488046944ed"/></dir><dir name="Invoiced"><file name="Collection.php" hash="5e7bf13e329243d88d2ce5572eb7f43c"/></dir><dir name="Order"><file name="Collection.php" hash="c961a023b52f2fc6ea28ff161bbe0967"/></dir><dir name="Product"><file name="Collection.php" hash="ed3780d956f83154f218e62970414c4e"/><dir name="Downloads"><file name="Collection.php" hash="641329ba2982601f084b07b8693b2871"/></dir><dir name="Index"><file name="Abstract.php" hash="88e2dc2b27500d435b8e22280943efd1"/><dir name="Collection"><file name="Abstract.php" hash="71630411364a2552ac383b63e0fbf831"/></dir><dir name="Compared"><file name="Collection.php" hash="696b12dd05e1f0d23a7e3a75949ce668"/></dir><file name="Compared.php" hash="f5dbc6ea9aa23b8fac130be6bacc2ee4"/><dir name="Viewed"><file name="Collection.php" hash="636cf44005f888d8bb62b07f9eb6e370"/></dir><file name="Viewed.php" hash="95171e2b6d01fa477231c9f427307ccd"/></dir><dir name="Lowstock"><file name="Collection.php" hash="8e1d09a3d67337acb37305948a37f7ae"/></dir><dir name="Ordered"><file name="Collection.php" hash="9efdf0700de6cab7243a7a88c20a1559"/></dir><dir name="Sold"><file name="Collection.php" hash="5e3d829af728da0bde83e50d9b581dcc"/></dir><dir name="Viewed"><file name="Collection.php" hash="481d4fa98830ab3f42cee09a2c9aaee0"/></dir></dir><dir name="Quote"><file name="Collection.php" hash="9f3b12f7d20632fbd52dcc33ba37a467"/></dir><dir name="Refunded"><file name="Collection.php" hash="66e1f3f5767dbe8833f3e15d3636468e"/></dir><dir name="Report"><file name="Abstract.php" hash="d67e66718893814b9659b0e9ea8b3e6a"/><dir name="Collection"><file name="Abstract.php" hash="f604fff5aca66711811461d9824fc1e0"/></dir><file name="Collection.php" hash="5fcde9791b16799d130e54ac1819dcb0"/><dir name="Product"><dir name="Viewed"><file name="Collection.php" hash="09cd77b4152936ffb6c807f786207077"/></dir><file name="Viewed.php" hash="99cffde7efbb7cfd449505f83b843b06"/></dir></dir><dir name="Review"><file name="Collection.php" hash="da8c3edf5aed4c1cf2bc5109ec3f1ec5"/><dir name="Customer"><file name="Collection.php" hash="2839e9b309c2750b569d64b872e02dcb"/></dir><dir name="Product"><file name="Collection.php" hash="9edc35ef7f987d4fcc89a88ed501e5bb"/></dir></dir><dir name="Shipping"><file name="Collection.php" hash="17cb03c7cc5109b4a6f99610a60dbb22"/></dir><dir name="Shopcart"><dir name="Product"><file name="Collection.php" hash="44dcf5437f060c0ed58efaba9d16d665"/></dir></dir><dir name="Tag"><file name="Collection.php" hash="cfd6e0454369ff72e419bc232ac3dedf"/><dir name="Customer"><file name="Collection.php" hash="11d7ae7f503e1272fd80face588c543d"/></dir><dir name="Product"><file name="Collection.php" hash="6f2a8754391eac9cd12f0510bccb0853"/></dir></dir><dir name="Tax"><file name="Collection.php" hash="34cf644c296e126f26d20ee0d86e3520"/></dir><dir name="Wishlist"><file name="Collection.php" hash="3389d8396885176702e0b5ac2bef8de1"/><dir name="Product"><file name="Collection.php" hash="965402449bb92e67c3addcec8b2dda62"/></dir></dir></dir><file name="Session.php" hash="c318347dd17ef625e851fe821f59a037"/><file name="Test.php" hash="1c65ee41eff9c26a65ba571d1036282c"/><file name="Totals.php" hash="9a52631051f75ea9436b42febf8c5373"/></dir><dir name="data"><dir name="reports_setup"><file name="data-install-1.6.0.0.php" hash="5d87abb48aedfc1019383ba77ae9d424"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="ade02826599b06c791beb38e752a0a54"/><file name="config.xml" hash="50bc806c9348a42d1413533d68ec4ccf"/><file name="system.xml" hash="2404876dca1c4a1dbc45ea99d0e143aa"/><file name="widget.xml" hash="87134e1fe691d2bf377ef3159e043329"/></dir><dir name="sql"><dir name="reports_setup"><file name="install-1.6.0.0.php" hash="dc8d574c567ff98a0c27768b2f721342"/><file name="mysql4-install-0.7.1.php" hash="6058a42394e2a6d1f3884d08b01d036a"/><file name="mysql4-install-1.5.0.0.php" hash="ad670ce1011e84d3027a29458499603b"/><file name="mysql4-install-1.6.0.0.php" hash="08c55d04a829df9b1bfced10dd7abdb6"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="ed4fa0f6004262fe49db95861e721c06"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="16440bfbbc893acaa2ff39192c639690"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="e4d91582c78cf488b6762b8c02452319"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="085cc5b0cffb7c3ae5bd087648ad519b"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="47e81be68ed4a18b2a6f72c18dca7d5e"/><file name="mysql4-upgrade-0.7.5-0.7.7.php" hash="e056f1c250f5a831587539c10b533f80"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="8edf4a8b3eb12800e15c7f829747267c"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="2a2af08d7a93fec5d949c9fe52d69fcc"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="beb5107a2beb2b4f8c23495b4751fbdf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="020dd3cc9ea0a3a47db93fef4bc2cf78"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="989fba539a23d744efe24bf3bbe1f704"/></dir></dir></dir><dir name="Review"><dir name="Block"><dir name="Customer"><file name="List.php" hash="75258599abbf2981862edf563aa80e24"/><file name="Recent.php" hash="1a913d3169511e51882470cd0d5c8853"/><file name="View.php" hash="24b8876f7614500ceee5695de6c0171e"/></dir><file name="Form.php" hash="578aa1bb652f5a4cc1acbbd3dbc8bf67"/><file name="Helper.php" hash="e0f2826aba59b1fadc3a3e98cbb45db2"/><dir name="Product"><dir name="View"><file name="List.php" hash="a1ef1ac325677b79f7bff957e3940867"/></dir><file name="View.php" hash="47e6c007eb6e024c888289c9350420c9"/></dir><file name="View.php" hash="c2c3227084a3c4d5dd1a380b926d2582"/></dir><dir name="Helper"><file name="Data.php" hash="cde72b775603ee4b6d144baf55d4d0b2"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Review"><file name="Collection.php" hash="36e926d673bcce527ab001ef75ac6d59"/><dir name="Product"><file name="Collection.php" hash="c57f813e17f672eab2bf5f4f33157b3e"/></dir><dir name="Status"><file name="Collection.php" hash="d79e8912b6077609e6bcd7f939c40c70"/></dir><dir name="Summary"><file name="Collection.php" hash="712e89eda07241326bd73eba5cfce3ee"/></dir><file name="Summary.php" hash="a19372cb153ef832ec65c799f30f8fd5"/></dir><file name="Review.php" hash="be633fb27d76ae1805b218e8e2dfa4f7"/></dir><file name="Observer.php" hash="f2fb97c8b99a01000322c87e8b506209"/><dir name="Resource"><dir name="Review"><file name="Collection.php" hash="f187a2386bace27e55ea8caf311b9f6e"/><dir name="Product"><file name="Collection.php" hash="12961346f71a630ecfefd64f7e6eeae5"/></dir><dir name="Status"><file name="Collection.php" hash="dd5a3e9a6e99ecb95d9946a1a161b46e"/></dir><file name="Status.php" hash="62b11d858f207ba1b81fbf9a86e47d7f"/><dir name="Summary"><file name="Collection.php" hash="292ec5a712b7f3bbcce63a8d8a0de40e"/></dir><file name="Summary.php" hash="2f46abb517f3f4b4c9a72f0055827bbb"/></dir><file name="Review.php" hash="b1432744f6df1fd38df903080602cc44"/></dir><dir name="Review"><file name="Status.php" hash="bfa530e158e2a41abad88448a5cfa75d"/><file name="Summary.php" hash="195a6570b452f499010b89aa29f43117"/></dir><file name="Review.php" hash="32401cc14dc04763601bca8aef509241"/><file name="Session.php" hash="f53a5a0528a2d93ac879b4a0a43e626f"/></dir><dir name="controllers"><file name="CustomerController.php" hash="8ad4aae4ebf43ba61a20be80c3ba971c"/><file name="ProductController.php" hash="944b7de015c7b693aa633a0967ac8012"/></dir><dir name="data"><dir name="review_setup"><file name="data-install-1.6.0.0.php" hash="36aae8d61319eef243cd891db00a91e2"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="643914e5212e3f7fa45185b5261eb6a8"/><file name="config.xml" hash="748472a893d4fb83fb1a1f327342607a"/><file name="system.xml" hash="a45dcfcb2a455add5f1204551109a3c6"/></dir><dir name="sql"><dir name="review_setup"><file name="install-1.6.0.0.php" hash="9bffc27b2df8f5d8b31da8b1130b659f"/><file name="mysql4-install-0.7.0.php" hash="63f50ba59bcd3126e2035b564c148fde"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="345e05077ab1f31240cbd2a97ed65c02"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="4aa3caf337afd47178a7723f7c7c1417"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="4cf527e131117f1b4cecf3c8d4101744"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="dc9e6a7b04391d3aff8b1d0e9a8d2e96"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="7260cb9368214b9ec23e6cef126978d7"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="324a8629ce44e1630819999498b198af"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="897902ad56188bb2119eb082e64f5465"/></dir></dir></dir><dir name="Rss"><dir name="Block"><file name="Abstract.php" hash="78b1e316fa251bd9072e370c69671bab"/><dir name="Catalog"><file name="Abstract.php" hash="0c04f1d3b359467765db675efbdb8db5"/><file name="Category.php" hash="639e02c0987dcae62f5767bf19014764"/><file name="New.php" hash="cc0b203243fa96d7205287276722dac4"/><file name="NotifyStock.php" hash="6dec5508cce929a912eb1d62784894fd"/><file name="Review.php" hash="a2d3ec4e7237a7ea9bff9543439e6b0d"/><file name="Salesrule.php" hash="935c030eb4e0e7e78ed606f3c4762154"/><file name="Special.php" hash="2ad46b236308cf322ea230c2dad2cdcb"/><file name="Tag.php" hash="1569866597c7998a8df5795c4655654a"/></dir><file name="List.php" hash="4cfbf0ecee48a0b3aea463e087f98522"/><dir name="Order"><file name="Details.php" hash="2ad732aa559d4378096c344e45ac8739"/><file name="New.php" hash="236c63a10c0b4fa74b3b93d89c0e58d1"/><file name="Status.php" hash="814d72fab5555894ec00e4233731249a"/></dir><file name="Wishlist.php" hash="0e41bb7a1d52eb4b292267ada80d1a85"/></dir><dir name="Controller"><file name="Abstract.php" hash="800fef71c54dbaa4ee5d14def6ad374c"/></dir><dir name="Helper"><file name="Catalog.php" hash="72b3e51589b9a45c4b79624e2e9e63a8"/><file name="Data.php" hash="784c8bbf33cb18724bb2e89376a6d3f9"/><file name="Order.php" hash="db4a311a8a8e449e551dfef72d49bb19"/></dir><dir name="Model"><dir name="Mysql4"><file name="Order.php" hash="a714c74aa9b2b08eaa25025ed8bae861"/></dir><file name="Observer.php" hash="91f50bed4e811ba74dfe1b6706fe88c5"/><dir name="Resource"><file name="Order.php" hash="06e83d676c21c78a978c5204eb299999"/></dir><file name="Rss.php" hash="b82ec9f4706f3cd88e47d44c69148107"/><file name="Session.php" hash="88190872a65a7b8cc6c0f97b87117fe1"/><dir name="System"><dir name="Config"><dir name="Backend"><file name="Links.php" hash="77af8de35a234eca3f85eb3eab1c74c3"/></dir></dir></dir></dir><dir name="controllers"><file name="CatalogController.php" hash="b0f5ff39a3ea319af8f1cb7dc72c64f5"/><file name="IndexController.php" hash="4aa833fe228b6f1347f0f03c3b0e3968"/><file name="OrderController.php" hash="4a78ace5090f6e43da34a47bde93f05a"/></dir><dir name="data"><dir name="rss_setup"><file name="data-install-1.6.0.0.php" hash="4a3e745f2b06780b810168f41e465fbb"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="719cc211ae152410041b215441302c96"/><file name="config.xml" hash="670a8d9348a1b9e5b5507713df1d8c87"/><file name="system.xml" hash="9992a900459d27147cb07a3617340659"/></dir></dir><dir name="Rule"><dir name="Block"><file name="Actions.php" hash="6610fb70932429b38248d2a2cb64833c"/><file name="Conditions.php" hash="ce8574b771220536f394089ee2beb6f6"/><file name="Editable.php" hash="cde8b6b2ba9a6d446813f5add9d50ec9"/><file name="Newchild.php" hash="d7c60ffcfac3a6019e08d30ef1d513dc"/><file name="Rule.php" hash="051685923b2392615c1594414c87fc98"/></dir><dir name="Helper"><file name="Data.php" hash="805f12fa0f9b45188625c45b682d0059"/></dir><dir name="Model"><file name="Abstract.php" hash="15333fa84757f9392b98ed5c0bd8cd8f"/><dir name="Action"><file name="Abstract.php" hash="337ba9c8479e1f8608137d0d4406c947"/><file name="Collection.php" hash="8373977869aae94fed30607913586599"/><file name="Interface.php" hash="a303f317f385252e6e394e99d4bb35c1"/></dir><dir name="Condition"><file name="Abstract.php" hash="1f683530e9348e26a9413f9bbb978b3e"/><file name="Combine.php" hash="c12fe8c3c64a58eedf81c9c9d54e0546"/><file name="Interface.php" hash="4e255c250a249f3c71fd5e0ad51fdce7"/><dir name="Product"><file name="Abstract.php" hash="befc50797a7c2ffa464a389cde6208a1"/></dir></dir><file name="Environment.php" hash="e01cb8bcbed1e56dcc51a42c9c15a5bc"/><dir name="Mysql4"><dir name="Rule"><file name="Collection.php" hash="c62062f2104b04e8f42da83bdd7fb630"/></dir><file name="Rule.php" hash="923f75b95afee693b39d8024acdef931"/></dir><dir name="Renderer"><file name="Actions.php" hash="cd8b6ec25840af7dac2ba99414c4a93c"/><file name="Conditions.php" hash="ca49f7b765b420cd490f2219cf8fb602"/></dir><dir name="Resource"><file name="Abstract.php" hash="d412ec94e493e31b0d052686f9fc5741"/><dir name="Rule"><dir name="Collection"><file name="Abstract.php" hash="aaa0a5c1b5db55160f9b6d78b3bfa45f"/></dir><file name="Collection.php" hash="69a1dbbf809f3a956c60006688ef46e7"/><dir name="Condition"><file name="SqlBuilder.php" hash="2bfce51eaf1077c49eb14b010e72607a"/></dir></dir><file name="Rule.php" hash="60161377f1ba79604a8385ade41b5ec7"/></dir><file name="Rule.php" hash="ee5ca4e39044fac00f020c1850c88e16"/></dir><dir name="etc"><file name="config.xml" hash="0308eb30269e8277974478f8b6f8801a"/></dir></dir><dir name="Sales"><dir name="Block"><dir name="Adminhtml"><dir name="Billing"><dir name="Agreement"><file name="Grid.php" hash="fef66ee16f00b29c84027c10aba81a52"/><dir name="View"><file name="Form.php" hash="1a86a3173f4d954b0c585a03f1f8a041"/><dir name="Tab"><file name="Info.php" hash="7dcce2f205c6f2da7a2383bed74760ed"/><file name="Orders.php" hash="9da38e7f7d07a4a8c6613924f8ed209f"/></dir><file name="Tabs.php" hash="bf8f53c4af65b488ec7d1b248088609f"/></dir><file name="View.php" hash="b8bf13cce32b6e719c7f87843f7a2a7b"/></dir><file name="Agreement.php" hash="4083da4fe5031bb1d0b8287912e1c82a"/></dir><dir name="Customer"><dir name="Edit"><dir name="Tab"><file name="Agreement.php" hash="a65e2d4a78d1006988d708b34d8cdad0"/><dir name="Recurring"><file name="Profile.php" hash="78ef77388e6c8ffc9bea8bd47a87d57d"/></dir></dir></dir></dir><dir name="Recurring"><dir name="Profile"><dir name="Edit"><file name="Form.php" hash="9279e2d6dbae446d2cb949f773a88211"/></dir><file name="Grid.php" hash="0d32af9ab885a9df05ac6f5eb6f339b2"/><dir name="View"><file name="Getawayinfo.php" hash="b9f496477acceadfd22adf5639854e57"/><file name="Info.php" hash="c525974a9aa0487e294eabca4f5b4113"/><file name="Items.php" hash="d0a4335bf5e22e83a1c75d59d100de86"/><dir name="Tab"><file name="Info.php" hash="4e895b956b76697afe0721b8f7c4e8ea"/><file name="Orders.php" hash="e1f95a70f025194e0d550daa520a8f14"/></dir></dir><file name="View.php" hash="b307b50baa307fc74e0f4b6c8a3219e7"/></dir><file name="Profile.php" hash="95f367babe1d664f0d6bac9fb07b7df0"/></dir><dir name="Report"><dir name="Filter"><dir name="Form"><file name="Coupon.php" hash="42d5d95abc0c3fe1817253a86e0c013c"/><file name="Order.php" hash="f4177c41f2f0d34a4124ae04fc91e619"/></dir><file name="Form.php" hash="b9b8ac502065c6f95a7a6b155284319e"/></dir></dir></dir><dir name="Billing"><dir name="Agreement"><file name="View.php" hash="34806b08430353c0c752c67573239728"/></dir><file name="Agreements.php" hash="149bc6329618f80fa1c82f614abc8fa3"/></dir><dir name="Guest"><file name="Links.php" hash="fbf86ecd7a9c3faf3e238a15b364cadf"/></dir><dir name="Items"><file name="Abstract.php" hash="6423bc55cc7e7c5aaeac666743f81b42"/></dir><dir name="Order"><file name="Comments.php" hash="a033815154ae896efc6e6947a109ff6c"/><dir name="Creditmemo"><file name="Items.php" hash="d9409c330900ac3fd50a6e0b6573d8a9"/><file name="Totals.php" hash="f97a4c171b571bbf4c999d07d29fd716"/></dir><file name="Creditmemo.php" hash="33b366b6894ecaf805a021c97a7ddba1"/><file name="Details.php" hash="9e117a5f8963fc689bfd34f6fbc57390"/><dir name="Email"><dir name="Creditmemo"><file name="Items.php" hash="c3abe3d0f0bafbc0f8a02167f60315aa"/></dir><dir name="Invoice"><file name="Items.php" hash="f122cb0a8c0909415883094ebaa76d1f"/></dir><dir name="Items"><file name="Default.php" hash="393e76596db55f0cab3db8622df19464"/><dir name="Order"><file name="Default.php" hash="d71a2b453dfd0f288694fb7a35610ad1"/><file name="Grouped.php" hash="7d18cecbcee39d9fd29befc8cc10ff12"/></dir></dir><file name="Items.php" hash="7b721ab6a462b662304b8d79e077df6c"/><dir name="Shipment"><file name="Items.php" hash="ec02e251e375e75f899d517a22aa44a8"/></dir></dir><file name="History.php" hash="174769627458bd9e71f9d8318c77a4cb"/><dir name="Info"><file name="Buttons.php" hash="04c841c1f16a53a09c6fe0b7ee4c495d"/></dir><file name="Info.php" hash="f48808e8c857b62578d75666964f59bd"/><dir name="Invoice"><file name="Items.php" hash="e836090b717d386e2938652a690d410a"/><file name="Totals.php" hash="585c8b5346a6a881f651ae2c85d960cc"/></dir><file name="Invoice.php" hash="061c0fad24390ee4fab4531721196b6e"/><dir name="Item"><dir name="Renderer"><file name="Default.php" hash="cbdc1858cc4c72c35f1fb6d3b0306f84"/><file name="Grouped.php" hash="7934d30462776f4eaa056cbb59f42559"/></dir></dir><file name="Items.php" hash="6f0636e12a64c5212f26f928711046e0"/><dir name="Print"><file name="Creditmemo.php" hash="02f0f0fa58e7441e59944ebb88264719"/><file name="Invoice.php" hash="e54128f7afc117787aa623a4d0b8af00"/><file name="Shipment.php" hash="35380109c64056fbe0ecc004a103d579"/></dir><file name="Print.php" hash="878669c71c801bd08cb288fbff97c93a"/><file name="Recent.php" hash="33fca43621bc85a175f50ba238c73376"/><dir name="Shipment"><file name="Items.php" hash="622048f99d9f7e266737d3ff52227de2"/></dir><file name="Shipment.php" hash="f77ffdd6745c19c233da4c733c5d3abb"/><file name="Tax.php" hash="16083f37a2591b8f488f5ae3a9cc3a1b"/><file name="Totals.php" hash="03225737c81193a65bb8580e81f3e847"/><file name="View.php" hash="850fd65e3a39b1876100de48ea2541a2"/></dir><dir name="Payment"><dir name="Form"><dir name="Billing"><file name="Agreement.php" hash="cd0b1ff96a419f14dcd7b0ff321724d3"/></dir></dir><dir name="Info"><dir name="Billing"><file name="Agreement.php" hash="3214efb275f83c788f5efc31b582ebaf"/></dir></dir></dir><dir name="Recurring"><dir name="Profile"><file name="View.php" hash="6b22675cfefa43d6f1733648b7985630"/></dir><file name="Profiles.php" hash="3ad863e0afda8cf52abb65bd0db1d5d3"/></dir><dir name="Reorder"><file name="Sidebar.php" hash="46a27506c5829e0542ee45aab3ca0672"/></dir><dir name="Widget"><dir name="Guest"><file name="Form.php" hash="c2967b98e93ab61a7a094d7b5284c078"/></dir></dir></dir><dir name="Controller"><file name="Abstract.php" hash="1f0ffd7a63f093d9164432d5d6b24a7b"/></dir><file name="Exception.php" hash="b2c312840dbc62b8dbc7723b3c7a42b1"/><dir name="Helper"><file name="Data.php" hash="1004e1652fa50e93a21e8a58823141e0"/><file name="Guest.php" hash="d35fedc9902ec64bbba80052187f48a6"/><file name="Reorder.php" hash="7092ac100d733a48a6b2c3a68cbb7cce"/></dir><dir name="Model"><file name="Abstract.php" hash="07efb83eb2281c9abadc549f84df6c56"/><dir name="Api"><file name="Resource.php" hash="6bdd0361747d25ca846832c96a749eef"/></dir><dir name="Api2"><dir name="Order"><dir name="Address"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="8f1aba6fae933a2b4bd6e3bd4f6c5389"/></dir><dir name="Customer"><file name="V1.php" hash="efad7a521ba151226ef438fe30405d6e"/></dir></dir><file name="Rest.php" hash="54c33502d2bfec77aa5735f0e8f23a5b"/></dir><file name="Address.php" hash="51702d27c5eefb9219ae08303b7f98fe"/><dir name="Comment"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="f2c0511ff538c27f5eab792c05792759"/></dir><dir name="Customer"><file name="V1.php" hash="73f856dcdaf15db656a80b533bcf0b4f"/></dir></dir><file name="Rest.php" hash="e2baaffd28d5ee0ea25418b0a7375387"/></dir><file name="Comment.php" hash="6c2b51994d77f1dbba28592e393c131b"/><dir name="Item"><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="fdb4f6c87f633b80e9a733503209041e"/></dir><dir name="Customer"><file name="V1.php" hash="f6bec0def4d992e1207aca7dfc267912"/></dir></dir><file name="Rest.php" hash="4d34daf2e2f0fa6a6685f1e0083d70e3"/></dir><file name="Item.php" hash="989a4f2e3ce1cee2666bc91894ed4c71"/><dir name="Rest"><dir name="Admin"><file name="V1.php" hash="080cbf5d63dfdb0fa74615ccf9f16c46"/></dir><dir name="Customer"><file name="V1.php" hash="ca9b754da5e11e2ab7449d2a8bdc8e00"/></dir></dir><file name="Rest.php" hash="b129022f37d1dfbe3fd34e17de97ca3a"/></dir><file name="Order.php" hash="bf8448d9cbd2b1ae4dc776d05f91e73c"/></dir><dir name="Billing"><file name="Agreement.php" hash="dc3110bfcd5aa6a10ff5881d7fbb670b"/></dir><dir name="Config"><file name="Ordered.php" hash="39b93b978aa3db28068ef8ddd33fd1a5"/></dir><file name="Config.php" hash="648e93992a3d7a83147332be1b3e86ba"/><dir name="Convert"><file name="Order.php" hash="bc2f1e45d6a5b02c7617f1fb23901297"/><file name="Quote.php" hash="0d299e87306356a2936c72e313055969"/></dir><dir name="Email"><file name="Template.php" hash="282e7d7486a63eeedc56d213e17294bb"/></dir><dir name="Entity"><dir name="Order"><dir name="Address"><file name="Collection.php" hash="1f912f0f6afaf7f0c97388eb817dcf99"/></dir><file name="Address.php" hash="6c7dc37688bcb3543ed7fb51e60f08b7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="861bfe37e0e2a3e8d397a7fef2b79e60"/><file name="Child.php" hash="32e2e2f27bfa2d6228a5e5ea52e95a0d"/><file name="Parent.php" hash="d0c59f53b0fd3b31019c4880bef0236c"/><file name="Shipping.php" hash="174751e68b10d15292fd4781ef2b9b2b"/></dir></dir><file name="Collection.php" hash="2837a7f5177feee8ed29c2752cf661b8"/><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="9f781f34dd65a08fc2cc0393b8cf828e"/><file name="Parent.php" hash="7e56c2cb6ee40e91311fde8c75a72802"/></dir></dir><file name="Collection.php" hash="a320322759710dfe01b2a22fd79bc860"/><dir name="Comment"><file name="Collection.php" hash="c98f05f953d0bfb92abe7c48fd1c0706"/></dir><file name="Comment.php" hash="cf31a5278f7ae28cb40396279456d781"/><dir name="Item"><file name="Collection.php" hash="31cc31022439310311152f81706d8b06"/></dir><file name="Item.php" hash="44b44e47e85ac4defbce067f2a5efbbc"/></dir><file name="Creditmemo.php" hash="fa9d7d9e5a182aaf5be33f57ffa96fb9"/><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="17d2f6acddf70955340cd16ca123f790"/><file name="Item.php" hash="350b2e92d565e1ca8f136341f9dd13e4"/><file name="Order.php" hash="71b4e11cd8ce30f4e849daf82bda36f9"/><file name="Parent.php" hash="17014ef1c8c55460d585792240589b30"/></dir></dir><file name="Collection.php" hash="e4fd5d1f010a81a38d0f69e1e69999e9"/><dir name="Comment"><file name="Collection.php" hash="39bf207a29d25f4026cf562e32514eb7"/></dir><file name="Comment.php" hash="6c0a8c3af07163bbc67f1e455fa2e795"/><dir name="Item"><file name="Collection.php" hash="6fb21806efade3609d74ac362340e202"/></dir><file name="Item.php" hash="af4e2b636b26ad8552e9a39e7bb14ff2"/></dir><file name="Invoice.php" hash="9244fb3d79789b51056af4ca334bdd27"/><dir name="Item"><file name="Collection.php" hash="d0f1974f5df6d4d4ad8118a7a4a33331"/></dir><file name="Item.php" hash="ebfb18aa744fb65cd0bb4bcbcd3b0159"/><dir name="Payment"><file name="Collection.php" hash="f86601c550633f0b86184558fa65edb8"/></dir><file name="Payment.php" hash="017b137b936fff5560dc52ff7be4db19"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="485af88c697482dfdeb660fba19aba1d"/><file name="Parent.php" hash="0d5463f462b0d95c35de762516ec8d71"/></dir></dir><file name="Collection.php" hash="de45615f732677a52bfd52c37cb6303d"/><dir name="Comment"><file name="Collection.php" hash="95845b75c54ea2360803a22bf1547511"/></dir><file name="Comment.php" hash="7f635292f8d94b496d5d9a924e679797"/><dir name="Item"><file name="Collection.php" hash="ea423b588ed1cf35b7893260d85e5010"/></dir><file name="Item.php" hash="3400a881edb8ddbc6392fa8c4a2f31af"/><dir name="Track"><file name="Collection.php" hash="79151ee6ffe9fe4fa66036d1d549db63"/></dir><file name="Track.php" hash="cf89f156c74844a3fc5becf420270301"/></dir><file name="Shipment.php" hash="522f8dc832513471f7f187053e1d1faa"/><dir name="Status"><dir name="History"><file name="Collection.php" hash="9d3587f093d4f5f985571df4115ed8d6"/></dir><file name="History.php" hash="574b5234e98cdf2dd6c887956169efd7"/></dir></dir><file name="Order.php" hash="ab0a6a94a06aad7663068783775ea885"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="8a7d48caa3ebfe50e244016ffa8f6d51"/><file name="Parent.php" hash="c1b6a8ce250c28503037d446ebeb675f"/><file name="Region.php" hash="00e741ec4cc5a131e1227c87de3ba781"/></dir><file name="Backend.php" hash="47a248dade8bfaafa1aa8d9613c6c7b3"/><dir name="Frontend"><file name="Custbalance.php" hash="da8e0105b25c2db53884eabf680e51c5"/><file name="Discount.php" hash="461fc93850f71621932c0ace20c42c1c"/><file name="Grand.php" hash="5f1bb2676fed3d05e45b524fa331473e"/><file name="Shipping.php" hash="7dfb3b96b2fff10b016e6e38d84bd3ef"/><file name="Subtotal.php" hash="f6dec9c5f5033e17b497aa4d7403827b"/><file name="Tax.php" hash="e97883a76f504a91e3b2e25ac589c916"/></dir><file name="Frontend.php" hash="68416b77686a2cbaa742dafc35b97c6b"/></dir><file name="Collection.php" hash="0d1effb4746b5ef2731f8a3db77591d8"/><dir name="Item"><file name="Collection.php" hash="2b23c9b0fa7bc8a568ac10873fe644ea"/></dir><file name="Item.php" hash="3a359de393d4a2481eefad5ec951a6fe"/><dir name="Rate"><file name="Collection.php" hash="0a9e1a909e6dedf3fd011711ceeb6819"/></dir><file name="Rate.php" hash="d98592762b0bb5dbd074438cdf274e4b"/></dir><file name="Address.php" hash="6c57625623ba17c72f936dafcf354542"/><file name="Collection.php" hash="00b7beb8a10a8717031b80932582ab62"/><dir name="Item"><file name="Collection.php" hash="e706b468a9fc83aeb90c87231e73b808"/></dir><file name="Item.php" hash="0263186f0984a5776acaf8597b9f6bf8"/><dir name="Payment"><file name="Collection.php" hash="0c68fd9376d580ba31b083a9e05083ca"/></dir><file name="Payment.php" hash="3920ade27c8d49d90ccaa37785f3385f"/></dir><file name="Quote.php" hash="b35dbb3c3ad4f1d557ee3b48137f0c8d"/><dir name="Sale"><file name="Collection.php" hash="a05db285ef3378e726ecab7b7c610098"/></dir><file name="Setup.php" hash="d3b20ae6df83b255f7803e0ec1ddcbca"/></dir><dir name="Mysql4"><file name="Abstract.php" hash="b0db47393634ae2f2e3e43f731996aa4"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="877605c9d028346183f66a166fb80d97"/></dir><file name="Agreement.php" hash="a17834c35bf457593b1fd608c18ba20f"/></dir><dir name="Collection"><file name="Abstract.php" hash="2f9b09bf0929b54b6ed60f032fd6ef2f"/></dir><dir name="Order"><file name="Abstract.php" hash="3ee44859719a0d126f4f16dbe99546ad"/><dir name="Address"><file name="Collection.php" hash="6f9fd6530a6e0ab930a26e99787a1e62"/></dir><file name="Address.php" hash="d530f4c4bf6c216f13904b8f871111e7"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="ccdc5106fea0b1d175a143442aa706e9"/><file name="Child.php" hash="ce3206207546abbc4e7e2d65ca268872"/><file name="Parent.php" hash="253a2ab63e2c7ba62a483764da207119"/><file name="Shipping.php" hash="5b41a69cbea2e558ccf12b15b95b916e"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="47f8ca61139eef629c833a69f0dc9425"/></dir><file name="Collection.php" hash="3b3cdd03bd52c7a6c662b8d81250a416"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="d7eae0947befb3406727cc6371bd5bec"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="90eeba23e00c6a7815baefe8c9f033af"/><file name="Parent.php" hash="9e1d0f68e5b5713fd554233b70a2cac3"/></dir></dir><file name="Collection.php" hash="13620d383b2db66173b8f0e28ab361bb"/><dir name="Comment"><file name="Collection.php" hash="93c787446d443e1fb947bc3eafc8f11b"/></dir><file name="Comment.php" hash="3efd0d6b04ff71dbe8747f8557010899"/><dir name="Grid"><file name="Collection.php" hash="8514c0d2572f47668736e9622cb1b747"/></dir><dir name="Item"><file name="Collection.php" hash="32078954b6ba46954b8bb76bb1fb7e9e"/></dir><file name="Item.php" hash="ca5e729c4f28926815cb2d35716dcd01"/></dir><file name="Creditmemo.php" hash="30a6bfe52bfd4c758c851f630a3ca79a"/><dir name="Grid"><file name="Collection.php" hash="d7621e63dc0f77fa94882507b558bf05"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="a29d3787865836132e83d266e79a8260"/><file name="Item.php" hash="40dc8b6364b0eb4742b55105331d8544"/><file name="Order.php" hash="ec82a177d214c96512f3556d11845b69"/><file name="Parent.php" hash="d2f24bdd157fe64e74177d3b8693e09b"/></dir></dir><file name="Collection.php" hash="8362cd59b4a7208afeae25642c921fbd"/><dir name="Comment"><file name="Collection.php" hash="2d3e26e2c5df7481c226d5fd9dc3e0b7"/></dir><file name="Comment.php" hash="4d68aca8967d97f04d462ff3bcba3f11"/><dir name="Grid"><file name="Collection.php" hash="6982b6cb3d2314cc9c9c9afda713327c"/></dir><dir name="Item"><file name="Collection.php" hash="09dda6d9c226fdad0bcb3d94de00216e"/></dir><file name="Item.php" hash="ee70addd50a7f6ac3719ceded067d40d"/></dir><file name="Invoice.php" hash="3da796261362ff3520542e936ac72d9d"/><dir name="Item"><file name="Collection.php" hash="5886223d56b9c5985913b035e9cbf789"/></dir><file name="Item.php" hash="8a97d0b600df39519ee5ffe53ccf48f6"/><dir name="Payment"><file name="Collection.php" hash="85a071a0702bec16e9280ad975b9e197"/><dir name="Transaction"><file name="Collection.php" hash="8970c3547e1966c415f8202d11d58c12"/></dir><file name="Transaction.php" hash="8f33aa78a64fe29bb1a2e8334fbd6b4f"/></dir><file name="Payment.php" hash="3c4c9266744a0fad5e4f2455a5722974"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="99d6cab63a21092408dff773054b9d93"/><file name="Parent.php" hash="50b6a40f22b9125e0a5f36e86db458fd"/></dir></dir><file name="Collection.php" hash="a059e54adb61bae5bfed655322ebde46"/><dir name="Comment"><file name="Collection.php" hash="b774124e32109950bbac93dea4588423"/></dir><file name="Comment.php" hash="f1dc455fe288891112e443a79bf53c18"/><dir name="Grid"><file name="Collection.php" hash="577564a98b72b6cd085165675705175f"/></dir><dir name="Item"><file name="Collection.php" hash="b6603794026494fd06fb5a4c45148fdc"/></dir><file name="Item.php" hash="711002d18fe28027f06ebc7a957aaabb"/><dir name="Track"><file name="Collection.php" hash="7611e9e72c1c8a3ab6e28bd69e4c7535"/></dir><file name="Track.php" hash="79e07fcce0ec1703777145ec544d0192"/></dir><file name="Shipment.php" hash="03d47ab43f685ece425f5638da9272fc"/><dir name="Status"><file name="Collection.php" hash="9f192ee27d9025ff9b4a767216c54d00"/><dir name="History"><file name="Collection.php" hash="48cfde1f1aa77484801117b25d14cce0"/></dir><file name="History.php" hash="d87bb0bf7e67f97ed88d574a1e934b94"/></dir><file name="Status.php" hash="21c7c1bc5c1a569118464f453f759c22"/><dir name="Tax"><file name="Collection.php" hash="9eded0afa051a25402911d17f881c659"/></dir><file name="Tax.php" hash="ccc2f221d2dfa06b63358daacb92bc52"/></dir><file name="Order.php" hash="c18b134589da38ec43c3bb0d82f9a91a"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="323ba6a863a0028ce315abead027d842"/><file name="Parent.php" hash="57dea111c8a4c38aa883c40cd5393e82"/><file name="Region.php" hash="657ab14d9fd351a8a047ba3ed756d13a"/></dir><file name="Backend.php" hash="20a973dec7d179b85d998275f1e06299"/><dir name="Frontend"><file name="Custbalance.php" hash="01da6eeb31194f578368e20e97bd1ce5"/><file name="Discount.php" hash="39955e5fe27a3668f5823859a8177cfc"/><file name="Grand.php" hash="ec54ee5503816d1ac68b77df348fb475"/><file name="Shipping.php" hash="24cbc84a2cef6b7579f6928f677f5ea2"/><file name="Subtotal.php" hash="0f576ad50ae1e87f41af1be267f7a970"/><file name="Tax.php" hash="a71555e6e0b97bc170fc2e5768b4f643"/></dir><file name="Frontend.php" hash="e9b14b0517b6dd3b202d19c039aedc45"/></dir><file name="Collection.php" hash="698f91405eac99e675da2ec5b0725f79"/><dir name="Item"><file name="Collection.php" hash="353e572a64eae0c4dd41247071a3bf9c"/></dir><file name="Item.php" hash="862d09a82f154ce69aa987eb072753eb"/><dir name="Rate"><file name="Collection.php" hash="94586c57fab25507f25517375b3fd6f9"/></dir><file name="Rate.php" hash="995bd0134fff2787b0b8582834b468a5"/></dir><file name="Address.php" hash="a0ce255d1e4df344e6a1cebb02b69d25"/><file name="Collection.php" hash="a54e42a302459a2ec0526d661ba3140d"/><dir name="Item"><file name="Collection.php" hash="5249b32713d5d80d6e419cc1e41abaed"/><dir name="Option"><file name="Collection.php" hash="7a08c0e8746cf374b68c6f4848b7ac52"/></dir><file name="Option.php" hash="7bbd8559002aa7cf3184a0ea60f7f02c"/></dir><file name="Item.php" hash="054f02aaac27f775de7286c652959d89"/><dir name="Payment"><file name="Collection.php" hash="a36deac36cd4cf30ed2c7ec66d4d082e"/></dir><file name="Payment.php" hash="c707e36f7b26fd5a1df4492fd7bf3243"/></dir><file name="Quote.php" hash="3694a2ec87135cb2f294dca9031a39b8"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="a2f16ce21d1d54bf58494eb7d889ee6e"/></dir><file name="Profile.php" hash="d79c55769f48e85709e6ed188d5a2fcd"/></dir><dir name="Report"><file name="Abstract.php" hash="251869ae0d7fab61e0f4398a0ee87216"/><dir name="Bestsellers"><file name="Collection.php" hash="ee0d2208c210d6a9cf8ddaf83c44328a"/></dir><file name="Bestsellers.php" hash="9176061a9d47038adf11bd5fc970f2a9"/><dir name="Collection"><file name="Abstract.php" hash="84c33f81cd1a5506b5989f296676e6fd"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="7fe5d21618431a6a48683b36c6898018"/><file name="Order.php" hash="d7a0958f14b0ae6d7469666505a32639"/></dir></dir><file name="Invoiced.php" hash="e6abb2a9f77d1951fd2433c44b8af3ee"/><dir name="Order"><file name="Collection.php" hash="d69baf4a6a4d2e47d2dc7b35cea0db63"/><dir name="Updatedat"><file name="Collection.php" hash="a925704447a04862aa6e760bc1c18106"/></dir></dir><file name="Order.php" hash="788ac7cfa70e0eeb2684c0675eb3b043"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="58420cb4a9e359195f587616d2379e6c"/><file name="Refunded.php" hash="37412528117ce7ae9544b5d2bf3264cb"/></dir></dir><file name="Refunded.php" hash="263fb59ceda14e4d836a3c544ff8857f"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="cec5e052f66d42a13cde5e36ab9a27b3"/><file name="Shipment.php" hash="c9581b73a854aa2f09df26d20e9b1141"/></dir></dir><file name="Shipping.php" hash="17c9236ac60fc0b991efdfbea2c7d630"/></dir><file name="Report.php" hash="77e1cf47540bb466e47447de3a972793"/><dir name="Sale"><file name="Collection.php" hash="d3d918f2b86c04b05244235c618d04c0"/></dir><file name="Setup.php" hash="034dd3a9f5b6b11ba008db9da36a3c96"/></dir><file name="Observer.php" hash="88b74b05c1d9c20a33ac3e09c5e35f37"/><dir name="Order"><file name="Address.php" hash="8916c4a42f48f388704a4facc5fee598"/><dir name="Api"><file name="V2.php" hash="53aecd75b1462122c4a5d80b6163cc50"/></dir><file name="Api.php" hash="9c7c6e95ff9d4808e31e9af6a9a8afdd"/><file name="Config.php" hash="7b62138f46b25e0f7ac47fdc02a59259"/><dir name="Creditmemo"><dir name="Api"><file name="V2.php" hash="33173dce34ec581719a9e1938d75037e"/></dir><file name="Api.php" hash="38f6d8318a71da652818390cb75d4bc3"/><file name="Comment.php" hash="cfe413b370dd450ef53986b75260b95b"/><file name="Config.php" hash="6df18821a105e506024d96cd383e73b2"/><file name="Item.php" hash="375c60679803b76dff4562329b8c5317"/><dir name="Total"><file name="Abstract.php" hash="46960310e82267bbb570745478b973cc"/><file name="Cost.php" hash="41b7062e0d7db18066d6b8634f3f33c4"/><file name="Discount.php" hash="2b70875f83ce8b84d55261a3e36ca75a"/><file name="Grand.php" hash="5480cb990680b2713db61ff7b3314e78"/><file name="Shipping.php" hash="efd1231c25d2b746d7edcafdeb466535"/><file name="Subtotal.php" hash="92e4788b748de21fc935430aa4a0c738"/><file name="Tax.php" hash="4b4d88cb5f840ba2099a1c3a654e7dce"/></dir></dir><file name="Creditmemo.php" hash="742ab7fc0bbcb80afd3e6e5964effabd"/><dir name="Invoice"><dir name="Api"><file name="V2.php" hash="3900df4ccc52977228c30c3e8b906034"/></dir><file name="Api.php" hash="fecb5690f768fc84ecdc296aee40ff73"/><file name="Comment.php" hash="df87e2a5bfd53856ee6280973f9fd99b"/><file name="Config.php" hash="cf03f276ce0dafd479bdd58aa06f53b4"/><file name="Item.php" hash="11425073c24ebf9eb613f123a0a32d52"/><dir name="Total"><file name="Abstract.php" hash="00ea50a41ad21f922b95cd08a5c8731f"/><file name="Cost.php" hash="3efa402ade37898b38b74f84adb89f7f"/><file name="Discount.php" hash="1529a1e0bf4a85474e17bec098339673"/><file name="Grand.php" hash="acc0bc6c08b724cd7d3d6fa0ab19cd48"/><file name="Shipping.php" hash="98c2805c93e8e1c89d3b3aefbf5ed7c3"/><file name="Subtotal.php" hash="7bdd77b2c41d4b74d45c9cbbc58ef80e"/><file name="Tax.php" hash="f092d289deca0c49b99ca6f368ca22bd"/></dir></dir><file name="Invoice.php" hash="0aa1fa01567a69372f75fa041c5d421d"/><file name="Item.php" hash="e6699d0a2621e12e151c26b9c38f6ccb"/><dir name="Payment"><file name="Transaction.php" hash="387b5696d397809fa31d850e92c43116"/></dir><file name="Payment.php" hash="86fca1ca2b2b314d7dbb0cd12f0aa1ba"/><dir name="Pdf"><file name="Abstract.php" hash="1efbaf2a4c3c19857662423556eaf6d1"/><file name="Creditmemo.php" hash="054630d48a754d8e9b83cdd22a92e2fe"/><file name="Invoice.php" hash="b2fc61c9816a9c7486cad2612efdf61a"/><dir name="Items"><file name="Abstract.php" hash="a87743efef9cc641171c700c086d6c92"/><dir name="Creditmemo"><file name="Default.php" hash="d7d0b9417f57164c3b760911aebc3f1b"/><file name="Grouped.php" hash="8a2ac12006fe8ed7ad728646f115f8c8"/></dir><dir name="Invoice"><file name="Default.php" hash="802dd4b102870533abefc3d7cb971d42"/><file name="Grouped.php" hash="b881d57c8e647a7a65dbdeb16a55abd1"/></dir><dir name="Shipment"><file name="Default.php" hash="bcdd58a6b6909374eb49814affd3d71d"/></dir></dir><dir name="Shipment"><file name="Packaging.php" hash="15c3cacfd1811f8e6fe7249ca987e617"/></dir><file name="Shipment.php" hash="4c64a7963af25e192d96a7fc11042521"/><dir name="Total"><file name="Default.php" hash="2405a97489855173f3df6a212dec9fe5"/></dir></dir><dir name="Shipment"><dir name="Api"><file name="V2.php" hash="7da2711d8341b3d03c58ec0a147516a2"/></dir><file name="Api.php" hash="6733ac7ae00096ef48e80f7ae8d96c7b"/><file name="Comment.php" hash="6ba3d5f7fd14212d41e75c510bb54658"/><file name="Item.php" hash="dd558f3d378bfd1b06c38e320eb0aca8"/><file name="Track.php" hash="0d132e1caaa80ea2b1e23cb3ff17a13a"/></dir><file name="Shipment.php" hash="9563c1a893b2e490dc0fcc6538a40576"/><dir name="Status"><file name="History.php" hash="56c69ef7957d32fac4e53fed47f672cf"/></dir><file name="Status.php" hash="d1c61f6ce1621935d9f2652cf2dddee4"/><file name="Tax.php" hash="adcc923fa9c2c6e2f862cefa1445ec51"/><dir name="Total"><file name="Abstract.php" hash="31cb81413da3aa688c15f2d31763561b"/><dir name="Config"><file name="Base.php" hash="7a30dcb898e00ad6dbd1044dceba54d9"/></dir></dir><file name="Total.php" hash="70d33c7cf4e96e3d5042f54a1304945f"/></dir><file name="Order.php" hash="05337465ddb568649d304c818d2d8814"/><dir name="Payment"><dir name="Method"><dir name="Billing"><file name="AgreementAbstract.php" hash="858f28ccdb7efb39531e48b6086dc1f7"/></dir></dir></dir><dir name="Quote"><dir name="Address"><file name="Item.php" hash="13167c8797b8d40f7624503edb80c42b"/><file name="Rate.php" hash="3d8160aaa1535a5ecc3bbddc3e5cf60b"/><dir name="Total"><file name="Abstract.php" hash="998eb1780efd04ae4fb2dfeb9b1da06d"/><file name="Collector.php" hash="bd9e85908788e72d1bfdd391caf9c4c5"/><file name="Custbalance.php" hash="ffaef95a9108f670fc8e25628b69da14"/><file name="Discount.php" hash="8d636214de72db05ba44c1a4b9896ef9"/><file name="Grand.php" hash="aa41c6640092a0a48ef4dd6feb0eaa03"/><file name="Msrp.php" hash="fff13c6912b5ae52cf139fc08733331b"/><dir name="Nominal"><file name="Collector.php" hash="953c4bd896cffa053253ae9bd46d7413"/><dir name="Recurring"><file name="Initial.php" hash="60476d4d1380a5bbb33be228b5e1b125"/><file name="Trial.php" hash="81e47180d95ee44b26761c2488763d67"/></dir><file name="RecurringAbstract.php" hash="068fcca6018196d6c9a4a8dab5cbfea8"/><file name="Shipping.php" hash="c6a723be5898cb394f5c5ece5ca93b2b"/><file name="Subtotal.php" hash="149b0984813abbcab03ebf4cdd78ce78"/></dir><file name="Nominal.php" hash="8328b2300cf771afa0f5f84a681d5f20"/><file name="Shipping.php" hash="bd4dd3b11a26f2e810f66d55953fb030"/><file name="Subtotal.php" hash="81110672832ae415ca383a900844ed2a"/><file name="Tax.php" hash="8faf93c094702542955ab4baf50cfe2c"/></dir><file name="Total.php" hash="d836886553dda5c5c26265c8ac0ea359"/></dir><file name="Address.php" hash="ae8cf173f9312f2add53a18783ef7933"/><file name="Config.php" hash="cc48d9cfb97d5b05e2df40e82cf97ac7"/><dir name="Item"><file name="Abstract.php" hash="35895a3a1c1492a971bcb03ba3983ba6"/><file name="Option.php" hash="505a1627ea636d6b84604ba6d05562a2"/></dir><file name="Item.php" hash="40debc8bc6fbc6082920941891de8fb5"/><file name="Payment.php" hash="f2f75f09e0ec0b96510f4151be8969c7"/></dir><file name="Quote.php" hash="c7b11d2b08b94f0a0a3c9e711487a325"/><dir name="Recurring"><file name="Profile.php" hash="6523889790dbc100ab3c90ca32785eaa"/></dir><dir name="Resource"><file name="Abstract.php" hash="06798d2bae372e5d5744318e627a7d76"/><dir name="Billing"><dir name="Agreement"><file name="Collection.php" hash="3a69e98730657ebf9b9da9086a225c6b"/></dir><file name="Agreement.php" hash="8e9efd873709fdd8ae6cf0f6f4fa162f"/></dir><dir name="Collection"><file name="Abstract.php" hash="ce9aec922526609215f1038782f9e777"/></dir><dir name="Helper"><file name="Interface.php" hash="03049c9d6a48a70a6ff3d2c1ff64cde1"/><file name="Mysql4.php" hash="387b0b29e187a32aeb3cf47b2706f5cf"/></dir><dir name="Order"><file name="Abstract.php" hash="c6bcdf9d41e749010b4fff0262f98390"/><dir name="Address"><file name="Collection.php" hash="b92fd2f5b157dd6546763dc83e50e00c"/></dir><file name="Address.php" hash="c6f6b1f5bb03ce120aac229a9e10181c"/><dir name="Attribute"><dir name="Backend"><file name="Billing.php" hash="d8a6abf75315b4230695e17706d1e22c"/><file name="Child.php" hash="a17ee5ee0ce105ba44fe088f778c8ba3"/><file name="Parent.php" hash="94a1d88f86e59d4256164d592876cca0"/><file name="Shipping.php" hash="18ca118303231681e53ece31d15d549c"/></dir></dir><dir name="Collection"><file name="Abstract.php" hash="4dc3ee4846909bcf704476a2785ce51d"/></dir><file name="Collection.php" hash="15582c6d423aa21d838709eb80bd0732"/><dir name="Comment"><dir name="Collection"><file name="Abstract.php" hash="8e4c6ca0755eb57a6787eb92ea690bbb"/></dir></dir><dir name="Creditmemo"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="43d42de1f5b84c38f65f0848fd489a37"/><file name="Parent.php" hash="78274d33ccf1d07c9552c791d2ace796"/></dir></dir><file name="Collection.php" hash="c5de7575c4e7f77e45f5e32ff930f418"/><dir name="Comment"><file name="Collection.php" hash="b6ce7282472670bc07ed65db12ad0c4e"/></dir><file name="Comment.php" hash="55125fc902f1b341d8d55d0a5197ac5b"/><dir name="Grid"><file name="Collection.php" hash="c2d7c0562273dea783196cfdebd1a0de"/></dir><dir name="Item"><file name="Collection.php" hash="9ea88230bb081da061d0c950eb32f015"/></dir><file name="Item.php" hash="d2bfc4c13fa06d03ccbff896522d8470"/></dir><file name="Creditmemo.php" hash="ad7a44336cf27fecbdb0b0e42168b259"/><dir name="Grid"><file name="Collection.php" hash="b97470cd6f0d203e5e18912b614f08fd"/></dir><dir name="Invoice"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="7c361107c04f9622b2404ded426b3931"/><file name="Item.php" hash="808ee216324a1342f4188cc1642c00cb"/><file name="Order.php" hash="9b25cb53b48355c923674af68226e44e"/><file name="Parent.php" hash="74f2d01b5b0c72e3303318bd56617401"/></dir></dir><file name="Collection.php" hash="22a1357726e3c914d38fe54ab9981543"/><dir name="Comment"><file name="Collection.php" hash="9177dbc3dd739beddacd6cd531d91d9a"/></dir><file name="Comment.php" hash="e7df04fca8aa7c24ec56bc8560c503ae"/><dir name="Grid"><file name="Collection.php" hash="bed2f149ed5df505d6a196d68b5b1301"/></dir><dir name="Item"><file name="Collection.php" hash="e3360d66615e407be221d97d179fe044"/></dir><file name="Item.php" hash="57bd03e9b419fc15edb75b04c09004a2"/></dir><file name="Invoice.php" hash="4ce11cd9dd6d5ee7bb373cbc958b521e"/><dir name="Item"><file name="Collection.php" hash="af905f388ddae3eec6b1ab297379205b"/></dir><file name="Item.php" hash="512defaeaed0f1a8d00804df39e3aec6"/><dir name="Payment"><file name="Collection.php" hash="02da4d7775cc4013e9c16aabe3589997"/><dir name="Transaction"><file name="Collection.php" hash="bf937a25f0c7df1031a09433c9842c4b"/></dir><file name="Transaction.php" hash="1a64212246c615d53b8a8afd0eb8d932"/></dir><file name="Payment.php" hash="f6aad82c2999d65ff80acf09fb23a7cc"/><dir name="Shipment"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="3bc1895d0f5e7ca581ee4e8d0fff6bb8"/><file name="Parent.php" hash="8b03ebab28ae10bcabd87b464cf02ab1"/></dir></dir><file name="Collection.php" hash="f87c1eba0c18fe329589998ca3516b73"/><dir name="Comment"><file name="Collection.php" hash="1b28c7f3ae35c30a413e69138ce56791"/></dir><file name="Comment.php" hash="e9a097c3f151fc3499455278f6f151da"/><dir name="Grid"><file name="Collection.php" hash="b419fb2d905b2ce911c304641b586c8c"/></dir><dir name="Item"><file name="Collection.php" hash="f8fbd616c36db514ce5280388d157c53"/></dir><file name="Item.php" hash="3a693ede88944e180463e241c3bf1d75"/><dir name="Track"><file name="Collection.php" hash="f092f45120fb61b7eca9b31a5c45350f"/></dir><file name="Track.php" hash="886bdcdfd193a9a233428f471e7f3831"/></dir><file name="Shipment.php" hash="afc9386f4ebb3ca7a5a4b4762f5101b2"/><dir name="Status"><file name="Collection.php" hash="8c9bbd30a771da83c9874b334c7020a5"/><dir name="History"><file name="Collection.php" hash="e94c4590c682e89d57fd22d3464a9b29"/></dir><file name="History.php" hash="26fe553862db8065db57c697ae82cfef"/></dir><file name="Status.php" hash="f49eee0230598a22e8985ccd5700e29c"/><dir name="Tax"><file name="Collection.php" hash="4ae4b3ee863688a1ebc506443a6d2606"/></dir><file name="Tax.php" hash="c1a9f6c1b5d5d73182d0d932f7300e59"/></dir><file name="Order.php" hash="0fa2698612cf4622c07e36e087b3cd8d"/><dir name="Quote"><dir name="Address"><dir name="Attribute"><dir name="Backend"><file name="Child.php" hash="fb22141b138c5e0e50513f15bc26a7ac"/><file name="Parent.php" hash="16d8bd420feca1b901d5e04d773ad618"/><file name="Region.php" hash="e6a34fade1af2de288cfdbac10923a5a"/></dir><file name="Backend.php" hash="91e5c98cda7d74c18ce94468049a4d9b"/><dir name="Frontend"><file name="Custbalance.php" hash="d3bb99b3eb04a9015acb64818d348156"/><file name="Discount.php" hash="1ac67dd5a166a2beebd5e5e28a3cdfa3"/><file name="Grand.php" hash="5390b3419a7b7ffbdfea5a5d461a74b0"/><file name="Shipping.php" hash="b90e09fbec681375c4fe797f5ba05e1e"/><file name="Subtotal.php" hash="b548298ef6284d214b77ce28bbcd105f"/><file name="Tax.php" hash="a0bbbd4cd0a823a1a03b6d2b6d05c75b"/></dir><file name="Frontend.php" hash="3e145300f6c2bbc7da8065ed2127b7fd"/></dir><file name="Collection.php" hash="614c9e681787b9e07926a8b2db538fe9"/><dir name="Item"><file name="Collection.php" hash="717fce4bb8b5be14d6804931fdedbea2"/></dir><file name="Item.php" hash="df52f7b5f964f968d2a2cbab2a20f850"/><dir name="Rate"><file name="Collection.php" hash="b1a6d36d4d0deb3514e1a710ba0964e2"/></dir><file name="Rate.php" hash="73c20b025222353dcefb33539c84a496"/></dir><file name="Address.php" hash="2b3cff37667b5609b9b93165d48dc5d7"/><file name="Collection.php" hash="c808ab68be9ead5f47720c82a60f78a7"/><dir name="Item"><file name="Collection.php" hash="666f34fcb64d15b4d64cae4266980547"/><dir name="Option"><file name="Collection.php" hash="2920aea6b88281281aeb58884e44ce54"/></dir><file name="Option.php" hash="d34f1dc3bc8eb9f3bb7bbd1f4e198924"/></dir><file name="Item.php" hash="abca577432cfb2cc219ccce735c11f5e"/><dir name="Payment"><file name="Collection.php" hash="50e02948cdcb847c5ba330fcf4a0a736"/></dir><file name="Payment.php" hash="c8aa350b64846464e465b959007382dc"/></dir><file name="Quote.php" hash="63add8e0f1afbf189ec39289b93ce644"/><dir name="Recurring"><dir name="Profile"><file name="Collection.php" hash="c86282d515fe55cec5d91d121d6b2fe0"/></dir><file name="Profile.php" hash="354252e2618207c5aae3e77845da39cf"/></dir><dir name="Report"><file name="Abstract.php" hash="42e7075a7e81c8d013fa51f8dc8d8fb7"/><dir name="Bestsellers"><file name="Collection.php" hash="308e0ea60f24f45a5fb6ccf8a321b29f"/></dir><file name="Bestsellers.php" hash="ec935ec54f750a3337955d11124acb73"/><dir name="Collection"><file name="Abstract.php" hash="4d979463398fa003e2bd7245be2a2349"/></dir><dir name="Invoiced"><dir name="Collection"><file name="Invoiced.php" hash="9f3886e190425851e71520cc7128eb36"/><file name="Order.php" hash="42db6ff58f5e6e5c73a09c2ec946d9f7"/></dir></dir><file name="Invoiced.php" hash="73005cba3e5df382cea54947a09a535b"/><dir name="Order"><file name="Collection.php" hash="734498dccb843dc88715bc0a3b83f04b"/><file name="Createdat.php" hash="fa0b3c1186587c6fca3fe7a84fd040c5"/><dir name="Updatedat"><file name="Collection.php" hash="dab368a79fc05593c94d52367641feb5"/></dir><file name="Updatedat.php" hash="94f641b4589c3a81286c926689500b69"/></dir><file name="Order.php" hash="c87912b9d48633e6520d586319d0cd77"/><dir name="Refunded"><dir name="Collection"><file name="Order.php" hash="41df56a612e9ac30fb1f23bab73679d6"/><file name="Refunded.php" hash="fad2658a14ad11de6be64791f1962387"/></dir></dir><file name="Refunded.php" hash="300935148418cb44d7303908d3377e57"/><dir name="Shipping"><dir name="Collection"><file name="Order.php" hash="88f0441418c4588c6f9cf4c4f3388a77"/><file name="Shipment.php" hash="4c320e03fbfbd7f64347015a3746d682"/></dir></dir><file name="Shipping.php" hash="8ee5cc8cd06446c300316ea80ba6bdc3"/></dir><file name="Report.php" hash="00e8090be521bae44556e85278a8a50f"/><dir name="Sale"><file name="Collection.php" hash="72c86de402df84a75807c5ee1808138e"/></dir><file name="Setup.php" hash="16b2ee3f2c3251ce26b9bf0202ca0bed"/></dir><dir name="Service"><file name="Order.php" hash="79c00b67105e67eed86edfa5c3989704"/><file name="Quote.php" hash="96c5e6a97ce62533f351d4959b400c42"/></dir><dir name="Status"><file name="List.php" hash="a95825954b50003525fb82228a9292de"/></dir></dir><dir name="controllers"><dir name="Billing"><file name="AgreementController.php" hash="6fbfc7001982d36aa06483c90898b0ed"/></dir><file name="DownloadController.php" hash="49594a42bf13124463382faf965394fb"/><file name="GuestController.php" hash="728699f2a41bbb6a026ef8e2e55653ff"/><file name="OrderController.php" hash="673ae998510996c015ae21e18da60958"/><dir name="Recurring"><file name="ProfileController.php" hash="0cc8c8d91d19ea96a1419fddc432d5b1"/></dir></dir><dir name="data"><dir name="sales_setup"><file name="data-install-1.6.0.0.php" hash="6ab71ddde7cb62e41cd3978f77ab7b2b"/><file name="data-upgrade-1.6.0.4-1.6.0.5.php" hash="24bc0e8094427988f236bbfb8998e5ae"/></dir></dir><dir name="doc"><file name="invoice.txt" hash="d41d8cd98f00b204e9800998ecf8427e"/><file name="order.txt" hash="5dce876530c94ebbedbba7a234c23846"/><file name="order_actions.HTM" hash="b955e61bff753ea0534f907ef6ba9bb6"/><file name="quote.txt" hash="55ecfbdd576958ff1b1fbf16957ba9df"/><file name="test.php" hash="75f5888687bd149423ad2262dc6be83d"/></dir><dir name="etc"><file name="adminhtml.xml" hash="64f3215b378e7cce530d2bbc1b5770ec"/><file name="api.xml" hash="20eba043e5bc0f7d826378f9239da63a"/><file name="api2.xml" hash="2dd8189de81a1cee9acccdb63d6dfd3f"/><file name="config.xml" hash="decb9d37095adc9aa779c392c77d9ad7"/><file name="system.xml" hash="cbe84ff8e194da1d5f619f88618e52aa"/><file name="widget.xml" hash="1ea392cd1357530eb3fb76396fde54b4"/><file name="wsdl.xml" hash="ed13de1dde6408ab508892374ef57b81"/><file name="wsi.xml" hash="6aba2f44765955ec8bcd1afcebfb0800"/></dir><dir name="sql"><dir name="sales_setup"><file name="install-1.6.0.0.php" hash="2c287c2fe9601ef04ff961b56c2967f9"/><file name="mysql4-install-0.7.0.php" hash="7d0d1fea503a57617f35fb7d4321e64e"/><file name="mysql4-install-0.8.11.php" hash="0f7b7ad16927275d67466655799f63f5"/><file name="mysql4-install-0.9.0.php" hash="df39d6b00a00297dde8bb809a3ce8d36"/><file name="mysql4-install-1.4.0.0.php" hash="ab55fbc1f42b45f62a8e25b00f3f8ec0"/><file name="mysql4-upgrade-0.6.2-0.7.0.php" hash="4b377082c213d2bd5fc011024ce5d38d"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="66dab89a7376dd328305a3c2c4363484"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f626b8de75933ed846c8fc1ab7989b"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="faf0a62c9033c06dc4142661630347f0"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a582cc340f96512440da05c34d4efdc3"/><file name="mysql4-upgrade-0.8.0-0.8.1.php" hash="4386c0a34c4ab15be88788dddd68eff4"/><file name="mysql4-upgrade-0.8.1-0.8.2.php" hash="b829b43451acd8d04045ec093c8b4dd2"/><file name="mysql4-upgrade-0.8.11-0.8.12.php" hash="328d56f9f7ebabe79ade0a1621e41d71"/><file name="mysql4-upgrade-0.8.12-0.8.13.php" hash="d2b6362bd9f351691adc12b4319351ed"/><file name="mysql4-upgrade-0.8.13-0.8.14.php" hash="17900afa4f64d66a9ac672f276912ea8"/><file name="mysql4-upgrade-0.8.14-0.8.15.php" hash="5ee57dce22f85605a6a6102faba2d90a"/><file name="mysql4-upgrade-0.8.15-0.8.16.php" hash="baec5a1400bf8826769266e1322503a0"/><file name="mysql4-upgrade-0.8.16-0.8.17.php" hash="f9cd2aecddc0fb919155cf2b7b62be10"/><file name="mysql4-upgrade-0.8.17-0.8.18.php" hash="f120725f256959ac634271b2352c0683"/><file name="mysql4-upgrade-0.8.18-0.8.19.php" hash="8076b36a75778b6545d82d7c0eb75576"/><file name="mysql4-upgrade-0.8.19-0.8.20.php" hash="8792c0f1b2e7545e52d0b8549ce11739"/><file name="mysql4-upgrade-0.8.2-0.8.3.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.20-0.8.21.php" hash="d1861afa10be4a63b988775d63b89eac"/><file name="mysql4-upgrade-0.8.21-0.8.22.php" hash="e41a5cb53beb7bdf5f85906af0e64af3"/><file name="mysql4-upgrade-0.8.22-0.8.23.php" hash="cdfd46b4c76f91d81832bcbac76d1f7e"/><file name="mysql4-upgrade-0.8.23-0.8.24.php" hash="1ef6d4fc564bef1e8883d9c55dda1d9f"/><file name="mysql4-upgrade-0.8.24-0.8.25.php" hash="8cd0c4b432833a8480e855822e182db0"/><file name="mysql4-upgrade-0.8.25-0.8.26.php" hash="36548ad7e5f7008c4feebc1ca0125449"/><file name="mysql4-upgrade-0.8.26-0.8.27.php" hash="7fb800a27788be2681a07dcb9e7138a3"/><file name="mysql4-upgrade-0.8.27-0.8.28.php" hash="eb14adbff9fc9add9d41ee53b80e3f1f"/><file name="mysql4-upgrade-0.8.28-0.8.29.php" hash="acb795a8927fb7eb42e26cc631b9eb9b"/><file name="mysql4-upgrade-0.8.29-0.9.0.php" hash="51700bb3315b81683d5297393915ba5c"/><file name="mysql4-upgrade-0.8.3-0.8.4.php" hash="6f76404ed26c596214b76cfa7acbd2fd"/><file name="mysql4-upgrade-0.8.6-0.8.7.php" hash="93632a56c83156ca377d75a0242b6019"/><file name="mysql4-upgrade-0.8.7-0.8.8.php" hash="291a933edceb5b0d0bf820d889a41dfd"/><file name="mysql4-upgrade-0.8.8-0.8.9.php" hash="d1d401880667acde9910dbd94baf45df"/><file name="mysql4-upgrade-0.9.0-0.9.1.php" hash="a08c394d9ee9e3b603271c87d9cdccaf"/><file name="mysql4-upgrade-0.9.1-0.9.2.php" hash="eee0131d0c1ff81d6a8217024328fd93"/><file name="mysql4-upgrade-0.9.10-0.9.11.php" hash="7dcad0f3276ab1c90aec34066cdf9af2"/><file name="mysql4-upgrade-0.9.11-0.9.12.php" hash="1419527e1368381becf382e165974eca"/><file name="mysql4-upgrade-0.9.12-0.9.13.php" hash="106cc11270541b4ad03bcf01da097a08"/><file name="mysql4-upgrade-0.9.13-0.9.14.php" hash="9a544c38081d67a9bf7ada5eea628ae6"/><file name="mysql4-upgrade-0.9.14-0.9.15.php" hash="3d94dfc65777523496ba202ac5481a32"/><file name="mysql4-upgrade-0.9.15-0.9.16.php" hash="288e17dfff62ec6e15de30218d96a4f3"/><file name="mysql4-upgrade-0.9.16-0.9.17.php" hash="a269dc8079c9566e5be0f4bab75379bd"/><file name="mysql4-upgrade-0.9.17-0.9.18.php" hash="c0a0fdde0cbb71fd548d2965e01ab3ea"/><file name="mysql4-upgrade-0.9.18-0.9.19.php" hash="be7b8ccda6a3e658ea86e0f2d99ee020"/><file name="mysql4-upgrade-0.9.19-0.9.20.php" hash="f6272f05d9077b84f9e9c5724c84b783"/><file name="mysql4-upgrade-0.9.2-0.9.3.php" hash="b6240c3ae6f61375f6723735345f3c7a"/><file name="mysql4-upgrade-0.9.20-0.9.21.php" hash="80230b5d45321b886002b4783a1178c5"/><file name="mysql4-upgrade-0.9.21-0.9.22.php" hash="9c2be0b2fd92f326dcff1a2425d255a6"/><file name="mysql4-upgrade-0.9.22-0.9.23.php" hash="71dc008ec0b1e195f853113329944b6c"/><file name="mysql4-upgrade-0.9.23-0.9.24.php" hash="ad08f3386682ab27c86fc9bfbd91f8e3"/><file name="mysql4-upgrade-0.9.24-0.9.25.php" hash="1dc0d317074dea066f265a40d00ed6f7"/><file name="mysql4-upgrade-0.9.25-0.9.26.php" hash="d69e73a174d61eefe0034c148cd09472"/><file name="mysql4-upgrade-0.9.26-0.9.27.php" hash="58353aafa8bcdb32a6d64184b6a3d60b"/><file name="mysql4-upgrade-0.9.27-0.9.28.php" hash="0213f58c16ab8bf2485bae528140ba69"/><file name="mysql4-upgrade-0.9.28-0.9.29.php" hash="da5ef2d5d6e6cfd6ef0d5e44136029a5"/><file name="mysql4-upgrade-0.9.29-0.9.30.php" hash="5c376558e9f329281c8363322f05e45a"/><file name="mysql4-upgrade-0.9.3-0.9.4.php" hash="fb67ff85b5b8e395e0e11598f2e202b7"/><file name="mysql4-upgrade-0.9.30-0.9.31.php" hash="0e4bc71fab792ede8edb992839b7fa66"/><file name="mysql4-upgrade-0.9.31-0.9.32.php" hash="59aa185b9b61d345081a24913f67d87c"/><file name="mysql4-upgrade-0.9.32-0.9.33.php" hash="f742c43458fbbe3cc4ecaf9679b444b9"/><file name="mysql4-upgrade-0.9.33-0.9.34.php" hash="ed2650dacba9c9c315b1bd15399ce8c2"/><file name="mysql4-upgrade-0.9.34-0.9.35.php" hash="4ea762659260ddb6ef8521fa1ea59af3"/><file name="mysql4-upgrade-0.9.35-0.9.36.php" hash="43ebb2aa25a9302eaad2fe67e29e187f"/><file name="mysql4-upgrade-0.9.36-0.9.37.php" hash="5eef7f246dc3135de09fa4ad63668236"/><file name="mysql4-upgrade-0.9.37-0.9.38.php" hash="7f1264d789044b4e0d53d88d6fae9aad"/><file name="mysql4-upgrade-0.9.38-0.9.39.php" hash="394b1c87ec14026fc9ec73a7aed8d164"/><file name="mysql4-upgrade-0.9.39-0.9.40.php" hash="f525b598b5e6a411e0fbf78f3e698b97"/><file name="mysql4-upgrade-0.9.4-0.9.5.php" hash="ae0c33db1187c63db22e3abb9b135e92"/><file name="mysql4-upgrade-0.9.40-0.9.41.php" hash="9606fd627ca520b83a8cbaa1af210f36"/><file name="mysql4-upgrade-0.9.41-0.9.42.php" hash="e3f73f0616866b38d27b455a29c884ef"/><file name="mysql4-upgrade-0.9.42-0.9.43.php" hash="86ae3db2278241132ecf0d78e94e4a6b"/><file name="mysql4-upgrade-0.9.43-0.9.44.php" hash="634530214656d52e0ebf1bc1796ba820"/><file name="mysql4-upgrade-0.9.44-0.9.45.php" hash="0ef1f74e5ff76cbdb77ef5c1cf1cff54"/><file name="mysql4-upgrade-0.9.45-0.9.46.php" hash="c836ec8263903c699810ed331018cdf2"/><file name="mysql4-upgrade-0.9.46-0.9.47.php" hash="c57f7c39b85e675a294487970842bf96"/><file name="mysql4-upgrade-0.9.47-0.9.48.php" hash="b15d0fe3d2da3fd72f11960ebe3944f4"/><file name="mysql4-upgrade-0.9.48-0.9.49.php" hash="2a21dddd1ee15ae790005478066c7e24"/><file name="mysql4-upgrade-0.9.49-0.9.50.php" hash="6cdb649f2797ab3dbe3609f64a2940fe"/><file name="mysql4-upgrade-0.9.5-0.9.6.php" hash="be8975bf7f0e7304212c2aaff5d9b23f"/><file name="mysql4-upgrade-0.9.50-0.9.51.php" hash="9a624fe9a93a011ea20fdc38f5dab386"/><file name="mysql4-upgrade-0.9.51-0.9.52.php" hash="97a685809fe84907429291f0d8a7da21"/><file name="mysql4-upgrade-0.9.52-0.9.53.php" hash="6b592cc19f7243afedefec86dcb2a314"/><file name="mysql4-upgrade-0.9.53-0.9.54.php" hash="67a7688245f2021ed2b9a421e483cc53"/><file name="mysql4-upgrade-0.9.54-0.9.55.php" hash="673b59dd7062eb7610d5a4f1237ad7a1"/><file name="mysql4-upgrade-0.9.55-0.9.56.php" hash="5665cbaa78fc32405f927db451b57b1d"/><file name="mysql4-upgrade-0.9.6-0.9.7.php" hash="6075078eb301b31f123ac710e0a2a0d9"/><file name="mysql4-upgrade-0.9.7-0.9.8.php" hash="a6087a1421def6bbe443c54ed7c85a8b"/><file name="mysql4-upgrade-0.9.8-0.9.9.php" hash="a803ee3e2911b1f245dd0549369ecc9f"/><file name="mysql4-upgrade-0.9.9-0.9.10.php" hash="2639b36ba32deb87f752d022d588078f"/><file name="mysql4-upgrade-1.3.99-1.4.0.0.php" hash="709b954c683e80cf4526303870128d82"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="6e96cade5538a2e661b1cdf8c08a7d44"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="c63f548243fce20ee961f6f80435bea3"/><file name="mysql4-upgrade-1.4.0.15-1.4.0.16.php" hash="88f689b208a1702ec4facf6e2b5ab134"/><file name="mysql4-upgrade-1.4.0.16-1.4.0.17.php" hash="3f5527bc6f1c015e3007ec2b43f25f95"/><file name="mysql4-upgrade-1.4.0.17-1.4.0.18.php" hash="a21261050a55e7b580ef646d1a0bd314"/><file name="mysql4-upgrade-1.4.0.18-1.4.0.19.php" hash="8d99789daac557da4ced224d36635e00"/><file name="mysql4-upgrade-1.4.0.19-1.4.0.20.php" hash="6f339125108f34c0b5477d214963d32a"/><file name="mysql4-upgrade-1.4.0.2-1.4.0.3.php" hash="740256606f0d22e7d2d4a1f8896c0b52"/><file name="mysql4-upgrade-1.4.0.20-1.4.0.21.php" hash="25cc7a47798177c4f52cf387a67125f7"/><file name="mysql4-upgrade-1.4.0.21-1.4.0.22.php" hash="f2ec84706e64018a70c0198a560bb917"/><file name="mysql4-upgrade-1.4.0.22-1.4.0.23.php" hash="9c6771fc168bece647cfc6c9fd4b478e"/><file name="mysql4-upgrade-1.4.0.23-1.4.0.24.php" hash="49febdd803be93c62dc09e51bdd330f0"/><file name="mysql4-upgrade-1.4.0.24-1.4.0.25.php" hash="d5fbae1bd7d9d45a6a284f8e93ae8314"/><file name="mysql4-upgrade-1.4.0.3-1.4.0.4.php" hash="303dd6693f7160546d6c1aad96d1348c"/><file name="mysql4-upgrade-1.4.0.4-1.4.0.5.php" hash="68ddd54ec15ac6f60213215682176f37"/><file name="mysql4-upgrade-1.4.0.5-1.4.0.6.php" hash="784a77ef434acf0ebe803805a213876c"/><file name="mysql4-upgrade-1.4.0.6-1.4.0.7.php" hash="2c560f9f57454ec7130e6c293cbf5266"/><file name="mysql4-upgrade-1.4.0.7-1.4.0.8.php" hash="357db82d9b817ecea185abaaeb70d317"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.15.php" hash="cdcd4d6492a5c27b73b5b1b3b9ac8d4a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e8356d6a48d76369b34f6e8bd27dd816"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="dfd84a2a8044c259c6f6e7feea9a5de7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="6ac3f9c8119c28fd6796dc98ec54e82a"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="c83205c28df3a6063f268f11195d27a8"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="3bbd8e0ff9448fa2d0bba25ac87b8492"/><file name="upgrade-1.6.0.4-1.6.0.5.php" hash="3b963ab1fa610c36577e8e43b279471d"/><file name="upgrade-1.6.0.5-1.6.0.6.php" hash="0d6e967b2a6bc110e143171210c80e54"/><file name="upgrade-1.6.0.6-1.6.0.7.php" hash="2eaf612b1ddcf939fec17e441c29c08e"/><file name="upgrade-1.6.0.7-1.6.0.8.php" hash="ef8e890ad206740f2c9d72803f30d063"/><file name="upgrade-1.6.0.8-1.6.0.9.php" hash="9d5a988492bd42371c47ee69186f7150"/><file name="upgrade-1.6.0.9-1.6.0.10.php" hash="40feccfa23344470891176db52fb26ba"/></dir></dir></dir><dir name="SalesRule"><file name="Exception.php" hash="462c8803b4baa19dc11ed76cf231a786"/><dir name="Helper"><file name="Coupon.php" hash="01e644f9fe0632bfb43cc46139af99f2"/><file name="Data.php" hash="0de3ba8633aa6d88b2696a28727b47eb"/></dir><dir name="Model"><dir name="Coupon"><file name="Codegenerator.php" hash="d8ac08012695de7a731cd66de91c6257"/><file name="CodegeneratorInterface.php" hash="af2ace052c52d6a73801866cc77db152"/><file name="Massgenerator.php" hash="dab0308b332c09681550a7c0ce7a2b9e"/></dir><file name="Coupon.php" hash="27ddc5154f825c75ca366042e2385ae5"/><dir name="Mysql4"><dir name="Coupon"><file name="Collection.php" hash="334608369ac389b1b67def7ada1aa5e0"/><file name="Usage.php" hash="40be9a4493b0936c1111ea7991f912b2"/></dir><file name="Coupon.php" hash="7844b0bc3fdb9de95382c1b12421123d"/><dir name="Report"><file name="Collection.php" hash="384fe7d3e3777b6233791bcb7a0e5a2e"/><file name="Rule.php" hash="7b9f3131640951ab7ddfcf8316ba78b0"/><dir name="Updatedat"><file name="Collection.php" hash="fc1d0841db7b9eebe8c15a18f694a742"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="8b5900d5125b47cbb540a6e2ccf47f41"/><dir name="Customer"><file name="Collection.php" hash="9cd01232278163f711a5c5283f94a21e"/></dir><file name="Customer.php" hash="4d45597acba3e88a0eb04b69349b9c68"/><dir name="Product"><file name="Collection.php" hash="4cc4b5b1fdf0b3a832bb7859288b303e"/></dir><file name="Product.php" hash="53b758f2c61474ba10c87c256e108314"/></dir><file name="Rule.php" hash="eb958a1b99441e8912d1d46510feeaf4"/></dir><file name="Observer.php" hash="4364e6fa8639634d504f66bbcc3cf808"/><dir name="Quote"><file name="Discount.php" hash="e41ec653892d0e8ecf82d9a52b62c676"/><file name="Freeshipping.php" hash="b035df813ef118ff1a1fb5ed875083f3"/><dir name="Nominal"><file name="Discount.php" hash="68a50a271796a47f8f55f2e7bad7d28a"/></dir></dir><dir name="Resource"><dir name="Coupon"><file name="Collection.php" hash="31b1a8e0fa51a8923ead28d407bf9c05"/><file name="Usage.php" hash="d7b327e2e3222cef7a55fd4f9e682e44"/></dir><file name="Coupon.php" hash="15b26e3aa1646ee2878b6bf46ab7bbae"/><dir name="Report"><file name="Collection.php" hash="e9236e12f64f8cdcaa8d8fb2a1224be4"/><dir name="Rule"><file name="Createdat.php" hash="60ed5d0e5377ae852c73e09326390fe8"/><file name="Updatedat.php" hash="5dfd0e8a15d115a4c14b2973415f0825"/></dir><file name="Rule.php" hash="505b8920f90d7af5cf09e815e5730a93"/><dir name="Updatedat"><file name="Collection.php" hash="a0f90a993ed70fd1adda36dc1a66ed1e"/></dir></dir><dir name="Rule"><file name="Collection.php" hash="771b2c8b33d233eb6d9bce7a7f880e7a"/><dir name="Customer"><file name="Collection.php" hash="bc371db1391974074a8aa8a8b719c4bb"/></dir><file name="Customer.php" hash="bb7ce9191d72f004a44013641bf38ac4"/><dir name="Product"><file name="Collection.php" hash="a8a62df60340b9a20035fb5c88872457"/></dir><file name="Product.php" hash="743ac84f509801340ac92952d97521ef"/></dir><file name="Rule.php" hash="c972025412fb5f531b709b8339a4867d"/></dir><dir name="Rule"><dir name="Action"><file name="Collection.php" hash="fad48a1e0d172cf50015cfed489df9a9"/><file name="Product.php" hash="899cfda115a181f3ed1e7f7dc320f017"/></dir><dir name="Condition"><file name="Address.php" hash="57556435014163ba73961cb8b2413f74"/><file name="Combine.php" hash="776e2fb5e3f152e70c3280d476011f76"/><dir name="Product"><dir name="Attribute"><file name="Assigned.php" hash="d981c3f7486bb60becc566329267d7d5"/></dir><file name="Combine.php" hash="ef7cc6d43ca96c3a0cf35095801e91a1"/><file name="Found.php" hash="351ebe3769717330a8b9ef971319e2b5"/><file name="Subselect.php" hash="56844666a23899ed9454aeadfe236e7a"/></dir><file name="Product.php" hash="44f952d096aa380ffcd16669eef5fa8f"/></dir><file name="Customer.php" hash="c67ccf31dc11f70be34803c04199debd"/><file name="Product.php" hash="48d130bb0e52c6eed39917b0e6e8ec41"/></dir><file name="Rule.php" hash="0095ccf926ee7550cf5811744a481774"/><dir name="System"><dir name="Config"><dir name="Source"><dir name="Coupon"><file name="Format.php" hash="00a3d50d33a25ead7adcb8b78b6a11bc"/></dir></dir></dir></dir><file name="Validator.php" hash="a77360dd111bb67dc3ff3ab8e19eb118"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f1d641409e95b4a606cf7ae575243cd4"/><file name="config.xml" hash="8fb7fdc054daf869b4adca215adafeda"/><file name="system.xml" hash="62888a487f9a077a97e962f9f5fe363f"/></dir><dir name="sql"><dir name="salesrule_setup"><file name="install-1.6.0.0.php" hash="4ff588a3f0c4ccf35fa2397c8b91a1e1"/><file name="mysql4-install-0.7.0.php" hash="a23c56ff9cbdac7509024202840d23c6"/><file name="mysql4-install-1.4.0.0.0.php" hash="a39e70beef1c7ea3e75ff031168c9d00"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="997f2d5225bc7918a86cfbb7046e3208"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="bcb109871d08fe03746b2d099d3f7e2e"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="2a33766197a359ff0069b9402cfe63ae"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="ca200dc284898ef45e3bea7d3e119db3"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="10e7b1b34289ff835d99eecb9a61dfec"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="aea3f32ffa01c60ddfc3925aa7ec3778"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="b966df9afad448c96c16cb7c78a9eaac"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="0db66744ac0846c22876582edee3c9e7"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="0517c2de9b809c31167d808c9939d185"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="2485c3b72c509b73892dfacb03f148a3"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="bbbd8c952701e3893076386e453e2f81"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="e5519218dcf0950044bb7c0d6028187f"/><file name="mysql4-upgrade-1.4.0.0.0-1.4.0.0.1.php" hash="ac46d45460c5c897c5a7facaa3e4b8d7"/><file name="mysql4-upgrade-1.4.0.0.1-1.4.0.0.2.php" hash="e0b75159537f13c2b75b1f83fbfc2083"/><file name="mysql4-upgrade-1.4.0.0.2-1.4.0.0.3.php" hash="253ca68169f6f044f04b18fafd74d540"/><file name="mysql4-upgrade-1.4.0.0.3-1.4.0.0.4.php" hash="b11964330203c4e34192b34e86d65b21"/><file name="mysql4-upgrade-1.4.0.0.4-1.4.0.0.5.php" hash="004721ffbc5a2d380a14864f08611b56"/><file name="mysql4-upgrade-1.4.0.0.5-1.4.0.0.6.php" hash="941b4b839bfe16a1f3874ba67f14f419"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="ac7e333071eb428749527e640bcd2c1e"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="27ce0d5d1598027bad1ace2feada0bb8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="18fa5d2dad035852fca429b986df8a4d"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="ae38a3fb75abc1a3dafb3b5278f27e0d"/></dir></dir></dir><dir name="Sendfriend"><dir name="Block"><file name="Send.php" hash="d0900cc748ef56c40c3551157156b6e3"/></dir><dir name="Helper"><file name="Data.php" hash="c8282d8b6b3610c761db46736e08fc8b"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Sendfriend"><file name="Collection.php" hash="122b8c8b50c55b13d867759cbdbaa9c6"/></dir><file name="Sendfriend.php" hash="61244da4dcae30c16dbb8d52fe2571f8"/><file name="Setup.php" hash="7b9ed257cc9bd891bae4bff716f22d0c"/></dir><file name="Observer.php" hash="301aa366775afba3bccc67529bdd0e65"/><dir name="Resource"><dir name="Sendfriend"><file name="Collection.php" hash="432e0466d874a74b3e1f4e10f1919b78"/></dir><file name="Sendfriend.php" hash="e5d542480b994ea78db380743bd782a0"/><file name="Setup.php" hash="6cb8411f99ae31fb4c7277675e3e26a9"/></dir><file name="Sendfriend.php" hash="0ccbc1ee40bc4796c2a3639399f891d9"/></dir><dir name="controllers"><file name="ProductController.php" hash="546740ca17ac1742f3e083e95c1541b0"/></dir><dir name="etc"><file name="config.xml" hash="3ce23230de553d3fee70b636ee972d1d"/><file name="system.xml" hash="8b1142ad25e62c9cd5d7ff49e94d55f9"/></dir><dir name="sql"><dir name="sendfriend_setup"><file name="install-1.6.0.0.php" hash="8337cc0478de35a6cbb12b2adfa46782"/><file name="mysql4-install-0.7.0.php" hash="495330536e267ecff7803b69d6a6ce58"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="db5bbae44f93fefeca37bc5f4a7ad02f"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="46cba5f2ec5161773cd2de5d40bb50be"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="905ed91131d6469ea8f8fc9b95b3c15a"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e699566eab2ede860af95c67836e0c1d"/><file name="mysql4-upgrade-1.6.0.0-1.6.0.1.php" hash="0321ede85958c89dff2672b3122fa975"/></dir></dir></dir><dir name="Shipping"><dir name="Block"><dir name="Tracking"><file name="Ajax.php" hash="60eb152db709b70af3a1301d7578c572"/><file name="Popup.php" hash="b3827ba58f592e3e378ba645db89b88d"/></dir></dir><file name="Exception.php" hash="c37e69239674d32986f8ff04caf09ba8"/><dir name="Helper"><file name="Data.php" hash="b176cad5e70504b035065f8790f56a33"/></dir><dir name="Model"><dir name="Carrier"><file name="Abstract.php" hash="1da2a6fe120aea258289b491a177b39f"/><file name="Flatrate.php" hash="b963278ed8e6f9a2c2d772b635d2a401"/><file name="Freeshipping.php" hash="6d35e8d3cd6ec02b1996435c87ed8d82"/><file name="Interface.php" hash="ec7d94e778fc9b56da5033417630587e"/><file name="Pickup.php" hash="3d6461ff7539d666ac8a91fa86ef6907"/><file name="Tablerate.php" hash="e26312f735d0740f7fe67700099314f4"/></dir><file name="Config.php" hash="e287066af283499ef8a2094963d4ac84"/><file name="Info.php" hash="49da8bcfd1fb2588bf3f358bbb595fa2"/><dir name="Mysql4"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="eb37ac0e4242114d7efc067ab84fa86d"/></dir><file name="Tablerate.php" hash="c1c7891ed4d60eaa07c2031050c118e4"/></dir></dir><dir name="Rate"><file name="Abstract.php" hash="c8120b50d7bd267a1cd5c2d709e17efe"/><file name="Request.php" hash="f0fb6eb354e53d6462614a2c219d3635"/><dir name="Result"><file name="Abstract.php" hash="e02a769764e6d75ef60ca85f8bd0b8a4"/><file name="Error.php" hash="ac860d8dff2e14d66bcdc3340d5be70b"/><file name="Method.php" hash="daae81ee20835511b24ca7367bf9f5f1"/></dir><file name="Result.php" hash="98ed87516d9efb709b14c395631bb9bf"/></dir><dir name="Resource"><dir name="Carrier"><dir name="Tablerate"><file name="Collection.php" hash="7265d1074c2edb0e64bf4a6fae8a74d0"/></dir><file name="Tablerate.php" hash="95421d9235b9935dcff724af1bfb061d"/></dir></dir><dir name="Shipment"><file name="Request.php" hash="e4efe7c8ad51ff44bf51b928b41d293f"/><file name="Return.php" hash="d4a688c26c39df16e3c22c526994d9d3"/></dir><file name="Shipping.php" hash="e3a8c48c31b9db700d0675f431773f75"/><dir name="Source"><file name="HandlingAction.php" hash="5b208e34e6b351c9aa7cff2b13983047"/><file name="HandlingType.php" hash="814c09576fde7947ef0cadffdf74aaec"/></dir><dir name="Tracking"><dir name="Result"><file name="Abstract.php" hash="159774fea23b004463db2ee8a9a60bcb"/><file name="Error.php" hash="dcfb4279dc5396c4e0b62b4e5c127e6d"/><file name="Status.php" hash="80df6a16b056bb8d87acdc1719824a34"/></dir><file name="Result.php" hash="bae51d8ec387de5741b61fd8638074bd"/></dir></dir><dir name="controllers"><file name="ShippingController.php" hash="1b3e10d476e8fe5d2e2d5fc62c4f3d57"/><file name="TrackingController.php" hash="fa19d9a3587e22e4027aaf0638470af1"/></dir><dir name="etc"><file name="adminhtml.xml" hash="3c1d155b5a034afb2250d25a8e3deb5f"/><file name="config.xml" hash="fd973e156b9c7525451d89bb19642035"/><file name="system.xml" hash="fc9f6b3f95040d578b12221fc8253f21"/></dir><dir name="sql"><dir name="shipping_setup"><file name="install-1.6.0.0.php" hash="36e7362e400987cecc8f40cedc89b207"/><file name="mysql4-install-0.7.0.php" hash="40a1d235256297f5b8356646b5d44b27"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="0cb07570004b1b9c15aae9fc53b3b3ef"/></dir></dir></dir><dir name="Sitemap"><dir name="Helper"><file name="Data.php" hash="0d1da1f7efa331833eea2e8d05ae2ef1"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Catalog"><file name="Category.php" hash="7cb44704862831285f1fb3024fe7bdc5"/><file name="Product.php" hash="8819b5bac443d29058a0caf7f36d6903"/></dir><dir name="Cms"><file name="Page.php" hash="c31f3e6eedbd0abbac79a0eca5f5c978"/></dir><dir name="Sitemap"><file name="Collection.php" hash="c9e5b30798bcf9de29efe6753a818c46"/></dir><file name="Sitemap.php" hash="080840f73523fc3c0cfbc26ef936f1ea"/></dir><file name="Observer.php" hash="0c525f0c8827adf6d45977abb0402997"/><dir name="Resource"><dir name="Catalog"><file name="Abstract.php" hash="ddeadf2425c985b44414fa19bdefde0c"/><file name="Category.php" hash="0805c996fb090101c66dbb187cc7a2dd"/><file name="Product.php" hash="3cb064607f3f8fbda715703fbd45c35b"/></dir><dir name="Cms"><file name="Page.php" hash="4f45f86704cdf27e8692bf92a07f38ec"/></dir><dir name="Sitemap"><file name="Collection.php" hash="f8f4b4c5c5227b4f2f2fc81ec39f47c6"/></dir><file name="Sitemap.php" hash="3ead76a8aaa778f199ba6a8846e9a46d"/></dir><file name="Sitemap.php" hash="15c53139c1f7417e58af0e0a50bd62dc"/></dir><dir name="etc"><file name="adminhtml.xml" hash="1af1c3ddee5195d95d8d2c6b4f7751e3"/><file name="config.xml" hash="e2e449e864d63173cd0decd800a1976d"/><file name="system.xml" hash="b2fd807782eb88310235daa07b9289a5"/></dir><dir name="sql"><dir name="sitemap_setup"><file name="install-1.6.0.0.php" hash="baa0c6a53cde49b484eda4027d249f5f"/><file name="mysql4-install-0.7.0.php" hash="2f99e2e6056dcb50bb50b16dd3adf6c3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3eea98e870b7a12f972b711972a41187"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="b7a5bf92b87d01f5fc7da34dcf779e08"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="b08a230d237e71d5c4d14113515c7b1b"/></dir></dir></dir><dir name="Tag"><dir name="Block"><file name="All.php" hash="9c586fa6c438210796b468861f021367"/><dir name="Customer"><file name="Edit.php" hash="48d9e49362f4d5624122a0c349a9da81"/><file name="Recent.php" hash="39a93ccd93d60d313ddba2430eb14278"/><file name="Tags.php" hash="575bb1a6e7321d4c07c80e85c1e536db"/><file name="View.php" hash="c51497ef2e787f5ed2d76ff31d297f94"/></dir><file name="Popular.php" hash="5e5aca7c58279a31ac8b7d819068c5d3"/><dir name="Product"><file name="List.php" hash="61bed3264fee80e1d495d705c78e3d96"/><file name="Result.php" hash="46df943675b8b838565df0df27834aa2"/></dir></dir><dir name="Helper"><file name="Data.php" hash="63d5f8bac429ec76ded751f08f199ea7"/></dir><dir name="Model"><dir name="Api"><file name="V2.php" hash="41c01c559d89f06ee8023984e39f341e"/></dir><file name="Api.php" hash="8c474827c3bd4085e3555e5b15518362"/><dir name="Entity"><dir name="Customer"><file name="Collection.php" hash="8d3f5a320ff6b9d8043dce39a6b00e28"/></dir></dir><dir name="Indexer"><file name="Summary.php" hash="da30d3f02de6867f52c02f74e5555c43"/></dir><dir name="Mysql4"><dir name="Customer"><file name="Collection.php" hash="b15f6d56b7a0370e8c36960e37c40ad8"/></dir><dir name="Indexer"><file name="Summary.php" hash="1677838d9e08726293ffdcc1a2a6a85f"/></dir><dir name="Popular"><file name="Collection.php" hash="e4b4a4d0a72ce42fba06b8d4df7cf881"/></dir><dir name="Product"><file name="Collection.php" hash="1b9c603a27674640553f8dddae1c3f61"/></dir><dir name="Tag"><file name="Collection.php" hash="195c1947f180ecd78bd8cc847a1c7541"/><file name="Relation.php" hash="74f25bf44aa6b8cac257e1563d5d2c0d"/></dir><file name="Tag.php" hash="efbd45b16d9062b73bee4e08732a6b2d"/></dir><dir name="Resource"><dir name="Customer"><file name="Collection.php" hash="ccef3608754c4bcfa32f17bae739d8ac"/></dir><dir name="Indexer"><file name="Summary.php" hash="363aaf754a1fef7684d995eaaa22c28c"/></dir><dir name="Popular"><file name="Collection.php" hash="656a1074cce99c835368a024ba45b58e"/></dir><dir name="Product"><file name="Collection.php" hash="71615e51db871bbf120514b12b456769"/></dir><dir name="Tag"><file name="Collection.php" hash="44a1ed8a1bff0c2b03dffcce228e4212"/><file name="Relation.php" hash="c80e4c0ba17e7f652c1dab298a07b615"/></dir><file name="Tag.php" hash="59dfe8a1e9621b64d8931b3b8a2f3157"/></dir><file name="Session.php" hash="b368fc576c8007cc36fcb51a28bb9a0d"/><dir name="Tag"><file name="Relation.php" hash="46200ffd008a5c7a40b620efe55b9272"/></dir><file name="Tag.php" hash="f6a664777ff027c6ff42fe3490125280"/></dir><dir name="controllers"><file name="CustomerController.php" hash="1e1bf9cb8bb6bd08e4b323673f6f0df7"/><file name="IndexController.php" hash="b3af6f013465abf3f0919b1bee6edf36"/><file name="ListController.php" hash="6d959bda65cdcb6f4d42a64e0c158f13"/><file name="ProductController.php" hash="9d02acffcfb4fe104f4c968bb4c3a7a6"/></dir><dir name="etc"><file name="adminhtml.xml" hash="87ff7b15b28edcfe304e4e5e68181339"/><file name="api.xml" hash="f5d2a45711c4a0dc4a7a53b7a0073769"/><file name="config.xml" hash="551ae7849f99b711c7e803e84e7800d9"/><file name="wsdl.xml" hash="e87343a710e0068dcc555ffc4b302a9b"/><file name="wsi.xml" hash="1d31787826a686590acf89ec2703b76e"/></dir><dir name="sql"><dir name="tag_setup"><file name="install-1.6.0.0.php" hash="c20cb71c35fc2bf52e63d91ffb03ab85"/><file name="mysql4-install-0.7.0.php" hash="ef39d408e4238c387220c3f03fe0a2f3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="3ac5fb48d5d88cfe81eddbecd5999840"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="421fe4350055fe9d9cc0e344215a3191"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="0e9ffe30aa58782b7d98db353edd7b43"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="15ab9bc5f0b17b294442748151f589c7"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="5eabbeea53bdb58142c8e77c35ada312"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="8d4b452e1f4a48eca7cee4d93ac57ad4"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="11efa2e8721861477941822c798799c0"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="65b46e90600a4da74ddf399dd6d566b9"/></dir></dir></dir><dir name="Tax"><dir name="Block"><dir name="Adminhtml"><dir name="Frontend"><dir name="Region"><file name="Updater.php" hash="beb7c108a4d58bf1807da68347e998ed"/></dir></dir><file name="Notifications.php" hash="877b42a681cb850d2f810b3c537b0b25"/></dir><dir name="Checkout"><file name="Discount.php" hash="f6b150a93995ffb864e841dd0c8da3a0"/><file name="Grandtotal.php" hash="18984bad028645b775779fdcd0d1ece1"/><file name="Shipping.php" hash="9af18eb97f235ed93a29b0cf9d60c525"/><file name="Subtotal.php" hash="62c887dc953d0cb81e82c20b50f6d53a"/><file name="Tax.php" hash="d100b6329e5c2109c995eaa0e0bed2ec"/></dir><dir name="Sales"><dir name="Order"><file name="Tax.php" hash="824870e67250cef4dad26ff4d5ad3163"/></dir></dir></dir><file name="Exception.php" hash="0288092bf16f117a251a68cd4615da1f"/><dir name="Helper"><file name="Data.php" hash="f00cd6b47d65f6cc4491af4dc8b77579"/></dir><dir name="Model"><dir name="Calculation"><dir name="Rate"><file name="Title.php" hash="eb8738069f4b44b0a4ef8848cf76fc10"/></dir><file name="Rate.php" hash="598d9df4f531764c227bac73584d787c"/><file name="Rule.php" hash="bddc2fa731b7233bc5fbedf45b97940b"/></dir><file name="Calculation.php" hash="b5519c3f29d263d9f0cee6b9aa3b20a2"/><dir name="Class"><dir name="Source"><file name="Customer.php" hash="0bd655313bcc6173ef8a567738eace67"/><file name="Product.php" hash="67cc75ab50a0dc7c2fe4a7161c082b5c"/></dir></dir><file name="Class.php" hash="1998d3c9588d16ba5a09142e76cf08ba"/><dir name="Config"><file name="Notification.php" hash="7208ba27883fd27e2806501d6259c2ba"/><dir name="Price"><file name="Include.php" hash="9415f30261fd589c0eab19d01a8e49ed"/></dir></dir><file name="Config.php" hash="d76e7f2c21563f450be0ad26e979ec03"/><dir name="Mysql4"><dir name="Calculation"><file name="Collection.php" hash="aaaf63f8d359ae9db2e7e211c6362d63"/><dir name="Rate"><file name="Collection.php" hash="8101da309f4bec11d9fff4afcd712379"/><dir name="Title"><file name="Collection.php" hash="6e50bf3eb1876c57b38745540fbb48d7"/></dir><file name="Title.php" hash="2a7c7e0ba65a7ea3a7af60941c1d464d"/></dir><file name="Rate.php" hash="9d8c18fa37a08f999ba9b22802d79aa9"/><dir name="Rule"><file name="Collection.php" hash="930edbdf3be5e2639a6d36ce5ca3da83"/></dir><file name="Rule.php" hash="221b5b00fff11e724cfc0cbdababa293"/></dir><file name="Calculation.php" hash="36495ff2315c6f8de48d4f28067ed567"/><dir name="Class"><file name="Collection.php" hash="77fdc197709c96c363fbf0d99dd71e8c"/></dir><file name="Class.php" hash="a13f5209537394288b026be6e04a105e"/><dir name="Report"><file name="Collection.php" hash="3e81ba620644a90f092bd0bc49366aa2"/><file name="Tax.php" hash="a5f9f107397fbc625105e7320c727c67"/><dir name="Updatedat"><file name="Collection.php" hash="a957bc0a2e1b24154ec184459c776178"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="077b167b7c0f031bc5113663d8880869"/></dir><file name="Tax.php" hash="d4702750f1bf5998e5056fb3dee8ed8f"/></dir></dir><file name="Setup.php" hash="e47b718538ded1126b82b9602d681d41"/></dir><file name="Observer.php" hash="d7efde9dd0cf39008662e2a8fec7a1a1"/><dir name="Resource"><dir name="Calculation"><file name="Collection.php" hash="1c569680aecbe5eab48ac45d05bdb6d2"/><dir name="Rate"><file name="Collection.php" hash="502be4d7ff30a162b7fa6368ab2112cd"/><dir name="Title"><file name="Collection.php" hash="aa43e7ad8084224399c9c066151bf705"/></dir><file name="Title.php" hash="8775240533d3a739b9b2fa9cd9482954"/></dir><file name="Rate.php" hash="d87edc2b2de1d830769bf91f72130ac8"/><dir name="Rule"><file name="Collection.php" hash="076e02339bd518be4fe9be6b3fbbff5c"/></dir><file name="Rule.php" hash="32803fa33d812af96fe1b9ceaab4abc9"/></dir><file name="Calculation.php" hash="688202244165823959d54e9d4b6363ab"/><dir name="Class"><file name="Collection.php" hash="5b47f5009f103c633bde387ac7adea4f"/></dir><file name="Class.php" hash="332c61fe7cb39e8203e55ae0f0d99fad"/><dir name="Report"><file name="Collection.php" hash="8bcdfc9f2d9211061822dfc870b98f62"/><dir name="Tax"><file name="Createdat.php" hash="d50b75e5628b6986f83479c6de48c369"/><file name="Updatedat.php" hash="069f0f7f45a8491b1eb51b1329674919"/></dir><file name="Tax.php" hash="e608ad7cfdd88ea1f9b6c7295708527e"/><dir name="Updatedat"><file name="Collection.php" hash="45bc6713a12931c6c43417182a5e6d67"/></dir></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Collection.php" hash="4798023eae71bac870b9bf164f57c21c"/><dir name="Item"><file name="Collection.php" hash="801e5275a9825c988327d6a1e0b55681"/></dir><file name="Item.php" hash="76adc830a3be5a27cf1bf1306221809e"/></dir><file name="Tax.php" hash="b1ff6195e235e016961f77cdaaf0cbed"/></dir></dir><file name="Setup.php" hash="dbdaed9eebb4822bda049ed4817a88af"/></dir><dir name="Sales"><dir name="Order"><dir name="Tax"><file name="Item.php" hash="1b581b47646f91bd1b98532595d6e44f"/></dir><file name="Tax.php" hash="9d4682194bcbbb567b6955b5e1ebe5c7"/></dir><dir name="Pdf"><file name="Grandtotal.php" hash="107952415d87c39e57cb64b34e4808bb"/><file name="Shipping.php" hash="1e86efcc35e93d89a13f239ee6b909b0"/><file name="Subtotal.php" hash="67ad16e534c7a6cd9cd2ea403b104460"/><file name="Tax.php" hash="d50ccdb4ae7f9f6f4cee8881740cf0d5"/></dir><dir name="Total"><dir name="Quote"><file name="Discount.php" hash="68e59646d4b3ed53cbef37278cb7fbbd"/><dir name="Nominal"><file name="Subtotal.php" hash="4f93a5807d975b92dad5b352f016697b"/><file name="Tax.php" hash="c809da9b571e1261579fa4e71ca1792f"/></dir><file name="Shipping.php" hash="1d0b5484d1912fc947ad4ab0527ea34a"/><file name="Subtotal.php" hash="5bb1ed31fd267d596f755d01a959a65e"/><file name="Tax.php" hash="10de0057288a63ed198dd29b5385dc84"/></dir></dir></dir><dir name="System"><dir name="Config"><dir name="Source"><file name="Algorithm.php" hash="347f5adebdd1619f6959cd3cc134f939"/><file name="Apply.php" hash="53d1f5b5c4a08070a783db8b72caeffd"/><file name="PriceType.php" hash="57c083bbde3ebd93602c6a40d2a6202e"/><dir name="Tax"><file name="Country.php" hash="12331f21e79b44fef3d6e9b1c0b34acd"/><dir name="Display"><file name="Type.php" hash="fcfcb7a434ea1fa9db79cd09cbac31b1"/></dir><file name="Region.php" hash="4b59757baeba8007f3809864d360f62e"/></dir></dir></dir></dir></dir><dir name="data"><dir name="tax_setup"><file name="data-install-1.6.0.0.php" hash="94b4f10de8f7a5a83fe087f06ac92739"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="4468e87f67dfbf16d33b9b2707ee26ad"/><file name="config.xml" hash="350957182c80c7d5e65451b96518fcbe"/><file name="system.xml" hash="bc6897ce79eacc48bd78a78c05828dc0"/></dir><dir name="sql"><dir name="tax_setup"><file name="install-1.6.0.0.php" hash="e0be5cd38897e0a29101a479a3c46576"/><file name="mysql4-install-0.7.0.php" hash="7fe22036e27e3228ef62c1b33ec84dd1"/><file name="mysql4-install-1.4.0.0.php" hash="9dec0361305355dc82b262882ccd81a9"/><file name="mysql4-upgrade-0.6.1-0.7.0.php" hash="d10c616c3450a99a2a070bd82be749d3"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="8ca3ac7b724434fc4580e89544ffc74c"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="0d67a01efd09ef2052d61e0c5e7bd980"/><file name="mysql4-upgrade-0.7.10-0.7.11.php" hash="8bbdcaf5614446a39c3cf669a45aa607"/><file name="mysql4-upgrade-0.7.11-0.7.12.php" hash="76a54f836cacb813942ffffc0f6cde04"/><file name="mysql4-upgrade-0.7.12-0.7.13.php" hash="579ed14c0fe3b95f41853eaef2d37374"/><file name="mysql4-upgrade-0.7.2-0.7.3.php" hash="c2dd0bdfccdc77a0a29d555a9b625ae3"/><file name="mysql4-upgrade-0.7.3-0.7.4.php" hash="e72fc20271969d7dc72fd6e11c87e562"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="326b3250a99912852647ae1f1a617f0b"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="2044ce6c72fa421cebbc936cdc3b9551"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="b4345cee38819d7335f8a4ac43a719c5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="d81466fa4aafe13fa8b643b9d9604a8f"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="005cb7ce377789522ee6113cc6faaf01"/><file name="mysql4-upgrade-0.7.9-0.7.10.php" hash="a45ecf83147580fd0b205cc5ba8ceb93"/><file name="mysql4-upgrade-1.3.9-1.4.0.php" hash="51c32172a42fe9bfb70246891955f7ac"/><file name="mysql4-upgrade-1.4.0.0-1.4.0.1.php" hash="1f40a8d2e8e62f6c7a5c6a801dcefec5"/><file name="mysql4-upgrade-1.4.0.1-1.4.0.2.php" hash="38940a651a3ccd71d6b51f2c56292df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="99f59a5a323d2ab93979bd978a71596b"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="c7b5e7a2c05c6bb645b16677ad022aa7"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="c40b4ac8f47a6e66aed870bc548424fe"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="39a4fa13ba11365822088398b51e5d7c"/><file name="upgrade-1.6.0.3-1.6.0.4.php" hash="a4fc58b853d6f51e1984160027bb54aa"/></dir></dir></dir><dir name="Uploader"><dir name="Block"><file name="Abstract.php" hash="3e4c27fef40ca4b4d06e9fbade2fc708"/><file name="Multiple.php" hash="6ad3435e9621366e3002f0fffdbb87a5"/><file name="Single.php" hash="6b7a9c61b8638188d753fd3d61326019"/></dir><dir name="Helper"><file name="Data.php" hash="9d9fe520b988530cf96c9d63df4e0273"/><file name="File.php" hash="74ec342ff936338e70a26356dd7a7008"/></dir><dir name="Model"><dir name="Config"><file name="Abstract.php" hash="9c894362a1fe640a42d12e2ab9dfd8d6"/><file name="Browsebutton.php" hash="33d4e27b9df48a99becd6b4804236ddd"/><file name="Misc.php" hash="f329b6490eec11bbfacb36becfd0331c"/><file name="Uploader.php" hash="458ca8fd03fb3358c8d44c551dec43b1"/></dir></dir><dir name="etc"><file name="config.xml" hash="910b0e0ba92f5510fb8a8de346fc9b47"/><file name="jstranslator.xml" hash="40957bd0383e10b88d3d245e7402b432"/></dir></dir><dir name="Usa"><dir name="Block"><dir name="Adminhtml"><dir name="Dhl"><file name="Unitofmeasure.php" hash="10997c949618283fcff3700837ddc369"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="558952e017a826983a6520f46e055ff0"/></dir><dir name="Model"><dir name="Shipping"><dir name="Carrier"><dir name="Abstract"><dir name="Backend"><file name="Abstract.php" hash="f69a281efe5ecaa85da5aec4b006f76c"/></dir><dir name="Source"><file name="Mode.php" hash="778451ea932baa5cf37697361ba5cae7"/><file name="Requesttype.php" hash="bb39b74b50887b170b0e9d838b5e2c66"/></dir></dir><file name="Abstract.php" hash="e1907149de0a3216004d3b4afa7afcb4"/><dir name="Dhl"><file name="Abstract.php" hash="0efbaa4bd4be9577339b213e882c548b"/><dir name="International"><dir name="Source"><file name="Contenttype.php" hash="e5359c32016f64a446917a655febd027"/><dir name="Method"><file name="Abstract.php" hash="ec7de521c44ed74b7a2803e3b81b1731"/><file name="Doc.php" hash="e58bed061386ca4a31f5c3520880b59a"/><file name="Freedoc.php" hash="f8ff29721fd591b809e51386a6ddbb9d"/><file name="Freenondoc.php" hash="655f111e076d1df9e9ba2a28397b561f"/><file name="Nondoc.php" hash="ce6ff2b22825d59552add3e3b3447c9a"/><file name="Size.php" hash="7b6e56c60b13a2dda8cf36ca4e1dc9ce"/><file name="Unitofmeasure.php" hash="9439cef75a91f110f5bec57c9677f545"/></dir></dir></dir><file name="International.php" hash="1aa74aea3c781fad751eb0721d8c5a70"/><dir name="Label"><dir name="Pdf"><file name="Page.php" hash="e66a0164e6463860135a132dc7895f01"/><file name="PageBuilder.php" hash="5bc6169b5bb68bc2da765e22cef408b4"/></dir><file name="Pdf.php" hash="46552005b344e2ad2daa13c2d8425177"/></dir><dir name="Source"><file name="Dutypaymenttype.php" hash="411ea53d37b0f580aef05290e7c69418"/><file name="Freemethod.php" hash="27aa2a02f19a892afec2bdfd862ea345"/><file name="Method.php" hash="841058d6dc0799bfacf30117871b0bc9"/><dir name="Protection"><file name="Rounding.php" hash="5107a44097c80fe3cbdbd833e7aa05d9"/><file name="Value.php" hash="14acb56219a067f77d7a3eab5406ac0b"/></dir><file name="Shipmenttype.php" hash="1305407602b8d6dbe650a32615bea321"/></dir></dir><file name="Dhl.php" hash="1525b3a3027bcaa419070242fb169599"/><dir name="Fedex"><dir name="Source"><file name="Dropoff.php" hash="aa425f98db3ba3bf9db264c20f2bf416"/><file name="Freemethod.php" hash="4eb4e8853d7f22f520c9d9b45ce27bca"/><file name="Method.php" hash="ac3c72ee7ca1ed4ac173660962e5b0b2"/><file name="Packaging.php" hash="e1111b6983c3a17869a51acd2d0f66cb"/><file name="Unitofmeasure.php" hash="7a5a94c0b97a5edc53782429b3927e86"/></dir></dir><file name="Fedex.php" hash="96d58629ed7b43932590a2a1d1c2e8e7"/><dir name="Ups"><dir name="Backend"><file name="Freemethod.php" hash="578cfe6da0fc52a9ccbf6896c7814030"/><file name="OriginShipment.php" hash="9f63eb33f4d0b9049a99d0d09251a974"/><file name="Type.php" hash="63f031871c1afd0ad464739002d6d18f"/></dir><dir name="Source"><file name="Container.php" hash="49f0d3eb8e52d5f8475a46f1952f52e5"/><file name="DestType.php" hash="fa1e1c6fcb60164ad648354e4648c6d0"/><file name="Freemethod.php" hash="7001561ea932cab7850b2136639c729b"/><file name="Method.php" hash="d1764d9b630f3306457384f87d262b79"/><file name="Mode.php" hash="6cbed4f0cfc486d75e35a7f9fca2a682"/><file name="OriginShipment.php" hash="5984b00f373bc8e95b344b32c3ae8d3a"/><file name="Pickup.php" hash="0b71e6481183c757ee6f3838bd7d146d"/><file name="Type.php" hash="5cd443e78fc2b12b8f96ad35b2cbc488"/><file name="Unitofmeasure.php" hash="8638b87440d4879ad2f5ee66898350cf"/></dir></dir><file name="Ups.php" hash="6454a3a22b8c6c6a8b8d3e38c7e2e1e1"/><dir name="Usps"><dir name="Source"><file name="Container.php" hash="ee6ba442e8ef11d24e53863075076575"/><file name="Freemethod.php" hash="57a6bcdc91fd3349d9f3a9544b7104fb"/><file name="Machinable.php" hash="eee52b5666bd94d3715b57346c1e0c32"/><file name="Method.php" hash="8efa1defbf4156700d26d60fbde252d5"/><file name="Size.php" hash="945f74071f8d37f367c5401cd90ea637"/></dir></dir><file name="Usps.php" hash="7c7a5d30b09e9f79d2e15ca492ad5d96"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f1246bda795b64de06487596bb03afde"/><dir name="dhl"><dir name="international"><file name="countries.xml" hash="8d254d9563909fbd3e7f103efb4b4cee"/></dir></dir><file name="system.xml" hash="f93f4300a2166bd43f9f208e79098e39"/><dir name="wsdl"><dir name="FedEx"><file name="RateService_v10.wsdl" hash="352ed0cd739b31d42d206aba31bf4c31"/><file name="RateService_v9.wsdl" hash="5e698519a3b3ae3dcea2105545053763"/><file name="ShipService_v10.wsdl" hash="4e661e70491a1af695c27878610054e2"/><file name="ShipService_v9.wsdl" hash="9c3779aa87540dcae41b43b16b724df6"/><file name="TrackService_v5.wsdl" hash="89cc7077a8fc439446e70bac0ca0f0c1"/></dir></dir></dir><dir name="sql"><dir name="usa_setup"><file name="install-1.6.0.0.php" hash="60c7ae9339249f390863deb05fe47784"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="1d01eca26e39ae48c0d3e427cfa1ab34"/><file name="upgrade-1.6.0.0-1.6.0.1.php" hash="2ea78f90b818e7cd228e83b8537b41e8"/><file name="upgrade-1.6.0.1-1.6.0.2.php" hash="1e2088d771a4e0b83d6e93891517b6f1"/><file name="upgrade-1.6.0.2-1.6.0.3.php" hash="758ef4152248dd60f9b3d941cbfd5026"/></dir></dir></dir><dir name="Weee"><dir name="Block"><dir name="Element"><dir name="Weee"><file name="Tax.php" hash="fd0f736c3d8545402e22118356162592"/></dir></dir><dir name="Renderer"><dir name="Weee"><file name="Tax.php" hash="3e6e14e572b75bd7294f08492fcf2402"/></dir></dir></dir><dir name="Helper"><file name="Data.php" hash="fd44707f27deb17645e7751740474cc6"/></dir><dir name="Model"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="84e0853d03e58f02dcfe8516110d4507"/></dir></dir></dir><dir name="Config"><dir name="Source"><file name="Display.php" hash="dd9b92f8467686bbea476a3ff1bfdcaf"/><dir name="Fpt"><file name="Tax.php" hash="3a4856fc7ef23c693b9e80ca535a0e70"/></dir></dir></dir><dir name="Mysql4"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="860cc567b8fc31a75afd88aba680a725"/></dir></dir></dir><file name="Setup.php" hash="07f6c26a85349e879b1ed3cbc5404ab4"/><file name="Tax.php" hash="d401f1ab63bd5f3a8f7bc821ccb394d4"/></dir><file name="Observer.php" hash="b513b4d768c5ba4adc809485fdae6f24"/><dir name="Resource"><dir name="Attribute"><dir name="Backend"><dir name="Weee"><file name="Tax.php" hash="77a42d4f015dceb9c8f4417415264b21"/></dir></dir></dir><file name="Setup.php" hash="fb6cd54cce66fa17c1830c238e29f377"/><file name="Tax.php" hash="c56763433b9e30cb95098e87ed696397"/></dir><file name="Tax.php" hash="32cd2697d7378f1eb60338b50aef134f"/><dir name="Total"><dir name="Creditmemo"><file name="Weee.php" hash="c56a76968ee4caa1864464fd29cefad1"/></dir><dir name="Invoice"><file name="Weee.php" hash="209638b57ec140cd66d5ac20a0cde1c7"/></dir><dir name="Quote"><dir name="Nominal"><file name="Weee.php" hash="8ae9e90a10b8dafab07435b26448bd99"/></dir><file name="Weee.php" hash="2f8c089417d978dcaaa3d656753e5952"/></dir></dir></dir><dir name="etc"><file name="config.xml" hash="f157980d75f3045c3a3a37ba7f6946f5"/><file name="system.xml" hash="43de9ea6b63cc96ab3e604e05ccb3247"/></dir><dir name="sql"><dir name="weee_setup"><file name="install-1.6.0.0.php" hash="a034deb1eddaa3d760f78ac3eb89dc4f"/><file name="mysql4-install-0.1.php" hash="2be73cb26708c54b64e7ed7165871924"/><file name="mysql4-upgrade-0.1-0.2.php" hash="200335244e836f11760a34534644126a"/><file name="mysql4-upgrade-0.10-0.11.php" hash="d2f31b8932743ebc6d497b910a106c83"/><file name="mysql4-upgrade-0.11-0.12.php" hash="98b5c962ad1991f4d698141fb41f212a"/><file name="mysql4-upgrade-0.12-0.13.php" hash="834fefba3bbf0cc63fb9997963ff1589"/><file name="mysql4-upgrade-0.2-0.3.php" hash="742e6f9e862bc4ebce15fa024805759e"/><file name="mysql4-upgrade-0.3-0.4.php" hash="4862530eb12a216c98dadb26793ff88a"/><file name="mysql4-upgrade-0.4-0.5.php" hash="0f301cf23c99e77c07649927172588bb"/><file name="mysql4-upgrade-0.5-0.6.php" hash="7b3bc07ac584ec31d163e9dd6c35d750"/><file name="mysql4-upgrade-0.6-0.7.php" hash="6dcd142adc03c785556a68679e4499f5"/><file name="mysql4-upgrade-0.7-0.8.php" hash="e0c094146fd1441de27c04c25e7c5e37"/><file name="mysql4-upgrade-0.8-0.9.php" hash="3b45b9510084a408c5370a6b9d323807"/><file name="mysql4-upgrade-0.9-0.10.php" hash="38844cce782c07afea0fe477a24c1fcf"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="bbb550408e834459dc0c24e395e301f3"/></dir></dir></dir><dir name="Widget"><dir name="Block"><dir name="Adminhtml"><dir name="Widget"><file name="Chooser.php" hash="f41f4a5d4abbb5317de07d76c0af9ce5"/><file name="Form.php" hash="2f430de2e4b79346ac15bc2db84a6086"/><dir name="Instance"><dir name="Edit"><dir name="Chooser"><file name="Block.php" hash="35b0a2189584bd507cba9273413713bf"/><file name="Layout.php" hash="4a3c6e4105a35ca9469b83a677a15aab"/><file name="Template.php" hash="d5bff7a35634d46aec79c838ef8028c7"/></dir><file name="Form.php" hash="e5c088065bbcc2f34b6b921a29434873"/><dir name="Tab"><dir name="Main"><file name="Layout.php" hash="4f72e2287ef012ae37a7d7ef1e56ecac"/></dir><file name="Main.php" hash="856e66104b67ba24ac31f8db4d90d36e"/><file name="Properties.php" hash="a03aabc3764bb85938af96b9f8865a8b"/><file name="Settings.php" hash="66721fb67187c4d84a064349697b4383"/></dir><file name="Tabs.php" hash="cd9abdda69b86e35e80d62282d7c083b"/></dir><file name="Edit.php" hash="e44bea2b39f359f75cccec1996681143"/><file name="Grid.php" hash="fc2f183e4fdb3120aa8132f3f045fe71"/></dir><file name="Instance.php" hash="2d2368b22010c6aa68698b61d9412702"/><file name="Options.php" hash="0ee8355dd026bf75ca4026cd5e6eb3a3"/></dir><file name="Widget.php" hash="0efda79c01989b1b371be56f094df65d"/></dir><file name="Interface.php" hash="7e8e943dbf9c350738e0c7b87bf33873"/></dir><dir name="Helper"><file name="Data.php" hash="fb9cd633320087c35b78e251572d4a3d"/></dir><dir name="Model"><dir name="Mysql4"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="fb7c16f16ca147b4b0277f705264615e"/></dir><file name="Instance.php" hash="33b19185739fa245b0ab24743f0da1ff"/></dir><file name="Widget.php" hash="669f7241dfd0a221866b183488d5d676"/></dir><file name="Observer.php" hash="3da4b54327a1f24dff9d479ea39d4004"/><dir name="Resource"><dir name="Widget"><dir name="Instance"><file name="Collection.php" hash="e07e92d933818e5ca96c67778a3f9286"/></dir><file name="Instance.php" hash="531253749642a5e9d5038879d48bab57"/></dir><file name="Widget.php" hash="ac5884a08704af82ca4b8a0dcbc61127"/></dir><dir name="Template"><file name="Filter.php" hash="72fd9c6fbcb49e145fc78728fb927ea0"/></dir><dir name="Widget"><file name="Config.php" hash="f439b671f2f89ca440a7f9ea3e01c60b"/><file name="Instance.php" hash="c5d1e18924f417073eb5ee65917cb7e4"/></dir><file name="Widget.php" hash="d691a3d871172a98fa64684d2c6e4910"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Widget"><file name="InstanceController.php" hash="63939b7121ca34e33ec7c5c303ec79ab"/></dir><file name="WidgetController.php" hash="5296aaec9297cc6a5eae90ddeb423ba5"/></dir></dir><dir name="etc"><file name="adminhtml.xml" hash="2d49ebc683d76e660e80f670aa824cb3"/><file name="config.xml" hash="d513372267bcab378f3490305c74aac7"/><file name="jstranslator.xml" hash="33ef3294aecd2ecf7d7918a12b8ccbd2"/></dir><dir name="sql"><dir name="widget_setup"><file name="install-1.6.0.0.php" hash="ee2405ce1bda7a5fd724c6e6579e6c23"/><file name="mysql4-install-1.4.0.0.0.php" hash="303d557b443da9a0b648e0b489db8df2"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="f26a2433a7568fdcc02a348d95efb285"/></dir></dir></dir><dir name="Wishlist"><dir name="Block"><file name="Abstract.php" hash="d41153ea1f2fd24037aa23ea1b02bbb0"/><dir name="Customer"><file name="Sharing.php" hash="693a4499b8c54044686c0450eb624f4f"/><file name="Sidebar.php" hash="c5a5f3501e9e4d95835da6beb107b569"/><dir name="Wishlist"><file name="Button.php" hash="9116b58cbcd737532fa9ab1368226915"/><dir name="Item"><dir name="Column"><file name="Cart.php" hash="1abc6a7fbce4370166aede5f704efcdf"/><file name="Comment.php" hash="411e2ffd53fecd487f416e8c97466be7"/><file name="Image.php" hash="e4fea81d458007fff38347b281f46016"/><file name="Remove.php" hash="183986e5e3c1ade450540b0061cfe184"/></dir><file name="Column.php" hash="ffd2c66332126dd318f30a5e285c3fe2"/><file name="Options.php" hash="3113081b2adcc919ce92a727ed83bd8e"/></dir><file name="Items.php" hash="d2bb5dff0a7138d97df7819fa1755149"/></dir><file name="Wishlist.php" hash="e80f560419ea9dc2ea0d3a9216638a8c"/></dir><dir name="Item"><file name="Configure.php" hash="3e9b9a068f1d885f7ba02c5d941529bb"/></dir><file name="Links.php" hash="25b1030ea691741332070314c09507e1"/><dir name="Render"><dir name="Item"><file name="Price.php" hash="9b022ae29781b7b542130588ad72e080"/></dir></dir><dir name="Share"><dir name="Email"><file name="Items.php" hash="d6a9ed3eb79687ba3fd613a80b0b77cb"/><file name="Rss.php" hash="49efbf8d871afeba9f65b5fcc0dbcd1b"/></dir><file name="Wishlist.php" hash="1d541e90a5793b84fe6eaca98dcbd49f"/></dir></dir><dir name="Controller"><file name="Abstract.php" hash="8645269d5466e6bd4b5e4e875a9d2216"/></dir><dir name="Helper"><file name="Data.php" hash="86851e022187af87ad203e235da38d53"/></dir><dir name="Model"><dir name="Config"><dir name="Source"><file name="Summary.php" hash="7a2b80db4fe6a978b5786e76a5c904fc"/></dir></dir><file name="Config.php" hash="2b2911baaf1c7185c3326e0ce0557a31"/><dir name="Item"><file name="Option.php" hash="6dd700cd04aab1da4261c3482b314bf2"/></dir><file name="Item.php" hash="1c0f79a254b69e888c6a59d781aa2c44"/><dir name="Mysql4"><dir name="Item"><file name="Collection.php" hash="ee47fa47f801be5897e46cb6a1b414e4"/><dir name="Option"><file name="Collection.php" hash="1d69f4047866ceba682ebba1760b7882"/></dir><file name="Option.php" hash="e8d6eb6783c0d110e1fb9019c18ae1bb"/></dir><file name="Item.php" hash="ed1dee8fe9f393fbbc09080bec44bb0e"/><dir name="Product"><file name="Collection.php" hash="d0d3b256caa2f2cf82b6749e71a1e250"/></dir><dir name="Wishlist"><file name="Collection.php" hash="f0de345db6724cf0f2215ca3d6e2c55a"/></dir><file name="Wishlist.php" hash="847ae12dfb58e6a7cfce9f225aa3c208"/></dir><file name="Observer.php" hash="2d1514b092fc4e0bc9476950f56d2e98"/><dir name="Resource"><dir name="Item"><file name="Collection.php" hash="1cb2d243a6a5f3e0a68fd3adad2ad37a"/><dir name="Option"><file name="Collection.php" hash="d0929064f2c7a8342fda1e353d672e1c"/></dir><file name="Option.php" hash="689b388fdb474b0a070a0e855e09aabc"/></dir><file name="Item.php" hash="21a88028b07b955f2bf263f17c2442d2"/><dir name="Product"><file name="Collection.php" hash="e83f7c166b796125b3b85ae4acb6642c"/></dir><dir name="Wishlist"><file name="Collection.php" hash="b88d95c758cf27ae03a3c9a4bbfbb943"/></dir><file name="Wishlist.php" hash="6f5081c171d93eb92a9c2920b0e0c67c"/></dir><file name="Session.php" hash="d2ae560ea5c56b10055d49fd4e66ebc3"/><file name="Wishlist.php" hash="b1fe5e818d5b092c37559f30437cb05e"/></dir><dir name="controllers"><file name="IndexController.php" hash="409f16b88fdceb021f5bdb3be84d44cd"/><file name="SharedController.php" hash="fa0c415383e783f70014b0f9376b60eb"/></dir><dir name="etc"><file name="adminhtml.xml" hash="9213f2e94f8cab90211fb80826a700c2"/><file name="config.xml" hash="34fc8f3562566125f8f093f4a165726d"/><file name="system.xml" hash="ee72b4a7f5247c4b29e3b4d94b4054ad"/></dir><dir name="sql"><dir name="wishlist_setup"><file name="install-1.6.0.0.php" hash="5d61c25439596c2594416b8eaebe9009"/><file name="mysql4-install-0.7.0.php" hash="932ebcea937b1affa6567809f946df3e"/><file name="mysql4-upgrade-0.7.0-0.7.1.php" hash="648bf1ff930a83ce088b2cb881d43758"/><file name="mysql4-upgrade-0.7.1-0.7.2.php" hash="45f65eaaf98841a9840acc3b3e5209c1"/><file name="mysql4-upgrade-0.7.2-0.7.4.php" hash="b4f3216bd940240253079c6899aeea46"/><file name="mysql4-upgrade-0.7.4-0.7.5.php" hash="15e4be127414d41faeabb193b044f543"/><file name="mysql4-upgrade-0.7.5-0.7.6.php" hash="11f60666b29d10381c810f39dd64fa1b"/><file name="mysql4-upgrade-0.7.6-0.7.7.php" hash="04074c4d3e41a0fb1eee82feba0537b5"/><file name="mysql4-upgrade-0.7.7-0.7.8.php" hash="7e43180e183e6236eea1a75c471d24ac"/><file name="mysql4-upgrade-0.7.8-0.7.9.php" hash="cf7c5d37479155a28c180252f3222bc8"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="afc76dcb77fca764870c502db86d244d"/></dir></dir></dir></dir><dir name="Zend"><dir name="Controller"><dir name="Request"><file name="Http.php" hash="92d5e6e2538a8c23af43faae8200c60b"/></dir></dir><file name="Date.php" hash="95bf218944785f606f22c2ea0c077f5d"/><dir name="Db"><file name="Select.php" hash="28f3efa5f9797af22f899fb525dbb44f"/><file name="Statement.php" hash="4b5b39a1e1c651ab9d6db332c882fdf7"/></dir><dir name="Filter"><file name="PregReplace.php" hash="1b5bbd52c2b2d17f19db273606e5ddfc"/></dir><dir name="Form"><dir name="Decorator"><file name="Form.php" hash="fbd6a6687ef13a8b7ba416c1ca50dd38"/></dir></dir><dir name="Locale"><dir name="Math"><file name="PhpMath.php" hash="a95d7d3d0d7220b47d0e518ffad508f7"/></dir></dir><file name="Mime.php" hash="f216d84221e3d7601822b4c95948aeaf"/><dir name="Serializer"><dir name="Adapter"><file name="PhpCode.php" hash="d19044ca7b67e672bb9627f572f1a069"/></dir></dir><dir name="Validate"><file name="EmailAddress.php" hash="e04917b783b4880bdc984e7774abf7a6"/><dir name="File"><file name="Upload.php" hash="a5de679b71a82a061dbddd3afde626b2"/></dir><file name="Hostname.php" hash="08c032ea8831e62e79c792e274220aa9"/></dir><dir name="Xml"><file name="Security.php" hash="7366a7b9e2dab5551b557f49d900d6a1"/></dir></dir></target><target name="mage"><dir name="app"><file name="Mage.php" hash="1d01e8decc3eb7605fe8bacebe12bd5f"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/><file name="bootstrap.php" hash="5692f824efc22a75246f10e88b1bd3b7"/></dir><dir name="."><file name="cron.php" hash="52235435ed8bf309f9fbbf2c47e80f04"/><file name="LICENSE.txt" hash="59563e7be45096d0833dade102989042"/><file name="index.php.sample" hash="a605f93d48608b283696e2473319f32a"/><file name=".htaccess.sample" hash="971c336db60ac86ae96b5c5871be1e8c"/><file name="LICENSE_AFL.txt" hash="45a399f2095030865fb962263ccd7506"/><file name="LICENSE.html" hash="caf0a79ffb5e4719f9f4de286f253a61"/><file name="cron.sh" hash="64e5df07f32d93c83a0c986bbce6bcc3"/><file name="install.php" hash="c9154ce64d8ce2c96aea25b242b7b077"/><file name="php.ini.sample" hash="d7412c2f78440a96fc2d9378ccf460cb"/><file name="get.php" hash="0e147e2a291707ab75091fe1b0f764e1"/><file name="RELEASE_NOTES.txt" hash="4bd10b750230d1d96fcdaba410b64b57"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="api.php" hash="2605aef23c3d1030ab6a10f91c7cbdd2"/></dir><dir name="errors"><file name="404.php" hash="557eebe76671c3f51ef07b0892802c67"/><file name="503.php" hash="5843bd0da9d8a0ef173154a81dc89305"/><dir name="default"><file name="404.phtml" hash="fd358b5b2dba922be64b1d711648c309"/><file name="503.phtml" hash="8b7b63a9e1c2a23179280af48e6b3633"/><dir name="css"><file name="styles.css" hash="730771c6f889a40e64e712541a909012"/></dir><dir name="images"><file name="bkg_body.gif" hash="82bfc5bfe346c8e974cd33b1314b0acf"/><file name="bkg_header.jpg" hash="0211c47be1493bd0ec72949c47932b81"/><file name="bkg_main1.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="bkg_main2.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="i_msg-error.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="i_msg-note.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="i_msg-success.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="logo.gif" hash="48b7eb03807fdf80bdfb19b872cf84b8"/></dir><file name="page.phtml" hash="09c7f4694acf2c1936e15e1304965840"/><file name="report.phtml" hash="e9dfdea4409fc2e8463de932b3a6147b"/></dir><file name="design.xml" hash="7bf4d647bade27485007ceff382c77eb"/><file name="local.xml.sample" hash="8c65e80b446b4b52592a216c2a4b9d8b"/><file name="processor.php" hash="34adac569448ace7ab4b33ad977e960a"/><file name="report.php" hash="2c28c37e5a006ce64946150a1c12168c"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/><file name=".htaccess" hash="8382e66b40fe15d7a1edfc780f9be92f"/></dir><dir name="var"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="shell"><file name="abstract.php" hash="3e9ed270d023a86541744119c8588fb7"/><file name="compiler.php" hash="0b90e3996b5f315e133a71b5613b957f"/><file name="indexer.php" hash="b80a6c7b2f641e98e487662eb5d1aaa6"/><file name="log.php" hash="0c2c4db2ac3b778106070484edf5b951"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="lib"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="media"><file name=".htaccess" hash="08de5b2f5ea1ce6f51f40a19bacbf42e"/><dir name="dhl"><file name="logo.jpg" hash="68500df59e568e01333ba078a262ca27"/></dir><dir name="downloadable"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="customer"><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir></dir></target><target name="mageetc"><dir name="."><file name="config.xml" hash="cd99effb308b25632010f59726b1894c"/><file name="local.xml.template" hash="ff798ff56329f93e4d253ee50083e07f"/><file name="local.xml.additional" hash="8504141dcf1d0b1f2e2ed54b19c902d3"/></dir><dir name="modules"><file name="Mage_All.xml" hash="fa6a5ea2883abbba8e96b84c96f2cfed"/><file name="Mage_Bundle.xml" hash="9c247f8a5d4a6fd39ed58ab6f4722058"/><file name="Mage_Api.xml" hash="48d6e1dee18721bd3048da0918ac246d"/><file name="Mage_Downloadable.xml" hash="6f0c7caf9bab79db23c43fd8f9bb4827"/><file name="Mage_Weee.xml" hash="5448953a4ace9de652ab42dae4836154"/><file name="Mage_Widget.xml" hash="751d506bebd89db6ff302f3cb5926875"/><file name="Mage_Connect.xml" hash="0df11e64ef7a39ffa53f65bbbda70d7d"/><file name="Mage_ImportExport.xml" hash="16908a3f3cdaeac311ea90dabec3c80f"/><file name="Mage_PageCache.xml" hash="4f7b1d28d3d6c002ed3b7d3923affcc5"/><file name="Mage_Persistent.xml" hash="5055d23f9ad54f04e64a8b54a304b25d"/><file name="Mage_Authorizenet.xml" hash="e4267c93799b07c3dcb2f192f51bdfda"/><file name="Mage_Captcha.xml" hash="c2f88e068ccee9bb077e02dd80299abf"/><file name="Mage_CurrencySymbol.xml" hash="7c0400eafc6d0f44e456852491f5476e"/><file name="Mage_Api2.xml" hash="c106f0994020cf2c392d6ba6732b8909"/><file name="Mage_Oauth.xml" hash="28c9f32075749d7711720fc73c20060e"/><file name="Mage_ConfigurableSwatches.xml" hash="3ca495f8c747f71eab4f15a892f75211"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Lib_Varien</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Google_Checkout</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Js_Calendar</name><channel>community</channel><min>1.51.1.19</min><max>1.51.1.19</max></package><package><name>Lib_Js_Mage</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Js_Prototype</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Phpseclib</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Mage_Locale_en_US</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Mage</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Magento</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Credis</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Pelago</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Unserialize</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_IDNA2</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package><package><name>Lib_Mcryptcompat</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Mage_Downloader-1.9.4.1.xml b/var/package/Mage_Downloader-1.9.4.1.xml
deleted file mode 100644
index e44d86b..0000000
--- a/var/package/Mage_Downloader-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Downloader</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Downloader</summary>
-    <description>Magento Downloader</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:58</time>
-    <contents><target name="mage"><dir name="downloader"><dir name="js"><file name="prototype.js" hash="3766aeff5778b54f74f93670322ca0df"/></dir><dir name="Maged"><dir name="BruteForce"><file name="Validator.php" hash="acc8254ffef60b0f441d2d90630ddf15"/></dir><dir name="Connect"><file name="Frontend.php" hash="408ec3c9963658780ff6abb42f94e1ac"/></dir><file name="Connect.php" hash="b4e74db8600ef82d72fa9d717fa78f67"/><file name="Controller.php" hash="d9333ca9c4ae423851d7dcce523801f1"/><file name="Exception.php" hash="ee26ba26af45f0a19656c452d53b8b6a"/><dir name="Model"><dir name="BruteForce"><file name="ConfigIni.php" hash="0a3fa333a35f3a223428fb5858d06523"/><file name="ModelConfigInterface.php" hash="c44f9f441fc64a35e17570d6cd142633"/><dir name="Resource"><file name="FTP.php" hash="06ef49748467877f5b58d3829c009587"/><file name="File.php" hash="91e2fa34bd140f11812216ee2bfe7a8c"/><file name="ResourceInterface.php" hash="c161e47a2c0bca4fae5630e749c25c5d"/></dir></dir><dir name="Config"><file name="Abstract.php" hash="53e5b1fc2ba051c52a8d713ff09088e1"/><file name="Community.php" hash="14294db527329c9b9772b1b7ed4215f1"/><file name="Interface.php" hash="9307087300464de5e797bc4ed83bd767"/></dir><file name="Config.php" hash="df5675930420d807d079b4329377ea8a"/><dir name="Connect"><file name="Request.php" hash="0bcabb3426028ef8782e4f0687c82f70"/></dir><file name="Connect.php" hash="fad1ef28d8df62b56a21d8ba643c6d81"/><file name="Dowloader.php" hash="8ea77759c21c4ed786763768b8e26267"/><file name="Session.php" hash="c5b09315bf2bb8bd39fabca81db0671b"/></dir><file name="Model.php" hash="1aaf2230d70385a8cc495949e754e313"/><file name="View.php" hash="505d920dbde496a83e62be417839d14d"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="skin"><file name="boxes.css" hash="20ae147246f9524ba94f886a5d5fa51a"/><file name="ie7boxes.css" hash="b89283355db186307bd9ddbc99b48a9f"/><file name="ieboxes.css" hash="3f37d81e3641aca52dcaf38ad64ae4bb"/><dir name="images"><file name="Magento_Connect.jpg" hash="20e1378c09506fdc5723abc0115d5f57"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="header_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="logo.gif" hash="5eb089ecea67d82311d7c91898460104"/><file name="nav_bg.gif" hash="1cb1366f03a9efad6b17e4483aef20cf"/><file name="nav_separator.gif" hash="492011a7de2de84a9c7837bfd879ab95"/></dir><dir name="install"><file name="boxes.css" hash="a8405daa1ad5b91c8952a2635c12189c"/><file name="clears.css" hash="b8216c54e90dd07482b519829aa7577e"/><file name="ie7minus.css" hash="1e74b90a2be87129de22a2d984254eea"/><file name="iestyles.css" hash="d01e1190b28afa379e5417b9e2a18f06"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="logo.gif" hash="073a947a39b967af678455a5c7f66e90"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir><file name="reset.css" hash="b6c9331f99c5980bba301ef2b225a360"/></dir></dir><dir name="template"><dir name="connect"><file name="iframe.phtml" hash="8d3e133dee30a8709081edcce534f75a"/><file name="packages.phtml" hash="0e11a582d7c24814034b547206a846ed"/><file name="packages_prepare.phtml" hash="2af685540d77fc84c0b0261ed7f7cc95"/></dir><file name="exception.phtml" hash="a6ca67c868177500370d6dd2c7a715a7"/><file name="footer.phtml" hash="5357c5d470fdecb8bd55e59f1f4f9862"/><file name="header.phtml" hash="abd0f8678805cecff97b818c0ebf3f6c"/><file name="index.phtml" hash="749c434b0a31738035ffbfdcad9daeba"/><dir name="install"><file name="download.phtml" hash="4d31173d99b724a4d71204d471a1140d"/><file name="footer.phtml" hash="16a6e4ffba022dad5a3a0c1b66caddb0"/><file name="header.phtml" hash="2b535e452e9a38c73674533fdfd20fcb"/><file name="writable.phtml" hash="5955552da9cc58975de006d7548d6245"/></dir><file name="login.phtml" hash="68b37c7bea381dc21cdc543a152377d8"/><file name="messages.phtml" hash="62b14d82ec912106fe0c8bd1742f3252"/><file name="noroute.phtml" hash="a137d82354c54ef3ecd042979335f3d5"/><file name="settings.phtml" hash="563130e568a9d54a7989975538bfb028"/><file name="writable.phtml" hash="051690dad77d27fd9b868798094aa9eb"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="index.php" hash="751c9e6c5ea6dad527b5e17743580683"/><dir name="lib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="c5e243e597744bb215c68870a7afdf08"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="bcf5c54d43deaa20c96f6f54042578c4"/></dir><file name="Archive.php" hash="57f041e79f6374fffdff1a78aa93f1e6"/><dir name="Autoload"><file name="Simple.php" hash="63356064ece27da0a19a7fbf14f6f298"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="c7673366523f3f507ae2775a5801bef0"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="d77622ce2c019ff20214c144f7fa4e1a"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Connect"><file name="Backup.php" hash="833a7437bff426efaefc44038c6b8299"/><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="74e6d9a8fddd6e293a3bc7ab1ee4e45e"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="fc1058b9c34921304afab39427541bb4"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="315b9b27c014e07271e808dc5df2483c"/><file name="Package_Header.php" hash="ed6fdd0037b6174e3a4db13c970a5037"/><file name="Registry.php" hash="137eff5218c4eac3700932a5e0b7de6e"/><file name="Registry_Header.php" hash="d291f8de7a407b8ca203a851b418b29d"/><file name="Remote.php" hash="ebc849e801e4df6fa318c22127336dce"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="1811c8b0bd15ec6d036f5538a380626d"/><file name="Config.php" hash="5d1de3361e853b0e0717268a009caac8"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="e962e532a8a319fc53b0665b37bdbda0"/></dir><file name="Frontend.php" hash="1ce669251eddea02964fc6f7f3c59292"/><file name="Ftp.php" hash="5f396f76dca69111c101236221e06f1a"/><dir name="Loader"><file name="Ftp.php" hash="3c28cffc500fae3dabd6762105fdbf3b"/></dir><file name="Loader.php" hash="63f4b94910ebea3d6210c43ce4313d07"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="3e5a54d74712928a640484cde25d5b0a"/></dir><file name="Package.php" hash="2a094d3964e012850e16f5514f8b8672"/><file name="Packager.php" hash="ff0a2ad9acbb35f7b6b8417953de6bea"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Rest"><file name="Builder.php" hash="6e04022fe762c4f67b35f906a93f0ded"/><file name="Factory.php" hash="0678655546bcdc692c4f31656be39f15"/></dir><file name="Rest.php" hash="7099cb876a1f6139666cafc1a444988c"/><file name="Singleconfig.php" hash="12d91ef1355c32bc30a0fa7e0ab558a5"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="42debf7c91b968ca832744eb60436ddc"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="399803c8e3dcceff1912c57397b5399c"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="e7e77a18e571129707b047d8c2997c5c"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="fc0720d6fd51b2e84b35226e045743e8"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="6e1ad19d742fbd22ee7f93db98fa483d"/><file name="Ftp.php" hash="bd6dd1f4eb9abdc5db20dcc5971d2bea"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="config.ini" hash="a52ba98e71ab19de387b3af1a04c6102"/><file name=".htaccess" hash="520cc012c84739584526b8a9ff098e23"/><file name="mage.php" hash="6b7de4cba72be38ba43378be38da4ec1"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="target.xml" hash="1674cd8105fdeccc8831b9d7071b5013"/></dir><dir name="."><file name=".htaccess" hash="242b96ab8c820ff12b9e610a8f4352ec"/><file name="index.php" hash="952234cc3415f3856800a588a3ce32c0"/><file name="mage" hash="f9cb2c3303b77bc760b585f616856f98"/></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Mage_Downloader-1.9.4.2.xml b/var/package/Mage_Downloader-1.9.4.2.xml
new file mode 100644
index 0000000..ac49009
--- /dev/null
+++ b/var/package/Mage_Downloader-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Downloader</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/osl-3.0.php">OSL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Downloader</summary>
+    <description>Magento Downloader</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:17</time>
+    <contents><target name="mage"><dir name="downloader"><dir name="js"><file name="prototype.js" hash="3766aeff5778b54f74f93670322ca0df"/></dir><dir name="Maged"><dir name="BruteForce"><file name="Validator.php" hash="acc8254ffef60b0f441d2d90630ddf15"/></dir><dir name="Connect"><file name="Frontend.php" hash="408ec3c9963658780ff6abb42f94e1ac"/></dir><file name="Connect.php" hash="b4e74db8600ef82d72fa9d717fa78f67"/><file name="Controller.php" hash="f3edeef71af3f4fbb02fda3dc809c351"/><file name="Exception.php" hash="ee26ba26af45f0a19656c452d53b8b6a"/><dir name="Model"><dir name="BruteForce"><file name="ConfigIni.php" hash="0a3fa333a35f3a223428fb5858d06523"/><file name="ModelConfigInterface.php" hash="c44f9f441fc64a35e17570d6cd142633"/><dir name="Resource"><file name="FTP.php" hash="06ef49748467877f5b58d3829c009587"/><file name="File.php" hash="91e2fa34bd140f11812216ee2bfe7a8c"/><file name="ResourceInterface.php" hash="c161e47a2c0bca4fae5630e749c25c5d"/></dir></dir><dir name="Config"><file name="Abstract.php" hash="53e5b1fc2ba051c52a8d713ff09088e1"/><file name="Community.php" hash="14294db527329c9b9772b1b7ed4215f1"/><file name="Interface.php" hash="9307087300464de5e797bc4ed83bd767"/></dir><file name="Config.php" hash="df5675930420d807d079b4329377ea8a"/><dir name="Connect"><file name="Request.php" hash="0bcabb3426028ef8782e4f0687c82f70"/></dir><file name="Connect.php" hash="fad1ef28d8df62b56a21d8ba643c6d81"/><file name="Dowloader.php" hash="8ea77759c21c4ed786763768b8e26267"/><file name="Session.php" hash="c5b09315bf2bb8bd39fabca81db0671b"/></dir><file name="Model.php" hash="1aaf2230d70385a8cc495949e754e313"/><file name="View.php" hash="505d920dbde496a83e62be417839d14d"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><dir name="skin"><file name="boxes.css" hash="20ae147246f9524ba94f886a5d5fa51a"/><file name="ie7boxes.css" hash="b89283355db186307bd9ddbc99b48a9f"/><file name="ieboxes.css" hash="3f37d81e3641aca52dcaf38ad64ae4bb"/><dir name="images"><file name="Magento_Connect.jpg" hash="20e1378c09506fdc5723abc0115d5f57"/><file name="ajax-loader-tr.gif" hash="1ae32bc8232ff2527c627e5b38eb319a"/><file name="btn_bg.gif" hash="37c51a4d48a92da9648dcd3ca011039f"/><file name="header_bg.gif" hash="8440b04c5cb6b1451bb886bfbef260a5"/><file name="logo.gif" hash="5eb089ecea67d82311d7c91898460104"/><file name="nav_bg.gif" hash="1cb1366f03a9efad6b17e4483aef20cf"/><file name="nav_separator.gif" hash="492011a7de2de84a9c7837bfd879ab95"/></dir><dir name="install"><file name="boxes.css" hash="a8405daa1ad5b91c8952a2635c12189c"/><file name="clears.css" hash="b8216c54e90dd07482b519829aa7577e"/><file name="ie7minus.css" hash="1e74b90a2be87129de22a2d984254eea"/><file name="iestyles.css" hash="d01e1190b28afa379e5417b9e2a18f06"/><dir name="images"><file name="error_msg_icon.gif" hash="e4f28607f075a105e53fa3113d84bd26"/><file name="footer_bg.gif" hash="d59784af16fd95ea82226e5708a89232"/><file name="footer_container_bg.gif" hash="d468e3943943cbbf711586e69d40ca42"/><file name="footer_info_separator.gif" hash="7da64eefaf4da3855ab6ee76dbced0c2"/><file name="footer_informational_bg.gif" hash="72d37f4b2ea747bf8969c2654ad1d1e0"/><file name="footer_left.gif" hash="2b15a54bea9409a75c142d14a62f0149"/><file name="footer_legality_bg.gif" hash="4eb1602e3369dccd901ffe98ea0fd4b3"/><file name="footer_right.gif" hash="a45eaf35c8797d299bd4d9b936528e8f"/><file name="header_bg.gif" hash="795c6de754d0d49717ed08d5cd8168c8"/><file name="header_nav_bg.gif" hash="80c6a18686eb0243e06d6176506a2502"/><file name="header_top_bg.jpg" hash="143f524392ee62fcc8183f5930d7258b"/><file name="header_top_container_bg.jpg" hash="294c18f3f6b838bba06ae41dd3c3d638"/><file name="logo.gif" hash="073a947a39b967af678455a5c7f66e90"/><file name="main_bg.gif" hash="cf18ba9f7c7e6b058b439cde1a897e9c"/><file name="main_container_bg.gif" hash="a8f5717873dc6cf8f6bd22924b5838fe"/><file name="note_msg_icon.gif" hash="e774ee481a2820789c1a77112377c4e0"/><file name="success_msg_icon.gif" hash="834dfafd5f8b44c4b24a4c00add56fcf"/><file name="validation_advice_bg.gif" hash="b85432906de8985a8b14eeb2dc652d3c"/></dir><file name="reset.css" hash="b6c9331f99c5980bba301ef2b225a360"/></dir></dir><dir name="template"><dir name="connect"><file name="iframe.phtml" hash="8d3e133dee30a8709081edcce534f75a"/><file name="packages.phtml" hash="0e11a582d7c24814034b547206a846ed"/><file name="packages_prepare.phtml" hash="2af685540d77fc84c0b0261ed7f7cc95"/></dir><file name="exception.phtml" hash="a6ca67c868177500370d6dd2c7a715a7"/><file name="footer.phtml" hash="5357c5d470fdecb8bd55e59f1f4f9862"/><file name="header.phtml" hash="abd0f8678805cecff97b818c0ebf3f6c"/><file name="index.phtml" hash="749c434b0a31738035ffbfdcad9daeba"/><dir name="install"><file name="download.phtml" hash="4d31173d99b724a4d71204d471a1140d"/><file name="footer.phtml" hash="16a6e4ffba022dad5a3a0c1b66caddb0"/><file name="header.phtml" hash="2b535e452e9a38c73674533fdfd20fcb"/><file name="writable.phtml" hash="5955552da9cc58975de006d7548d6245"/></dir><file name="login.phtml" hash="68b37c7bea381dc21cdc543a152377d8"/><file name="messages.phtml" hash="62b14d82ec912106fe0c8bd1742f3252"/><file name="noroute.phtml" hash="a137d82354c54ef3ecd042979335f3d5"/><file name="settings.phtml" hash="563130e568a9d54a7989975538bfb028"/><file name="writable.phtml" hash="051690dad77d27fd9b868798094aa9eb"/><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="index.php" hash="751c9e6c5ea6dad527b5e17743580683"/><dir name="lib"><dir name="Mage"><dir name="Archive"><file name="Abstract.php" hash="785c44d93ce97bd0f16eca11907307fb"/><file name="Bz.php" hash="7643f62b00e872d1ac2a334dd5ea77f9"/><file name="Gz.php" hash="768e4a75145d08e80ac67a8f549daf2e"/><dir name="Helper"><dir name="File"><file name="Bz.php" hash="c5e243e597744bb215c68870a7afdf08"/><file name="Gz.php" hash="041cfa3ffe63f38ac4a16afbcef7f088"/></dir><file name="File.php" hash="3c4354d14f0e7ecf041ccf84cc9f9843"/></dir><file name="Interface.php" hash="14a80dbe160912aef837ff140bcccfbc"/><file name="Tar.php" hash="bcf5c54d43deaa20c96f6f54042578c4"/></dir><file name="Archive.php" hash="57f041e79f6374fffdff1a78aa93f1e6"/><dir name="Autoload"><file name="Simple.php" hash="63356064ece27da0a19a7fbf14f6f298"/></dir><dir name="Backup"><file name="Abstract.php" hash="4261ef894d330d562584e825bbc635d4"/><dir name="Archive"><file name="Tar.php" hash="38281d09120748828b57fff64e78e11b"/></dir><file name="Db.php" hash="c9c2322695a793dbdcc051ab4eae114c"/><dir name="Exception"><file name="CantLoadSnapshot.php" hash="205b761f45b767a5bf1aa79b36c260a0"/><file name="FtpConnectionFailed.php" hash="7374b6e0f2204bd2cbe74d9bfe6b9612"/><file name="FtpValidationFailed.php" hash="9487e2ec33cfd01f6da1b7f45ff9bfda"/><file name="NotEnoughFreeSpace.php" hash="14ac963c0c7ee7bb8f783540cac3436c"/><file name="NotEnoughPermissions.php" hash="5079081da8a5675f0534903806b5bc5c"/></dir><file name="Exception.php" hash="759e10905d4d738e4fc7451d8c537491"/><dir name="Filesystem"><file name="Helper.php" hash="c7673366523f3f507ae2775a5801bef0"/><dir name="Iterator"><file name="File.php" hash="9d461475d2830c5c99dc4562fda3dcf2"/><file name="Filter.php" hash="3551ef18155bf0a1069a7bbfd1eaafc2"/></dir><dir name="Rollback"><file name="Abstract.php" hash="6b053a30d4e9e492fa00e7d48785dfaf"/><file name="Fs.php" hash="e81801a6c4df916bf354fac6bfad8c88"/><file name="Ftp.php" hash="d77622ce2c019ff20214c144f7fa4e1a"/></dir></dir><file name="Filesystem.php" hash="f0aa433f0abae1e6205caf99e38c6565"/><file name="Interface.php" hash="fb21c7ce8bd463e83c8c49480a70e9be"/><file name="Media.php" hash="475444c04c09c4149322657d45f48263"/><file name="Nomedia.php" hash="aaf57bfd243788b5e4cc4ecc03a5080c"/><file name="Snapshot.php" hash="f148a7cd69f9315ac6a3923d26ab10de"/></dir><file name="Backup.php" hash="d782dcb7354a3d997d28ebffb7d12810"/><dir name="Connect"><file name="Backup.php" hash="833a7437bff426efaefc44038c6b8299"/><dir name="Channel"><file name="Generator.php" hash="c155121226420614c3e9f46ad593456b"/><file name="Parser.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="VO.php" hash="1a61d42aaadbdd3ac6c1c8fd855884b6"/></dir><dir name="Command"><file name="Channels.php" hash="f105c955b4ae859dd77a1507c5b1d5f7"/><file name="Channels_Header.php" hash="0837ebacc6db79dacfab68a84023f6e8"/><file name="Config.php" hash="74e6d9a8fddd6e293a3bc7ab1ee4e45e"/><file name="Config_Header.php" hash="9db55c3ff3cbd69425bd57d498a2febb"/><file name="Install.php" hash="fc1058b9c34921304afab39427541bb4"/><file name="Install_Header.php" hash="d99b8f0f09ff0ba216132b10d7221541"/><file name="Package.php" hash="315b9b27c014e07271e808dc5df2483c"/><file name="Package_Header.php" hash="ed6fdd0037b6174e3a4db13c970a5037"/><file name="Registry.php" hash="137eff5218c4eac3700932a5e0b7de6e"/><file name="Registry_Header.php" hash="d291f8de7a407b8ca203a851b418b29d"/><file name="Remote.php" hash="ebc849e801e4df6fa318c22127336dce"/><file name="Remote_Header.php" hash="02e09ddba00e315edec81b19479d6ef8"/></dir><file name="Command.php" hash="1811c8b0bd15ec6d036f5538a380626d"/><file name="Config.php" hash="5d1de3361e853b0e0717268a009caac8"/><file name="Converter.php" hash="4830540b2236ccb5123153f479162712"/><dir name="Frontend"><file name="CLI.php" hash="e962e532a8a319fc53b0665b37bdbda0"/></dir><file name="Frontend.php" hash="1ce669251eddea02964fc6f7f3c59292"/><file name="Ftp.php" hash="5f396f76dca69111c101236221e06f1a"/><dir name="Loader"><file name="Ftp.php" hash="3c28cffc500fae3dabd6762105fdbf3b"/></dir><file name="Loader.php" hash="63f4b94910ebea3d6210c43ce4313d07"/><dir name="Package"><file name="Extension.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Hotfix.php" hash="b843f5d16e61744b92f2375612f829ae"/><file name="Maintainer.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Reader.php" hash="716acdc438a8027faf3054ccce9193dc"/><file name="Target.php" hash="591e3a36cd36342e2846dd628516c52b"/><file name="VO.php" hash="f88baa3075ee4ab0077fd4875a722592"/><file name="Writer.php" hash="3e5a54d74712928a640484cde25d5b0a"/></dir><file name="Package.php" hash="2a094d3964e012850e16f5514f8b8672"/><file name="Packager.php" hash="ff0a2ad9acbb35f7b6b8417953de6bea"/><dir name="Repository"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Channel"><file name="Abstract.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Commercial.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Community.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Core.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Channel.php" hash="7942bb04e40b85268c389ab635b152d4"/><file name="Local.php" hash="7942bb04e40b85268c389ab635b152d4"/></dir><file name="Repository.php" hash="7942bb04e40b85268c389ab635b152d4"/><dir name="Rest"><file name="Builder.php" hash="6e04022fe762c4f67b35f906a93f0ded"/><file name="Factory.php" hash="0678655546bcdc692c4f31656be39f15"/></dir><file name="Rest.php" hash="7099cb876a1f6139666cafc1a444988c"/><file name="Singleconfig.php" hash="12d91ef1355c32bc30a0fa7e0ab558a5"/><dir name="Structures"><file name="Graph.php" hash="d620e4c9465608df531ac86a65d38208"/><file name="Node.php" hash="8e30dd5974f1e8620eff437fa4cb9e21"/></dir><file name="Validator.php" hash="42debf7c91b968ca832744eb60436ddc"/></dir><dir name="DB"><file name="Exception.php" hash="6a1513fcf2289f024e82c4763726cbdb"/><file name="Mysqli.php" hash="3423266b58c6765be416d52b9be6aa6a"/></dir><file name="Exception.php" hash="399803c8e3dcceff1912c57397b5399c"/><dir name="HTTP"><dir name="Client"><file name="Curl.php" hash="e7e77a18e571129707b047d8c2997c5c"/><file name="Socket.php" hash="c695f1502b57480c76256303dec67772"/></dir><file name="Client.php" hash="fc0720d6fd51b2e84b35226e045743e8"/><file name="IClient.php" hash="cffd1c58daea1fe74c2314a951db43e3"/></dir><dir name="System"><file name="Args.php" hash="55ce5fd0519108723c088612b1988df2"/><file name="Dirs.php" hash="6e1ad19d742fbd22ee7f93db98fa483d"/><file name="Ftp.php" hash="bd6dd1f4eb9abdc5db20dcc5971d2bea"/></dir><dir name="Xml"><file name="Generator.php" hash="78d72d8131a4e323354776bfb59c3ece"/><file name="Parser.php" hash="79b5db7a3db76933ffeedfe8ddc37925"/></dir></dir><file name=".htaccess" hash="72617d60821288133a367f70bf39ad93"/></dir><file name="config.ini" hash="a52ba98e71ab19de387b3af1a04c6102"/><file name=".htaccess" hash="520cc012c84739584526b8a9ff098e23"/><file name="mage.php" hash="6b7de4cba72be38ba43378be38da4ec1"/><file name="favicon.ico" hash="88733ee53676a47fc354a61c32516e82"/><file name="target.xml" hash="1674cd8105fdeccc8831b9d7071b5013"/></dir><dir name="."><file name=".htaccess" hash="242b96ab8c820ff12b9e610a8f4352ec"/><file name="index.php" hash="952234cc3415f3856800a588a3ce32c0"/><file name="mage" hash="f9cb2c3303b77bc760b585f616856f98"/></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Mage_Locale_en_US-1.9.4.1.xml b/var/package/Mage_Locale_en_US-1.9.4.1.xml
deleted file mode 100644
index 9b9e347..0000000
--- a/var/package/Mage_Locale_en_US-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Mage_Locale_en_US</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>en_US locale</summary>
-    <description>en_US locale</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:58</time>
-    <contents><target name="magelocale"><dir name="en_US"><file name="Mage_AdminNotification.csv" hash="e240a88785e337747afb4d0bc83ccaba"/><file name="Mage_AmazonPayments.csv" hash="00494825779e0ae3f0db0abd30e666b7"/><file name="Mage_Api.csv" hash="5a8919e82128dbd894c8f22c8238384d"/><file name="Mage_Api2.csv" hash="bc4b31da02edb34d29274da37a0a0f60"/><file name="Mage_Authorizenet.csv" hash="56def78c56270d23b57c1c17d3304288"/><file name="Mage_Backup.csv" hash="7fb40353a4c161de2a92edd8dcb35587"/><file name="Mage_Bundle.csv" hash="8a0263be85d7ac77e54d6044dcfc6420"/><file name="Mage_Captcha.csv" hash="de6aef08396245ed644b213ecfcf309b"/><file name="Mage_Catalog.csv" hash="975c73c165ccfc226d1032dc64c4ba96"/><file name="Mage_CatalogInventory.csv" hash="d3692d562e917fd71b5944aa050648c7"/><file name="Mage_CatalogRule.csv" hash="c7dcdd7d6192fbbbee177aaeb56b1685"/><file name="Mage_CatalogSearch.csv" hash="9a4687677cd0ff4ce75ead38b69fc2fc"/><file name="Mage_Checkout.csv" hash="a547d47e61822e2e35d2a7dcac41da74"/><file name="Mage_Cms.csv" hash="9a538e344acce7afa686fbed65082c63"/><file name="Mage_ConfigurableSwatches.csv" hash="8d9ad57fa2b4012dbb49e6dfebfeadba"/><file name="Mage_Connect.csv" hash="8cd1b22e3bb2b18a59b6bfb6a7e4e7f9"/><file name="Mage_Contacts.csv" hash="7e367e9a924c19b6df2fa5c8adca9be4"/><file name="Mage_Core.csv" hash="d1dbc0bea321a9b809f9bc8bb1dac9b2"/><file name="Mage_Cron.csv" hash="f963e0b41f877519fd8f6e723f25ee3c"/><file name="Mage_CurrencySymbol.csv" hash="2cc13530e2f9387349c6a162d4d22bc9"/><file name="Mage_Customer.csv" hash="9e21dccf81d5f27d3e7ec3ced9b8e65f"/><file name="Mage_Dataflow.csv" hash="342acf10a1911a335f112133bd31b3f5"/><file name="Mage_Directory.csv" hash="83f83f81a84aafce6f0d8e731e87653e"/><file name="Mage_Downloadable.csv" hash="05085f8d10c4df507ad96790a0f4f31a"/><file name="Mage_Eav.csv" hash="1fd5bcd482e23bffd25b979c4eb8985f"/><file name="Mage_GiftMessage.csv" hash="6cd672267af7f7183f47c58450c2779a"/><file name="Mage_GoogleAnalytics.csv" hash="c8a08b1e094bdf42d8222c97241296c2"/><file name="Mage_GoogleBase.csv" hash="453420e7b2a7c67d983436cd07c3f1c1"/><file name="Mage_GoogleCheckout.csv" hash="218bdb6351129bc11f5fbb7abeff7e18"/><file name="Mage_ImportExport.csv" hash="7f6895b2225a808013a8caeeafb47ffe"/><file name="Mage_Index.csv" hash="a12d6e56dec19a45380375e7ea3f7a7c"/><file name="Mage_Install.csv" hash="ff1231e1db62fc550cac4674d0ba5190"/><file name="Mage_Log.csv" hash="302d7736324e74584e23ea35289e5593"/><file name="Mage_Media.csv" hash="9d16c10b1ba6569a972018353d17f471"/><file name="Mage_Newsletter.csv" hash="85bd38e7b398fed22997f9bd87f7afa1"/><file name="Mage_Oauth.csv" hash="53c0c0f9390456fd1be2df79ed995a61"/><file name="Mage_Page.csv" hash="920443fbde0f505cb3e1fb5df1c7fa86"/><file name="Mage_PageCache.csv" hash="365e8f2f9dace7313711e9a27d27cd97"/><file name="Mage_Paygate.csv" hash="311566b283975d5c481046346023026b"/><file name="Mage_Payment.csv" hash="4f42a6296fada9e8a3dbccf19d143fce"/><file name="Mage_Paypal.csv" hash="1df7ff2e0a9957243cdef854551fad70"/><file name="Mage_PaypalUk.csv" hash="d9d163d9c022d37e6bef2bf231469572"/><file name="Mage_Persistent.csv" hash="8df1299e4ddacadd638b7dd2f66749da"/><file name="Mage_Poll.csv" hash="01084dbcb43b1da9de35c5730fabd692"/><file name="Mage_ProductAlert.csv" hash="8ceb95248eeb2e4611d01767a7331840"/><file name="Mage_Rating.csv" hash="88db484c67afdb565255d210044bd034"/><file name="Mage_Reports.csv" hash="c49ae3155e93f7eff90b3058ec8e7b40"/><file name="Mage_Review.csv" hash="a251b73a3f358bcdd93cfde7f0a2f10f"/><file name="Mage_Rss.csv" hash="69782e132cf7ba76069b975978857b10"/><file name="Mage_Rule.csv" hash="a6a968b628d92b7f172801ce05755962"/><file name="Mage_Sales.csv" hash="d819588fd9a0eccc737b8a70ecac6cbc"/><file name="Mage_SalesRule.csv" hash="1703499a655a66855f2fa13597c09587"/><file name="Mage_Sendfriend.csv" hash="b1e310cf2fdaf674de1e7604826146e9"/><file name="Mage_Shipping.csv" hash="1c64b4423ab6fd12c0c9e2d05a80c570"/><file name="Mage_Sitemap.csv" hash="4837691c0e5c8cfbc4d75b10f196eb65"/><file name="Mage_Tag.csv" hash="d37771ca3a2321a6f1dd6c59a378981b"/><file name="Mage_Tax.csv" hash="a0665ad32147d01fec271dc8d2ee12d1"/><file name="Mage_Uploader.csv" hash="044e66927e4a70710e2d5e27105ad308"/><file name="Mage_Usa.csv" hash="dedc63b54ae93cb0f0bb82364e937425"/><file name="Mage_Weee.csv" hash="60f8a4821b2733ba6b16cba691d3ada6"/><file name="Mage_Widget.csv" hash="4bf276ac67557290beeb7ea3dd68113c"/><file name="Mage_Wishlist.csv" hash="b870b694148efc6a75fcc29a88a86924"/><dir name="template"><dir name="email"><file name="account_new.html" hash="c7516c316c9fd94aeb4a007adb42b47c"/><file name="account_new_confirmation.html" hash="c404affe58ec3947379beabf6cf2dee9"/><file name="account_new_confirmed.html" hash="19223ed36f7076dee12a8fc6f542f00f"/><file name="account_password_reset_confirmation.html" hash="f5d6538ff20ded76d73ef6dbc34c94b0"/><file name="admin_new_user_notification.html" hash="08ed9ba46dc26ef22e4d97f7350564b8"/><file name="admin_password_new.html" hash="e0cb7a16e03f1e57fc42fa3b60920bb2"/><file name="admin_password_reset_confirmation.html" hash="385547f1fd11e85b6cd818e91f519bfd"/><file name="contact_form.html" hash="ee7a957b249d9bf8d2f84787d9276958"/><file name="currency_update_warning.html" hash="be68b2b00692c3071942df42d206575f"/><dir name="html"><file name="footer.html" hash="72d4ef13825ca2143557f5baf67c27cf"/><file name="header.html" hash="739a3ea8e07bbe3be76e4c93237bc5d2"/></dir><file name="log_clean_warning.html" hash="36eb1af6eca088bdafe6e91c5a355a98"/><file name="newsletter_subscr_confirm.html" hash="cc7849aaa2ada032e0d0cbcdc4c15222"/><file name="newsletter_subscr_success.html" hash="83fc3c7d1cae23c24561f803e41ea988"/><file name="newsletter_unsub_success.html" hash="3bd611af2d1fae78622e6217ff2b189e"/><file name="password_new.html" hash="e633e5d80e81549e29b239960f5187cb"/><file name="password_or_email_changed.html" hash="26ce55df2b817a5ed2373c71feff3652"/><file name="payment_failed.html" hash="693051923f748ed9e695c0b300597034"/><file name="product_alert_cron_error.html" hash="8ea80affba71491f4371b0524d0c3399"/><file name="product_price_alert.html" hash="18ff254fcaea714647caf21b39d36e9b"/><file name="product_share.html" hash="02c76a3380f98aaaa9c3ac6a86da3545"/><file name="product_stock_alert.html" hash="6a0fc4ef5203e195d1a0957accc1fca3"/><dir name="sales"><file name="creditmemo_new.html" hash="c487a7c825477974835891019d2b55bd"/><file name="creditmemo_new_guest.html" hash="47dc131ea102b0cf72d1e8bb50df2514"/><file name="creditmemo_update.html" hash="4dd0fedbe075abc51dd3647bedbf051a"/><file name="creditmemo_update_guest.html" hash="d805b77120143a070d44a01866df8f3f"/><file name="invoice_new.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_new_guest.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_update.html" hash="1ced4397da53d8a73bfa854b1ce60c24"/><file name="invoice_update_guest.html" hash="f8e7d66c9d607f3a349a9c21544c9854"/><file name="order_new.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_new_guest.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_update.html" hash="8d8d3f6a5831909532984817afc81647"/><file name="order_update_guest.html" hash="04ffcc29c74931d5f46b6ecb25cc049e"/><file name="shipment_new.html" hash="1a8e314cada334caffe213efd1e5ce31"/><file name="shipment_new_guest.html" hash="6ba64b3b35a39bfcc4c3d0ff4acc6fad"/><file name="shipment_update.html" hash="4425c3dfceb25ea1a5b80fd054a0f79f"/><file name="shipment_update_guest.html" hash="45b6f10c6853a36879b17f86e761edbf"/></dir><file name="sitemap_generate_warning.html" hash="7eb47e4ddd7eab22272397cff8c9441d"/><file name="token.html" hash="71f392398f6f80481b2e0edba7cefc78"/><file name="wishlist_share.html" hash="8d4d4838c76468c2be6149f5314b27a6"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
-</package>
diff --git a/var/package/Mage_Locale_en_US-1.9.4.2.xml b/var/package/Mage_Locale_en_US-1.9.4.2.xml
new file mode 100644
index 0000000..92671c4
--- /dev/null
+++ b/var/package/Mage_Locale_en_US-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Mage_Locale_en_US</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license uri="http://opensource.org/licenses/afl-3.0.php">AFL v3.0</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>en_US locale</summary>
+    <description>en_US locale</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:17</time>
+    <contents><target name="magelocale"><dir name="en_US"><file name="Mage_AdminNotification.csv" hash="e240a88785e337747afb4d0bc83ccaba"/><file name="Mage_AmazonPayments.csv" hash="00494825779e0ae3f0db0abd30e666b7"/><file name="Mage_Api.csv" hash="5a8919e82128dbd894c8f22c8238384d"/><file name="Mage_Api2.csv" hash="bc4b31da02edb34d29274da37a0a0f60"/><file name="Mage_Authorizenet.csv" hash="b73a0d88f4c0f0848ad4a183fb6df253"/><file name="Mage_Backup.csv" hash="7fb40353a4c161de2a92edd8dcb35587"/><file name="Mage_Bundle.csv" hash="8a0263be85d7ac77e54d6044dcfc6420"/><file name="Mage_Captcha.csv" hash="de6aef08396245ed644b213ecfcf309b"/><file name="Mage_Catalog.csv" hash="975c73c165ccfc226d1032dc64c4ba96"/><file name="Mage_CatalogInventory.csv" hash="d3692d562e917fd71b5944aa050648c7"/><file name="Mage_CatalogRule.csv" hash="b706182c1bc9a8419a20703d04cbbe71"/><file name="Mage_CatalogSearch.csv" hash="9a4687677cd0ff4ce75ead38b69fc2fc"/><file name="Mage_Checkout.csv" hash="a547d47e61822e2e35d2a7dcac41da74"/><file name="Mage_Cms.csv" hash="9a538e344acce7afa686fbed65082c63"/><file name="Mage_ConfigurableSwatches.csv" hash="8d9ad57fa2b4012dbb49e6dfebfeadba"/><file name="Mage_Connect.csv" hash="8cd1b22e3bb2b18a59b6bfb6a7e4e7f9"/><file name="Mage_Contacts.csv" hash="7e367e9a924c19b6df2fa5c8adca9be4"/><file name="Mage_Core.csv" hash="4d82dd222a6139e55fc63c97e7b4e7aa"/><file name="Mage_Cron.csv" hash="f963e0b41f877519fd8f6e723f25ee3c"/><file name="Mage_CurrencySymbol.csv" hash="2cc13530e2f9387349c6a162d4d22bc9"/><file name="Mage_Customer.csv" hash="9e21dccf81d5f27d3e7ec3ced9b8e65f"/><file name="Mage_Dataflow.csv" hash="342acf10a1911a335f112133bd31b3f5"/><file name="Mage_Directory.csv" hash="83f83f81a84aafce6f0d8e731e87653e"/><file name="Mage_Downloadable.csv" hash="05085f8d10c4df507ad96790a0f4f31a"/><file name="Mage_Eav.csv" hash="1fd5bcd482e23bffd25b979c4eb8985f"/><file name="Mage_GiftMessage.csv" hash="6cd672267af7f7183f47c58450c2779a"/><file name="Mage_GoogleAnalytics.csv" hash="c8a08b1e094bdf42d8222c97241296c2"/><file name="Mage_GoogleBase.csv" hash="453420e7b2a7c67d983436cd07c3f1c1"/><file name="Mage_GoogleCheckout.csv" hash="218bdb6351129bc11f5fbb7abeff7e18"/><file name="Mage_ImportExport.csv" hash="7f6895b2225a808013a8caeeafb47ffe"/><file name="Mage_Index.csv" hash="a12d6e56dec19a45380375e7ea3f7a7c"/><file name="Mage_Install.csv" hash="ff1231e1db62fc550cac4674d0ba5190"/><file name="Mage_Log.csv" hash="302d7736324e74584e23ea35289e5593"/><file name="Mage_Media.csv" hash="9d16c10b1ba6569a972018353d17f471"/><file name="Mage_Newsletter.csv" hash="85bd38e7b398fed22997f9bd87f7afa1"/><file name="Mage_Oauth.csv" hash="53c0c0f9390456fd1be2df79ed995a61"/><file name="Mage_Page.csv" hash="920443fbde0f505cb3e1fb5df1c7fa86"/><file name="Mage_PageCache.csv" hash="365e8f2f9dace7313711e9a27d27cd97"/><file name="Mage_Paygate.csv" hash="1fb12db7d249044ce4f0c66d22299ffa"/><file name="Mage_Payment.csv" hash="4f42a6296fada9e8a3dbccf19d143fce"/><file name="Mage_Paypal.csv" hash="1df7ff2e0a9957243cdef854551fad70"/><file name="Mage_PaypalUk.csv" hash="d9d163d9c022d37e6bef2bf231469572"/><file name="Mage_Persistent.csv" hash="8df1299e4ddacadd638b7dd2f66749da"/><file name="Mage_Poll.csv" hash="01084dbcb43b1da9de35c5730fabd692"/><file name="Mage_ProductAlert.csv" hash="8ceb95248eeb2e4611d01767a7331840"/><file name="Mage_Rating.csv" hash="88db484c67afdb565255d210044bd034"/><file name="Mage_Reports.csv" hash="c49ae3155e93f7eff90b3058ec8e7b40"/><file name="Mage_Review.csv" hash="a251b73a3f358bcdd93cfde7f0a2f10f"/><file name="Mage_Rss.csv" hash="69782e132cf7ba76069b975978857b10"/><file name="Mage_Rule.csv" hash="a6a968b628d92b7f172801ce05755962"/><file name="Mage_Sales.csv" hash="c414fb921b13bc45f88fdd186844faa2"/><file name="Mage_SalesRule.csv" hash="1703499a655a66855f2fa13597c09587"/><file name="Mage_Sendfriend.csv" hash="b1e310cf2fdaf674de1e7604826146e9"/><file name="Mage_Shipping.csv" hash="1c64b4423ab6fd12c0c9e2d05a80c570"/><file name="Mage_Sitemap.csv" hash="8f0ec04e6bf71d0ada3109bf8712fd36"/><file name="Mage_Tag.csv" hash="d37771ca3a2321a6f1dd6c59a378981b"/><file name="Mage_Tax.csv" hash="a0665ad32147d01fec271dc8d2ee12d1"/><file name="Mage_Uploader.csv" hash="044e66927e4a70710e2d5e27105ad308"/><file name="Mage_Usa.csv" hash="dedc63b54ae93cb0f0bb82364e937425"/><file name="Mage_Weee.csv" hash="60f8a4821b2733ba6b16cba691d3ada6"/><file name="Mage_Widget.csv" hash="4bf276ac67557290beeb7ea3dd68113c"/><file name="Mage_Wishlist.csv" hash="b870b694148efc6a75fcc29a88a86924"/><dir name="template"><dir name="email"><file name="account_new.html" hash="c7516c316c9fd94aeb4a007adb42b47c"/><file name="account_new_confirmation.html" hash="c404affe58ec3947379beabf6cf2dee9"/><file name="account_new_confirmed.html" hash="19223ed36f7076dee12a8fc6f542f00f"/><file name="account_password_reset_confirmation.html" hash="f5d6538ff20ded76d73ef6dbc34c94b0"/><file name="admin_new_user_notification.html" hash="08ed9ba46dc26ef22e4d97f7350564b8"/><file name="admin_password_new.html" hash="e0cb7a16e03f1e57fc42fa3b60920bb2"/><file name="admin_password_reset_confirmation.html" hash="385547f1fd11e85b6cd818e91f519bfd"/><file name="contact_form.html" hash="ee7a957b249d9bf8d2f84787d9276958"/><file name="currency_update_warning.html" hash="be68b2b00692c3071942df42d206575f"/><dir name="html"><file name="footer.html" hash="72d4ef13825ca2143557f5baf67c27cf"/><file name="header.html" hash="739a3ea8e07bbe3be76e4c93237bc5d2"/></dir><file name="log_clean_warning.html" hash="36eb1af6eca088bdafe6e91c5a355a98"/><file name="newsletter_subscr_confirm.html" hash="cc7849aaa2ada032e0d0cbcdc4c15222"/><file name="newsletter_subscr_success.html" hash="83fc3c7d1cae23c24561f803e41ea988"/><file name="newsletter_unsub_success.html" hash="3bd611af2d1fae78622e6217ff2b189e"/><file name="password_new.html" hash="e633e5d80e81549e29b239960f5187cb"/><file name="password_or_email_changed.html" hash="26ce55df2b817a5ed2373c71feff3652"/><file name="payment_failed.html" hash="693051923f748ed9e695c0b300597034"/><file name="product_alert_cron_error.html" hash="8ea80affba71491f4371b0524d0c3399"/><file name="product_price_alert.html" hash="18ff254fcaea714647caf21b39d36e9b"/><file name="product_share.html" hash="02c76a3380f98aaaa9c3ac6a86da3545"/><file name="product_stock_alert.html" hash="6a0fc4ef5203e195d1a0957accc1fca3"/><dir name="sales"><file name="creditmemo_new.html" hash="c487a7c825477974835891019d2b55bd"/><file name="creditmemo_new_guest.html" hash="47dc131ea102b0cf72d1e8bb50df2514"/><file name="creditmemo_update.html" hash="4dd0fedbe075abc51dd3647bedbf051a"/><file name="creditmemo_update_guest.html" hash="d805b77120143a070d44a01866df8f3f"/><file name="invoice_new.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_new_guest.html" hash="0bfd2645ebb5289edcef0ae6fc7f93de"/><file name="invoice_update.html" hash="1ced4397da53d8a73bfa854b1ce60c24"/><file name="invoice_update_guest.html" hash="f8e7d66c9d607f3a349a9c21544c9854"/><file name="order_new.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_new_guest.html" hash="f3ce547016c4d497805360460c6c5ec3"/><file name="order_update.html" hash="8d8d3f6a5831909532984817afc81647"/><file name="order_update_guest.html" hash="04ffcc29c74931d5f46b6ecb25cc049e"/><file name="shipment_new.html" hash="1a8e314cada334caffe213efd1e5ce31"/><file name="shipment_new_guest.html" hash="6ba64b3b35a39bfcc4c3d0ff4acc6fad"/><file name="shipment_update.html" hash="4425c3dfceb25ea1a5b80fd054a0f79f"/><file name="shipment_update_guest.html" hash="45b6f10c6853a36879b17f86e761edbf"/></dir><file name="sitemap_generate_warning.html" hash="7eb47e4ddd7eab22272397cff8c9441d"/><file name="token.html" hash="71f392398f6f80481b2e0edba7cefc78"/><file name="wishlist_share.html" hash="8d4d4838c76468c2be6149f5314b27a6"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php></required></dependencies>
+</package>
diff --git a/var/package/Magento_Mobile-1.9.4.1.xml b/var/package/Magento_Mobile-1.9.4.1.xml
deleted file mode 100644
index 67c466e..0000000
--- a/var/package/Magento_Mobile-1.9.4.1.xml
+++ /dev/null
@@ -1,18 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Magento_Mobile</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Magento Mobile Xml Interface</summary>
-    <description>An integration Magento with mobile applications (e.g. iPhone, Android, iPad)</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:58</time>
-    <contents><target name="magecore"><dir name="Mage"><dir name="XmlConnect"><dir><dir name="Block"><dir name="Adminhtml"><dir name="Admin"><dir name="Application"><dir name="Edit"><file name="Form.php" hash="42cbf9631bb3eef431e9398b1bffb6f9"/><dir name="Tab"><file name="Settings.php" hash="60f79bfea8f31a45f68c384c62b51a6a"/></dir><file name="Tabs.php" hash="e164c429630358b7ed08b12fba12a0bf"/></dir><file name="Edit.php" hash="da4aa415cc7f509e9c5b4ab0abedf6b7"/></dir></dir><dir name="Connect"><file name="Config.php" hash="ef6f52f638874cae27d71a60ab7f6390"/><dir name="Dashboard"><file name="BestSellers.php" hash="fd83fa0abede5e1120d9f2607728c660"/><file name="Customers.php" hash="7c15234d44f4580d4d09c9c480913fd8"/><file name="GraphAmountsData.php" hash="8651060b90056a1a73097eb675669a4c"/><file name="GraphDataAbstract.php" hash="631981805df46cc521a6d78981d62f14"/><file name="GraphInfo.php" hash="fa60ad1ecad8eebea1a814fa8f3f11fc"/><file name="GraphOrderData.php" hash="4c57f103ed14ac56374548198a3f1c0c"/><file name="GraphTotalsData.php" hash="6362d716bf62d4203c0c5e4a58fa70ae"/><file name="LastOrders.php" hash="9e4d98b91e353ace105f5dc2e8880a37"/><file name="LastSearchTerms.php" hash="da93c128090d68728518b47f1937c0e6"/><file name="MostViewedProducts.php" hash="0d2f13760e47ec747772eb4fa669a577"/><file name="NewCustomers.php" hash="71faee15fdd7933ce87a579712330629"/><file name="SalesInfo.php" hash="fb77263dc72fbb4514f59270700ee798"/><file name="StoreSwitcher.php" hash="be57a6337549e4d072ce80cbe38004d3"/><file name="TopSearchTerms.php" hash="8ab84597489faa349365e2320dc6256d"/></dir><file name="Dashboard.php" hash="4d55218423a2577e0db0e65f390a0eaa"/><file name="Loginform.php" hash="3b4b92ef534eadbaae38bbef867cea04"/></dir><dir name="History"><file name="Grid.php" hash="36511c8994308a45c6b13e753ced86cc"/></dir><file name="History.php" hash="107c69ecac1edfb0b4724c5707a0ce1e"/><dir name="Mobile"><dir name="Edit"><file name="Form.php" hash="8986f753b1c7487e8c4a372a297f700c"/><file name="Submission.php" hash="c21b6576548b2f627ea224c88ec595a6"/><dir name="Tab"><file name="Cache.php" hash="980297562509b4d08f5914d3f5fce3fd"/><file name="Content.php" hash="b39a9829604497c7c0dab3b20866882f"/><dir name="Design"><dir name="Accordion"><file name="Images.php" hash="a92f18f8c4014230ce95dd1c62a128b0"/><file name="Tabs.php" hash="1c27d76f5428dd09c64e7b2f16095f73"/><file name="Themes.php" hash="e4e0e33198c8eafe2e827463cbe9ccac"/></dir><file name="Accordion.php" hash="dc535a038a8833aeba8e0c50327e03e8"/><file name="Images.php" hash="6b5f93bba329732e91da9df1e2df5751"/><file name="Preview.php" hash="49134611eb84b29dd0b99e8b415316c8"/><file name="Themes.php" hash="6090d653f395866788358daad5698d6b"/></dir><file name="Design.php" hash="dc566d2f573e2392a5d5670deb87c40f"/><file name="Flurryanalytics.php" hash="9fa282f43ceb9c9bd0d21c2ed8a61daf"/><file name="General.php" hash="824c36bebef3952c9f576de13c8bea98"/><file name="Notification.php" hash="75b24ca6db9d117d57d11ad4a9e2b93b"/><file name="OfflineCatalog.php" hash="92ee4fb43aeea91d7b01a59bb0d63592"/><file name="Payment.php" hash="812419b60554837546a757911a9aad54"/><file name="Settings.php" hash="7fe481b44647e6b124ded33afd3006e7"/><file name="Social.php" hash="cfb2fbbc99e569c5ac1c5d9c2817470b"/><dir name="Submission"><file name="History.php" hash="7d747f93da808e60db9d1c6fc9b5615a"/></dir></dir><file name="Tabs.php" hash="477fbc0c585e4ad400cc9b857663168c"/></dir><file name="Edit.php" hash="e22b7a01bb4999c6755c8843f1595214"/><dir name="Form"><dir name="Element"><file name="Addrow.php" hash="10480a9e700140671bdf129077491079"/><file name="Color.php" hash="50129c1b65d750aeedec27ed4a7d4f43"/><file name="Country.php" hash="3920f03b1786f6421f2b35543f90ad79"/><file name="Datetime.php" hash="0faa673cc2d2333d94a68fb8f6ae1840"/><file name="Font.php" hash="01a83b1dd25de9dea96d7bd3b120eb80"/><file name="Image.php" hash="afc307c06eb3acc95a22a9f7366789ae"/><file name="Page.php" hash="d677d9ede74ac4d4205295af7aa1fb98"/><file name="Tabs.php" hash="b8a9210e9dc047cbd7d6a0678f0ef3c3"/><file name="Theme.php" hash="ad796959f3425fa9076a1bd8f41ae88e"/></dir></dir><dir name="Grid"><dir name="Renderer"><file name="Bool.php" hash="e933ea09a79b53d5128649a2c944b410"/><file name="Type.php" hash="20c0c938068768cba49b3137bd9995e0"/></dir></dir><file name="Grid.php" hash="edd7bffddc1da5a3fe1cc83ad9cf8576"/><dir name="Preview"><file name="Content.php" hash="364903e644af0f3b4d23efe14620aff0"/><file name="Tabitems.php" hash="8416116abed11a4eeb200dba0e92ce10"/></dir><dir name="Submission"><file name="Form.php" hash="72ec9817f5a562163bb62334c5be1bc8"/><dir name="Renderer"><dir name="Country"><file name="Androidmarket.php" hash="28a255a8d7bc2c80e28056146e862bb3"/><file name="Istore.php" hash="7cb3d129e63a5d7b601b8e176a56fe69"/></dir></dir><dir name="Tab"><dir name="Container"><file name="Submission.php" hash="bd162efb92f38afa814d8f811acc677d"/></dir><file name="Container.php" hash="d88f4280209e67efb62e425dfb51181f"/></dir><file name="Tabs.php" hash="273e945bcc16fe9ebf2507e9202b109a"/></dir><file name="Submission.php" hash="f5d121c59912fae01944db2a90a9e46c"/><dir name="Widget"><file name="Form.php" hash="c6596c73c3a03e55035a1435138a757c"/></dir></dir><file name="Mobile.php" hash="c4bb3627a57b2bded79ded4bf1f76ba7"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="8a69da64c633c90b815a149d418e1e60"/></dir><file name="Edit.php" hash="bac0cf8d7090e606e62fba0443a77401"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="afbdc54e2d2182d3f1ebe8867ec46f9b"/><file name="Application.php" hash="5e6d1a4cd82c8f148665280814c6a66d"/><file name="Id.php" hash="564b9860db7e21d1d9a644e276d92748"/><file name="Msgtitle.php" hash="bfa380f535758215d9c714aae53b87b9"/><file name="Pushtitle.php" hash="90ebc1553ba4d8bea1e41926e281e85c"/><file name="Status.php" hash="f7230c7dca270a2d0e1a8f7046d70f7e"/><file name="Template.php" hash="aebbc022bfb288eb5101304c8b656d37"/></dir></dir><file name="Grid.php" hash="e4ea25e1eb6515633cb933b1dc653041"/></dir><file name="Queue.php" hash="07f1dcf45efd1ca07e12bd6a8defce77"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="83997726da0b6e8d5c9123f27b59a538"/></dir><file name="Edit.php" hash="4ff833041c232ca1ea787633de5a8511"/><dir name="Grid"><dir name="Renderer"><file name="Application.php" hash="2ffba8b1be1d1942f9f0648ebe5ee077"/><file name="Name.php" hash="09e2e85e74df397c903528a853d055fb"/></dir></dir><file name="Grid.php" hash="b373a577f1c41fb9d7fed57c0c67965a"/><dir name="Preview"><file name="Form.php" hash="01e6987b191e4e3d5ceee4a2816e43a3"/></dir><file name="Preview.php" hash="45a7ec71db6beb22c54f8610e966b910"/></dir><file name="Template.php" hash="66c96b78a0d7a202268681fd84f6a6c3"/></dir><dir name="Cart"><dir name="CartTotals"><file name="Default.php" hash="aa4a54fa28ebbb5dddd92e11cf1be9be"/><file name="Grandtotal.php" hash="85c3426ab148a9e015dd07acda656532"/><dir name="Nodes"><file name="Default.php" hash="21708d567639f087d30797c810d6b5d1"/><file name="Giftcardaccount.php" hash="3ab9b8cf4b4e710258f208f03cdb09a5"/></dir><file name="Shipping.php" hash="0d0e531150a5afaa13e52ee9dede860e"/><file name="Subtotal.php" hash="47d8122cdc887d0dff9e3912eb7ceab9"/></dir><file name="CartTotals.php" hash="c1fa081e4688824455c63a429b40c7b3"/><file name="Crosssell.php" hash="22984daab011bbe59f36986f0c44f7f4"/><file name="Info.php" hash="987fc8f96cfcd31a5d57d874591c87dd"/><dir name="Item"><dir name="Renderer"><file name="Configurable.php" hash="f5670a94587490768a94816c6a7043f4"/><file name="Grouped.php" hash="d9218c9a232a947f9667deefca98f376"/></dir><file name="Renderer.php" hash="413196834f1cc45c849284764cf72ced"/></dir><file name="Items.php" hash="9ef9351b39bbb23a79843138571b5a3f"/><dir name="Paypal"><dir name="Mecl"><file name="Details.php" hash="06a1c937089063423e8f7703fbef2dd2"/><file name="OrderDetails.php" hash="0d7e04d6be3962552e65535fbcce234d"/><file name="Review.php" hash="780bde503e02e74b68ad48a4aa178d4d"/><file name="Shippingmethods.php" hash="20598482b0508e2987a5342f223ff7f7"/></dir><dir name="Mep"><file name="Totals.php" hash="42a88f97d59f3f2e8b79d255e16144ef"/></dir></dir><file name="Totals.php" hash="eb6f3381db7cd39a5f39ea195b1f5182"/></dir><file name="Cart.php" hash="fde0584dc2b2811f6bb8f26cf2ed67f7"/><dir name="Catalog"><dir name="Category"><file name="Info.php" hash="c08a92405bf045de2e81e850f849f023"/></dir><file name="Category.php" hash="1b236585d2f8ff81a588699d6085f29c"/><file name="Filters.php" hash="800c575490bceda583cb7cbf43e06b0e"/><dir name="Product"><file name="Attributes.php" hash="9b3cf0c0e19fbbfe34c3d044a1823f62"/><file name="Gallery.php" hash="0afbc24f715bf88cd1167c318427d788"/><dir name="ItemPrice"><file name="Bundle.php" hash="ade6f06324b5c32fc0bb14b3a045ccd9"/><file name="Default.php" hash="1a0927b5ad5e1f8d7ab4e7ee0d28618f"/><file name="Giftcard.php" hash="f4d4f56ef7cc963ad365040d6b156949"/></dir><file name="ItemPrice.php" hash="e953ef560e9677ac54cb36d7ed6654e0"/><file name="List.php" hash="48390c6fdb31105e9e6356b6c5952074"/><dir name="Options"><file name="Bundle.php" hash="b15512d69c62d0559935f8d01b9cf941"/><file name="Configurable.php" hash="a83c4152060bf608b17d4bc3e33ff20d"/><file name="Downloadable.php" hash="0460412f67215b73fd0d3fd495685239"/><file name="Giftcard.php" hash="7df14238d142344e8acab77e6db8c451"/><file name="Grouped.php" hash="a8d50a53444b5593a31b2845a4752719"/><file name="Simple.php" hash="fb17951ec6e37da9b59531173336061b"/><file name="Virtual.php" hash="3aa13acb5b4f778f93d145ef67bcdef1"/></dir><file name="Options.php" hash="c73a87c8f50953f13d3de6c62c2fa561"/><dir name="Price"><file name="Bundle.php" hash="19b19f708134f2efa72ae044a19e13a6"/><file name="Default.php" hash="a462cf7fca028e973afe141455727014"/><file name="Giftcard.php" hash="6d4ae9ca376e16f2ce85994187b2810d"/></dir><file name="Price.php" hash="1936b972ce882fb03c99419474c86e3a"/><file name="Related.php" hash="bf8bca72c91a15837c0bc5f2685e2609"/><dir name="Review"><file name="List.php" hash="788ceecda434b52908495b30bc1501e4"/></dir><file name="Review.php" hash="c78e32b03f67861300f36bde6a57f8b4"/></dir><file name="Product.php" hash="38e22e7743f7798fd852232aafa13215"/><dir name="Search"><file name="Suggest.php" hash="76286050a2f2355fc93ff8a3c5dd503b"/></dir><file name="Search.php" hash="c19748ad0547bfeb05ac7d29069e9b94"/></dir><file name="Catalog.php" hash="1f83bf40bc69b7a90a7e3a92e5141cc8"/><dir name="Checkout"><dir name="Address"><file name="Billing.php" hash="60f5d7fda1904c44d269e83d32b04c21"/><file name="Form.php" hash="a1f8e3ad1cdeccc275374bf300f233d7"/><file name="Shipping.php" hash="9688c172819d8642184f80f24f8ffe2c"/></dir><file name="Agreements.php" hash="1c59b6dfb81133936ce928eac880c4f4"/><dir name="Cart"><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="fbb065663009c95ee39ba735cbdb6f38"/><file name="Configurable.php" hash="32ec7bc671b88c1105c656d59e7a6097"/><file name="Downloadable.php" hash="deeb8e695aa914ead6c718936bb0caee"/><file name="Giftcard.php" hash="06adc988117d07b3402bc07d632dd1d0"/><file name="Grouped.php" hash="813b8d991c30043fc43f6d9f98c113b5"/></dir><file name="Renderer.php" hash="4e410027b4a1b0f8dc56acec9a3ef0dc"/></dir></dir><dir name="Onepage"><dir name="Address"><file name="Form.php" hash="d741113a5edf198d37034368413c0f24"/><file name="List.php" hash="7bd1944b55751bfb1d0742e8c7de15c1"/></dir><file name="Address.php" hash="65aabe67caaf3899cf51ac2b32941b74"/><file name="Review.php" hash="698a09561d3706593516b72eb68b307a"/></dir><dir name="Order"><dir name="Review"><file name="Info.php" hash="a059b6066b3736fe060886608dca1ff0"/></dir><file name="Review.php" hash="67ed1ba38387ca695ec59ec72326a0b1"/></dir><dir name="Payment"><dir name="Method"><file name="Authorizenet.php" hash="834362380417a44933542381babf2ae4"/><file name="Ccsave.php" hash="3b9620de2dd955aa5fde1dbb50ed7d45"/><file name="Checkmo.php" hash="a4e64c79441c7ed6f9f1af4768476cd1"/><dir name="Info"><file name="Authorizenet.php" hash="1205a19f9cae588ae8f6182786341ac6"/><file name="Ccsave.php" hash="f88eaa8cae31cf309919eae02c9bd1e7"/><file name="Checkmo.php" hash="a3ac5e69918948a578e4b2b45cbd6fb7"/><file name="Free.php" hash="293ba305893aa93e6c46280c270c5344"/><dir name="Paypal"><file name="Abstract.php" hash="64b61f0037e0cb6db6f02d29af5af0c8"/><file name="Express.php" hash="92dedcdce406e8a28ffd3880406f0929"/><file name="Mecl.php" hash="45458c3b1756b5370b989c6cc80a19ef"/></dir><dir name="Pbridge"><file name="Authorizenet.php" hash="c13c201ba4ca62dad0c3a87cf4a9f703"/><dir name="Paypal"><file name="Direct.php" hash="b16b116cae5073631b334fa21c977771"/></dir><dir name="Paypaluk"><file name="Direct.php" hash="097c94fce223fa8c522d800bd6cc13fe"/></dir><file name="Verisign.php" hash="5d4511d4102ab8644ffe03dd1c79977e"/></dir><file name="Purchaseorder.php" hash="e58212454a851d514a84ee42a2cde91a"/></dir><file name="List.php" hash="a3e2ce26d286aabcab0f55c032239851"/><file name="ListApi23.php" hash="9b5e71077e7a0fd02946da3f486cfbb7"/><dir name="Paypal"><file name="Direct.php" hash="d3e4408ba28a9ba8f94eab98e4e4e490"/><file name="Payflow.php" hash="972c68fbe72496667bea7de3a799cdb8"/></dir><dir name="Pbridge"><file name="Abstract.php" hash="3642dfbe2d063ce90cf0ff55179a4bae"/><file name="Authorizenet.php" hash="401dc6b998dab46602a6c2ac157a70cd"/><file name="Paypal.php" hash="c2a29305f8fc181bb6076f2ff3f1d763"/><file name="Paypaluk.php" hash="0f666eb6c38c09f523d00889a4cdbe57"/><file name="Verisign.php" hash="cf6a0ed466ad465730863ba50834cd3f"/></dir><file name="Purchaseorder.php" hash="e989e488a318c9d67110a00cfc7daa32"/></dir></dir><dir name="Pbridge"><file name="Result.php" hash="349e21d3652cc2724119ce99b98d2285"/></dir><dir name="Shipping"><dir name="Method"><file name="Available.php" hash="a79a59eaf32107633f87fb552d83567e"/><file name="AvailableList.php" hash="fd5013cf123d5b353b16c37db7da2f91"/></dir></dir></dir><dir name="Cms"><file name="Page.php" hash="e6d1e375bae972eb739373dc044acb17"/></dir><file name="Configuration.php" hash="724321f880ef2d348ce935123249bf96"/><dir name="Customer"><dir name="Address"><file name="Form.php" hash="de7c6b19495fc25240c47dde1fe61385"/><file name="List.php" hash="42546489a24f4c1bfa098026eb3482b5"/></dir><file name="Downloads.php" hash="321d9c650ddd35139815aec45d16d679"/><dir name="Form"><dir name="Renderer"><file name="Boolean.php" hash="296e8a888cfe12328d8a806b2ccebbce"/><file name="Date.php" hash="f6c9d7d8c45c40ed22b3b3aed92cdc6b"/><file name="File.php" hash="35bf591fc6d1657c8f22c284ca2ff081"/><file name="Image.php" hash="dba177ca91d49f760099dcdedc507d46"/><file name="Multiline.php" hash="8587fa80557a9ca19ccafccc076886a7"/><file name="Multiselect.php" hash="68a93aaeb54eda0af2aae6f094409f2e"/><file name="Select.php" hash="a24eec858dfb4829cf9d1ba0986ecd60"/><file name="Text.php" hash="5ccdfbb2f721bf1a55cb5c746170026f"/><file name="Textarea.php" hash="a8df2c653799ab45b88d7a93cbfc3a57"/></dir></dir><file name="Form.php" hash="e35595b42e88bd5fdbbda85a1dd1b967"/><file name="GiftcardCheck.php" hash="5502c3c64d26a729f95d49beddfda484"/><dir name="Order"><file name="Details.php" hash="d3a76a64725673fefcff223a7cbc678e"/><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="9b8ec135915a09aee481a1f5afb77ab3"/><file name="Default.php" hash="c13320e211521393b62c18446a1b19a1"/><file name="Downloadable.php" hash="0f7ab7a67658a4e63c1691774405c517"/><file name="Giftcard.php" hash="3b2e6d3a8e4d9f28c0480219da746f6b"/><file name="Grouped.php" hash="bf8405d76c72db226d4edd52cac1eb1c"/></dir></dir><file name="Items.php" hash="626d61c1f7021402743169e508d826b7"/><file name="List.php" hash="c491e8b728aa767c0ab958c31adecdbf"/><dir name="Totals"><dir name="Customerbalance"><file name="Refunded.php" hash="2db2f90238a01322af451d6cb13d0227"/></dir><file name="Customerbalance.php" hash="382c7eb584ca913e12d79b54746e7123"/><file name="Giftcards.php" hash="a530fa9d0642e595f30b14c9fb846e3e"/><file name="Tax.php" hash="f801e9b97383271e443cc41add0a36f2"/></dir><file name="Totals.php" hash="9ea5b26f3a26653dbe71803512228679"/></dir><file name="Storecredit.php" hash="14bd1d964a2f70f330b35c6a1d06e396"/></dir><file name="Home.php" hash="579d6c53346982d239e7e009e400eef6"/><file name="Homebanners.php" hash="28b0ad997a792d9ec7ebf269f0995010"/><file name="Localization.php" hash="d9e0b6f7ed0670a5da165c58d74cdf85"/><dir name="Review"><file name="Form.php" hash="a31ea24b2cb1e22708fc5226296b1267"/></dir><file name="ShoppingCart.php" hash="0fcad0c7d269914600461e82df23d42a"/><file name="Wishlist.php" hash="c90c53dac188bc6d1eb0aaadc52e4ba4"/></dir><dir name="Controller"><file name="Action.php" hash="15ca45ed36fb4242715ff316487df41b"/><file name="AdminAction.php" hash="cca66931020159b3eae2455f28f09a27"/></dir><dir name="Helper"><file name="AdminApplication.php" hash="b17105d0e66e7c686ff38d5edee5cefc"/><dir name="Adminhtml"><dir name="Dashboard"><file name="Order.php" hash="9419e418ef0c1aca45a927c6076ba0d0"/></dir></dir><file name="Android.php" hash="1ed6e9dd7ee1e1ebe7c379e30160cc4d"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="57f732135ff7734cc77f6abb4c8b2449"/></dir><dir name="Product"><file name="Image.php" hash="087532b6f1dec902b53ec28cb659f497"/></dir></dir><dir name="Customer"><dir name="Form"><file name="Renderer.php" hash="045b5ccd69deefa693d7d4c5353ce68c"/></dir><file name="Order.php" hash="de100b167840320bafacc6e93a3283cc"/></dir><file name="Data.php" hash="b896980dc209bb614eb793846c46523e"/><dir name="Device"><file name="Abstract.php" hash="9bc6f1ac0f697acffb01a11236a40401"/></dir><file name="Image.php" hash="6921779e72abaacc241b34f07ed02830"/><file name="Ipad.php" hash="1effe2957ce188b6cedfb0263adef0ce"/><file name="Iphone.php" hash="6675faef922a3cfb36d39b2b86d94cfe"/><file name="OfflineCatalog.php" hash="728a6f556f0686e6903f2b3370907a9a"/><file name="Payment.php" hash="f1012b729117d69e9ab6c8d080417022"/><file name="Theme.php" hash="8977a5214ed2ac3238e8c2419be069ab"/><file name="Translate.php" hash="01435e6bf81bbc0227659b139197639b"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="Search"><file name="Catalog.php" hash="ccb6094d28df925b20ec8c031ac51a53"/><file name="Category.php" hash="52e81d55648a8570ec4e8668d53f8b80"/></dir><dir name="System"><dir name="Config"><dir name="Backend"><file name="Baseurl.php" hash="04e9900121da0d400bf9096ca7d23cd1"/><dir name="Currency"><file name="Default.php" hash="0ce2ee64ede63a08ce1b3f360eb52084"/></dir></dir></dir></dir></dir><file name="Application.php" hash="959a3812d11730d81f67a85ac6372a0b"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="fa2f7f5e7242d935f9d5e1741f9048b4"/><dir name="Media"><file name="Config.php" hash="233724daf60fb819ff318003be19dfe8"/></dir></dir></dir><file name="ConfigData.php" hash="562df19fe23520a347f96af3bfd322b4"/><file name="Configuration.php" hash="05c4089e805717727903febc0912a005"/><dir name="Device"><file name="Abstract.php" hash="f45b3f1ac62150225bb095fc0052a6ae"/><file name="Android.php" hash="7958c43e6e197d60a8ad1f1958d48833"/><file name="Ipad.php" hash="fd91ddec607efe8cfb6a26519ec8f49b"/><file name="Iphone.php" hash="b086f46206e53a0b5123fab10a0f44a2"/></dir><file name="History.php" hash="1dc8e48c826d5d4b0b556913ea82cb65"/><file name="ImageAction.php" hash="3af7f7f5fad331edaaf66613d5688e19"/><dir name="ImageLimits"><file name="Abstract.php" hash="19d6e7017a3463dbd7d4dc4acc9d3993"/></dir><file name="ImageLimits.php" hash="8c80b771068d8ab4140720aa535088f9"/><file name="Images.php" hash="9e8dcf76a202aab0ff0cb7fa4efe3558"/><dir name="Mysql4"><dir name="Application"><file name="Collection.php" hash="20ca3e05eddb2a4db99d71b8ff3552ae"/></dir><file name="Application.php" hash="cc9679db2f16fdb328d26fc730c4cea7"/><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="3cc019e54c09e49a36338cd363cb1155"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="c5b21c467e407202bd04ca85f5211a63"/></dir><file name="ConfigData.php" hash="9768cd6b2b4a5f77d29a21dbc027d437"/><dir name="Filter"><file name="Collection.php" hash="25a4d5ed9b4f11190115a23ae234f3a6"/></dir><dir name="History"><file name="Collection.php" hash="e868422aa36ce2af614a2bc025c7e5a8"/></dir><file name="History.php" hash="2bc18554615e6aa04f8fb2f4dc43cfb8"/><dir name="Queue"><file name="Collection.php" hash="c363e0c70a3940e8d990315ed8ebadec"/></dir><file name="Queue.php" hash="9c158e0e23293c0d6a0c3853fccf6018"/><file name="Setup.php" hash="dbaeabb2554c70666ef25921e89277a6"/><dir name="Template"><file name="Collection.php" hash="4993a7470f4bd5fa3ada384737234c79"/></dir><file name="Template.php" hash="5be4d94478a10677cc3f8e0ec7f3738a"/></dir><file name="Observer.php" hash="17dbbf57381227eedca5fdac00e1e937"/><dir name="OfflineCatalog"><file name="Abstract.php" hash="fff50211793a39f51c0a0d059e769eaf"/><dir name="Category"><file name="Category.php" hash="2ee314872c6cd7e9a9b075110eb6c282"/><file name="IndexCategory.php" hash="0da913c58cb221745cd0f5f93cf9722b"/></dir><file name="Category.php" hash="84c5080d5085630afd13847204d9f76f"/><file name="Config.php" hash="165414539f36e14d54a267ff93750ad6"/><file name="Home.php" hash="3fe7a558d082dcf0525e6063b35a46fc"/><file name="Homebanners.php" hash="9bd332243faec8b27a99adf80d0276c1"/><dir name="Product"><file name="Gallery.php" hash="475088e1291fb55e55dfccc2b251964e"/><file name="Product.php" hash="5cfc4c77f8d7b7431f9b922f7fc6bd87"/><file name="Review.php" hash="a343151fe3ca1c07c3bc3835b8b3de7b"/></dir><file name="Product.php" hash="2ae833518fdfbc68291b12dd306d54f6"/></dir><file name="OfflineCatalog.php" hash="becd222a9465a2a76ec745d6dc87e73f"/><dir name="Payment"><dir name="Method"><dir name="Paypal"><file name="Config.php" hash="be507f3c7ed91dee5a5dfda94cf2a402"/><file name="Mecl.php" hash="d5e0d81cacb7daa01ba6de5e4c2a34ae"/><file name="Mep.php" hash="aadc840055d64e79797fdc8b8131e1d3"/><file name="Pro.php" hash="95f452b7a53b725e3cf46361735e4c5e"/></dir></dir></dir><dir name="Paypal"><dir name="Mecl"><file name="Checkout.php" hash="ae8b531a989747319baf9c182c831ff8"/></dir><dir name="Mep"><file name="Checkout.php" hash="ff0a95a4ccf4b634ad399dd39f749d58"/></dir></dir><dir name="Preview"><file name="Abstract.php" hash="327ed7f692c9753472c5d728996d2b2d"/><file name="Android.php" hash="f5ac4ba6b2246221403cbb204f2d46e8"/><file name="Ipad.php" hash="12d621382059de3c6b8273414aedba13"/><file name="Iphone.php" hash="afcaf2577c9fd1e0f0fc991110de36c1"/></dir><file name="Queue.php" hash="251cfb9268a1b64b835ca11839a5f4d9"/><dir name="Resource"><dir name="Application"><file name="Collection.php" hash="b19fbd256a73fa6d78aab9ee42888f84"/></dir><file name="Application.php" hash="c05f1f9873f7ecbbff20c3672e058a7c"/><dir name="CategorySearch"><file name="Collection.php" hash="35b85a98ad9c7d074b59c3525ae4eb4b"/></dir><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="334fb74e0088e436d295b40bf811980b"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="b01894e4fb13a260d780b85d73001f0a"/></dir><file name="ConfigData.php" hash="974643c62572f321cf1e70942a1f2ff2"/><dir name="Filter"><file name="Collection.php" hash="090585923738dbc5d2d3e92ac74d5fc8"/></dir><dir name="History"><file name="Collection.php" hash="24579eca5258b06809924f16aca34e8a"/></dir><file name="History.php" hash="87b18d53ac3045fdf42e0054bac99fde"/><dir name="Images"><file name="Collection.php" hash="3419fabd2f739625f03ead28a84d130e"/></dir><file name="Images.php" hash="4ccc3ec55afa49cb28d15d3f1c6ef4ee"/><dir name="Queue"><file name="Collection.php" hash="e2aeb583c914787669ef7c7cc463ddc8"/></dir><file name="Queue.php" hash="76a8caa2179a95d4d9a0d10a43369470"/><file name="Setup.php" hash="41a1d11f4a4a00e46537da93c5874926"/><dir name="Template"><file name="Collection.php" hash="5d157bdf254052b152067c7b8f9b2708"/></dir><file name="Template.php" hash="4a025a389dfda83885d3be99f673592e"/></dir><dir name="Simplexml"><file name="Element.php" hash="fd7c3598aa177f1907716cf601219aeb"/><dir name="Form"><file name="Abstract.php" hash="fbe0e291e7546f965265cb2d6504f657"/><dir name="Element"><file name="Abstract.php" hash="6377bbab9d7c7f04b73d5056537e28de"/><file name="Checkbox.php" hash="da7c40c59be8e0cfc51df1602279bb8f"/><file name="Collection.php" hash="235fc8c09ff4309c925d06f2410d1252"/><file name="CountryListSelect.php" hash="51968904d112c467dd8100a578565f44"/><file name="Custom.php" hash="c4ad54563c5fa4e66125317591d9aa8f"/><file name="Date.php" hash="71f716a28728d14c386b999e0e73964e"/><file name="Email.php" hash="120682a40beb8230de3a0c8e26da78ef"/><file name="Fieldset.php" hash="71022934e1f20bbd60b039edfc084cf2"/><file name="File.php" hash="585cf229c446581ea47490078fa19f18"/><file name="Image.php" hash="dd5919b1c52222c8dc2ebb10da3be619"/><file name="Multiline.php" hash="a5d802913e78cc43a3284ec8271721e5"/><file name="Multiselect.php" hash="f79b0a7c5b747105e2b763bfceb9a999"/><file name="Password.php" hash="a9779cce59679bd46c532233702795b4"/><dir name="Renderer"><file name="Interface.php" hash="b84d0ee6d9b66f8d9f84cc52f2867af5"/></dir><file name="Select.php" hash="c2ba59f1b627c2692c45a82ea022332e"/><file name="Text.php" hash="00d613d55512fa7279159b9b1e38e3fe"/><file name="Textarea.php" hash="3fa4f12a6f898283a6b89fb0af467f96"/><dir name="Validator"><file name="Abstract.php" hash="89c217eadb21f35369abfb681e96f482"/><file name="Rule.php" hash="33e8edb8c896b25f2a1b220a82716a7a"/></dir><file name="Validator.php" hash="be511ff573d219d60de0ba0b3f740ea6"/></dir></dir><file name="Form.php" hash="c98434080575ce5a55d076be917f1d80"/><dir name="Message"><file name="Abstract.php" hash="6587dfdcc1073929966a38f397e64236"/><file name="Error.php" hash="4fdf18c0200d1cdc03baa45a375ebe22"/><file name="Success.php" hash="1a4c003a718295df9ee5c4610001a6ab"/></dir><file name="Message.php" hash="a312abeacffcde7d58f7d34624751e7c"/></dir><file name="Tabs.php" hash="ceb9453dec3fe8dbadb9130f57fff771"/><file name="Template.php" hash="7232e9f4ce510d1986371e833082ad1e"/><file name="Theme.php" hash="3b26aad383159deb98cb9235eb134d41"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Admin"><file name="ApplicationController.php" hash="d85220bbcf83701e8c4d1339edafe1f9"/></dir><dir name="Connect"><file name="ConfigController.php" hash="181c3a7c1c8c5c7126da20e2948d7afa"/><file name="DashboardController.php" hash="98a02bb6afe602c605a75224de855536"/><file name="UserController.php" hash="d361715dd4fca6a6c8b70a50ce88d6c3"/></dir><file name="MobileController.php" hash="5265057d806f41f1c888f095a422aae8"/></dir><file name="CartController.php" hash="09a71b3690f40ead7d78e33da3fa55ac"/><file name="CatalogController.php" hash="9aba97e5852376a5b5c586ffbe633d90"/><file name="CheckoutController.php" hash="5899163c45d6687a4f55efa3eca97ee4"/><file name="CmsController.php" hash="2dc7b2e14643e26444493f05434d29cc"/><file name="ConfigurationController.php" hash="67c8bc4a5a346f10b5106189c0b9afd7"/><file name="CustomerController.php" hash="f17ae4c197b7aacb4059f232a0b0e7f2"/><file name="HomebannersController.php" hash="f8f921cb733dc3d95b43c2d115612e07"/><file name="IndexController.php" hash="a4424c3802baa3fb782a7cfca984fc11"/><file name="LocalizationController.php" hash="deec1cf96b89da98feb0d72d98c7d448"/><file name="OfflineCatalogController.php" hash="61dc9bc4d698a8a9f675500331c8bc58"/><dir name="Paypal"><file name="MeclController.php" hash="e50ebf752c625a42561e4963f85c19a6"/><file name="MepController.php" hash="6a174a59d145109495b140f64b46bbac"/></dir><file name="PbridgeController.php" hash="2cbd655210d48d2fa4a921e9bdea881a"/><file name="ReviewController.php" hash="1863fbdc0eb62ee07e4e410a129c74a1"/><file name="WishlistController.php" hash="40a7c7951ae734b2c4414d0bf6c475c2"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f2935498f8438d93ac1a0084c7fb6da2"/><file name="config.xml" hash="6c643a21e6a52ea45f058329d881cec2"/><file name="system.xml" hash="817a56b1540cc8ed651b26ed0258fef0"/><dir name="themes"><file name="custom.xml" hash="117a8bb4d666ef613f19b7221268ebd0"/><file name="default.xml" hash="aaf6d41dd756497982a3ea55e13d790f"/><file name="funk_leaf.xml" hash="8c8f9210b10d43c0d90e8d6a2367cfbe"/><file name="hot_red.xml" hash="fca3e8ca7fc3634cae1979313c9b7177"/><file name="sky_blue.xml" hash="b6add2ae0a7ca115013355e316fa0137"/></dir></dir><dir name="sql"><dir name="xmlconnect_setup"><file name="install-1.6.0.0.php" hash="32c08a2bcf373250206437333d7603e1"/><file name="mysql4-data-upgrade-1.4.0.13-1.4.0.14.php" hash="c7315a31f8cef0b7d2ae8f80fbbc3163"/><file name="mysql4-data-upgrade-1.5.9.9-1.6.0.0.php" hash="d5cc11489f9a00b93b6014e065ef5715"/><file name="mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php" hash="438ed4be093ee9c3719d409d82a2ab72"/><file name="mysql4-install-1.4.0.8.php" hash="562ee2192b6688270cb8ae67116b4b2c"/><file name="mysql4-upgrade-1.4.0.10-1.4.0.11.php" hash="47239ae89b5e9879faeade3fcc5e8dff"/><file name="mysql4-upgrade-1.4.0.11-1.4.0.12.php" hash="2682567c7edffaf8818e74b1b89cec57"/><file name="mysql4-upgrade-1.4.0.12-1.4.0.13.php" hash="323be46c94ee31f0cecbc3b4551babd7"/><file name="mysql4-upgrade-1.4.0.13-1.4.0.14.php" hash="0299bd412387a948eca34642c7aef36f"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.9.php" hash="67d93828e93566e400f15df69cd07aad"/><file name="mysql4-upgrade-1.4.0.9-1.4.0.10.php" hash="4a79e3db4382b4239759a117f3261018"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e7ac9d8d2277ffd0d2ef3443c5babd50"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="a5ab0527c9e10a82421e58cf2e7946f9"/></dir></dir></dir></dir></dir></target><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="1dc6e4389554dc766d8a1f8ce14c8880"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="centinel"><file name="authentication.phtml" hash="97d0bda33c048c75071079360a633bbc"/></dir><dir name="pbridge"><file name="result.phtml" hash="eaf8dea1c847a163c6e03a79373f13db"/></dir></dir></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="9da94b4c6b75358e208d77fa71394894"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="edit"><dir name="tab"><file name="content.phtml" hash="8e5ee302d26adf7de3c5190ba3615290"/><dir name="design"><file name="autocomplete.phtml" hash="b896b29fbee0f6a694a4c1bbd4b47239"/><file name="image_edit.phtml" hash="9446db1ebe986034e800854a6cf4a58d"/><file name="images_android.phtml" hash="41e74b4bb5f363898b9c6bbba1abf340"/><file name="images_ipad.phtml" hash="7f4e7170149376c61839b7cd0aeaa535"/><file name="images_iphone.phtml" hash="5f4d38883d8c5b23186dd67aee5c2fdb"/><dir name="preview"><file name="banner_rotator.phtml" hash="21185f73d23a35eb5c2d8947f7f2e920"/><file name="catalog_android.phtml" hash="eaefb0f45613f6300099aa7bf23f301e"/><file name="catalog_hor_ipad.phtml" hash="3f23959c59286a29cfcaa719f78a13f5"/><file name="catalog_ipad.phtml" hash="624c310ec710c971fdd7e35c2122207e"/><file name="catalog_iphone.phtml" hash="c2ce0a7ca0a71f5d02e48147cd707ea0"/><file name="home_android.phtml" hash="058ea828dbc70b1eaa89b431102d5d52"/><file name="home_hor_ipad.phtml" hash="1ba3118600cd47f3db4eace31715f007"/><file name="home_ipad.phtml" hash="1f3033ec5eab6394b1bf7a91ebd3e0a6"/><file name="home_iphone.phtml" hash="f08e7358cac7612f7029e7caf0f8f9c0"/><file name="productinfo_iphone.phtml" hash="165165a8c05b6a667fbeca353d6ec216"/><file name="tab_items_android.phtml" hash="606e607fd42a6eec6ed1ef5d3855512f"/><file name="tab_items_ipad.phtml" hash="b178a8b51482b294b183a34f784b1f1e"/><file name="tab_items_iphone.phtml" hash="296eb9ad61ed6ab61d60b8f4c3dde341"/></dir><file name="preview_android.phtml" hash="e89c6f0b5622334370eeb03dbab11f52"/><file name="preview_ipad.phtml" hash="2f60401391a74808b2906a6e8468aae7"/><file name="preview_iphone.phtml" hash="cbd3e9ce74c2d4135227b24fdbd887fa"/></dir><file name="design.phtml" hash="f99ec1e92a0f6759b781a32332fc89d5"/><file name="offlinecatalog.phtml" hash="50b4394967e3e4053ae774fd8c0365a4"/></dir></dir><dir name="form"><dir name="element"><file name="addrow.phtml" hash="742de06e43b52a50f676098f8fa4e26e"/><file name="app_tabs_android.phtml" hash="0065b3e36e67c53933b823bbfbfd2bc4"/><file name="app_tabs_ipad.phtml" hash="89e64551169dffb436cebcf1f2429e0f"/><file name="app_tabs_iphone.phtml" hash="fe56e0132269b3824592eea17dc49c78"/><dir name="country"><file name="androidmarket.phtml" hash="d3702381cf57187df6ce2fb072c76f11"/><file name="istore.phtml" hash="861c3513f38f5d1cfb9303919bcab2dc"/></dir><file name="themes.phtml" hash="d3bc3e4d2b0a66acaaceb4545b5243f7"/></dir></dir><dir name="mobile"><file name="notification_helper.phtml" hash="1eb816a7bb47c809b028e9678c68282d"/></dir><dir name="submission"><file name="app_icons_preview.phtml" hash="b2f951860b9d0be57341d0e47a3b229a"/><file name="container.phtml" hash="a2a4e92c17ac1298c5012ef28b68a458"/></dir><dir name="template"><file name="preview.phtml" hash="c2b5375cc3a30ed8250effe88a81e494"/></dir></dir></dir></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_XmlConnect.xml" hash="26dbfbfa2414f06ef6db95abde509e31"/></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_XmlConnect.csv" hash="50e9493da78f8e6591fd3fad1311047c"/></dir></target><target name="magemedia"><dir name="xmlconnect"><dir><dir name="custom"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="original"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="system"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="xmlconnect"><file name="boxes.css" hash="a5a92bc3147999c70608672cceb8d818"/><file name="dropdown.css" hash="c631ab21a370129eb5526a26df214ba5"/><dir><dir name="fonts"><file name="android_icons-webfont.eot" hash="2fc917efbfb3c933ccfddc108ef05f33"/><file name="android_icons-webfont.svg" hash="e8cb2b5ef019bbc2885c97ed0caaf2a0"/><file name="android_icons-webfont.ttf" hash="bc567dd7a381093fbb652c58cbad9430"/><file name="android_icons-webfont.woff" hash="8310b54d55bf84a8a3f3a86c22a51aef"/><file name="stars-webfont.eot" hash="019beb4b8ec19447657cf3106138bbe3"/><file name="stars-webfont.svg" hash="20cf0312c0b951d173d4531ea18abc6f"/><file name="stars-webfont.ttf" hash="d63d95e9adaf775f410437535622bf60"/><file name="stars-webfont.woff" hash="526d9756131c94139f0f1df5272197fd"/></dir></dir><file name="iestyles.css" hash="8d5df1c3013797471e228162afc411e5"/><file name="mobile-android.css" hash="cc441eb45f35bd3d29b6f0833cd3b9fc"/><file name="mobile-catalog.css" hash="78e840f9871cb34662962efc4d03a514"/><file name="mobile-home.css" hash="2c38e64a3d024616bb85439707143fc9"/><file name="mobile-ipad-catalog.css" hash="22de5fda6eb0c3f2e4700f8360d62a0c"/><file name="mobile-ipad-home.css" hash="d07bbd12056c3a87cf92595e19f7a493"/><file name="remove.png" hash="b4903936d44dc498d2f32b72d9161ff0"/><file name="styles.css" hash="fb40b0c19d8fbc44d5032f69a9ebc92b"/></dir><dir name="images"><dir name="xmlconnect"><file name="btn_edit.gif" hash="e7ecc9fea5c3813957814050508507a5"/><dir><dir name="design_default"><file name="accordion_open.png" hash="4c89d903ebbc61ee295ef64a60724b10"/><file name="accordion_open_android.png" hash="7ef2f1d193990c3f4c2c90aae9ab3281"/><file name="accordion_open_android_l.png" hash="bc27688afbfd866c618477ea2c7bf0ee"/><file name="accordion_open_android_p.png" hash="2e4549cba575c12ef2a39c12e9ffe173"/><file name="accordion_open_ipad_l.png" hash="dcdda97da6556393b972d6dae8d6bac5"/><file name="accordion_open_ipad_p.png" hash="55cca08a0ab79047961858789ff8c3a7"/><file name="banner_1_2.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="banner_android.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="banner_ipad.png" hash="c1d59a6ec67da1bb76c5142453da7acf"/><file name="banner_ipad_l.png" hash="04e850d481a9ae902f33fd8c1f89cbf0"/><file name="smallIcon_1_6.png" hash="c1ce9e289eaf2c0504d502928693bd89"/></dir><dir name="mobile_preview"><file name="1.gif" hash="817fd84187db3eee00799b0acf316457"/><file name="2.gif" hash="1a842d8f3ac25cfcdeab6c86dd8fea89"/><file name="3.gif" hash="207cd55e968c284bd52c86efdcdda1c7"/><file name="actionsBackground.png" hash="11faa8baee72f3e6a9a02a83915c8658"/><file name="actionsBg.png" hash="9acccd1980f17006942d74a718ebd7da"/><dir name="android"><file name="background_home_landscape.jpg" hash="1f79a1f42ca4e2cf6010ab6c3ef66aa4"/><file name="background_portrait.jpg" hash="197b15e6455ad1a85e1bad6595371fa3"/><file name="bg_button_up.gif" hash="204f590a88933c930b7fc92963accfab"/><file name="bg_cat_item.png" hash="2859b45c387b66243d4af2ba973b2ae1"/><file name="bg_catalog_filters.png" hash="7464191ebaf576b73a3c021eb1cfcc25"/><file name="bg_catalog_filters_shadow.png" hash="5021ad60917190026d85fae1d33bdaa9"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_frame.gif" hash="7062ed9b7563fc658f49ce7cfdd34f1c"/><file name="bg_header.png" hash="d4a46c8850d1d89259921b1c28b5bce1"/><file name="bg_header_catalog.png" hash="c1080cd18a89e21da18fdc6955bf6230"/><file name="bg_header_home.png" hash="dfce0445ca7c7a45c7914a986b596ce0"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="8bc1887a0c5760cc47b77b8a7a320426"/><file name="bg_logo.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="bg_page.png" hash="d65f1d123655c2eaf3bb4a1e6035a08d"/><file name="bg_star.png" hash="fc6de6c4e0ed3478b8840e1ab81da725"/><file name="bg_star_empty.png" hash="3f0421fb8c8f6c4be6ca501168a881e8"/><file name="bg_status_bar.png" hash="52b41106451ac34672f82338bbc5370c"/><file name="ico_account.png" hash="c1fd338c74fcf483155acbd37c430807"/><file name="ico_home.png" hash="2de37f640463b354d68945320bfe3e4f"/><file name="ico_search.png" hash="8b0dd17a3e9c3328e66204fe379c66aa"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.png" hash="dd975b128ba303e0ae2adc9772e0433c"/><file name="product_image_1.jpg" hash="8994979d4dcc1f339c73cd1f44398a7d"/><file name="product_image_2.jpg" hash="26d6599bdb35d80b25a1e903b40cfa19"/><file name="product_image_3.jpg" hash="d7c6d05196a84341afe0025d01b9dc61"/><file name="product_image_4.jpg" hash="2a88ead3dbbeff1d40168db692841f2f"/></dir><file name="arrow.png" hash="837259a7c365e46034dca728bffe9070"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="background.png" hash="3717f4b4ba725701e2a0604129a3a815"/><file name="banner.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="btn-l.png" hash="92b2454528e9d39119038777cf53329c"/><file name="btn-r.png" hash="8c6aa9fd9203bc10822e0505f11e0c4d"/><file name="circle.png" hash="f4c116cb0554bf936d3b9ee38b7f3d1f"/><dir name="custom_icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="e33876648546e99d875ca92bd2cd78e9"/><file name="addToWishlist.png" hash="1018602b7c5e0e11f0427ace96fd7d52"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="buttons.gif" hash="0cd19a9d9178976906161ea100cba958"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="image-bg.png" hash="14bde5cf8b00dc5f6c60e52a0fa964dc"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="tellAFriend.png" hash="46f8ef48b29f245977d66d9312d87e70"/><file name="viewDetails.png" hash="9bacc63bcc483d3db5614a026d9391f6"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><dir name="gradients"><file name="footer.png" hash="31a2feed50ef9c8637b412c4211f8300"/><file name="header.png" hash="5386da930a944cd75562216249cce08a"/><file name="header2.png" hash="ad5a2dc6ec93914e925cfe2d43fb30a2"/><file name="header3.png" hash="920ad8c6903e90323a57fb02dca37280"/><file name="item-bg.png" hash="a14886d1f9e14284ac6b4f1b61e68646"/><file name="sort-bg.png" hash="b8053bb772e849909e5b87e4fd1ebbe4"/></dir><file name="grid.png" hash="23faa3f5572cdeb597c2bceedd93a7f8"/><dir name="icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="more.png" hash="f3662ae29923b87eba3a729192aa3df3"/><file name="page.png" hash="2291d77f21de042040bc0864be40138b"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/></dir><file name="image-bg.png" hash="a588b9cced95a25fc18e28c775d9a001"/><file name="info.png" hash="3f0d2ed85b81e8251f294457c6bfa404"/><dir name="ipad"><file name="background_home_landscape.jpg" hash="9e3ef117985113b804531142d539b60a"/><file name="background_portrait.jpg" hash="bdf9e034fd30b923086e6c622ea10451"/><file name="banner_image.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="banner_image_l.png" hash="a070a40d57610b5cc7160fe894482a1c"/><file name="bg_catalog_header_hor.png" hash="f61a67aa288e1b8a8df7b4d4527c662e"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_filter_button.png" hash="728f1cd358446881ffd863eff12204a1"/><file name="bg_filters_buttons.png" hash="02fcb0ed7a7268e9f64ebaf06235bc09"/><file name="bg_filters_tooltip.png" hash="3b05ca6e585acd3d766be01eeaa23d47"/><file name="bg_filters_wrap.png" hash="31288784fe95c67de9b45b44458b4155"/><file name="bg_header.png" hash="e2cf5a575a27e6e4533e3c85e3472a82"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="00f2fbf96d2b915dcbcd921b0301ef3f"/><file name="bg_home_header_hor.png" hash="9bfef728ece003d5b3433d2623ea168c"/><file name="bg_home_products.png" hash="ac6a8a79b959a0c8298b1f607c0f0af8"/><file name="bg_home_shadow.png" hash="c54b071ca3e97a6ee67588ef74b7b44e"/><file name="bg_home_shadow_hor.png" hash="0d21a99c5c749d0e5070e3585ff4a23f"/><file name="bg_product_image.png" hash="4da74325c1a4ee1ca19b414e5d590f75"/><file name="bg_search.png" hash="6ee08d05d0c4ef9ed64b9914b821f408"/><file name="bg_sections.jpg" hash="0ee90005663aced09a9ce6385bdbce2c"/><file name="bg_status_bar.png" hash="17124d9d392bb8e37b202c80a595df54"/><file name="bg_status_bar_hor.png" hash="bd4a9f11ecb1c896145267731d8a951d"/><file name="i_cart.png" hash="1bbe0a0e54eed5bb14b9bfcce83da758"/><file name="i_info.png" hash="3f0fda8b294b67bf698badbcaa99150b"/><file name="i_login.png" hash="deb4089bdc61582c78c90ef192d577e8"/><file name="i_remove.png" hash="4923eb5e76b3c6ba6df5c667db816a0c"/><file name="logo.png" hash="49c19f59b459b6c0b3b99daa3fe7f932"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.jpg" hash="2bb6c69129bcb18dc93e9f48605647c6"/><file name="sections_arrow.png" hash="7db7144083a31882e8a62cb9579f478f"/><file name="stars.png" hash="70d38cd9883d70e4f6b21ac4874b9868"/></dir><file name="lightStar.png" hash="b5dc40d5b793dae6a069357f49cccc24"/><file name="lightStar2.png" hash="75928926a6112540c9cb073157cb7d95"/><file name="lines-h.png" hash="ea3d95812c9838affc6df2f3a3cb1977"/><file name="lines-v.png" hash="9e3ffee29ba28477d50da9642019bc0a"/><file name="login-btn-left-alt.png" hash="71bb6c7d24252aace27bee711d7616f4"/><file name="login-btn-left.png" hash="cbbf9afc6e9fc433f57270e88b63f351"/><file name="login-btn-right.png" hash="438fcc598d012bf6d33184e95accfd24"/><file name="login-btn.png" hash="051ee2c1a8ce3f7b8de3293cd2e2ed85"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="logo_25.png" hash="ba41ed568d916175c32803b614442447"/><file name="men.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="mm-frame.gif" hash="eebf30806f1dbf2118e7ec39a016c86d"/><file name="mobile-catalog.css" hash="c808bf7f4ef7d84e6c0848f88abef943"/><file name="mobile-home.css" hash="a4a5f38b76b58bd4d18fb50e5977b1bd"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><dir name="slider"><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="2a146be4bc63713df19cc353e030d44f"/><file name="addToWishlist.png" hash="9b23a4e0d9acfc79f314e9082f14c4de"/><file name="tellAFriend.png" hash="b7600fa2ae52bdb1d6bb86fe4d9f1773"/><file name="viewDetails.png" hash="90cf37c6dbbee1861350b4c05469e3ae"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><file name="slider.gif" hash="c6b87bf15b85b18c0515e2cbefaabe60"/><file name="smallIcon.png" hash="e76d2a6364042f41b3f35fc8cdc9c0ee"/><dir name="sort_buttons"><file name="bg_button.png" hash="87d0f1b123f01c3aea3cb8a2b146306e"/><file name="button_up.gif" hash="7ad527f99b9975d5634fb2d5cc99e6b3"/><file name="buttons.gif" hash="2f14f1a3f0fb38790779c992a58654ae"/><file name="buttons.png" hash="b4a3f17370e03bf5d2a5cdf7800c25a7"/><file name="center-active.png" hash="5903988cd458cd794f23a212d51aa725"/><file name="center-inactive.png" hash="135b46aaa5c3b131a5a7e9c45c004e06"/><file name="filters.png" hash="3837ab6fcfe959833dd998533db1ca7f"/><file name="left-active.png" hash="86e94441b96a0d27d0b0a7e5108f86ed"/><file name="left-inactive.png" hash="0ddcb75aa9971cca39a5a65b4bdff8c4"/><file name="right-active.png" hash="320740ff608187301b06a96eab2f9e8e"/><file name="right-inactive.png" hash="cac4b39ab380353ffd5fdbcedb6e0a0a"/></dir><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="t-shirt.gif" hash="7505efdaabf13c4f8e26f7cfe15c8c96"/><file name="t-shirt.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="women.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="youth.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/></dir></dir><file name="dropdown-arrow.gif" hash="332e99ca6b4d1e0d39972e04fb0b2395"/><file name="empty.png" hash="23dc9dc3c4751f83c2df7a5c42668824"/><file name="full-arrow-left.gif" hash="8ec91b60d38d1a16cba7670f2088a5c7"/><file name="full-arrow.gif" hash="36ddff0fca1c7d8900cb3633e0a30cea"/><file name="gel_green.png" hash="591959d831e8e42c9175d12a88f0bae2"/><file name="gel_red.png" hash="db442c023014df9da32b84bc1bb5a39f"/><file name="l-arrow.gif" hash="ee49f7eab64657b5131953acef0238fd"/><file name="loading.gif" hash="5d25806dac7cbee5f894b13144783866"/><file name="r-arrow.gif" hash="d0429a9781e915fc9d9ca8875c470d32"/><file name="remove.png" hash="ee9497c5f31933eaab3e9e352495ee12"/><file name="small_logo.gif" hash="d5c8be7c0f16aac2549759c0228492d6"/><file name="swatch_black.gif" hash="fd31d6a3a435c8ad1f7c43f346bb47e4"/><file name="swatch_custom.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_default.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_funk_leaf.gif" hash="f1d3ba87efb742b47da879a6f48909c4"/><file name="swatch_hot_red.gif" hash="d9363d45dc2993c2fdc3ea43c5b6f71c"/><file name="swatch_sky_blue.gif" hash="ded1455db119d09a3aedd7474fd1875a"/><file name="swatch_user_custom.gif" hash="a24f31421a1ff56d1be0845f9a7c7020"/><file name="switch-arrow.gif" hash="dc7243962b341f366cd072d486687e6a"/><file name="tab_account.png" hash="27101fbaa78a07426be4768acc4c53ff"/><file name="tab_account_android.png" hash="77605cbc87f75ca17e91a5393765ceb1"/><file name="tab_account_ipad.png" hash="2997de5402195d0720309b73c6446fab"/><file name="tab_cart.png" hash="e803f760ee81cb35183f1122f388b774"/><file name="tab_cart_android.png" hash="477e97f8d03ea8aa674e952709f86578"/><file name="tab_empty.png" hash="bdd4cc355566e8861b2c45424ad94516"/><file name="tab_home.png" hash="dfa104e4da74e4a55d3c98d6ee0f7122"/><file name="tab_home_active.png" hash="bba5eb9bb724c84c1ede9e6f4bec3575"/><file name="tab_home_android.png" hash="1fefc6b070cc21b31b43194a7d85f9d9"/><file name="tab_info_android.png" hash="67fc19d8d926f7aede482f5a7083fc71"/><file name="tab_more.png" hash="2803359cb3e795bf67457e727aa16020"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="2cf29dbe325558353621b4241543204f"/><file name="tab_search_android.png" hash="932c2c568872fd9e119367c887f0539a"/><file name="tab_shop.png" hash="f36be0d3d27f2b37626247d3f6a55e2a"/><file name="tab_shop_active.png" hash="de907d6a52d477d4319649f9b0e2e4aa"/><file name="tab_shop_android.png" hash="e119fcd20f8cba856d550a64d775ddbb"/><file name="tmp-icon.gif" hash="58b759aecf3bdae26d5aaff7a0be5c90"/><file name="xmlconnect_tab.png" hash="cd99a7e01a42a6c82d866f7684faeb95"/></dir></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="xmlconnect"><dir><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="jscolor"><file name="arrow.gif" hash="5034704a76cd55c1cbcbc58ea6bf523f"/><file name="cross.gif" hash="ba9a274b9323753cd95bc3b1eb2f4e5f"/><file name="demo.html" hash="edf71251cb2be20322d2efb00aee86a6"/><file name="hs.png" hash="fefa1a03d92ebad25c88dca94a0b63db"/><file name="hv.png" hash="990d71cada17da100653636cf8490884"/><file name="jscolor.js" hash="b65a1505390592ac6c0177d6b84774e0"/></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Magento_Mobile-1.9.4.2.xml b/var/package/Magento_Mobile-1.9.4.2.xml
new file mode 100644
index 0000000..7a4ddba
--- /dev/null
+++ b/var/package/Magento_Mobile-1.9.4.2.xml
@@ -0,0 +1,18 @@
+<?xml version="1.0"?>
+<package>
+    <name>Magento_Mobile</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Magento Mobile Xml Interface</summary>
+    <description>An integration Magento with mobile applications (e.g. iPhone, Android, iPad)</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:17</time>
+    <contents><target name="magecore"><dir name="Mage"><dir name="XmlConnect"><dir><dir name="Block"><dir name="Adminhtml"><dir name="Admin"><dir name="Application"><dir name="Edit"><file name="Form.php" hash="42cbf9631bb3eef431e9398b1bffb6f9"/><dir name="Tab"><file name="Settings.php" hash="60f79bfea8f31a45f68c384c62b51a6a"/></dir><file name="Tabs.php" hash="e164c429630358b7ed08b12fba12a0bf"/></dir><file name="Edit.php" hash="da4aa415cc7f509e9c5b4ab0abedf6b7"/></dir></dir><dir name="Connect"><file name="Config.php" hash="ef6f52f638874cae27d71a60ab7f6390"/><dir name="Dashboard"><file name="BestSellers.php" hash="fd83fa0abede5e1120d9f2607728c660"/><file name="Customers.php" hash="7c15234d44f4580d4d09c9c480913fd8"/><file name="GraphAmountsData.php" hash="8651060b90056a1a73097eb675669a4c"/><file name="GraphDataAbstract.php" hash="631981805df46cc521a6d78981d62f14"/><file name="GraphInfo.php" hash="fa60ad1ecad8eebea1a814fa8f3f11fc"/><file name="GraphOrderData.php" hash="4c57f103ed14ac56374548198a3f1c0c"/><file name="GraphTotalsData.php" hash="6362d716bf62d4203c0c5e4a58fa70ae"/><file name="LastOrders.php" hash="9e4d98b91e353ace105f5dc2e8880a37"/><file name="LastSearchTerms.php" hash="da93c128090d68728518b47f1937c0e6"/><file name="MostViewedProducts.php" hash="0d2f13760e47ec747772eb4fa669a577"/><file name="NewCustomers.php" hash="71faee15fdd7933ce87a579712330629"/><file name="SalesInfo.php" hash="fb77263dc72fbb4514f59270700ee798"/><file name="StoreSwitcher.php" hash="be57a6337549e4d072ce80cbe38004d3"/><file name="TopSearchTerms.php" hash="8ab84597489faa349365e2320dc6256d"/></dir><file name="Dashboard.php" hash="4d55218423a2577e0db0e65f390a0eaa"/><file name="Loginform.php" hash="3b4b92ef534eadbaae38bbef867cea04"/></dir><dir name="History"><file name="Grid.php" hash="36511c8994308a45c6b13e753ced86cc"/></dir><file name="History.php" hash="107c69ecac1edfb0b4724c5707a0ce1e"/><dir name="Mobile"><dir name="Edit"><file name="Form.php" hash="8986f753b1c7487e8c4a372a297f700c"/><file name="Submission.php" hash="c21b6576548b2f627ea224c88ec595a6"/><dir name="Tab"><file name="Cache.php" hash="980297562509b4d08f5914d3f5fce3fd"/><file name="Content.php" hash="b39a9829604497c7c0dab3b20866882f"/><dir name="Design"><dir name="Accordion"><file name="Images.php" hash="a92f18f8c4014230ce95dd1c62a128b0"/><file name="Tabs.php" hash="1c27d76f5428dd09c64e7b2f16095f73"/><file name="Themes.php" hash="e4e0e33198c8eafe2e827463cbe9ccac"/></dir><file name="Accordion.php" hash="dc535a038a8833aeba8e0c50327e03e8"/><file name="Images.php" hash="6b5f93bba329732e91da9df1e2df5751"/><file name="Preview.php" hash="49134611eb84b29dd0b99e8b415316c8"/><file name="Themes.php" hash="6090d653f395866788358daad5698d6b"/></dir><file name="Design.php" hash="dc566d2f573e2392a5d5670deb87c40f"/><file name="Flurryanalytics.php" hash="9fa282f43ceb9c9bd0d21c2ed8a61daf"/><file name="General.php" hash="824c36bebef3952c9f576de13c8bea98"/><file name="Notification.php" hash="75b24ca6db9d117d57d11ad4a9e2b93b"/><file name="OfflineCatalog.php" hash="92ee4fb43aeea91d7b01a59bb0d63592"/><file name="Payment.php" hash="812419b60554837546a757911a9aad54"/><file name="Settings.php" hash="7fe481b44647e6b124ded33afd3006e7"/><file name="Social.php" hash="cfb2fbbc99e569c5ac1c5d9c2817470b"/><dir name="Submission"><file name="History.php" hash="7d747f93da808e60db9d1c6fc9b5615a"/></dir></dir><file name="Tabs.php" hash="477fbc0c585e4ad400cc9b857663168c"/></dir><file name="Edit.php" hash="e22b7a01bb4999c6755c8843f1595214"/><dir name="Form"><dir name="Element"><file name="Addrow.php" hash="10480a9e700140671bdf129077491079"/><file name="Color.php" hash="50129c1b65d750aeedec27ed4a7d4f43"/><file name="Country.php" hash="3920f03b1786f6421f2b35543f90ad79"/><file name="Datetime.php" hash="0faa673cc2d2333d94a68fb8f6ae1840"/><file name="Font.php" hash="01a83b1dd25de9dea96d7bd3b120eb80"/><file name="Image.php" hash="afc307c06eb3acc95a22a9f7366789ae"/><file name="Page.php" hash="d677d9ede74ac4d4205295af7aa1fb98"/><file name="Tabs.php" hash="b8a9210e9dc047cbd7d6a0678f0ef3c3"/><file name="Theme.php" hash="ad796959f3425fa9076a1bd8f41ae88e"/></dir></dir><dir name="Grid"><dir name="Renderer"><file name="Bool.php" hash="e933ea09a79b53d5128649a2c944b410"/><file name="Type.php" hash="20c0c938068768cba49b3137bd9995e0"/></dir></dir><file name="Grid.php" hash="edd7bffddc1da5a3fe1cc83ad9cf8576"/><dir name="Preview"><file name="Content.php" hash="364903e644af0f3b4d23efe14620aff0"/><file name="Tabitems.php" hash="8416116abed11a4eeb200dba0e92ce10"/></dir><dir name="Submission"><file name="Form.php" hash="72ec9817f5a562163bb62334c5be1bc8"/><dir name="Renderer"><dir name="Country"><file name="Androidmarket.php" hash="28a255a8d7bc2c80e28056146e862bb3"/><file name="Istore.php" hash="7cb3d129e63a5d7b601b8e176a56fe69"/></dir></dir><dir name="Tab"><dir name="Container"><file name="Submission.php" hash="bd162efb92f38afa814d8f811acc677d"/></dir><file name="Container.php" hash="d88f4280209e67efb62e425dfb51181f"/></dir><file name="Tabs.php" hash="273e945bcc16fe9ebf2507e9202b109a"/></dir><file name="Submission.php" hash="f5d121c59912fae01944db2a90a9e46c"/><dir name="Widget"><file name="Form.php" hash="c6596c73c3a03e55035a1435138a757c"/></dir></dir><file name="Mobile.php" hash="c4bb3627a57b2bded79ded4bf1f76ba7"/><dir name="Queue"><dir name="Edit"><file name="Form.php" hash="8a69da64c633c90b815a149d418e1e60"/></dir><file name="Edit.php" hash="bac0cf8d7090e606e62fba0443a77401"/><dir name="Grid"><dir name="Renderer"><file name="Action.php" hash="afbdc54e2d2182d3f1ebe8867ec46f9b"/><file name="Application.php" hash="5e6d1a4cd82c8f148665280814c6a66d"/><file name="Id.php" hash="564b9860db7e21d1d9a644e276d92748"/><file name="Msgtitle.php" hash="bfa380f535758215d9c714aae53b87b9"/><file name="Pushtitle.php" hash="90ebc1553ba4d8bea1e41926e281e85c"/><file name="Status.php" hash="f7230c7dca270a2d0e1a8f7046d70f7e"/><file name="Template.php" hash="aebbc022bfb288eb5101304c8b656d37"/></dir></dir><file name="Grid.php" hash="e4ea25e1eb6515633cb933b1dc653041"/></dir><file name="Queue.php" hash="07f1dcf45efd1ca07e12bd6a8defce77"/><dir name="Template"><dir name="Edit"><file name="Form.php" hash="83997726da0b6e8d5c9123f27b59a538"/></dir><file name="Edit.php" hash="4ff833041c232ca1ea787633de5a8511"/><dir name="Grid"><dir name="Renderer"><file name="Application.php" hash="2ffba8b1be1d1942f9f0648ebe5ee077"/><file name="Name.php" hash="09e2e85e74df397c903528a853d055fb"/></dir></dir><file name="Grid.php" hash="b373a577f1c41fb9d7fed57c0c67965a"/><dir name="Preview"><file name="Form.php" hash="01e6987b191e4e3d5ceee4a2816e43a3"/></dir><file name="Preview.php" hash="45a7ec71db6beb22c54f8610e966b910"/></dir><file name="Template.php" hash="66c96b78a0d7a202268681fd84f6a6c3"/></dir><dir name="Cart"><dir name="CartTotals"><file name="Default.php" hash="aa4a54fa28ebbb5dddd92e11cf1be9be"/><file name="Grandtotal.php" hash="85c3426ab148a9e015dd07acda656532"/><dir name="Nodes"><file name="Default.php" hash="21708d567639f087d30797c810d6b5d1"/><file name="Giftcardaccount.php" hash="3ab9b8cf4b4e710258f208f03cdb09a5"/></dir><file name="Shipping.php" hash="0d0e531150a5afaa13e52ee9dede860e"/><file name="Subtotal.php" hash="47d8122cdc887d0dff9e3912eb7ceab9"/></dir><file name="CartTotals.php" hash="c1fa081e4688824455c63a429b40c7b3"/><file name="Crosssell.php" hash="22984daab011bbe59f36986f0c44f7f4"/><file name="Info.php" hash="987fc8f96cfcd31a5d57d874591c87dd"/><dir name="Item"><dir name="Renderer"><file name="Configurable.php" hash="f5670a94587490768a94816c6a7043f4"/><file name="Grouped.php" hash="d9218c9a232a947f9667deefca98f376"/></dir><file name="Renderer.php" hash="413196834f1cc45c849284764cf72ced"/></dir><file name="Items.php" hash="9ef9351b39bbb23a79843138571b5a3f"/><dir name="Paypal"><dir name="Mecl"><file name="Details.php" hash="06a1c937089063423e8f7703fbef2dd2"/><file name="OrderDetails.php" hash="0d7e04d6be3962552e65535fbcce234d"/><file name="Review.php" hash="780bde503e02e74b68ad48a4aa178d4d"/><file name="Shippingmethods.php" hash="20598482b0508e2987a5342f223ff7f7"/></dir><dir name="Mep"><file name="Totals.php" hash="42a88f97d59f3f2e8b79d255e16144ef"/></dir></dir><file name="Totals.php" hash="eb6f3381db7cd39a5f39ea195b1f5182"/></dir><file name="Cart.php" hash="fde0584dc2b2811f6bb8f26cf2ed67f7"/><dir name="Catalog"><dir name="Category"><file name="Info.php" hash="c08a92405bf045de2e81e850f849f023"/></dir><file name="Category.php" hash="1b236585d2f8ff81a588699d6085f29c"/><file name="Filters.php" hash="800c575490bceda583cb7cbf43e06b0e"/><dir name="Product"><file name="Attributes.php" hash="9b3cf0c0e19fbbfe34c3d044a1823f62"/><file name="Gallery.php" hash="0afbc24f715bf88cd1167c318427d788"/><dir name="ItemPrice"><file name="Bundle.php" hash="ade6f06324b5c32fc0bb14b3a045ccd9"/><file name="Default.php" hash="1a0927b5ad5e1f8d7ab4e7ee0d28618f"/><file name="Giftcard.php" hash="f4d4f56ef7cc963ad365040d6b156949"/></dir><file name="ItemPrice.php" hash="e953ef560e9677ac54cb36d7ed6654e0"/><file name="List.php" hash="48390c6fdb31105e9e6356b6c5952074"/><dir name="Options"><file name="Bundle.php" hash="b15512d69c62d0559935f8d01b9cf941"/><file name="Configurable.php" hash="a83c4152060bf608b17d4bc3e33ff20d"/><file name="Downloadable.php" hash="0460412f67215b73fd0d3fd495685239"/><file name="Giftcard.php" hash="7df14238d142344e8acab77e6db8c451"/><file name="Grouped.php" hash="a8d50a53444b5593a31b2845a4752719"/><file name="Simple.php" hash="fb17951ec6e37da9b59531173336061b"/><file name="Virtual.php" hash="3aa13acb5b4f778f93d145ef67bcdef1"/></dir><file name="Options.php" hash="c73a87c8f50953f13d3de6c62c2fa561"/><dir name="Price"><file name="Bundle.php" hash="19b19f708134f2efa72ae044a19e13a6"/><file name="Default.php" hash="a462cf7fca028e973afe141455727014"/><file name="Giftcard.php" hash="6d4ae9ca376e16f2ce85994187b2810d"/></dir><file name="Price.php" hash="1936b972ce882fb03c99419474c86e3a"/><file name="Related.php" hash="bf8bca72c91a15837c0bc5f2685e2609"/><dir name="Review"><file name="List.php" hash="788ceecda434b52908495b30bc1501e4"/></dir><file name="Review.php" hash="c78e32b03f67861300f36bde6a57f8b4"/></dir><file name="Product.php" hash="38e22e7743f7798fd852232aafa13215"/><dir name="Search"><file name="Suggest.php" hash="76286050a2f2355fc93ff8a3c5dd503b"/></dir><file name="Search.php" hash="c19748ad0547bfeb05ac7d29069e9b94"/></dir><file name="Catalog.php" hash="1f83bf40bc69b7a90a7e3a92e5141cc8"/><dir name="Checkout"><dir name="Address"><file name="Billing.php" hash="60f5d7fda1904c44d269e83d32b04c21"/><file name="Form.php" hash="a1f8e3ad1cdeccc275374bf300f233d7"/><file name="Shipping.php" hash="9688c172819d8642184f80f24f8ffe2c"/></dir><file name="Agreements.php" hash="1c59b6dfb81133936ce928eac880c4f4"/><dir name="Cart"><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="fbb065663009c95ee39ba735cbdb6f38"/><file name="Configurable.php" hash="32ec7bc671b88c1105c656d59e7a6097"/><file name="Downloadable.php" hash="deeb8e695aa914ead6c718936bb0caee"/><file name="Giftcard.php" hash="06adc988117d07b3402bc07d632dd1d0"/><file name="Grouped.php" hash="813b8d991c30043fc43f6d9f98c113b5"/></dir><file name="Renderer.php" hash="4e410027b4a1b0f8dc56acec9a3ef0dc"/></dir></dir><dir name="Onepage"><dir name="Address"><file name="Form.php" hash="d741113a5edf198d37034368413c0f24"/><file name="List.php" hash="7bd1944b55751bfb1d0742e8c7de15c1"/></dir><file name="Address.php" hash="65aabe67caaf3899cf51ac2b32941b74"/><file name="Review.php" hash="698a09561d3706593516b72eb68b307a"/></dir><dir name="Order"><dir name="Review"><file name="Info.php" hash="a059b6066b3736fe060886608dca1ff0"/></dir><file name="Review.php" hash="67ed1ba38387ca695ec59ec72326a0b1"/></dir><dir name="Payment"><dir name="Method"><file name="Authorizenet.php" hash="834362380417a44933542381babf2ae4"/><file name="Ccsave.php" hash="3b9620de2dd955aa5fde1dbb50ed7d45"/><file name="Checkmo.php" hash="a4e64c79441c7ed6f9f1af4768476cd1"/><dir name="Info"><file name="Authorizenet.php" hash="1205a19f9cae588ae8f6182786341ac6"/><file name="Ccsave.php" hash="f88eaa8cae31cf309919eae02c9bd1e7"/><file name="Checkmo.php" hash="a3ac5e69918948a578e4b2b45cbd6fb7"/><file name="Free.php" hash="293ba305893aa93e6c46280c270c5344"/><dir name="Paypal"><file name="Abstract.php" hash="64b61f0037e0cb6db6f02d29af5af0c8"/><file name="Express.php" hash="92dedcdce406e8a28ffd3880406f0929"/><file name="Mecl.php" hash="45458c3b1756b5370b989c6cc80a19ef"/></dir><dir name="Pbridge"><file name="Authorizenet.php" hash="c13c201ba4ca62dad0c3a87cf4a9f703"/><dir name="Paypal"><file name="Direct.php" hash="b16b116cae5073631b334fa21c977771"/></dir><dir name="Paypaluk"><file name="Direct.php" hash="097c94fce223fa8c522d800bd6cc13fe"/></dir><file name="Verisign.php" hash="5d4511d4102ab8644ffe03dd1c79977e"/></dir><file name="Purchaseorder.php" hash="e58212454a851d514a84ee42a2cde91a"/></dir><file name="List.php" hash="a3e2ce26d286aabcab0f55c032239851"/><file name="ListApi23.php" hash="9b5e71077e7a0fd02946da3f486cfbb7"/><dir name="Paypal"><file name="Direct.php" hash="d3e4408ba28a9ba8f94eab98e4e4e490"/><file name="Payflow.php" hash="972c68fbe72496667bea7de3a799cdb8"/></dir><dir name="Pbridge"><file name="Abstract.php" hash="3642dfbe2d063ce90cf0ff55179a4bae"/><file name="Authorizenet.php" hash="401dc6b998dab46602a6c2ac157a70cd"/><file name="Paypal.php" hash="c2a29305f8fc181bb6076f2ff3f1d763"/><file name="Paypaluk.php" hash="0f666eb6c38c09f523d00889a4cdbe57"/><file name="Verisign.php" hash="cf6a0ed466ad465730863ba50834cd3f"/></dir><file name="Purchaseorder.php" hash="e989e488a318c9d67110a00cfc7daa32"/></dir></dir><dir name="Pbridge"><file name="Result.php" hash="349e21d3652cc2724119ce99b98d2285"/></dir><dir name="Shipping"><dir name="Method"><file name="Available.php" hash="a79a59eaf32107633f87fb552d83567e"/><file name="AvailableList.php" hash="fd5013cf123d5b353b16c37db7da2f91"/></dir></dir></dir><dir name="Cms"><file name="Page.php" hash="e6d1e375bae972eb739373dc044acb17"/></dir><file name="Configuration.php" hash="724321f880ef2d348ce935123249bf96"/><dir name="Customer"><dir name="Address"><file name="Form.php" hash="de7c6b19495fc25240c47dde1fe61385"/><file name="List.php" hash="42546489a24f4c1bfa098026eb3482b5"/></dir><file name="Downloads.php" hash="321d9c650ddd35139815aec45d16d679"/><dir name="Form"><dir name="Renderer"><file name="Boolean.php" hash="296e8a888cfe12328d8a806b2ccebbce"/><file name="Date.php" hash="f6c9d7d8c45c40ed22b3b3aed92cdc6b"/><file name="File.php" hash="35bf591fc6d1657c8f22c284ca2ff081"/><file name="Image.php" hash="dba177ca91d49f760099dcdedc507d46"/><file name="Multiline.php" hash="8587fa80557a9ca19ccafccc076886a7"/><file name="Multiselect.php" hash="68a93aaeb54eda0af2aae6f094409f2e"/><file name="Select.php" hash="a24eec858dfb4829cf9d1ba0986ecd60"/><file name="Text.php" hash="5ccdfbb2f721bf1a55cb5c746170026f"/><file name="Textarea.php" hash="a8df2c653799ab45b88d7a93cbfc3a57"/></dir></dir><file name="Form.php" hash="e35595b42e88bd5fdbbda85a1dd1b967"/><file name="GiftcardCheck.php" hash="5502c3c64d26a729f95d49beddfda484"/><dir name="Order"><file name="Details.php" hash="d3a76a64725673fefcff223a7cbc678e"/><dir name="Item"><dir name="Renderer"><file name="Bundle.php" hash="9b8ec135915a09aee481a1f5afb77ab3"/><file name="Default.php" hash="c13320e211521393b62c18446a1b19a1"/><file name="Downloadable.php" hash="0f7ab7a67658a4e63c1691774405c517"/><file name="Giftcard.php" hash="3b2e6d3a8e4d9f28c0480219da746f6b"/><file name="Grouped.php" hash="bf8405d76c72db226d4edd52cac1eb1c"/></dir></dir><file name="Items.php" hash="626d61c1f7021402743169e508d826b7"/><file name="List.php" hash="c491e8b728aa767c0ab958c31adecdbf"/><dir name="Totals"><dir name="Customerbalance"><file name="Refunded.php" hash="2db2f90238a01322af451d6cb13d0227"/></dir><file name="Customerbalance.php" hash="382c7eb584ca913e12d79b54746e7123"/><file name="Giftcards.php" hash="a530fa9d0642e595f30b14c9fb846e3e"/><file name="Tax.php" hash="f801e9b97383271e443cc41add0a36f2"/></dir><file name="Totals.php" hash="9ea5b26f3a26653dbe71803512228679"/></dir><file name="Storecredit.php" hash="14bd1d964a2f70f330b35c6a1d06e396"/></dir><file name="Home.php" hash="579d6c53346982d239e7e009e400eef6"/><file name="Homebanners.php" hash="28b0ad997a792d9ec7ebf269f0995010"/><file name="Localization.php" hash="d9e0b6f7ed0670a5da165c58d74cdf85"/><dir name="Review"><file name="Form.php" hash="a31ea24b2cb1e22708fc5226296b1267"/></dir><file name="ShoppingCart.php" hash="0fcad0c7d269914600461e82df23d42a"/><file name="Wishlist.php" hash="c90c53dac188bc6d1eb0aaadc52e4ba4"/></dir><dir name="Controller"><file name="Action.php" hash="15ca45ed36fb4242715ff316487df41b"/><file name="AdminAction.php" hash="cca66931020159b3eae2455f28f09a27"/></dir><dir name="Helper"><file name="AdminApplication.php" hash="b17105d0e66e7c686ff38d5edee5cefc"/><dir name="Adminhtml"><dir name="Dashboard"><file name="Order.php" hash="9419e418ef0c1aca45a927c6076ba0d0"/></dir></dir><file name="Android.php" hash="1ed6e9dd7ee1e1ebe7c379e30160cc4d"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="57f732135ff7734cc77f6abb4c8b2449"/></dir><dir name="Product"><file name="Image.php" hash="087532b6f1dec902b53ec28cb659f497"/></dir></dir><dir name="Customer"><dir name="Form"><file name="Renderer.php" hash="045b5ccd69deefa693d7d4c5353ce68c"/></dir><file name="Order.php" hash="de100b167840320bafacc6e93a3283cc"/></dir><file name="Data.php" hash="b896980dc209bb614eb793846c46523e"/><dir name="Device"><file name="Abstract.php" hash="9bc6f1ac0f697acffb01a11236a40401"/></dir><file name="Image.php" hash="6921779e72abaacc241b34f07ed02830"/><file name="Ipad.php" hash="1effe2957ce188b6cedfb0263adef0ce"/><file name="Iphone.php" hash="6675faef922a3cfb36d39b2b86d94cfe"/><file name="OfflineCatalog.php" hash="728a6f556f0686e6903f2b3370907a9a"/><file name="Payment.php" hash="f1012b729117d69e9ab6c8d080417022"/><file name="Theme.php" hash="8977a5214ed2ac3238e8c2419be069ab"/><file name="Translate.php" hash="01435e6bf81bbc0227659b139197639b"/></dir><dir name="Model"><dir name="Adminhtml"><dir name="Search"><file name="Catalog.php" hash="ccb6094d28df925b20ec8c031ac51a53"/><file name="Category.php" hash="52e81d55648a8570ec4e8668d53f8b80"/></dir><dir name="System"><dir name="Config"><dir name="Backend"><file name="Baseurl.php" hash="04e9900121da0d400bf9096ca7d23cd1"/><dir name="Currency"><file name="Default.php" hash="0ce2ee64ede63a08ce1b3f360eb52084"/></dir></dir></dir></dir></dir><file name="Application.php" hash="959a3812d11730d81f67a85ac6372a0b"/><dir name="Catalog"><dir name="Category"><file name="Image.php" hash="fa2f7f5e7242d935f9d5e1741f9048b4"/><dir name="Media"><file name="Config.php" hash="233724daf60fb819ff318003be19dfe8"/></dir></dir></dir><file name="ConfigData.php" hash="562df19fe23520a347f96af3bfd322b4"/><file name="Configuration.php" hash="05c4089e805717727903febc0912a005"/><dir name="Device"><file name="Abstract.php" hash="f45b3f1ac62150225bb095fc0052a6ae"/><file name="Android.php" hash="7958c43e6e197d60a8ad1f1958d48833"/><file name="Ipad.php" hash="fd91ddec607efe8cfb6a26519ec8f49b"/><file name="Iphone.php" hash="b086f46206e53a0b5123fab10a0f44a2"/></dir><file name="History.php" hash="1dc8e48c826d5d4b0b556913ea82cb65"/><file name="ImageAction.php" hash="3af7f7f5fad331edaaf66613d5688e19"/><dir name="ImageLimits"><file name="Abstract.php" hash="19d6e7017a3463dbd7d4dc4acc9d3993"/></dir><file name="ImageLimits.php" hash="8c80b771068d8ab4140720aa535088f9"/><file name="Images.php" hash="9e8dcf76a202aab0ff0cb7fa4efe3558"/><dir name="Mysql4"><dir name="Application"><file name="Collection.php" hash="20ca3e05eddb2a4db99d71b8ff3552ae"/></dir><file name="Application.php" hash="cc9679db2f16fdb328d26fc730c4cea7"/><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="3cc019e54c09e49a36338cd363cb1155"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="c5b21c467e407202bd04ca85f5211a63"/></dir><file name="ConfigData.php" hash="9768cd6b2b4a5f77d29a21dbc027d437"/><dir name="Filter"><file name="Collection.php" hash="25a4d5ed9b4f11190115a23ae234f3a6"/></dir><dir name="History"><file name="Collection.php" hash="e868422aa36ce2af614a2bc025c7e5a8"/></dir><file name="History.php" hash="2bc18554615e6aa04f8fb2f4dc43cfb8"/><dir name="Queue"><file name="Collection.php" hash="c363e0c70a3940e8d990315ed8ebadec"/></dir><file name="Queue.php" hash="9c158e0e23293c0d6a0c3853fccf6018"/><file name="Setup.php" hash="dbaeabb2554c70666ef25921e89277a6"/><dir name="Template"><file name="Collection.php" hash="4993a7470f4bd5fa3ada384737234c79"/></dir><file name="Template.php" hash="5be4d94478a10677cc3f8e0ec7f3738a"/></dir><file name="Observer.php" hash="17dbbf57381227eedca5fdac00e1e937"/><dir name="OfflineCatalog"><file name="Abstract.php" hash="fff50211793a39f51c0a0d059e769eaf"/><dir name="Category"><file name="Category.php" hash="2ee314872c6cd7e9a9b075110eb6c282"/><file name="IndexCategory.php" hash="0da913c58cb221745cd0f5f93cf9722b"/></dir><file name="Category.php" hash="84c5080d5085630afd13847204d9f76f"/><file name="Config.php" hash="165414539f36e14d54a267ff93750ad6"/><file name="Home.php" hash="3fe7a558d082dcf0525e6063b35a46fc"/><file name="Homebanners.php" hash="9bd332243faec8b27a99adf80d0276c1"/><dir name="Product"><file name="Gallery.php" hash="475088e1291fb55e55dfccc2b251964e"/><file name="Product.php" hash="5cfc4c77f8d7b7431f9b922f7fc6bd87"/><file name="Review.php" hash="a343151fe3ca1c07c3bc3835b8b3de7b"/></dir><file name="Product.php" hash="2ae833518fdfbc68291b12dd306d54f6"/></dir><file name="OfflineCatalog.php" hash="becd222a9465a2a76ec745d6dc87e73f"/><dir name="Payment"><dir name="Method"><dir name="Paypal"><file name="Config.php" hash="be507f3c7ed91dee5a5dfda94cf2a402"/><file name="Mecl.php" hash="d5e0d81cacb7daa01ba6de5e4c2a34ae"/><file name="Mep.php" hash="aadc840055d64e79797fdc8b8131e1d3"/><file name="Pro.php" hash="95f452b7a53b725e3cf46361735e4c5e"/></dir></dir></dir><dir name="Paypal"><dir name="Mecl"><file name="Checkout.php" hash="ae8b531a989747319baf9c182c831ff8"/></dir><dir name="Mep"><file name="Checkout.php" hash="ff0a95a4ccf4b634ad399dd39f749d58"/></dir></dir><dir name="Preview"><file name="Abstract.php" hash="327ed7f692c9753472c5d728996d2b2d"/><file name="Android.php" hash="f5ac4ba6b2246221403cbb204f2d46e8"/><file name="Ipad.php" hash="12d621382059de3c6b8273414aedba13"/><file name="Iphone.php" hash="afcaf2577c9fd1e0f0fc991110de36c1"/></dir><file name="Queue.php" hash="251cfb9268a1b64b835ca11839a5f4d9"/><dir name="Resource"><dir name="Application"><file name="Collection.php" hash="b19fbd256a73fa6d78aab9ee42888f84"/></dir><file name="Application.php" hash="c05f1f9873f7ecbbff20c3672e058a7c"/><dir name="CategorySearch"><file name="Collection.php" hash="35b85a98ad9c7d074b59c3525ae4eb4b"/></dir><dir name="Cms"><dir name="Page"><file name="Collection.php" hash="334fb74e0088e436d295b40bf811980b"/></dir></dir><dir name="ConfigData"><file name="Collection.php" hash="b01894e4fb13a260d780b85d73001f0a"/></dir><file name="ConfigData.php" hash="974643c62572f321cf1e70942a1f2ff2"/><dir name="Filter"><file name="Collection.php" hash="090585923738dbc5d2d3e92ac74d5fc8"/></dir><dir name="History"><file name="Collection.php" hash="24579eca5258b06809924f16aca34e8a"/></dir><file name="History.php" hash="87b18d53ac3045fdf42e0054bac99fde"/><dir name="Images"><file name="Collection.php" hash="3419fabd2f739625f03ead28a84d130e"/></dir><file name="Images.php" hash="4ccc3ec55afa49cb28d15d3f1c6ef4ee"/><dir name="Queue"><file name="Collection.php" hash="e2aeb583c914787669ef7c7cc463ddc8"/></dir><file name="Queue.php" hash="76a8caa2179a95d4d9a0d10a43369470"/><file name="Setup.php" hash="41a1d11f4a4a00e46537da93c5874926"/><dir name="Template"><file name="Collection.php" hash="5d157bdf254052b152067c7b8f9b2708"/></dir><file name="Template.php" hash="4a025a389dfda83885d3be99f673592e"/></dir><dir name="Simplexml"><file name="Element.php" hash="fd7c3598aa177f1907716cf601219aeb"/><dir name="Form"><file name="Abstract.php" hash="fbe0e291e7546f965265cb2d6504f657"/><dir name="Element"><file name="Abstract.php" hash="6377bbab9d7c7f04b73d5056537e28de"/><file name="Checkbox.php" hash="da7c40c59be8e0cfc51df1602279bb8f"/><file name="Collection.php" hash="235fc8c09ff4309c925d06f2410d1252"/><file name="CountryListSelect.php" hash="51968904d112c467dd8100a578565f44"/><file name="Custom.php" hash="c4ad54563c5fa4e66125317591d9aa8f"/><file name="Date.php" hash="71f716a28728d14c386b999e0e73964e"/><file name="Email.php" hash="120682a40beb8230de3a0c8e26da78ef"/><file name="Fieldset.php" hash="71022934e1f20bbd60b039edfc084cf2"/><file name="File.php" hash="585cf229c446581ea47490078fa19f18"/><file name="Image.php" hash="dd5919b1c52222c8dc2ebb10da3be619"/><file name="Multiline.php" hash="a5d802913e78cc43a3284ec8271721e5"/><file name="Multiselect.php" hash="f79b0a7c5b747105e2b763bfceb9a999"/><file name="Password.php" hash="a9779cce59679bd46c532233702795b4"/><dir name="Renderer"><file name="Interface.php" hash="b84d0ee6d9b66f8d9f84cc52f2867af5"/></dir><file name="Select.php" hash="c2ba59f1b627c2692c45a82ea022332e"/><file name="Text.php" hash="00d613d55512fa7279159b9b1e38e3fe"/><file name="Textarea.php" hash="3fa4f12a6f898283a6b89fb0af467f96"/><dir name="Validator"><file name="Abstract.php" hash="89c217eadb21f35369abfb681e96f482"/><file name="Rule.php" hash="33e8edb8c896b25f2a1b220a82716a7a"/></dir><file name="Validator.php" hash="be511ff573d219d60de0ba0b3f740ea6"/></dir></dir><file name="Form.php" hash="c98434080575ce5a55d076be917f1d80"/><dir name="Message"><file name="Abstract.php" hash="6587dfdcc1073929966a38f397e64236"/><file name="Error.php" hash="4fdf18c0200d1cdc03baa45a375ebe22"/><file name="Success.php" hash="1a4c003a718295df9ee5c4610001a6ab"/></dir><file name="Message.php" hash="a312abeacffcde7d58f7d34624751e7c"/></dir><file name="Tabs.php" hash="ceb9453dec3fe8dbadb9130f57fff771"/><file name="Template.php" hash="7232e9f4ce510d1986371e833082ad1e"/><file name="Theme.php" hash="3b26aad383159deb98cb9235eb134d41"/></dir><dir name="controllers"><dir name="Adminhtml"><dir name="Admin"><file name="ApplicationController.php" hash="d85220bbcf83701e8c4d1339edafe1f9"/></dir><dir name="Connect"><file name="ConfigController.php" hash="181c3a7c1c8c5c7126da20e2948d7afa"/><file name="DashboardController.php" hash="98a02bb6afe602c605a75224de855536"/><file name="UserController.php" hash="d361715dd4fca6a6c8b70a50ce88d6c3"/></dir><file name="MobileController.php" hash="5265057d806f41f1c888f095a422aae8"/></dir><file name="CartController.php" hash="09a71b3690f40ead7d78e33da3fa55ac"/><file name="CatalogController.php" hash="9aba97e5852376a5b5c586ffbe633d90"/><file name="CheckoutController.php" hash="5899163c45d6687a4f55efa3eca97ee4"/><file name="CmsController.php" hash="2dc7b2e14643e26444493f05434d29cc"/><file name="ConfigurationController.php" hash="67c8bc4a5a346f10b5106189c0b9afd7"/><file name="CustomerController.php" hash="f17ae4c197b7aacb4059f232a0b0e7f2"/><file name="HomebannersController.php" hash="f8f921cb733dc3d95b43c2d115612e07"/><file name="IndexController.php" hash="a4424c3802baa3fb782a7cfca984fc11"/><file name="LocalizationController.php" hash="deec1cf96b89da98feb0d72d98c7d448"/><file name="OfflineCatalogController.php" hash="61dc9bc4d698a8a9f675500331c8bc58"/><dir name="Paypal"><file name="MeclController.php" hash="e50ebf752c625a42561e4963f85c19a6"/><file name="MepController.php" hash="6a174a59d145109495b140f64b46bbac"/></dir><file name="PbridgeController.php" hash="2cbd655210d48d2fa4a921e9bdea881a"/><file name="ReviewController.php" hash="1863fbdc0eb62ee07e4e410a129c74a1"/><file name="WishlistController.php" hash="40a7c7951ae734b2c4414d0bf6c475c2"/></dir><dir name="etc"><file name="adminhtml.xml" hash="f2935498f8438d93ac1a0084c7fb6da2"/><file name="config.xml" hash="6c643a21e6a52ea45f058329d881cec2"/><file name="system.xml" hash="817a56b1540cc8ed651b26ed0258fef0"/><dir name="themes"><file name="custom.xml" hash="117a8bb4d666ef613f19b7221268ebd0"/><file name="default.xml" hash="aaf6d41dd756497982a3ea55e13d790f"/><file name="funk_leaf.xml" hash="8c8f9210b10d43c0d90e8d6a2367cfbe"/><file name="hot_red.xml" hash="fca3e8ca7fc3634cae1979313c9b7177"/><file name="sky_blue.xml" hash="b6add2ae0a7ca115013355e316fa0137"/></dir></dir><dir name="sql"><dir name="xmlconnect_setup"><file name="install-1.6.0.0.php" hash="32c08a2bcf373250206437333d7603e1"/><file name="mysql4-data-upgrade-1.4.0.13-1.4.0.14.php" hash="c7315a31f8cef0b7d2ae8f80fbbc3163"/><file name="mysql4-data-upgrade-1.5.9.9-1.6.0.0.php" hash="d5cc11489f9a00b93b6014e065ef5715"/><file name="mysql4-data-upgrade-1.6.0.0-1.6.0.0.1.php" hash="438ed4be093ee9c3719d409d82a2ab72"/><file name="mysql4-install-1.4.0.8.php" hash="562ee2192b6688270cb8ae67116b4b2c"/><file name="mysql4-upgrade-1.4.0.10-1.4.0.11.php" hash="47239ae89b5e9879faeade3fcc5e8dff"/><file name="mysql4-upgrade-1.4.0.11-1.4.0.12.php" hash="2682567c7edffaf8818e74b1b89cec57"/><file name="mysql4-upgrade-1.4.0.12-1.4.0.13.php" hash="323be46c94ee31f0cecbc3b4551babd7"/><file name="mysql4-upgrade-1.4.0.13-1.4.0.14.php" hash="0299bd412387a948eca34642c7aef36f"/><file name="mysql4-upgrade-1.4.0.8-1.4.0.9.php" hash="67d93828e93566e400f15df69cd07aad"/><file name="mysql4-upgrade-1.4.0.9-1.4.0.10.php" hash="4a79e3db4382b4239759a117f3261018"/><file name="mysql4-upgrade-1.5.9.9-1.6.0.0.php" hash="e7ac9d8d2277ffd0d2ef3443c5babd50"/><file name="upgrade-1.6.0.0-1.6.0.0.1.php" hash="a5ab0527c9e10a82421e58cf2e7946f9"/></dir></dir></dir></dir></dir></target><target name="magedesign"><dir name="frontend"><dir name="base"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="1dc6e4389554dc766d8a1f8ce14c8880"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="centinel"><file name="authentication.phtml" hash="97d0bda33c048c75071079360a633bbc"/></dir><dir name="pbridge"><file name="result.phtml" hash="eaf8dea1c847a163c6e03a79373f13db"/></dir></dir></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="layout"><file name="xmlconnect.xml" hash="9da94b4c6b75358e208d77fa71394894"/></dir><dir name="template"><dir name="xmlconnect"><dir><dir name="edit"><dir name="tab"><file name="content.phtml" hash="8e5ee302d26adf7de3c5190ba3615290"/><dir name="design"><file name="autocomplete.phtml" hash="b896b29fbee0f6a694a4c1bbd4b47239"/><file name="image_edit.phtml" hash="9446db1ebe986034e800854a6cf4a58d"/><file name="images_android.phtml" hash="41e74b4bb5f363898b9c6bbba1abf340"/><file name="images_ipad.phtml" hash="7f4e7170149376c61839b7cd0aeaa535"/><file name="images_iphone.phtml" hash="5f4d38883d8c5b23186dd67aee5c2fdb"/><dir name="preview"><file name="banner_rotator.phtml" hash="21185f73d23a35eb5c2d8947f7f2e920"/><file name="catalog_android.phtml" hash="eaefb0f45613f6300099aa7bf23f301e"/><file name="catalog_hor_ipad.phtml" hash="3f23959c59286a29cfcaa719f78a13f5"/><file name="catalog_ipad.phtml" hash="624c310ec710c971fdd7e35c2122207e"/><file name="catalog_iphone.phtml" hash="c2ce0a7ca0a71f5d02e48147cd707ea0"/><file name="home_android.phtml" hash="058ea828dbc70b1eaa89b431102d5d52"/><file name="home_hor_ipad.phtml" hash="1ba3118600cd47f3db4eace31715f007"/><file name="home_ipad.phtml" hash="1f3033ec5eab6394b1bf7a91ebd3e0a6"/><file name="home_iphone.phtml" hash="f08e7358cac7612f7029e7caf0f8f9c0"/><file name="productinfo_iphone.phtml" hash="165165a8c05b6a667fbeca353d6ec216"/><file name="tab_items_android.phtml" hash="606e607fd42a6eec6ed1ef5d3855512f"/><file name="tab_items_ipad.phtml" hash="b178a8b51482b294b183a34f784b1f1e"/><file name="tab_items_iphone.phtml" hash="296eb9ad61ed6ab61d60b8f4c3dde341"/></dir><file name="preview_android.phtml" hash="e89c6f0b5622334370eeb03dbab11f52"/><file name="preview_ipad.phtml" hash="2f60401391a74808b2906a6e8468aae7"/><file name="preview_iphone.phtml" hash="cbd3e9ce74c2d4135227b24fdbd887fa"/></dir><file name="design.phtml" hash="f99ec1e92a0f6759b781a32332fc89d5"/><file name="offlinecatalog.phtml" hash="50b4394967e3e4053ae774fd8c0365a4"/></dir></dir><dir name="form"><dir name="element"><file name="addrow.phtml" hash="742de06e43b52a50f676098f8fa4e26e"/><file name="app_tabs_android.phtml" hash="0065b3e36e67c53933b823bbfbfd2bc4"/><file name="app_tabs_ipad.phtml" hash="89e64551169dffb436cebcf1f2429e0f"/><file name="app_tabs_iphone.phtml" hash="fe56e0132269b3824592eea17dc49c78"/><dir name="country"><file name="androidmarket.phtml" hash="d3702381cf57187df6ce2fb072c76f11"/><file name="istore.phtml" hash="861c3513f38f5d1cfb9303919bcab2dc"/></dir><file name="themes.phtml" hash="d3bc3e4d2b0a66acaaceb4545b5243f7"/></dir></dir><dir name="mobile"><file name="notification_helper.phtml" hash="1eb816a7bb47c809b028e9678c68282d"/></dir><dir name="submission"><file name="app_icons_preview.phtml" hash="b2f951860b9d0be57341d0e47a3b229a"/><file name="container.phtml" hash="a2a4e92c17ac1298c5012ef28b68a458"/></dir><dir name="template"><file name="preview.phtml" hash="c2b5375cc3a30ed8250effe88a81e494"/></dir></dir></dir></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Mage_XmlConnect.xml" hash="26dbfbfa2414f06ef6db95abde509e31"/></dir></target><target name="magelocale"><dir name="en_US"><file name="Mage_XmlConnect.csv" hash="50e9493da78f8e6591fd3fad1311047c"/></dir></target><target name="magemedia"><dir name="xmlconnect"><dir><dir name="custom"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="original"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir><dir name="system"><file name="ok.gif" hash="398f81b3983f802a99932eaf97ee0806"/></dir></dir></dir></target><target name="mageskin"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="xmlconnect"><file name="boxes.css" hash="a5a92bc3147999c70608672cceb8d818"/><file name="dropdown.css" hash="c631ab21a370129eb5526a26df214ba5"/><dir><dir name="fonts"><file name="android_icons-webfont.eot" hash="2fc917efbfb3c933ccfddc108ef05f33"/><file name="android_icons-webfont.svg" hash="e8cb2b5ef019bbc2885c97ed0caaf2a0"/><file name="android_icons-webfont.ttf" hash="bc567dd7a381093fbb652c58cbad9430"/><file name="android_icons-webfont.woff" hash="8310b54d55bf84a8a3f3a86c22a51aef"/><file name="stars-webfont.eot" hash="019beb4b8ec19447657cf3106138bbe3"/><file name="stars-webfont.svg" hash="20cf0312c0b951d173d4531ea18abc6f"/><file name="stars-webfont.ttf" hash="d63d95e9adaf775f410437535622bf60"/><file name="stars-webfont.woff" hash="526d9756131c94139f0f1df5272197fd"/></dir></dir><file name="iestyles.css" hash="8d5df1c3013797471e228162afc411e5"/><file name="mobile-android.css" hash="cc441eb45f35bd3d29b6f0833cd3b9fc"/><file name="mobile-catalog.css" hash="78e840f9871cb34662962efc4d03a514"/><file name="mobile-home.css" hash="2c38e64a3d024616bb85439707143fc9"/><file name="mobile-ipad-catalog.css" hash="22de5fda6eb0c3f2e4700f8360d62a0c"/><file name="mobile-ipad-home.css" hash="d07bbd12056c3a87cf92595e19f7a493"/><file name="remove.png" hash="b4903936d44dc498d2f32b72d9161ff0"/><file name="styles.css" hash="fb40b0c19d8fbc44d5032f69a9ebc92b"/></dir><dir name="images"><dir name="xmlconnect"><file name="btn_edit.gif" hash="e7ecc9fea5c3813957814050508507a5"/><dir><dir name="design_default"><file name="accordion_open.png" hash="4c89d903ebbc61ee295ef64a60724b10"/><file name="accordion_open_android.png" hash="7ef2f1d193990c3f4c2c90aae9ab3281"/><file name="accordion_open_android_l.png" hash="bc27688afbfd866c618477ea2c7bf0ee"/><file name="accordion_open_android_p.png" hash="2e4549cba575c12ef2a39c12e9ffe173"/><file name="accordion_open_ipad_l.png" hash="dcdda97da6556393b972d6dae8d6bac5"/><file name="accordion_open_ipad_p.png" hash="55cca08a0ab79047961858789ff8c3a7"/><file name="banner_1_2.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="banner_android.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="banner_ipad.png" hash="c1d59a6ec67da1bb76c5142453da7acf"/><file name="banner_ipad_l.png" hash="04e850d481a9ae902f33fd8c1f89cbf0"/><file name="smallIcon_1_6.png" hash="c1ce9e289eaf2c0504d502928693bd89"/></dir><dir name="mobile_preview"><file name="1.gif" hash="817fd84187db3eee00799b0acf316457"/><file name="2.gif" hash="1a842d8f3ac25cfcdeab6c86dd8fea89"/><file name="3.gif" hash="207cd55e968c284bd52c86efdcdda1c7"/><file name="actionsBackground.png" hash="11faa8baee72f3e6a9a02a83915c8658"/><file name="actionsBg.png" hash="9acccd1980f17006942d74a718ebd7da"/><dir name="android"><file name="background_home_landscape.jpg" hash="1f79a1f42ca4e2cf6010ab6c3ef66aa4"/><file name="background_portrait.jpg" hash="197b15e6455ad1a85e1bad6595371fa3"/><file name="bg_button_up.gif" hash="204f590a88933c930b7fc92963accfab"/><file name="bg_cat_item.png" hash="2859b45c387b66243d4af2ba973b2ae1"/><file name="bg_catalog_filters.png" hash="7464191ebaf576b73a3c021eb1cfcc25"/><file name="bg_catalog_filters_shadow.png" hash="5021ad60917190026d85fae1d33bdaa9"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_frame.gif" hash="7062ed9b7563fc658f49ce7cfdd34f1c"/><file name="bg_header.png" hash="d4a46c8850d1d89259921b1c28b5bce1"/><file name="bg_header_catalog.png" hash="c1080cd18a89e21da18fdc6955bf6230"/><file name="bg_header_home.png" hash="dfce0445ca7c7a45c7914a986b596ce0"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="8bc1887a0c5760cc47b77b8a7a320426"/><file name="bg_logo.png" hash="02695661b8e50e1a001c3369622f322f"/><file name="bg_page.png" hash="d65f1d123655c2eaf3bb4a1e6035a08d"/><file name="bg_star.png" hash="fc6de6c4e0ed3478b8840e1ab81da725"/><file name="bg_star_empty.png" hash="3f0421fb8c8f6c4be6ca501168a881e8"/><file name="bg_status_bar.png" hash="52b41106451ac34672f82338bbc5370c"/><file name="ico_account.png" hash="c1fd338c74fcf483155acbd37c430807"/><file name="ico_home.png" hash="2de37f640463b354d68945320bfe3e4f"/><file name="ico_search.png" hash="8b0dd17a3e9c3328e66204fe379c66aa"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.png" hash="dd975b128ba303e0ae2adc9772e0433c"/><file name="product_image_1.jpg" hash="8994979d4dcc1f339c73cd1f44398a7d"/><file name="product_image_2.jpg" hash="26d6599bdb35d80b25a1e903b40cfa19"/><file name="product_image_3.jpg" hash="d7c6d05196a84341afe0025d01b9dc61"/><file name="product_image_4.jpg" hash="2a88ead3dbbeff1d40168db692841f2f"/></dir><file name="arrow.png" hash="837259a7c365e46034dca728bffe9070"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="background.png" hash="3717f4b4ba725701e2a0604129a3a815"/><file name="banner.png" hash="0637d31df6b5a434c9a332ee46122ef4"/><file name="btn-l.png" hash="92b2454528e9d39119038777cf53329c"/><file name="btn-r.png" hash="8c6aa9fd9203bc10822e0505f11e0c4d"/><file name="circle.png" hash="f4c116cb0554bf936d3b9ee38b7f3d1f"/><dir name="custom_icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="e33876648546e99d875ca92bd2cd78e9"/><file name="addToWishlist.png" hash="1018602b7c5e0e11f0427ace96fd7d52"/><file name="background.gif" hash="bd92833eb2eb32e4a0282cea153ac13f"/><file name="buttons.gif" hash="0cd19a9d9178976906161ea100cba958"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="image-bg.png" hash="14bde5cf8b00dc5f6c60e52a0fa964dc"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="tellAFriend.png" hash="46f8ef48b29f245977d66d9312d87e70"/><file name="viewDetails.png" hash="9bacc63bcc483d3db5614a026d9391f6"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><dir name="gradients"><file name="footer.png" hash="31a2feed50ef9c8637b412c4211f8300"/><file name="header.png" hash="5386da930a944cd75562216249cce08a"/><file name="header2.png" hash="ad5a2dc6ec93914e925cfe2d43fb30a2"/><file name="header3.png" hash="920ad8c6903e90323a57fb02dca37280"/><file name="item-bg.png" hash="a14886d1f9e14284ac6b4f1b61e68646"/><file name="sort-bg.png" hash="b8053bb772e849909e5b87e4fd1ebbe4"/></dir><file name="grid.png" hash="23faa3f5572cdeb597c2bceedd93a7f8"/><dir name="icons"><file name="account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="cart.png" hash="815b4c64fae21b4c162525ece76dc44d"/><file name="home.png" hash="9e473791b022b7c2dfc7d29b1b6de887"/><file name="more.png" hash="f3662ae29923b87eba3a729192aa3df3"/><file name="page.png" hash="2291d77f21de042040bc0864be40138b"/><file name="search.png" hash="10bfa7ec3361ce7cbcc5d25087f181eb"/><file name="shop.png" hash="e6639a9fdc143363da82a7d78e126f1c"/></dir><file name="image-bg.png" hash="a588b9cced95a25fc18e28c775d9a001"/><file name="info.png" hash="3f0d2ed85b81e8251f294457c6bfa404"/><dir name="ipad"><file name="background_home_landscape.jpg" hash="9e3ef117985113b804531142d539b60a"/><file name="background_portrait.jpg" hash="bdf9e034fd30b923086e6c622ea10451"/><file name="banner_image.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="banner_image_l.png" hash="a070a40d57610b5cc7160fe894482a1c"/><file name="bg_catalog_header_hor.png" hash="f61a67aa288e1b8a8df7b4d4527c662e"/><file name="bg_content.jpg" hash="70ddfc8959d878d1231dc7cbee4a063c"/><file name="bg_filter_button.png" hash="728f1cd358446881ffd863eff12204a1"/><file name="bg_filters_buttons.png" hash="02fcb0ed7a7268e9f64ebaf06235bc09"/><file name="bg_filters_tooltip.png" hash="3b05ca6e585acd3d766be01eeaa23d47"/><file name="bg_filters_wrap.png" hash="31288784fe95c67de9b45b44458b4155"/><file name="bg_header.png" hash="e2cf5a575a27e6e4533e3c85e3472a82"/><file name="bg_home_content.jpg" hash="1d55a198279e4f2b163c98c18f699646"/><file name="bg_home_header.png" hash="00f2fbf96d2b915dcbcd921b0301ef3f"/><file name="bg_home_header_hor.png" hash="9bfef728ece003d5b3433d2623ea168c"/><file name="bg_home_products.png" hash="ac6a8a79b959a0c8298b1f607c0f0af8"/><file name="bg_home_shadow.png" hash="c54b071ca3e97a6ee67588ef74b7b44e"/><file name="bg_home_shadow_hor.png" hash="0d21a99c5c749d0e5070e3585ff4a23f"/><file name="bg_product_image.png" hash="4da74325c1a4ee1ca19b414e5d590f75"/><file name="bg_search.png" hash="6ee08d05d0c4ef9ed64b9914b821f408"/><file name="bg_sections.jpg" hash="0ee90005663aced09a9ce6385bdbce2c"/><file name="bg_status_bar.png" hash="17124d9d392bb8e37b202c80a595df54"/><file name="bg_status_bar_hor.png" hash="bd4a9f11ecb1c896145267731d8a951d"/><file name="i_cart.png" hash="1bbe0a0e54eed5bb14b9bfcce83da758"/><file name="i_info.png" hash="3f0fda8b294b67bf698badbcaa99150b"/><file name="i_login.png" hash="deb4089bdc61582c78c90ef192d577e8"/><file name="i_remove.png" hash="4923eb5e76b3c6ba6df5c667db816a0c"/><file name="logo.png" hash="49c19f59b459b6c0b3b99daa3fe7f932"/><file name="logo_big.png" hash="693bb9d118155a146b21ce9fcfba08da"/><file name="product_image.jpg" hash="2bb6c69129bcb18dc93e9f48605647c6"/><file name="sections_arrow.png" hash="7db7144083a31882e8a62cb9579f478f"/><file name="stars.png" hash="70d38cd9883d70e4f6b21ac4874b9868"/></dir><file name="lightStar.png" hash="b5dc40d5b793dae6a069357f49cccc24"/><file name="lightStar2.png" hash="75928926a6112540c9cb073157cb7d95"/><file name="lines-h.png" hash="ea3d95812c9838affc6df2f3a3cb1977"/><file name="lines-v.png" hash="9e3ffee29ba28477d50da9642019bc0a"/><file name="login-btn-left-alt.png" hash="71bb6c7d24252aace27bee711d7616f4"/><file name="login-btn-left.png" hash="cbbf9afc6e9fc433f57270e88b63f351"/><file name="login-btn-right.png" hash="438fcc598d012bf6d33184e95accfd24"/><file name="login-btn.png" hash="051ee2c1a8ce3f7b8de3293cd2e2ed85"/><file name="logo-small.png" hash="9b3477a4552bcb878b4943aae5351622"/><file name="logo_25.png" hash="ba41ed568d916175c32803b614442447"/><file name="men.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="mm-frame.gif" hash="eebf30806f1dbf2118e7ec39a016c86d"/><file name="mobile-catalog.css" hash="c808bf7f4ef7d84e6c0848f88abef943"/><file name="mobile-home.css" hash="a4a5f38b76b58bd4d18fb50e5977b1bd"/><file name="rowBgIcon.gif" hash="9ee89b961ae2bb047672ba5d2d2677c6"/><dir name="slider"><file name="actionsBg.jpg" hash="ee3db742cbec9a436ba46118c8a01303"/><file name="addToCart.png" hash="2a146be4bc63713df19cc353e030d44f"/><file name="addToWishlist.png" hash="9b23a4e0d9acfc79f314e9082f14c4de"/><file name="tellAFriend.png" hash="b7600fa2ae52bdb1d6bb86fe4d9f1773"/><file name="viewDetails.png" hash="90cf37c6dbbee1861350b4c05469e3ae"/><file name="viewGallery.png" hash="304f3d03949d07055bc056359fe17763"/></dir><file name="slider.gif" hash="c6b87bf15b85b18c0515e2cbefaabe60"/><file name="smallIcon.png" hash="e76d2a6364042f41b3f35fc8cdc9c0ee"/><dir name="sort_buttons"><file name="bg_button.png" hash="87d0f1b123f01c3aea3cb8a2b146306e"/><file name="button_up.gif" hash="7ad527f99b9975d5634fb2d5cc99e6b3"/><file name="buttons.gif" hash="2f14f1a3f0fb38790779c992a58654ae"/><file name="buttons.png" hash="b4a3f17370e03bf5d2a5cdf7800c25a7"/><file name="center-active.png" hash="5903988cd458cd794f23a212d51aa725"/><file name="center-inactive.png" hash="135b46aaa5c3b131a5a7e9c45c004e06"/><file name="filters.png" hash="3837ab6fcfe959833dd998533db1ca7f"/><file name="left-active.png" hash="86e94441b96a0d27d0b0a7e5108f86ed"/><file name="left-inactive.png" hash="0ddcb75aa9971cca39a5a65b4bdff8c4"/><file name="right-active.png" hash="320740ff608187301b06a96eab2f9e8e"/><file name="right-inactive.png" hash="cac4b39ab380353ffd5fdbcedb6e0a0a"/></dir><file name="star-active.png" hash="d4ab959a92bda610527a3e3942c4c0b0"/><file name="star-inactive.png" hash="f7fb99710be4c03ac23b1206f20e761d"/><file name="t-shirt.gif" hash="7505efdaabf13c4f8e26f7cfe15c8c96"/><file name="t-shirt.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="women.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/><file name="youth.png" hash="46d7d1773118ef0a27353e8a9f6719fe"/></dir></dir><file name="dropdown-arrow.gif" hash="332e99ca6b4d1e0d39972e04fb0b2395"/><file name="empty.png" hash="23dc9dc3c4751f83c2df7a5c42668824"/><file name="full-arrow-left.gif" hash="8ec91b60d38d1a16cba7670f2088a5c7"/><file name="full-arrow.gif" hash="36ddff0fca1c7d8900cb3633e0a30cea"/><file name="gel_green.png" hash="591959d831e8e42c9175d12a88f0bae2"/><file name="gel_red.png" hash="db442c023014df9da32b84bc1bb5a39f"/><file name="l-arrow.gif" hash="ee49f7eab64657b5131953acef0238fd"/><file name="loading.gif" hash="5d25806dac7cbee5f894b13144783866"/><file name="r-arrow.gif" hash="d0429a9781e915fc9d9ca8875c470d32"/><file name="remove.png" hash="ee9497c5f31933eaab3e9e352495ee12"/><file name="small_logo.gif" hash="d5c8be7c0f16aac2549759c0228492d6"/><file name="swatch_black.gif" hash="fd31d6a3a435c8ad1f7c43f346bb47e4"/><file name="swatch_custom.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_default.gif" hash="fb34791a48366957a141e12b563888c2"/><file name="swatch_funk_leaf.gif" hash="f1d3ba87efb742b47da879a6f48909c4"/><file name="swatch_hot_red.gif" hash="d9363d45dc2993c2fdc3ea43c5b6f71c"/><file name="swatch_sky_blue.gif" hash="ded1455db119d09a3aedd7474fd1875a"/><file name="swatch_user_custom.gif" hash="a24f31421a1ff56d1be0845f9a7c7020"/><file name="switch-arrow.gif" hash="dc7243962b341f366cd072d486687e6a"/><file name="tab_account.png" hash="27101fbaa78a07426be4768acc4c53ff"/><file name="tab_account_android.png" hash="77605cbc87f75ca17e91a5393765ceb1"/><file name="tab_account_ipad.png" hash="2997de5402195d0720309b73c6446fab"/><file name="tab_cart.png" hash="e803f760ee81cb35183f1122f388b774"/><file name="tab_cart_android.png" hash="477e97f8d03ea8aa674e952709f86578"/><file name="tab_empty.png" hash="bdd4cc355566e8861b2c45424ad94516"/><file name="tab_home.png" hash="dfa104e4da74e4a55d3c98d6ee0f7122"/><file name="tab_home_active.png" hash="bba5eb9bb724c84c1ede9e6f4bec3575"/><file name="tab_home_android.png" hash="1fefc6b070cc21b31b43194a7d85f9d9"/><file name="tab_info_android.png" hash="67fc19d8d926f7aede482f5a7083fc71"/><file name="tab_more.png" hash="2803359cb3e795bf67457e727aa16020"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="2cf29dbe325558353621b4241543204f"/><file name="tab_search_android.png" hash="932c2c568872fd9e119367c887f0539a"/><file name="tab_shop.png" hash="f36be0d3d27f2b37626247d3f6a55e2a"/><file name="tab_shop_active.png" hash="de907d6a52d477d4319649f9b0e2e4aa"/><file name="tab_shop_android.png" hash="e119fcd20f8cba856d550a64d775ddbb"/><file name="tmp-icon.gif" hash="58b759aecf3bdae26d5aaff7a0be5c90"/><file name="xmlconnect_tab.png" hash="cd99a7e01a42a6c82d866f7684faeb95"/></dir></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="xmlconnect"><dir><dir name="catalog"><dir name="category"><dir name="placeholder"><file name="image.jpg" hash="097ab8a3051bc037ea3de0e17f440540"/><file name="small_image.jpg" hash="f825d16f97a640453553c79c48ebaa73"/><file name="thumbnail.jpg" hash="b2b682d28a08a748a73d2cda70ab5a57"/></dir></dir></dir></dir><file name="tab_account.png" hash="0498d73e47ed47179e5546dc15c17dc7"/><file name="tab_cart.png" hash="9055ba76e256a51d3fee53a8c41d5226"/><file name="tab_home.png" hash="07d0af93e167b9366d3d4fb3d6cdb31c"/><file name="tab_more.png" hash="b9fc21feb8d7655bc9c2985c37b0de2f"/><file name="tab_page.png" hash="ca05dbc42f944b8d4255f6675f6dd93a"/><file name="tab_search.png" hash="25e880eb2a4d06828e2e1c3f32d22400"/><file name="tab_shop.png" hash="fe602fc2e7093efef5ecc0b027a32d91"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="jscolor"><file name="arrow.gif" hash="5034704a76cd55c1cbcbc58ea6bf523f"/><file name="cross.gif" hash="ba9a274b9323753cd95bc3b1eb2f4e5f"/><file name="demo.html" hash="edf71251cb2be20322d2efb00aee86a6"/><file name="hs.png" hash="fefa1a03d92ebad25c88dca94a0b63db"/><file name="hv.png" hash="990d71cada17da100653636cf8490884"/><file name="jscolor.js" hash="b65a1505390592ac6c0177d6b84774e0"/></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
diff --git a/var/package/Phoenix_Moneybookers-1.9.4.1.xml b/var/package/Phoenix_Moneybookers-1.9.4.1.xml
deleted file mode 100644
index 6befe41..0000000
--- a/var/package/Phoenix_Moneybookers-1.9.4.1.xml
+++ /dev/null
@@ -1,35 +0,0 @@
-<?xml version="1.0"?>
-<package>
-    <name>Phoenix_Moneybookers</name>
-    <version>1.9.4.1</version>
-    <stability>stable</stability>
-    <license>mixed</license>
-    <channel>community</channel>
-    <extends/>
-    <summary>Moneybookers payment gateway integration</summary>
-    <description>Moneybookers payment gateway official integration, implemented by Phoenix Medien GmbH. Provides integration for payment options powered by Moneybookers, as separate payment methods:
-All Credit Cards / Visa, Mastercard, AMEX, JCB, Diners - International
-CartaSi - Italy
-Lastschrift (ELV) - Germany
-Dankort - Denmark
-Nordea Solo - Sweden
-eNETS - Singapore
-Carte Bleue - France
-Giropay - Germany
-iDeal - Netherlands
-Laser - Ireland
-EPS Online-&#xDC;berweisung - Austria
-POLi - Australia
-Postepay - Italy
-Przelewy24 - Poland
-Sofort&#xFC;berweisung - Germany
-Nordea Solo - Finland
-Moneybookers eWallet</description>
-    <notes>1.9.4.1</notes>
-    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
-    <date>2019-03-20</date>
-    <time>21:53:59</time>
-    <contents><target name="magecommunity"><dir name="Phoenix"><dir name="Moneybookers"><dir name="Block"><file name="Form.php" hash="49ba46fdbc2aee011df8979b3b22f095"/><file name="Info.php" hash="58e286f9b4d26fd2900930b809141f54"/><file name="Jsinit.php" hash="ca7643a653dbca6aab7bc4543ae8a2f3"/><file name="Payment.php" hash="ee89a5a3350a9932b0e68216b5c4eb51"/><file name="Placeform.php" hash="8bfa12841f7aa2e95c8d28547dca383c"/><file name="Redirect.php" hash="6499e4dae9bbb05bce000f667d5fcef7"/></dir><dir name="Helper"><file name="Data.php" hash="1798f14aa0fd940730aae6856e3963e2"/></dir><dir name="Model"><file name="Abstract.php" hash="d551ffe2e896c4146b05f37a5f7b3bed"/><file name="Acc.php" hash="939e2da57b59227ce2c888a571f6d68d"/><file name="Csi.php" hash="0b34b7abc133fcabacab4a5e1227e784"/><file name="Did.php" hash="a77efea0f47ddc0dbcf2178ade90d7f8"/><file name="Dnk.php" hash="4ef8510289004955286cb5fc3fb9369f"/><file name="Ebt.php" hash="beb720b8a91cda6d8dd54aa2f76c43ec"/><file name="Ent.php" hash="f3c4a7ba1f698153097cd77326992c0f"/><file name="Event.php" hash="b373bd655a3a794dfcf7e6b7683a27c9"/><file name="Gcb.php" hash="10630a1d324af938fa2c7e7d732b1ec3"/><file name="Gir.php" hash="db996ac84d4a616888ab096025c649d6"/><file name="Idl.php" hash="6ec8eba6c330c0f3f6137422713d8b60"/><file name="Lsr.php" hash="4f09028709d716e0aa7e56102a54f355"/><file name="Mae.php" hash="68f7e7bcaba63d61ea5ac56ef0e07f7f"/><file name="Npy.php" hash="cde76b9858dbeb6d239b5ffa8d6e2845"/><file name="Obt.php" hash="fdd8ed79882ab27d9f679065f0812e65"/><file name="Pli.php" hash="46ccf1cc56ec503727ccf0b01ed3ecfc"/><file name="Psp.php" hash="d704c4bd3441c5dcfbc7528fe4868e26"/><file name="Pwy.php" hash="71c9af54425a98e557b7174d784da04f"/><file name="Sft.php" hash="f1bccacf2ec8a5a198d2f433cb21d7d8"/><file name="So2.php" hash="45fb61c9c13b5abeca6aa59ff69dfb7f"/><file name="Wlt.php" hash="4a8e5d3937814de9dbc3b1bca262ba8e"/></dir><dir name="controllers"><file name="MoneybookersController.php" hash="92e1ccc2a361ee8a2e5305262857a592"/><file name="ProcessingController.php" hash="c41e0232a55d4bf492adf3fdb7caa6b1"/></dir><dir name="etc"><file name="config.xml" hash="2893116b8a4f1f5aae9635b08c7ecd2c"/><file name="system.xml" hash="706c223e723559a349c18f42d78b2695"/></dir><dir name="sql"><dir name="moneybookers_setup"><file name="install-1.6.0.0.php" hash="1d9bbf3c5025ed0d7d9ad3d3c5e22bd6"/><file name="mysql4-upgrade-1.2-1.2.0.1.php" hash="29e544d8bbde79af0a3b0a60e571cbfe"/></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Phoenix_Moneybookers.xml" hash="14751dc6d49492ef809111a97c2c01bb"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="info.phtml" hash="00b41d6fb627c4e02bb5e1b3410958fa"/><file name="jsinit.phtml" hash="368eb5021a3bd3e79651d40c1ad80733"/><dir name="pdf"><file name="info.phtml" hash="67e5414f72c8c7cedd118f6c094e6c0d"/></dir></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="0c2ea969ce71386db5a2af6360073a34"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="blank.phtml" hash="2b838fe6caaf3b36c962db5935036873"/><file name="form.phtml" hash="6bfad26b37ba6f9c59020193d24618ab"/><file name="info.phtml" hash="d80f64d287917ff499636786959cf0ab"/><file name="payment.phtml" hash="bc07fbcf3816775ce4f5a41b7270b855"/><file name="placeform.phtml" hash="11d1fc3021a0bf174dc64ed14e72ba0b"/><file name="redirect.phtml" hash="c4d74978faac32659af356b87e2a2364"/></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="56bdd4771be815d661a3a01b7b3d7b20"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Phoenix_Moneybookers.csv" hash="c92cee5c0ca36fdedfbab70e95a91983"/><dir name="template"><dir name="email"><file name="moneybookers_activateemail.html" hash="035d73b26c54c8042e03e7551df49457"/></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner_120_de.gif" hash="74815117bf378543e5b3496bb5bc4e8a"/><file name="banner_120_de.png" hash="6c3f708fcb6dac92e53472d4c2246c68"/><file name="banner_120_dk.gif" hash="2106bd994d188d40474bf2a2e8d62a8d"/><file name="banner_120_fr.gif" hash="a84241eef7bc38fb38567e7aa8ca245a"/><file name="banner_120_fr.png" hash="8994d1dc3b4f5c9e5efc67ce3f9f55a9"/><file name="banner_120_int.gif" hash="e23ddcf71e15f0a9300062ef9cdea512"/><file name="banner_120_int.png" hash="f9dfbc26041e52b34eea65348707d64f"/><file name="banner_120_pl.gif" hash="44313c7d27cdcf59c2f66708c6c5abd5"/><file name="banner_120_pl.png" hash="67d3385f93bc9113880305ee7c7da9de"/><file name="banner_120_sp.gif" hash="a003ed8db63620672ae945682b1e1e39"/><file name="banner_120_sp.png" hash="f9c4a653d6814ab3f8c535da706f5f77"/><file name="moneybookers_acc.png" hash="a3e639a68fafdffaca81e91985127735"/><file name="moneybookers_csi.gif" hash="4eec4ed7c494d01d518a3c6c691128e9"/><file name="moneybookers_did.gif" hash="6a3a3365894e9cdb199647a5b74ba35b"/><file name="moneybookers_dnk.gif" hash="7d4b8d27784f8a6fa6ef81c4e911831b"/><file name="moneybookers_ebt.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_ent.gif" hash="704e9551ed4aff82b67114242b9fba1a"/><file name="moneybookers_gcb.gif" hash="e2e7c0f501e5ab0136f859ca5f57abc2"/><file name="moneybookers_gir.gif" hash="f16e949bc60bbd812f803d5e377d47f6"/><file name="moneybookers_idl.gif" hash="fe0ad1efc12d43df6c9ff3ffdd9dd59b"/><file name="moneybookers_lsr.gif" hash="58cdadfa20b6d37aeaa19e50995e4baf"/><file name="moneybookers_mae.gif" hash="4d4b5f0cf3377939c7738fc7e416d25f"/><file name="moneybookers_npy.gif" hash="01242c5ad7bc667e7493b550b6397fab"/><file name="moneybookers_obt_de.png" hash="ce44fd2974b8d279401778292e2c4484"/><file name="moneybookers_obt_dk.png" hash="2985e8cb472d1886d584fa31d56bee92"/><file name="moneybookers_obt_ee.png" hash="cb186be1c7595544f61d3737c7bf85aa"/><file name="moneybookers_obt_en.png" hash="eee098a06e3ea34f33e276724b084774"/><file name="moneybookers_obt_fl.png" hash="6c3766df052d875ce399e62ad8a435f8"/><file name="moneybookers_obt_lt.png" hash="adf61f248fc6d5985840db3e0c23391e"/><file name="moneybookers_obt_lv.png" hash="4e7f16b4988ea30f049942d4dcdb5f78"/><file name="moneybookers_obt_pl.png" hash="fb2c43c18ba73d390e5b5f5261261f4a"/><file name="moneybookers_obt_se.png" hash="9028412e9c3f25d114bf40bb2049d225"/><file name="moneybookers_pli.gif" hash="93989e85caff760af7a61838db0300bf"/><file name="moneybookers_psp.gif" hash="7abffc2246f172625be2ce31f4315cb2"/><file name="moneybookers_pwy.gif" hash="b4a0b9db9a031855e6e3899592012fae"/><file name="moneybookers_sft.gif" hash="e9e774163c99a8ab4deb18d37feaf658"/><file name="moneybookers_so2.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_wlt.gif" hash="4b9cbc5aa5c32f3015ce7bec98da2670"/></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner.jpg" hash="382b1eea5550ce6c1b88cd4444058362"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><file name="moneybookers.js" hash="bdfe32503bd325d15b085c5c4938a428"/></dir></dir></dir></target></contents>
-    <compatible/>
-    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.1</min><max>1.9.4.1</max></package></required></dependencies>
-</package>
diff --git a/var/package/Phoenix_Moneybookers-1.9.4.2.xml b/var/package/Phoenix_Moneybookers-1.9.4.2.xml
new file mode 100644
index 0000000..b033690
--- /dev/null
+++ b/var/package/Phoenix_Moneybookers-1.9.4.2.xml
@@ -0,0 +1,35 @@
+<?xml version="1.0"?>
+<package>
+    <name>Phoenix_Moneybookers</name>
+    <version>1.9.4.2</version>
+    <stability>stable</stability>
+    <license>mixed</license>
+    <channel>community</channel>
+    <extends/>
+    <summary>Moneybookers payment gateway integration</summary>
+    <description>Moneybookers payment gateway official integration, implemented by Phoenix Medien GmbH. Provides integration for payment options powered by Moneybookers, as separate payment methods:
+All Credit Cards / Visa, Mastercard, AMEX, JCB, Diners - International
+CartaSi - Italy
+Lastschrift (ELV) - Germany
+Dankort - Denmark
+Nordea Solo - Sweden
+eNETS - Singapore
+Carte Bleue - France
+Giropay - Germany
+iDeal - Netherlands
+Laser - Ireland
+EPS Online-&#xDC;berweisung - Austria
+POLi - Australia
+Postepay - Italy
+Przelewy24 - Poland
+Sofort&#xFC;berweisung - Germany
+Nordea Solo - Finland
+Moneybookers eWallet</description>
+    <notes>1.9.4.2</notes>
+    <authors><author><name>Magento Core Team</name><user>core</user><email>core@magentocommerce.com</email></author></authors>
+    <date>2019-06-13</date>
+    <time>15:58:18</time>
+    <contents><target name="magecommunity"><dir name="Phoenix"><dir name="Moneybookers"><dir name="Block"><file name="Form.php" hash="49ba46fdbc2aee011df8979b3b22f095"/><file name="Info.php" hash="58e286f9b4d26fd2900930b809141f54"/><file name="Jsinit.php" hash="ca7643a653dbca6aab7bc4543ae8a2f3"/><file name="Payment.php" hash="ee89a5a3350a9932b0e68216b5c4eb51"/><file name="Placeform.php" hash="8bfa12841f7aa2e95c8d28547dca383c"/><file name="Redirect.php" hash="6499e4dae9bbb05bce000f667d5fcef7"/></dir><dir name="Helper"><file name="Data.php" hash="1798f14aa0fd940730aae6856e3963e2"/></dir><dir name="Model"><file name="Abstract.php" hash="d551ffe2e896c4146b05f37a5f7b3bed"/><file name="Acc.php" hash="939e2da57b59227ce2c888a571f6d68d"/><file name="Csi.php" hash="0b34b7abc133fcabacab4a5e1227e784"/><file name="Did.php" hash="a77efea0f47ddc0dbcf2178ade90d7f8"/><file name="Dnk.php" hash="4ef8510289004955286cb5fc3fb9369f"/><file name="Ebt.php" hash="beb720b8a91cda6d8dd54aa2f76c43ec"/><file name="Ent.php" hash="f3c4a7ba1f698153097cd77326992c0f"/><file name="Event.php" hash="b373bd655a3a794dfcf7e6b7683a27c9"/><file name="Gcb.php" hash="10630a1d324af938fa2c7e7d732b1ec3"/><file name="Gir.php" hash="db996ac84d4a616888ab096025c649d6"/><file name="Idl.php" hash="6ec8eba6c330c0f3f6137422713d8b60"/><file name="Lsr.php" hash="4f09028709d716e0aa7e56102a54f355"/><file name="Mae.php" hash="68f7e7bcaba63d61ea5ac56ef0e07f7f"/><file name="Npy.php" hash="cde76b9858dbeb6d239b5ffa8d6e2845"/><file name="Obt.php" hash="fdd8ed79882ab27d9f679065f0812e65"/><file name="Pli.php" hash="46ccf1cc56ec503727ccf0b01ed3ecfc"/><file name="Psp.php" hash="d704c4bd3441c5dcfbc7528fe4868e26"/><file name="Pwy.php" hash="71c9af54425a98e557b7174d784da04f"/><file name="Sft.php" hash="f1bccacf2ec8a5a198d2f433cb21d7d8"/><file name="So2.php" hash="45fb61c9c13b5abeca6aa59ff69dfb7f"/><file name="Wlt.php" hash="4a8e5d3937814de9dbc3b1bca262ba8e"/></dir><dir name="controllers"><file name="MoneybookersController.php" hash="92e1ccc2a361ee8a2e5305262857a592"/><file name="ProcessingController.php" hash="c41e0232a55d4bf492adf3fdb7caa6b1"/></dir><dir name="etc"><file name="config.xml" hash="2893116b8a4f1f5aae9635b08c7ecd2c"/><file name="system.xml" hash="706c223e723559a349c18f42d78b2695"/></dir><dir name="sql"><dir name="moneybookers_setup"><file name="install-1.6.0.0.php" hash="1d9bbf3c5025ed0d7d9ad3d3c5e22bd6"/><file name="mysql4-upgrade-1.2-1.2.0.1.php" hash="29e544d8bbde79af0a3b0a60e571cbfe"/></dir></dir></dir></dir></target><target name="mageetc"><dir name="modules"><file name="Phoenix_Moneybookers.xml" hash="14751dc6d49492ef809111a97c2c01bb"/></dir></target><target name="magedesign"><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="info.phtml" hash="00b41d6fb627c4e02bb5e1b3410958fa"/><file name="jsinit.phtml" hash="368eb5021a3bd3e79651d40c1ad80733"/><dir name="pdf"><file name="info.phtml" hash="67e5414f72c8c7cedd118f6c094e6c0d"/></dir></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="0c2ea969ce71386db5a2af6360073a34"/></dir></dir></dir></dir><dir name="frontend"><dir name="base"><dir name="default"><dir name="template"><dir name="moneybookers"><file name="blank.phtml" hash="2b838fe6caaf3b36c962db5935036873"/><file name="form.phtml" hash="6bfad26b37ba6f9c59020193d24618ab"/><file name="info.phtml" hash="d80f64d287917ff499636786959cf0ab"/><file name="payment.phtml" hash="bc07fbcf3816775ce4f5a41b7270b855"/><file name="placeform.phtml" hash="11d1fc3021a0bf174dc64ed14e72ba0b"/><file name="redirect.phtml" hash="c4d74978faac32659af356b87e2a2364"/></dir></dir><dir name="layout"><file name="moneybookers.xml" hash="56bdd4771be815d661a3a01b7b3d7b20"/></dir></dir></dir></dir></target><target name="magelocale"><dir name="en_US"><file name="Phoenix_Moneybookers.csv" hash="c92cee5c0ca36fdedfbab70e95a91983"/><dir name="template"><dir name="email"><file name="moneybookers_activateemail.html" hash="035d73b26c54c8042e03e7551df49457"/></dir></dir></dir></target><target name="mageskin"><dir name="frontend"><dir name="base"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner_120_de.gif" hash="74815117bf378543e5b3496bb5bc4e8a"/><file name="banner_120_de.png" hash="6c3f708fcb6dac92e53472d4c2246c68"/><file name="banner_120_dk.gif" hash="2106bd994d188d40474bf2a2e8d62a8d"/><file name="banner_120_fr.gif" hash="a84241eef7bc38fb38567e7aa8ca245a"/><file name="banner_120_fr.png" hash="8994d1dc3b4f5c9e5efc67ce3f9f55a9"/><file name="banner_120_int.gif" hash="e23ddcf71e15f0a9300062ef9cdea512"/><file name="banner_120_int.png" hash="f9dfbc26041e52b34eea65348707d64f"/><file name="banner_120_pl.gif" hash="44313c7d27cdcf59c2f66708c6c5abd5"/><file name="banner_120_pl.png" hash="67d3385f93bc9113880305ee7c7da9de"/><file name="banner_120_sp.gif" hash="a003ed8db63620672ae945682b1e1e39"/><file name="banner_120_sp.png" hash="f9c4a653d6814ab3f8c535da706f5f77"/><file name="moneybookers_acc.png" hash="a3e639a68fafdffaca81e91985127735"/><file name="moneybookers_csi.gif" hash="4eec4ed7c494d01d518a3c6c691128e9"/><file name="moneybookers_did.gif" hash="6a3a3365894e9cdb199647a5b74ba35b"/><file name="moneybookers_dnk.gif" hash="7d4b8d27784f8a6fa6ef81c4e911831b"/><file name="moneybookers_ebt.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_ent.gif" hash="704e9551ed4aff82b67114242b9fba1a"/><file name="moneybookers_gcb.gif" hash="e2e7c0f501e5ab0136f859ca5f57abc2"/><file name="moneybookers_gir.gif" hash="f16e949bc60bbd812f803d5e377d47f6"/><file name="moneybookers_idl.gif" hash="fe0ad1efc12d43df6c9ff3ffdd9dd59b"/><file name="moneybookers_lsr.gif" hash="58cdadfa20b6d37aeaa19e50995e4baf"/><file name="moneybookers_mae.gif" hash="4d4b5f0cf3377939c7738fc7e416d25f"/><file name="moneybookers_npy.gif" hash="01242c5ad7bc667e7493b550b6397fab"/><file name="moneybookers_obt_de.png" hash="ce44fd2974b8d279401778292e2c4484"/><file name="moneybookers_obt_dk.png" hash="2985e8cb472d1886d584fa31d56bee92"/><file name="moneybookers_obt_ee.png" hash="cb186be1c7595544f61d3737c7bf85aa"/><file name="moneybookers_obt_en.png" hash="eee098a06e3ea34f33e276724b084774"/><file name="moneybookers_obt_fl.png" hash="6c3766df052d875ce399e62ad8a435f8"/><file name="moneybookers_obt_lt.png" hash="adf61f248fc6d5985840db3e0c23391e"/><file name="moneybookers_obt_lv.png" hash="4e7f16b4988ea30f049942d4dcdb5f78"/><file name="moneybookers_obt_pl.png" hash="fb2c43c18ba73d390e5b5f5261261f4a"/><file name="moneybookers_obt_se.png" hash="9028412e9c3f25d114bf40bb2049d225"/><file name="moneybookers_pli.gif" hash="93989e85caff760af7a61838db0300bf"/><file name="moneybookers_psp.gif" hash="7abffc2246f172625be2ce31f4315cb2"/><file name="moneybookers_pwy.gif" hash="b4a0b9db9a031855e6e3899592012fae"/><file name="moneybookers_sft.gif" hash="e9e774163c99a8ab4deb18d37feaf658"/><file name="moneybookers_so2.gif" hash="9911d8cc223e7f3d9ec12f50c280ec61"/><file name="moneybookers_wlt.gif" hash="4b9cbc5aa5c32f3015ce7bec98da2670"/></dir></dir></dir></dir></dir><dir name="adminhtml"><dir name="default"><dir name="default"><dir name="images"><dir name="moneybookers"><file name="banner.jpg" hash="382b1eea5550ce6c1b88cd4444058362"/></dir></dir></dir></dir></dir></target><target name="mageweb"><dir name="js"><dir name="mage"><dir name="adminhtml"><file name="moneybookers.js" hash="bdfe32503bd325d15b085c5c4938a428"/></dir></dir></dir></target></contents>
+    <compatible/>
+    <dependencies><required><php><min>5.2.0</min><max>6.0.0</max></php><package><name>Mage_Core_Modules</name><channel>community</channel><min>1.9.4.2</min><max>1.9.4.2</max></package></required></dependencies>
+</package>
